#! /bin/sh

BACKUPFILE="/var/www/hiawatha/upload/backup*.tar.gz"
FILELIST=$(ls $BACKUPFILE 2> /dev/null | wc -l)
LOGFILE="/var/log/configRestore.log"
yfile=""
tCfg="/tmp/tmpConfig"
xtractDir="${tCfg}/gxserve"
tSysPath="${xtractDir}/system.tar"
coreConf="/usr/bin/coreconf"
whitelist="/etc/keep-configfiles"
RESTORE_NETWORK="$(echo "${REQUEST_URI}" | egrep -o '[\?&](restore_network)=([^&]+)' | cut -d= -f2 | head -n 1)"

# cleanup old logfile and make new one!
if [ -f "${LOGFILE}" ]; then
   rm -f "${LOGFILE}"
fi
touch "${LOGFILE}"
chmod 664 "${LOGFILE}"

log() {
   echo "$1" >> $LOGFILE
   echo "$1"
   return 0
}

if [ "$FILELIST" != "0" ]; then
   #echo "File $BACKUPFILE exists."
   :
else
   log "ERROR:: File $BACKUPFILE not found."
   exit 1
fi

getBackupfile() {
   yfile="$(ls -lt $BACKUPFILE | awk '{print $9}' | head -1)"
   if [ ! -f "$yfile" ]; then
      log "ERROR backup file not found ($BACKUPFILE)"
      return 1
   fi
   return 0
}

verifyHash() {
   if [ ! -f $1 ]; then
      log "file not found ${1}."
      return 1;
   fi
   $(cd "${xtractDir}"; md5sum -sc ${1} 2>/dev/null)
   if [ "0" -ne "$?" ]; then
      log "hash failed for ${1}"
      return 1
   fi
}

xtractwhitelistedFiles() {
   while read p; do
      file=$(echo "${p}" | awk '{split($0,a," /"); print a[2]}')
      fmod=$(echo "${p}" | awk '{split($0,a," /"); print a[1]}')
      tar -C "${tCfg}/root" -xf "${tSysPath}" "${file}" >/dev/null 2>&1
      if [ "0" -eq "$?" ]; then
         chmod ${fmod} "${tCfg}/root/${file}" >/dev/null 2>&1
         if [ "0" -eq "$?" ]; then
            log "extracted ${file} (${fmod})"
         fi
      fi
   done <$whitelist
   return 0
}

checkKeepNetworkSettings() {
   if [ "${RESTORE_NETWORK}" = "true" ]; then
      log "restoring network settings!"
      return 0
   fi
   log "keeping old network settings!"
   rm -rf "${tCfg}/root/etc/config"
   rm -rf "${tCfg}/root/etc/hiawatha/hosts.conf"
   return 0
}

extractTmpConfig() {
   if [ -d "$tCfg" ]; then
      log "removing old tmp dir: ${tCfg}"
      rm -rf "$tCfg"
   fi
   mkdir -p "${tCfg}/root"
   gunzip -c "$yfile" | tar -x -C "$tCfg"
   verifyHash "${tSysPath}.md5"
   if [ "0" -ne "$?" ]; then
      return 1
   fi
   log "md5 hash check success!"
   xtractwhitelistedFiles
   log "run checkKeepNetworkSettings..."
   checkKeepNetworkSettings
   return $?
}

restoreConfig() {
   local RESTORE_FAIL=0
   # coreconf should expect extracted config files that are to be restored to be found at ${tCfg}/root
   "${coreConf}" "--workingroot=${tCfg}/root" "--mode=restore"
   RESTORE_FAIL=$?
   if [ 0 -ne $RESTORE_FAIL ]; then
      log "cannot restore gxserve configuration files"
      return 1
   fi
   # does coreconf restore the files in tmp dir, or already dst directory? is the following step necessary?
   cp -rf "${tCfg}/root/etc" "/"
   RESTORE_FAIL=$?
   if [ 0 -ne $RESTORE_FAIL ]; then
      log "cannot restore gxserve configuration files"
      return 1
   fi

   return $RESTORE_FAIL
}

restoreAllConfig() {
   local RESTORE_FAIL=0
   restoreConfig
   RESTORE_FAIL=$?

   if [ 0 -eq $RESTORE_FAIL ]; then
      # fix access rights to system files:
      chown root:root "/etc/shadow"
      chmod 600 "/etc/shadow"
      chown root:root "/etc/passwd"
      chmod 644 "/etc/passwd"
      chown root:root "/etc/group"
      chmod 644 "/etc/group"
      chmod 644 "/etc/hiawatha/.password"
      chmod 644 "/etc/hiawatha/hosts.conf"
   fi
   return $RESTORE_FAIL
}

# sets global variable $yfile
getBackupfile
if [ "0" -ne "$?" ]; then
   log "ERROR:: finding backup file."
   exit 1;
fi

log "RUNNING:: Config backup found. Using: $yfile"
# extracts config and verifies md5sum
extractTmpConfig

restoreAllConfig
if [ "0" -eq "$?" ]; then
   log "SUCCESS:: Restore succeeded!"
else
   log "ERROR:: Restore failed!"
   exit 1
fi
# tidy up mess in /tmp
rm -rf "$tCfg"
# tidy up all backup files in upload directory!
rm -f "$BACKUPFILE"

# reboot system
reboot

