var chart;
var minichart;
var legend = false;
var c_name = 'DataLog';
var c_options = {
   xaxis: { mode:"time",
            timeformat: "%y/%m/%d %H:%M:%S"
          },
   lines: { show:true },
   grid: { hoverable: true, clickable: true },
   legend: { show: false },
   selection: { mode: "xy", color: "#333" }
}
var c_minioptions = {
   xaxis: { labelWidth:0, labelHeight:0, tickFormatter:empty_label},
   yaxis: { min:0, max:0 },
   lines: { show:true },
   grid: { hoverable: false, clickable: false },
   legend: { show: false },
   selection: { mode: "xy", color: "#333" }
}
var c_colors = ["#F49C9C", "#9CB1F4", "#C8F49C", "#F49CDC", "#9CF3F4", "#F4DE9C", "#CA9CF4", "#9CF4B3",
                "#FF5555", "#55FF55", "#5555FF", "#FFFF55", "#FF55FF", "#55FFFF", "#888888", "#444444",
                "#F49C9C", "#9CB1F4", "#C8F49C", "#F49CDC", "#9CF3F4", "#F4DE9C", "#CA9CF4", "#9CF4B3",
                "#FF5555", "#55FF55", "#5555FF", "#FFFF55", "#FF55FF", "#55FFFF", "#888888", "#444444",
                "#D49B9B", "#9BB1D4", "#B8D49B", "#D49BDB", "#9BD3D4", "#D4DE9B", "#BA9BD4", "#9BD4B3",
                "#DD5555", "#55DD55", "#5555DD", "#DDDD55", "#DD55DD", "#55DDDD", "#888888", "#444444",
                "#D49B9B", "#9BB1D4", "#B8D49B", "#D49BDB", "#9BD3D4", "#D4DE9B", "#BA9BD4", "#9BD4B3",
                "#DD5555", "#55DD55", "#5555DD", "#DDDD55", "#DD55DD", "#55DDDD", "#666666", "#333333"];
var c_data = [];
var sel_data = [];
var prevPoint = null;

function empty_label(val, axis) {
   return "";
}

function bind_events() {
   $("#chart").bind("plothover", function (event, pos, item) {
      if(item) {
         if(prevPoint != item.datapoint) {
            prevPoint = item.datapoint;
            $("#tooltip").remove();
            var date = new Date(Number(item.datapoint[0]));
            var x = date.toUTCString();
            x = x.replace(/GMT/i, "");
            x = x.replace(/UTC/i, "");
            var y = item.datapoint[1].toFixed(1);
            show_tooltip(item.pageX, item.pageY, "<b>"+item.series.label+"</b><br>"+x+"<br>"+y);
         }
      }
      else {
         $("#tooltip").remove();
         prevPoint = null;
      }
   });
   $("#chart").bind("plotselected", function (event, ranges) {
      // clamp the zooming to prevent eternal zoom
      show_progress(true, _("Drawing Chart..."));
      if(ranges.xaxis.to - ranges.xaxis.from < 0.00001) ranges.xaxis.to = ranges.xaxis.from + 0.00001;
      if(ranges.yaxis.to - ranges.yaxis.from < 0.00001) ranges.yaxis.to = ranges.yaxis.from + 0.00001;
      // do the zooming
      chart = $.plot($("#chart"), sel_data,
          $.extend(true, {}, c_options, {
             xaxis: { min: ranges.xaxis.from, max: ranges.xaxis.to },
             yaxis: { min: ranges.yaxis.from, max: ranges.yaxis.to }
      }));
      // don't fire event on the overview to prevent eternal loop
      minichart.setSelection(ranges, true);
      $("#zoom_out").removeAttr("disabled");
      show_progress(false, "");
   });

   $("#minichart").bind("plotselected", function (event, ranges) {
      chart.setSelection(ranges);
   });
}

function show_progress(show, text) {
   $("#progress_msg").html(text);
   if(show) {
      $("#progress").removeClass("hidden");
      $(".disable_on_load").addClass("hidden");
   }
   else {
      $("#progress").addClass("hidden");
      $(".disable_on_load").removeClass("hidden");
   }
}

function show_tooltip(x, y, contents) {
   $('<div id="tooltip">' + contents + '</div>').css( {
      position: 'absolute',
      display: 'none',
      top: y + 20,
      left: x + 5,
      border: '1px solid #000',
      padding: '2px',
      'background-color': '#FFFFC0',
      opacity: 0.80
   }).appendTo("body").show();
}

function toHex2(d) {
   var hex = Number(d).toString(16);
   if(hex.length < 2) hex = '0'+hex;
   return hex;
}

function dlg_options() {
   var id = Number( $(this).attr('id').substr(4) );
   var name = c_data[id]["label"];
   var color = $.color.parse(c_data[id]["color"]);
   var col = "#" + toHex2(color.r) + toHex2(color.g) + toHex2(color.b);

   $("#dlg_name").html(name);
   $("#dlg_id").html(id);
   $("#dlg_color").attr('value',col).css('background-color',col);
   $.farbtastic('#dlg_picker',"#dlg_color").setColor(col);
   $("#dlg").dialog('option', 'title', _('Options for Chart')+' '+(id+1));
   // replace button labels
   $(".ui-button-text:contains('OK')").html(_("OK"));
   $(".ui-button-text:contains('Cancel')").html(_("Cancel"));
   $("#dlg").dialog('open');
}

function dlg_options_ok(dlg) {
   var id = Number($("#dlg_id").html());
   var color = $("#dlg_color").val();
   $("#col_"+id).find("span").css("background", color);
   c_colors[id] = c_data[id].color = color;
   draw_chart_zoomed();
   dlg.dialog('close');
}

function draw_legend() {
   var txt="";
   set_data_colors();
   if (!c_data || c_data.length == 0) {
    return;
   }
   $.each(c_data, function(key, val) {
      txt += '<input type="checkbox" class="crtl" name="' +key+ '" checked="checked">&nbsp;' +
             '<span id="col_' +key+ '"><span title="'+ _('Click here to edit chart color')+'" style="cursor:pointer; border:1px solid black; background:' +val.color+ ';">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>' +
             '&nbsp;' +val.label+ '</span><br>';
   });
   $("#legend").html(txt);
   $("#legend input").click(draw_chart_zoomed);
   $("#legend span").click(dlg_options);
   legend = true;
}

function set_data_colors() {
   var i = 0;
   $.each(c_data, function(key, val) {
      val.color = c_colors[i%c_colors.length];
      i++;
   });
}

function draw_chart_zoomed() {
   var ranges = minichart.getSelection();
   if(! ranges) {
      draw_chart();
      return;
   }
   sel_data = [];
   show_progress(true, _("Drawing Chart..."));
   set_data_colors();
   $("#legend").find("input:checked").each(function () {
      var key = $(this).attr("name");
      if(key && c_data[key])
         sel_data.push(c_data[key]);
   });
   chart = $.plot($("#chart"), sel_data,
              $.extend(true, {}, c_options, {
                 xaxis: { min: ranges.xaxis.from, max: ranges.xaxis.to },
                 yaxis: { min: ranges.yaxis.from, max: ranges.yaxis.to }
   }));
   var axis = minichart.getAxes();
   c_minioptions.yaxis.min = axis.yaxis.min;
   c_minioptions.yaxis.max = axis.yaxis.max;
   minichart = $.plot($("#minichart"), sel_data, c_minioptions);
   minichart.setSelection(ranges, true);
   show_progress(false, "");
}

function draw_chart() {
   sel_data = [];
   show_progress(true, _("Drawing Chart..."));
   set_data_colors();
   $("#legend").find("input:checked").each(function () {
      var key = $(this).attr("name");
      if(key && c_data[key])
         sel_data.push(c_data[key]);
   });
   chart = $.plot($("#chart"), sel_data, c_options);
   var axis = chart.getAxes();
   c_minioptions.yaxis.min = axis.yaxis.min;
   c_minioptions.yaxis.max = axis.yaxis.max;
   minichart = $.plot($("#minichart"), sel_data, c_minioptions);
   $("#zoom_out").attr("disabled","disabled");
   show_progress(false, "");
}

function update_data(data) {
   var c,d;
   if(c_data && c_data[0]) {
      for(c=0; c<c_data.length; c++) {
        // for(d=0; d<data.Data[c].data.length; d++)
        //    c_data[c].data.push(data.Data[c].data[d]);
        c_data[c].data = data.Data[c].data;
      }
   }
   else
      c_data = data.Data;
  // if(data.Complete<1)
  // kein automatischer refresh
  //    window.setTimeout(refresh_data, 5000);
}

function hide_all() {
   $("#legend input").attr("checked","");
   draw_chart();
   return false;
}

var dnow = new Date();
var maxstarttime = dnow.getTime();
var endtime = maxstarttime;
var dnowtrunced = new Date(dnow.getFullYear(), dnow.getMonth(), dnow.getDate(), 0, 0, 0, 0);
console.log('dnowtrunced='+dnowtrunced.toString());
var starttime = dnowtrunced.getTime() - (1000*60*60*24)*5;
var minstarttime = starttime;

function refresh_data() {
   var last = 0;
   if(c_data && c_data[0] && c_data[0].data && c_data[0].data.length)
      last = c_data[0].data[c_data[0].data.length-1][0] / 1000;
   get_json(starttime, endtime);
}

$(window).load(function() {
   $.ajaxSetup({cache: false});       // IE needs this
   $("#chart").mouseleave(function(){ // hide tooltip when leaving the chart area
      $("#tooltip").remove();
      $("#chart").unhighlight();
   });
   $("#dlg").dialog({
      autoOpen: false,
      //modal: true,
      closeOnEscape: false,
      buttons: {
         'OK': function() {
            dlg_options_ok($(this));
         },
         'Cancel': function() {
            $(this).dialog('close');
         }
      }
   });
   refresh_data();
   window.setTimeout(refresh_data, 2000);
   bind_events();
});

function get_json(first, last) {
   show_progress(true, _("Loading Data..."));
   console.log('get_json(first='+(new Date(first))+'|last='+(new Date(last)));
   if (!c_data || !c_data[0]) {
     $.ajax({
        url: '/api/system/datalog/chartheader', // '/log.json',
        data: {},
        dataType: 'json',
        success: function(data) {
          c_data = [];
          for (var c = 0; c < data.headers.length; c++) {
            c_data.push({ "label": data.headers[c], "data":[] });
          }
        },
        error: function(data) {
           alert('ERROR: Load was not performed.');
           show_progress(false, "");
           return;
        }
     });
   }
   $.ajax({
      url: '/api/system/datalog/chartdata', // '/log.json',
      data: {},
      dataType: 'json',
      success: function(data) {
        var moddata = { "Data" : [] };
        console.log('get_json: data start');
        for (var m = 0; m < c_data.length; m++) {
          var coldata = { "label": c_data[m].label, "data": [] };
          var coldataval = [];
          for (var n = data[m].length-1; n >= 0; n--) {
            if (data[m][n][0] > first && data[m][n][0] < last) {
              coldataval.push(data[m][n]);
            }
            if (m === 0) {
              if (n === 0) {
                minstarttime = data[m][n][0];
                $( "#dp_start" ).datepicker("option", "minDate", new Date(minstarttime));
                $( "#dp_end" ).datepicker("option", "minDate", new Date(minstarttime));
              } else if (n === data[m].length) {
                maxstarttime = data[m][n][0];
                $( "#dp_start" ).datepicker("option", "maxDate", new Date(maxstarttime));
                $( "#dp_end" ).datepicker("option", "maxDate", new Date(maxstarttime));
              }
            }
          }
          coldata.data = coldataval.reverse();
          moddata.Data.push(coldata);
        }
        console.log('get_json: data start update');
        update_data(moddata);
        if(!legend) draw_legend();
        draw_chart();
        console.log('get_json: data finish');
      },
      error: function(data) {
         alert('ERROR: Load was not performed.');
         show_progress(false, "");
      }
   });
}

function startSelected(startText, dp_start) {
  console.log('startSelected: '+startText);
  var newStart = $( "#dp_start" ).datepicker("getDate");
  if (newStart) {
    if (newStart.getTime() >= endtime) {
      alert('ERROR: End <= Start');
      $( "#dp_start" ).datepicker("setDate", new Date(starttime));
    } else {
      starttime = newStart.getTime();
      refresh_data();
    }
  } else {
    $( "#dp_end" ).datepicker("setDate", new Date(endtime));
  }
}

function endSelected(endText, dp_end) {
  console.log('endSelected: '+endText);
  var newEnd = $( "#dp_end" ).datepicker("getDate");
  if (newEnd) {
    if (newEnd.getTime() <= starttime) {
      alert('ERROR: End <= Start');
      $( "#dp_end" ).datepicker("setDate", new Date(endtime));
    } else {
      endtime = newEnd.getTime() - 1 + (1000*60*60*24);
      refresh_data();
    }
  } else {
    $( "#dp_end" ).datepicker("setDate", new Date(endtime));
  }
}

$( function() {
  $( "#dp_start" ).datepicker({
    setDate: new Date(starttime), 
    minDate: new Date(minstarttime), 
    maxDate: -5, 
    showButtonPanel: false, 
    dateFormat: "yy/mm/dd",
    onSelect: startSelected
  });
  $( "#dp_start" ).datepicker("setDate", new Date(starttime)); 
  $( "#dp_end" ).datepicker({ 
    setDate: new Date(),
    minDate: new Date(minstarttime), 
    maxDate: new Date(maxstarttime), 
    showButtonPanel: false, 
    dateFormat: "yy/mm/dd",
    onSelect: endSelected
  });
  $( "#dp_end" ).datepicker("setDate", new Date()); 
} );

