/*
   atsgpser_panel.js - ATS screen.
   Copyright (c) 2015, Generex GmbH. All rights reserved.
   UW.
*/

var atsgpser_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  css_obj, attr_obj,
  valtable_obj, report_obj, unms_obj,
  x_pos = 10,
  y_pos = 10;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.ups == null) {
      return;
    }

    var refresh
    valtable_obj = data.ups.valtable;
    report_obj = data.report;

    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }

    set_sts_led();
    set_input_src_1(); //Set Input Source 1
    set_input_src_2(); //Set Input Source 2
    set_syn_ballance(); //Set Phase synchron and balance measurements
    set_output();
    set_outpower_loadbars(); //outpower loadbars
    if (valtable_obj._platform !== "ups_view")
    panes_api.set_rom_temp_values(valtable_obj); //set rom temp values
    set_footer();
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: '470px',
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_bg(); //background
    create_model_panes();
    create_sts_led();
    create_input_src_1_pane() //Input Source 1
    create_input_src_2_pane() //Input Source 2
    create_syn_ballance_pane(); //Phase synchron and balance measurements
    create_output_pane();
    create_outpower_loadbars(); //outpower loadbars
    if (valtable_obj._platform !== "ups_view")
    create_rom_temp(); //rom temp
    create_footer_pane();
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 950, height: 446, border: 'solid 1px #808080', align: 'center' };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').css({ display: 'block', 'margin-left': 'auto', 'margin-right': 'auto', 'margin-top': '80px' }).
    attr({ 'id': 'bg_img_id', 'class': 'img-rounded', src: './image/sts/sts_d.png', align: 'middle' }).appendTo(img_div);

    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function create_model_panes() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 950 };
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active' }).append(valtable_obj.MODEL).appendTo(model_div);
  }

  function create_sts_led() {
    var fragment = document.createDocumentFragment(),
    div, img, src;

    //Preferred 1
    css_obj = { position: 'absolute', top: y_pos + 115, left: x_pos + 235, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append(i18n('Selected A'));
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 132;
    css_obj.left = x_pos + 260;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_switch_led({ fail_bit_nr: 1, on_bit_nr: 13 });
    $('<img />').attr({ 'id': 'pref_1_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //Preferred 2
    css_obj = { position: 'absolute', top: y_pos + 334, left: x_pos + 235, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append(i18n('Selected B'));
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 316;
    css_obj.left = x_pos + 260;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_switch_led({ fail_bit_nr: 2, on_bit_nr: 14 });
    $('<img />').attr({ 'id': 'pref_2_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    // A OK
    css_obj = { 'text-align': 'center', position: 'absolute', top: y_pos + 115, left: x_pos + 430, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('A ' + i18n('OK'));
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 132;
    css_obj.left = x_pos + 460;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_src_led(7);
    $('<img />').attr({ 'id': 'ok_1_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //B OK 2
    css_obj = { 'text-align': 'center', position: 'absolute', top: y_pos + 334, left: x_pos + 430, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('B ' + i18n('OK'));
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 316;
    css_obj.left = x_pos + 460;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_src_led(8);
    $('<img />').attr({ 'id': 'ok_2_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    // out 1
    css_obj = { position: 'absolute', top: y_pos + 115, left: x_pos + 530, width: 100, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append(i18n('Output from') + ' A');
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 132;
    css_obj.left = x_pos + 550;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_switch_led({ fail_bit_nr: 1, on_bit_nr: 3 });
    $('<img />').attr({ 'id': 'out_1_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    // out 2
    css_obj = { position: 'absolute', top: y_pos + 334, left: x_pos + 530, width: 100, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append(i18n('Output from') + ' B');
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 316;
    css_obj.left = x_pos + 550;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_switch_led({ fail_bit_nr: 2, on_bit_nr: 4 });
    $('<img />').attr({ 'id': 'out_2_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //warn img
    css_obj.top = y_pos + 220;
    css_obj.left = x_pos + 560;
    css_obj.width = 26;
    css_obj.height = 30;
    div = $('<div/>').css(css_obj);
    $('<img />').attr({ 'class': 'img-rounded', width: 24, 'height': 28, src: './image/sts/warn.png' }).appendTo(div);
    fragment.appendChild(div[0]);

    //alarm led
    css_obj.top = y_pos + 225;
    css_obj.left = x_pos + 585;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_alarm_led();
    $('<img />').attr({ 'id': 'alarm_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    document.body.appendChild(fragment);
  }

  function set_sts_led() {
    var src;
    // pref 1
    src = get_switch_led({ fail_bit_nr: 1, on_bit_nr: 13 });
    $('#pref_1_img').attr('src', src);
    // pref 2
    src = get_switch_led({ fail_bit_nr: 2, on_bit_nr: 14 });
    $('#pref_2_img').attr('src', src);
    // ok 1
    src = get_src_led(7);
    $('#ok_1_img').attr('src', src);
    // ok 2
    src = get_src_led(8);
    $('#ok_2_img').attr('src', src);
    // out 1
    src = get_switch_led({ fail_bit_nr: 1, on_bit_nr: 3 });
    $('#out_1_img').attr('src', src);
    // out 2
    src = get_switch_led({ fail_bit_nr: 2, on_bit_nr: 4 });
    $('#out_2_img').attr('src', src);
    //alarm led
    src = get_alarm_led();
    $('#alarm_img').attr('src', src);
  }

  function create_input_src_pane(xp, yp, src_idx) //Input Source
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, div, idx, inphases,
    involtname, infreqname;

    inphases = valtable_obj.INPHASES;
    involtname = "SOCO_INPVOLT_NET_" + src_idx;
    infreqname = "SOCO_INPFREQ_NET_" + src_idx;
    if (inphases == 1)
    yp += 30;
    css_obj = { position: 'absolute', top: yp, left: xp };

    div = $('<div/>', { id: 'input_src_' + src_idx }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    if (inphases > 1) {
      tr = $('<tr />').append($('<th />', { colspan: 3 }).append(i18n(lang_Input) + ' ' + i18n('source') + ' ' + src_idx)).appendTo(thead);
    } else {
      tr = $('<tr />').append($('<th />', { colspan: 2 }).append(i18n(lang_Input) + ' ' + i18n('source') + ' ' + src_idx)).appendTo(thead);
    }

    for (idx = 0; idx < inphases; idx++) {
      if (inphases > 1) {
        tr = $('<tr />').append($('<td />').append("L" + (idx + 1) + ":")).appendTo(tbody);
      } else {
        tr = $('<tr />').appendTo(tbody);
      }
      td = $('<td />', { id: 'src_' + src_idx + '_volt_' + (idx + 1), align: 'left' }).
      append(get_value({ values: valtable_obj[involtname], index: idx, unit: ' V', precision: 1 })).appendTo(tr);
      if (idx == 0) {
        td = $('<td />', { id: 'src_' + src_idx + '_freq_1', align: 'left' }).
        append(get_value({ values: [valtable_obj[infreqname]], index: 0, unit: ' Hz', precision: 1 })).appendTo(tr);
      }
    }
    fragment.appendChild(div[0]);
    document.body.appendChild(fragment);
  }

  function create_input_src_1_pane() //Input Source 1
  {
    create_input_src_pane(x_pos + 28, y_pos + 86, 1);
  }

  function create_input_src_2_pane() //Input Source 2
  {
    create_input_src_pane(x_pos + 28, y_pos + 268, 2);
  }

  function set_input_src(src_idx) {
    var idx, involtname, infreqname;
    involtname = "SOCO_INPVOLT_NET_" + src_idx;
    infreqname = "SOCO_INPFREQ_NET_" + src_idx;
    for (idx = 0; idx < valtable_obj.INPHASES; idx++) {
      $('#src_' + src_idx + '_volt_' + (idx + 1)).
      text(get_value({ values: valtable_obj[involtname], index: idx, unit: ' V', precision: 1 }));
    }
    $('#src_' + src_idx + '_freq_1').
    text(get_value({ values: [valtable_obj[infreqname]], index: 0, unit: ' Hz', precision: 1 }));
  }

  function set_input_src_1() //Set Input Source 1
  {
    set_input_src(1);
  }

  function set_input_src_2() //Set Input Source 2
  {
    set_input_src(2);
  }

  function create_output_pane() //Output
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, div, idx, outphases, yp;

    yp = y_pos + 86;
    outphases = valtable_obj.OUTPHASES;
    if (outphases == 1)
    yp += 30;
    css_obj = { position: 'absolute', top: yp, left: x_pos + 790 };

    div = $('<div/>', { id: 'output' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    if (outphases > 1) {
      tr = $('<tr />').append($('<th />', { colspan: 2 }).append(i18n(lang_Output))).appendTo(thead);
    } else {
      tr = $('<tr />').append($('<th />').append(i18n(lang_Output))).appendTo(thead);
    }

    for (idx = 0; idx < outphases; idx++) {
      if (outphases > 1) {
        tr = $('<tr />').append($('<td />').append("L" + (idx + 1) + ":")).appendTo(tbody);
      } else {
        tr = $('<tr />').appendTo(tbody);
      }
      td = $('<td />', { id: 'output_curr_' + (idx + 1), align: 'left' }).
      append(get_value({ values: valtable_obj.EX_OUT_CURR, index: idx, unit: ' A', precision: 2 })).appendTo(tr);
    }
    fragment.appendChild(div[0]);
    document.body.appendChild(fragment);
  }

  function set_output() //Set Output
  {
    var idx;
    for (idx = 0; idx < valtable_obj.OUTPHASES; idx++) {
      $('#output_curr_' + (idx + 1)).
      text(get_value({ values: valtable_obj.EX_OUT_CURR, index: idx, unit: ' A', precision: 2 }));
    }
  }

  function create_syn_ballance_pane() //Phase synchron and balance measurements
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, div;

    css_obj = { position: 'absolute', top: y_pos + 180, left: x_pos + 250 };

    div = $('<div/>', { id: 'output' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 2 }).append(i18n('Measurements'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Synchron angle") + ":")).appendTo(tbody);
    td = $('<td />', { id: 'synchron_angle', align: 'left' }).
    append(get_value({ values: [valtable_obj.STS_SYNCANGLE], index: 0, unit: ' ', precision: 2 })).appendTo(tr);

    if (valtable_obj.STS_S1BALANCE != -9999.00) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("S1 " + i18n("phase balance") + ":")).appendTo(tbody);
      td = $('<td />', { id: 'phase_balance_1', align: 'left' }).
      append(get_value({ values: [valtable_obj.STS_S1BALANCE], index: 0, unit: ' ', precision: 0 })).appendTo(tr);
    }

    if (valtable_obj.STS_S2BALANCE != -9999.00) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("S2 " + i18n("phase balance") + ":")).appendTo(tbody);
      td = $('<td />', { id: 'phase_balance_2', align: 'left' }).
      append(get_value({ values: [valtable_obj.STS_S2BALANCE], index: 0, unit: ' ', precision: 0 })).appendTo(tr);
    }

    fragment.appendChild(div[0]);
    document.body.appendChild(fragment);
  }

  function set_syn_ballance() //Set Phase synchron and balance measurements
  {
    $('#synchron_angle').
    text(get_value({ values: [valtable_obj.STS_SYNCANGLE], index: 0, unit: ' ', precision: 2 }));

    if (valtable_obj.STS_S1BALANCE != -9999.00) {
      $('#phase_balance_1').
      text(get_value({ values: [valtable_obj.STS_S1BALANCE], index: 0, unit: ' ', precision: 0 }));
    }
    if (valtable_obj.STS_S2BALANCE != -9999.00) {
      $('#phase_balance_2').
      text(get_value({ values: [valtable_obj.STS_S2BALANCE], index: 0, unit: ' ', precision: 0 }));
    }
  }

  function create_outpower_loadbars() //outpower loadbars
  {
    var idx, outphases, loadtitle, scaler;

    if (valtable_obj.OUTPOWER == null)
    return true;
    outpower_loadbars_created = true;
    outphases = valtable_obj.OUTPHASES;
    for (idx = 0; idx < outphases; idx++) {
      if (outphases > 1) {
        loadtitle = "L" + (idx + 1);
      } else {
        loadtitle = "";
      }
      if (idx == 0)
      scaler = 1;
      else
      scaler = 0;
      if (valtable_obj.OUTPOWER[idx] != -9999.00)
      panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[idx], id: 'loadbar' + (idx + 1) + '_id', left: x_pos + 730, top: y_pos + 308 + (idx * 30), title: loadtitle, scaler: scaler });
    }
  }

  function set_outpower_loadbars() //outpower loadbars
  {
    var outphases;
    if (valtable_obj.OUTPOWER == null)
    return true;
    outphases = valtable_obj.OUTPHASES;
    for (idx = 0; idx < outphases; idx++) {
      if (valtable_obj.OUTPOWER[idx] != -9999)
      panes_api.set_loabar_value(valtable_obj.OUTPOWER[idx], 'loadbar' + (idx + 1) + '_id');
    }
  }

  function get_switch_led(obj) {
    var fail_bit_val = 1 << obj.fail_bit_nr,
    on_bit_val = 1 << obj.on_bit_nr;
    if (valtable_obj.STS_STATUS == null)
    return './image/bacs2/b_grey.gif';

    if (((valtable_obj.STS_STATUS & on_bit_val) == on_bit_val) && ((valtable_obj.STS_STATUS & fail_bit_val) == fail_bit_val))
    return './image/bacs2/b_grey.gif';

    if ((valtable_obj.STS_STATUS & on_bit_val) == on_bit_val)
    return './image/bacs2/b_green.gif';

    if ((valtable_obj.STS_STATUS & fail_bit_val) == fail_bit_val)
    return './image/bacs2/b_grey.gif';

    return './image/bacs2/b_grey.gif';
  }

  function get_src_led(bit_nr) {
    var bit_val = 1 << bit_nr;
    if (valtable_obj.STS_STATUS == null)
    return './image/bacs2/b_grey.gif';
    if ((valtable_obj.STS_STATUS & bit_val) == bit_val)
    return './image/bacs2/b_grey.gif';
    return './image/bacs2/b_green.gif';
  }

  function get_alarm_led() {
    if (valtable_obj.STS_STATUS == null)
    return './image/bacs2/b_grey.gif';
    if ((valtable_obj.STS_STATUS & 0x200) || (valtable_obj.STS_STATUS & 0x400))
    return './image/bacs2/b_flashred.gif';
    return './image/bacs2/b_grey.gif';
  }

  function get_output_led() {
    if (valtable_obj.STATUS == null)
    return './image/bacs2/b_grey.gif';
    if ((valtable_obj.STATUS & 2) == 2)
    return './image/bacs2/b_grey.gif';
    return './image/bacs2/b_green.gif';
  }

  function get_value(val_obj) {
    if (!val_obj.values || (val_obj.values.length <= val_obj.index))
    return 'N/A';
    var val = val_obj.values[val_obj.index];
    if (val == null || val_obj.values[val_obj.index] == -9999)
    return 'N/A';

    if (Math.round(val) == val)
    val = val.toString();
    else
    val = val.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }

  function create_rom_temp() //rom temp
  {
    var fragment = document.createDocumentFragment(),
    rom_temp_div;
    css_obj = { position: 'absolute', top: y_pos + 180, left: x_pos + 410 };
    rom_temp_div = $('<div/>').attr({ id: 'rom_temp_div_id' }).css(css_obj);
    panes_api.create_rom_temp_pane(valtable_obj, { id: 'rom_temp_table_id', 'class': 'table table-condensed table-hover' }).appendTo(rom_temp_div);
    fragment.appendChild(rom_temp_div[0]);
    document.body.appendChild(fragment);
  }

}(jQuery));