/*
   datalogchart_panel.js - data log chart panels.
   Copyright (c) 2011, Generex GmbH. All rights reserved.
   Michael, Said.
   Last change : function get_time_diff_ms() 23.07.2013
*/

var chart_api = (function ($) {
  var cb = null,
  chart,
  minichart,
  legend = false,
  pannes_created = false,
  time_diff_ms = get_time_diff_ms(),
  c_data = [],
  sel_data = [],
  prevPoint = null,
  up_flag = 0,
  down_flag = 0,
  selected_time_id = "h1";

  var c_options = {
    xaxis: { //mode:"time",timeformat: "%m/%d/%y %H:%M:%S",
      tickFormatter: function (val, axis) {
        var date = new Date(val + time_diff_ms);
        var y = date.getYear();
        y = y < 1000 ? y + 1900 : y;
        date.setYear(y);
        return utils_api.formatDate(date, 'mm/dd/yyyy<br/>hh:nn:ss');
      }
    },
    lines: { show: true },
    grid: { hoverable: true, clickable: true },
    legend: { show: false },
    selection: { mode: "xy", color: "#333" }
  };

  var c_minioptions = {
    xaxis: { labelWidth: 0, labelHeight: 0, tickFormatter: empty_label },
    yaxis: { min: 0, max: 0 },
    lines: { show: true },
    grid: { hoverable: false, clickable: false },
    legend: { show: false },
    selection: { mode: "xy", color: "#333" }
  };

  var c_colors = [
    "#F49C9C", "#9CB1F4", "#C8F49C", "#F49CDC", "#9CF3F4", "#F4DE9C", "#CA9CF4", "#9CF4B3",
    "#FF5555", "#55FF55", "#5555FF", "#FFFF55", "#FF55FF", "#55FFFF", "#888888", "#444444",
    "#F49C9C", "#9CB1F4", "#C8F49C", "#F49CDC", "#9CF3F4", "#F4DE9C", "#CA9CF4", "#9CF4B3",
    "#FF5555", "#55FF55", "#5555FF", "#FFFF55", "#FF55FF", "#55FFFF", "#888888", "#444444",
    "#D49B9B", "#9BB1D4", "#B8D49B", "#D49BDB", "#9BD3D4", "#D4DE9B", "#BA9BD4", "#9BD4B3",
    "#DD5555", "#55DD55", "#5555DD", "#DDDD55", "#DD55DD", "#55DDDD", "#888888", "#444444",
    "#D49B9B", "#9BB1D4", "#B8D49B", "#D49BDB", "#9BD3D4", "#D4DE9B", "#BA9BD4", "#9BD4B3",
    "#DD5555", "#55DD55", "#5555DD", "#DDDD55", "#DD55DD", "#55DDDD", "#666666", "#333333"
  ];

  //[COPY_DATALOG2] [1374482940][1374486540]

  var req_params = {
    url: get_url("log.json"),
    data: { name: 'DataLog', s: '', e: '' },
    data_type: 'json',
    refresh_tm: 10
  };
  /*public functions*/
  return {
    init: init,
    changeColor: changeColor,
    up_flag: this.up_flag,
    down_flag: this.down_flag,
    get_time_inmillisecs: get_time_inmillisecs,
    bind_events: bind_chart_events,
    get_timed_chart: get_timed_chart,
    draw_chart: draw_chart,
    hide_all: hide_all
  }

  function init() {
    var start_time, end_time;
    if (!pannes_created) {
      set_init_time();
      pannes_created = true;
    }

    start_time = get_time_inmillisecs('startdate', 'time_from');
    end_time = get_time_inmillisecs('enddate', 'time_to');

    req_params.data.s = start_time;
    req_params.data.e = end_time;

    show_progress(true, i18n("Drawing Chart") + " ...");
    cb = jqmodule.subscribe(this, { update: update, error: null }, req_params);
  }


  function get_timed_chart() {
    init();
  }

  function update(data) {
    var location;
    jqmodule.unsubscribe(cb);
    if (data.Error == 1)
    alert("Something went wrong while connecting to UPSMan!");

    location = data.Location;
    if (location == "")
    location = i18n("Unknown");
    $('#location_id').text(location);

    set_chart_time(data);
    update_data(data);
    if (!legend) draw_legend();
    draw_chart();
  }

  function set_chart_time(data) {
    var date = new Date(data.Data[0].data[0][0] + time_diff_ms);
    $('#chart_startdate_id').text(utils_api.formatDate(date, 'mm/dd/yyyy hh:nn'));
    $('#startdate').attr('value', utils_api.formatDate(date, 'mm/dd/yyyy'));
    $('#time_from').attr('value', utils_api.formatDate(date, 'hh:nn'));
    date = new Date(data.Data[0].data[data.Data[0].data.length - 1][0] + time_diff_ms);
    $('#chart_enddate_id').text(utils_api.formatDate(date, 'mm/dd/yyyy hh:nn'));
    $('#enddate').attr('value', utils_api.formatDate(date, 'mm/dd/yyyy'));
    $('#time_to').attr('value', utils_api.formatDate(date, 'hh:nn'));
  }

  function update_data(data) {
    /*var c,d;
    if(c_data && c_data[0]) {
       for(c=0; c<c_data.length; c++)
          for(d=0; d<data.Data[c].data.length; d++)
             c_data[c].data.push(data.Data[c].data[d]);
    }
    else*/
    c_data = data.Data;
  }

  function draw_chart() {
    sel_data = [];
    show_progress(true, "Drawing Chart ...");
    set_data_colors();
    $("#legend").find("input:checked").each(function () {
      var key = $(this).attr("name");
      if (key && c_data[key])
      sel_data.push(c_data[key]);
    });
    chart = $.plot($("#chart"), sel_data, c_options);
    var axis = chart.getAxes();
    c_minioptions.yaxis.min = axis.yaxis.min;
    c_minioptions.yaxis.max = axis.yaxis.max;
    minichart = $.plot($("#minichart"), sel_data, c_minioptions);
    $("#zoom_out").attr("disabled", "disabled");
    show_progress(false, "");
  }

  function empty_label(val, axis) {
    return "";
  }

  function bind_chart_events() {
    $("#chart").bind("plothover", function (event, pos, item) {
      if (item) {
        if (prevPoint != item.datapoint) {
          prevPoint = item.datapoint;
          $("#tooltip").remove();
          var date = new Date(Number(item.datapoint[0]));
          var x = date.toLocaleString();
          var y = item.datapoint[1].toFixed(1);
          show_tooltip(item.pageX, item.pageY, "<b>" + i18n(item.series.label) + "</b><br>" + x + "<br>" + y);
        }
      } else {
        $("#tooltip").remove();
        prevPoint = null;
      }

    });

    $("#chart").bind("plotselected", function (event, ranges) {

      // clamp the zooming to prevent eternal zoom
      show_progress(true, "Drawing Chart ...");
      if (ranges.xaxis.to - ranges.xaxis.from < 0.00001) ranges.xaxis.to = ranges.xaxis.from + 0.00001;
      if (ranges.yaxis.to - ranges.yaxis.from < 0.00001) ranges.yaxis.to = ranges.yaxis.from + 0.00001;
      // do the zooming
      chart = $.plot($("#chart"), sel_data,
        $.extend(true, {}, c_options, {
          xaxis: { min: ranges.xaxis.from, max: ranges.xaxis.to },
          yaxis: { min: ranges.yaxis.from, max: ranges.yaxis.to }
        }));

      // don't fire event on the overview to prevent eternal loop
      if (minichart != null)
      minichart.setSelection(ranges, true);
      $("#zoom_out").removeAttr('disabled');
      show_progress(false, "");
    });

    $("#minichart").bind("plotselected", function (event, ranges) {
      chart.setSelection(ranges);
    });
  }

  function show_progress(show, text) {
    $("#progress_msg").html(text);
    if (show) {
      //$("#loading_id").removeClass("hidden");
      $(".disable_on_load").addClass("hidden");
    } else {
      //$("#loading_id").addClass("hidden");
      $(".disable_on_load").removeClass("hidden");
    }
  }

  function show_tooltip(x, y, contents) {
    $('<div id="tooltip">' + contents + '</div>').css({
      position: 'absolute',
      display: 'none',
      top: y + 20,
      left: x + 5,
      border: '1px solid #000',
      padding: '2px',
      'background-color': '#FFFFC0',
      opacity: 0.80
    }).appendTo("body").show();

  }

  function toHex2(d) {
    var hex = Number(d).toString(16);
    if (hex.length < 2) hex = '0' + hex;
    return hex;
  }

  function dlg_options(_id) {
    var id = Number(_id.substr(4));
    var name = c_data[id]["label"];
    var color = $.color.parse(c_data[id]["color"]);
    var col = "#" + toHex2(color.r) + toHex2(color.g) + toHex2(color.b);
    $("#dlg_name").html(name);
    $("#dlg_id").html(id);
    $("#dlg_color").attr('value', col).css('background-color', col);
    $.farbtastic('#dlg_picker', "#dlg_color").setColor(col);
    $("#dlg").dialog('option', 'title', i18n('Options for Chart') + ' ' + (id + 1));
    $("#dlg").dialog('open');

  }

  function dlg_options_ok(dlg) {
    var id = Number($("#dlg_id").html());
    var color = $("#dlg_color").val();
    $("#col_" + id).find("span").css("background", color);
    c_colors[id] = c_data[id].color = color;
    draw_chart_zoomed();
    dlg.dialog('close');
  }

  function draw_legend() {
    var txt = "";
    set_data_colors();
    $.each(c_data, function (key, val) {
      txt += '<input type="checkbox" class="crtl" name="' + key + '" checked="checked">&nbsp;' +
      '<span id="col_' + key + '" onclick = "dlg_options(this.id)"><span title=' + i18n("Click here to edit chart color") + ' style="cursor:pointer; border:1px solid black; background:' + val.color + ';">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>' +
      '&nbsp;' + val.label + '</span><br>';
    });
    $("#legend").html(txt);
    $("#legend input").click(draw_chart_zoomed);
    legend = true;
  }

  function set_data_colors() {
    var i = 0;
    $.each(c_data, function (key, val) {
      val.color = c_colors[i % c_colors.length];
      i++;
    });
  }

  function draw_chart_zoomed() {
    var ranges = minichart.getSelection();
    if (!ranges) {
      draw_chart();
      return;
    }
    sel_data = [];

    show_progress(true, "Drawing Chart ...");
    set_data_colors();
    $("#legend").find("input:checked").each(function () {
      var key = $(this).attr("name");
      if (key && c_data[key])
      sel_data.push(c_data[key]);
    });
    chart = $.plot($("#chart"), sel_data,
      $.extend(true, {}, c_options, {
        xaxis: { min: ranges.xaxis.from, max: ranges.xaxis.to },
        yaxis: { min: ranges.yaxis.from, max: ranges.yaxis.to }
      }));
    var axis = minichart.getAxes();
    c_minioptions.yaxis.min = axis.yaxis.min;
    c_minioptions.yaxis.max = axis.yaxis.max;
    minichart = $.plot($("#minichart"), sel_data, c_minioptions);
    minichart.setSelection(ranges, true);
    show_progress(false, "");
  }

  function hide_all() {
    $("#legend input[type='checkbox']").attr("checked", false);
    draw_chart();
    return false;
  }

  function refresh_data() {
    init();
  }

  function info() {
    alert(c_data.length + ' Charts mit je ' + c_data[0].data.length + ' Punkten');
    return false;
  }


  function get_time_diff_ms() {

    var now = new Date(),
    diff = now.getTimezoneOffset() / 60;
    if (diff == -2)
    return 0; //7200000;
    else if (diff == -1)
    return 3600000;
  }

  function set_init_time() {
    var date = new Date();
    $('#enddate').attr('value', utils_api.formatDate(date, 'mm/dd/yyyy'));
    $('#time_to').attr('value', utils_api.formatDate(date, 'hh:nn'));

    if (date.getHours() > 0)
    date.setHours(date.getHours() - 1);
    else
    date.setHours(23);
    $('#startdate').attr('value', utils_api.formatDate(date, 'mm/dd/yyyy'));
    $('#time_from').attr('value', utils_api.formatDate(date, 'hh:nn'));

  }

  function get_time_inmillisecs(text_date_id, text_time_id) {
    var inmillisecs = 0,
    txt_date, txt_time, txt_hour, txt_min,
    txt_time_array;

    txt_date = $('#' + text_date_id).attr('value');
    txt_time = $('#' + text_time_id).attr('value');
    txt_time_array = txt_time.split(':');


    txt_hour = txt_time_array[0] || "";
    txt_min = txt_time_array[1] || "";

    if (txt_date == "" || txt_hour == "" || txt_min == "")
    return inmillisecs;

    //(jahr, monat, tag, stunde, minute, sekunde);
    inmillisecs = new Date(
      parseInt(txt_date.substring(6, 10), 10),
      parseInt(txt_date.substring(0, 2), 10) - 1,
      parseInt(txt_date.substring(3, 5), 10),
      parseInt(txt_hour, 10),
      parseInt(txt_min, 10)).getTime(); //.getTime()/1000

    return inmillisecs;
  }

  function changeColor(obj, val) {
    if (val == 2)
    obj.style.backgroundColor = "#A9A9A9";
    else
    obj.style.backgroundColor = "#C6C6C6";
  }

}(jQuery));