/*
   evo_panel.js - Astrid (evo|evo3) screen.
   Copyright (c) 2016, Generex GmbH. All rights reserved.
   Said.
*/

var evo_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  css_obj,
  valtable_obj, report_obj, unms_obj,
  inphases = null,
  outphases = null,
  x_pos = 5,
  y_pos = 5,
  ups_protocol,
  ups_protocol_evo = 32974,
  ups_protocol_evo2 = 32979,
  ups_protocol_evo3 = 32989,
  ups_protocol_evo4 = 33007,
  ups_protocol_evo5 = 33033,
  ups_protocol_evo6 = 33043;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.ups == null) {
      return;
    }

    set_variable(data);
    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }
    set_footer();
    set_vdc_batt_ocb(); //VDC, Battery  and Output Breaker (OCB) Status
    set_inp_byp_inv(); //Input, Bypass  and Inverter Status
    set_ssb_mbcb_svr(); //Bypass static switch, Manual bypass  and Service Status
    set_epo(); //Emergency power off status
    set_alarms_status(); // set alarms and status
    set_input_measures();
    set_output_measures();
  }

  function create_footer_pane() {
    var top = $("#alarms_status_div_id").outerHeight(true) + 10 + $("#measures_div_id").outerHeight(true) + 490;
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: top,
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    var top = $("#alarms_status_div_id").outerHeight(true) + 10 + $("#measures_div_id").outerHeight(true) + 490;
    $("#panel2").attr("top", top);
    footer_api.set(unms_obj);
  }

  function set_variable(data) {
    valtable_obj = data.ups.valtable;
    report_obj = data.report;


    if (valtable_obj._upsProtocol == null) {
      ups_protocol = valtable_obj.CONNECT & 0XFFFF;
    } else {
      ups_protocol = valtable_obj._upsProtocol;
    }


    if (valtable_obj.INPHASES != null)
    inphases = valtable_obj.INPHASES;
    else
    inphases = valtable_obj.PHASES;

    if (valtable_obj.OUTPHASES != null)
    outphases = valtable_obj.OUTPHASES;
    else
    outphases = valtable_obj.PHASES;

    valtable_obj._tempUnit = valtable_obj._tempUnit || 0; //0 = Celsius

  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_bg(); //background
    create_vdc_batt_ocb_panel(); //VDC, Battery  and Output Breaker (OCB) Status
    create_inp_byp_inv_panel(); //Input, Bypass  and Inverter Status
    create_ssb_mbcb_svr_panel(); //Bypass static switch, Manual bypass  and Service Status
    create_epo_panel(); //Emergency power off status
    create_alarms_status_panel(); //alarms and status
    create_inp_outp_measures(); // create input output measures

    create_footer_pane();
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 575, height: 432 };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'bg_img_id', 'class': 'img-rounded', width: 575, 'height': 431, src: './image/astrid/evo_bg.png' }).appendTo(img_div);
    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function create_vdc_batt_ocb_panel() //VDC, Battery  and Output Breaker (OCB) Status
  {
    var fragment = document.createDocumentFragment(),
    img_div;

    //VDC
    css_obj = { position: 'absolute', top: y_pos + 116, left: x_pos + 255, width: 15, height: 15 };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_vdc', 'class': 'img-rounded', width: 15, 'height': 15, src: get_vdc_batt_ocb_img(2) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    //Battery
    css_obj.top = y_pos + 170;
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_batt', 'class': 'img-rounded', width: 15, 'height': 15, src: get_vdc_batt_ocb_img(3) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    //Output Breaker (OCB)
    css_obj.top = y_pos + 170;
    css_obj.left = x_pos + 461;
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_ocb', 'class': 'img-rounded', width: 15, 'height': 15, src: get_vdc_batt_ocb_img(6) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    document.body.appendChild(fragment);
  }

  function set_vdc_batt_ocb() //VDC, Battery  and Output Breaker (OCB) Status
  {
    $('#img_vdc').attr('src', get_vdc_batt_ocb_img(2));
    $('#img_batt').attr('src', get_vdc_batt_ocb_img(3));
    $('#img_ocb').attr('src', get_vdc_batt_ocb_img(6));
  }

  function create_inp_byp_inv_panel() //Input, Bypass  and Inverter Status
  {
    var fragment = document.createDocumentFragment(),
    img_div;

    //Input
    css_obj = { position: 'absolute', top: y_pos + 116, left: x_pos + 120, width: 15, height: 15 };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_inp', 'class': 'img-rounded', width: 15, 'height': 15, src: get_inp_byp_inv_img(0) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    //Bypass
    css_obj.top = y_pos + 221;
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_byp', 'class': 'img-rounded', width: 15, 'height': 15, src: get_inp_byp_inv_img(1) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    //Inverter
    css_obj.top = y_pos + 116;
    css_obj.left = x_pos + 398;
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_ssi', 'class': 'img-rounded', width: 15, 'height': 15, src: get_inp_byp_inv_img(4) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    document.body.appendChild(fragment);
  }

  function set_inp_byp_inv() //Input, Bypass  and Inverter Status
  {
    $('#img_inp').attr('src', get_inp_byp_inv_img(0));
    $('#img_byp').attr('src', get_inp_byp_inv_img(1));
    $('#img_ssi').attr('src', get_inp_byp_inv_img(4));
  }

  function create_ssb_mbcb_svr_panel() //Bypass static switch, Manual bypass  and Service Status
  {
    var fragment = document.createDocumentFragment(),
    img_div;

    //Bypass static switch
    css_obj = { position: 'absolute', top: y_pos + 223, left: x_pos + 398, width: 15, height: 15 };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_ssb', 'class': 'img-rounded', width: 15, 'height': 15, src: get_ssb_mbcb_svr_img(5) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    //Manual bypass
    css_obj.top = y_pos + 291;
    css_obj.left = x_pos + 120;
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_mbcb', 'class': 'img-rounded', width: 15, 'height': 15, src: get_ssb_mbcb_svr_img(7) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    //Service
    css_obj.top = y_pos + 366;
    css_obj.left = x_pos + 463;
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_svr', 'class': 'img-rounded', width: 15, 'height': 15, src: get_ssb_mbcb_svr_img(9) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    document.body.appendChild(fragment);
  }

  function set_ssb_mbcb_svr() //Bypass static switch, Manual bypass  and Service Status
  {
    $('#img_ssb').attr('src', get_ssb_mbcb_svr_img(5));
    $('#img_mbcb').attr('src', get_ssb_mbcb_svr_img(7));
    $('#img_svr').attr('src', get_ssb_mbcb_svr_img(9));
  }

  function create_epo_panel() //Emergency power off status
  {
    var fragment = document.createDocumentFragment(),
    img_div;

    css_obj.top = y_pos + 323;
    css_obj.left = x_pos + 463;
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'img_epo', 'class': 'img-rounded', width: 15, 'height': 15, src: get_epo_img(8) }).appendTo(img_div);
    fragment.appendChild(img_div[0]);

    document.body.appendChild(fragment);
  }

  function set_epo() //Emergency power off status
  {
    $('#img_epo').attr('src', get_epo_img(8));
  }

  function create_alarms_status_panel() // create alarms and status
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, alarms_status_div;

    css_obj = { position: 'absolute', top: y_pos + 460, left: x_pos + 2, width: 578, border: 'solid 1px #808080' };

    alarms_status_div = $('<div/>', { id: 'alarms_status_div_id', 'class': 'img-rounded' }).css(css_obj);

    table = $('<table />', { id: 'alarms_status_table', 'class': 'table table-condensed' }).appendTo(alarms_status_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<td />', { colspan: 2, align: 'center', 'text-align': 'center' }).css({ color: 'white', 'background-color': '#315284' }).append(i18n("Alarms & Statuses"))).appendTo(thead);

    tr = $('<tr />').appendTo(tbody);

    $('<td />', { id: 'alarms_id' }).append(get_alarms_table()).appendTo(tr);
    $('<td />', { id: 'status_id' }).append(get_status_table()).appendTo(tr);

    fragment.appendChild(alarms_status_div[0]);
    document.body.appendChild(fragment);
  }

  function set_alarms_status() // set alarms and status
  {
    $('#alarms_id').empty();
    $('#alarms_id').append(get_alarms_table());

    $('#status_id').empty();
    $('#status_id').append(get_status_table());

  }

  function create_inp_outp_measures() // create input output measures
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, measures_div,
    top = $("#alarms_status_div_id").outerHeight(true) + 490;

    css_obj = { position: 'absolute', left: x_pos + 2, top: top, width: 750, border: 'solid 1px #808080' };

    measures_div = $('<div/>', { id: 'measures_div_id', 'class': 'img-rounded' }).css(css_obj);

    table = $('<table />', { id: 'measures_table', 'class': 'table table-condensed', 'table-layout': 'fixed', width: '100%' }).appendTo(measures_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<td />', { colspan: 2, align: 'center', 'text-align': 'center' }).css({ color: 'white', 'background-color': '#315284' }).append(i18n("Measures"))).appendTo(thead);

    tr = $('<tr />').appendTo(tbody);

    $('<td />', { id: 'inp_measures_id', width: '50%' }).append(get_inp_measures_table()).appendTo(tr);
    $('<td />', { id: 'outp_measures_id', width: '50%' }).append(get_outp_measures_table()).appendTo(tr);

    fragment.appendChild(measures_div[0]);
    document.body.appendChild(fragment);
  }

  function get_inp_measures_table() {
    var table, tbody;

    table = $('<table />', { id: 'inp_measures_table', 'class': 'table table-condensed', width: '100%' });
    tbody = $('<tbody />').appendTo(table);

    if (ups_protocol != ups_protocol_evo6)
    {
      $('<tr />').append($('<td />', { align: 'left', width: '50%' }).append(get_mains_measures_table())).appendTo(tbody);
      $('<tr />').append($('<td />', { align: 'left', width: '50%' }).append(get_batt_measures_table())).appendTo(tbody);
    }
    $('<tr />').append($('<td />', { align: 'left', width: '50%' }).append(get_byp_measures_table())).appendTo(tbody);
    if (ups_protocol != ups_protocol_evo6)
    {
      $('<tr />').append($('<td />', { align: 'left', width: '50%' }).append(get_inv_measures_table())).appendTo(tbody);
    }

    return table;

  }

  function get_mains_measures_table() // create mains input measures
  {
    var tr, td, table, tbody, thead;

    table = $('<table />', { id: 'mains_measures_table', 'class': 'table table-condensed table-hover', width: '100%' });
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    //      tr = $('<tr />').append($('<th />', {colspan:2}).css("text-decoration", "underline").append(i18n('Input Measures'))).appendTo(thead);
    tr = $('<tr />').append($('<th />', { colspan: 2 }).css("text-decoration", "underline").append(i18n('Input Measures'))).appendTo(thead);

    if (inphases == 3) {
      //Input Voltage
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Mains Voltage Phase R"))).appendTo(tbody);
      $('<td />', { id: 'inp_volt1', align: 'left' }).append(get_value({ value: valtable_obj.INVOLT[0], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Voltage Phase S"))).appendTo(tbody);
      $('<td />', { id: 'inp_volt2', align: 'left' }).append(get_value({ value: valtable_obj.INVOLT[1], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Voltage Phase T"))).appendTo(tbody);
      $('<td />', { id: 'inp_volt3', align: 'left' }).append(get_value({ value: valtable_obj.INVOLT[2], unit: ' V', precision: 1 })).appendTo(tr);

      //input current
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Current Phase R"))).appendTo(tbody);
      $('<td />', { id: 'inp_cur1', align: 'left' }).append(get_value({ value: valtable_obj.INCURR[0], unit: ' A', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Current Phase S"))).appendTo(tbody);
      $('<td />', { id: 'inp_cur2', align: 'left' }).append(get_value({ value: valtable_obj.INCURR[1], unit: ' A', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Current Phase T"))).appendTo(tbody);
      $('<td />', { id: 'inp_cur3', align: 'left' }).append(get_value({ value: valtable_obj.INCURR[2], unit: ' A', precision: 1 })).appendTo(tr);

    } else {
      //Input Voltage
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Mains Voltage Phase R"))).appendTo(tbody);
      $('<td />', { id: 'inp_volt1', align: 'left' }).append(get_value({ value: valtable_obj.INVOLT[0], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Voltage Phase S"))).appendTo(tbody);
      $('<td />', { id: 'inp_volt2', align: 'left' }).append('---').appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Voltage Phase T"))).appendTo(tbody);
      $('<td />', { id: 'inp_volt3', align: 'left' }).append('---').appendTo(tr);

      //input current
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Current Phase R"))).appendTo(tbody);
      $('<td />', { id: 'inp_cur1', align: 'left' }).append(get_value({ value: valtable_obj.INCURR[0], unit: ' A', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Current Phase S"))).appendTo(tbody);
      $('<td />', { id: 'inp_cur2', align: 'left' }).append('---').appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Current Phase T"))).appendTo(tbody);
      $('<td />', { id: 'inp_cur3', align: 'left' }).append('---').appendTo(tr);
    }

    //Mains Frequency
    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Mains Frequency"))).appendTo(tbody);
    $('<td />', { id: 'inp_freq', align: 'left' }).append(get_value({ value: valtable_obj.INFREQ[0], unit: ' Hz', precision: 1 })).appendTo(tr);
    //Input Power
    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Input Power"))).appendTo(tbody);
    $('<td />', { id: 'inp_power', align: 'left' }).append(get_value({ value: valtable_obj.EX_INP_WATT[0], unit: ' kVA', precision: 1 })).appendTo(tr);

    return table;
  }

  function get_batt_measures_table() // create Battery measures
  {
    var tr, td, table, tbody, thead;

    table = $('<table />', { id: 'mains_measures_table', 'class': 'table table-condensed table-hover', width: '100%' });
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 2 }).css("text-decoration", "underline").append(i18n("Battery Measures"))).appendTo(thead);


    //Batt Voltage
    tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Battery Voltage"))).appendTo(tbody);
    $('<td />', { id: 'batt_volt', align: 'left' }).append(get_value({ value: valtable_obj.BATTVOLT, unit: ' V', precision: 1 })).appendTo(tr);

    if (ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo2) {
      //Battery Voltage Neg
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Voltage Neg"))).appendTo(tbody);
      $('<td />', { id: 'batt_volt_neg', align: 'left' }).append("---").appendTo(tr);

      //Battery Voltage Pos
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Voltage Pos"))).appendTo(tbody);
      $('<td />', { id: 'batt_volt_pos', align: 'left' }).append('---').appendTo(tr);
    } else {
      //Battery Voltage Neg
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Voltage Neg"))).appendTo(tbody);
      $('<td />', { id: 'batt_volt_neg', align: 'left' }).append(get_value({ value: valtable_obj.EX_BATT_VOLTNEG, unit: ' V', precision: 1 })).appendTo(tr);

      //Battery Voltage Pos
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Voltage Pos"))).appendTo(tbody);
      $('<td />', { id: 'batt_volt_pos', align: 'left' }).append(get_value({ value: valtable_obj.EX_BATT_VOLTPOS, unit: ' V', precision: 1 })).appendTo(tr);
    }

    if (ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo2) {
      //Battery Current
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Current"))).appendTo(tbody);
      $('<td />', { id: 'batt_cur', align: 'left' }).append(get_value({ value: valtable_obj.EX_BATT_CURRPOS, unit: ' A', precision: 1 })).appendTo(tr);
      //Battery Current Neg
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Current Neg"))).appendTo(tbody);
      $('<td />', { id: 'batt_cur_neg', align: 'left' }).append('---').appendTo(tr);
      //Battery Current Pos
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Current Pos"))).appendTo(tbody);
      $('<td />', { id: 'batt_cur_pos', align: 'left' }).append('---').appendTo(tr);
    } else {
      //Battery Current
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Current"))).appendTo(tbody);
      $('<td />', { id: 'batt_cur', align: 'left' }).append(get_value({ value: valtable_obj.CHARGECURR, unit: ' A', precision: 1 })).appendTo(tr);
      //Battery Current Neg
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Current Neg"))).appendTo(tbody);
      $('<td />', { id: 'batt_cur_neg', align: 'left' }).append(get_value({ value: valtable_obj.EX_BATT_CURRNEG, unit: ' A', precision: 1 })).appendTo(tr);
      //Battery Current Pos
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Current Pos"))).appendTo(tbody);
      $('<td />', { id: 'batt_cur_pos', align: 'left' }).append(get_value({ value: valtable_obj.EX_BATT_CURRPOS, unit: ' A', precision: 1 })).appendTo(tr);
    }

    //Battery Autonomy
    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Autonomy"))).appendTo(tbody);
    $('<td />', { id: 'batt_autotime', align: 'left' }).append(valtable_obj.AUTONOMTIME.toFixed(0) + ' min(' + valtable_obj.BATTCAP + ' %)').appendTo(tr);
    //Battery Temperature
    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Temperature"))).appendTo(tbody);
    $('<td />', { id: 'batt_temp', align: 'left' }).append(get_batt_temp()).appendTo(tr);

    return table;
  }

  function get_byp_measures_table() // create Bypass Measures
  {
    var tr, td, table, tbody, thead;

    table = $('<table />', { id: 'byp_measures_table', 'class': 'table table-condensed  table-hover', width: '100%' });
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 2 }).css("text-decoration", "underline").append(i18n("Bypass Measures"))).appendTo(thead);

    if (outphases == 3) {
      //byp Voltage
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Bypass Voltage Phase R"))).appendTo(tbody);
      $('<td />', { id: 'byp_volt1', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_VOLT[0], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Voltage Phase S"))).appendTo(tbody);
      $('<td />', { id: 'byp_volt2', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_VOLT[1], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Voltage Phase T"))).appendTo(tbody);
      $('<td />', { id: 'byp_volt3', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_VOLT[2], unit: ' V', precision: 1 })).appendTo(tr);
    } else {
      //byp Voltage
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Bypass Voltage Phase R"))).appendTo(tbody);
      $('<td />', { id: 'byp_volt1', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_VOLT[0], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Voltage Phase S"))).appendTo(tbody);
      $('<td />', { id: 'byp_volt2', align: 'left' }).append('---').appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Voltage Phase T"))).appendTo(tbody);
      $('<td />', { id: 'byp_volt3', align: 'left' }).append('---').appendTo(tr);
    }

    if (ups_protocol == ups_protocol_evo6)
    {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Frequency Phase R"))).appendTo(tbody);
      $('<td />', { id: 'byp_freq1', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_FREQ[0], unit: ' Hz', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Frequency Phase S"))).appendTo(tbody);
      $('<td />', { id: 'byp_freq2', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_FREQ[1], unit: ' Hz', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Frequency Phase T"))).appendTo(tbody);
      $('<td />', { id: 'byp_freq3', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_FREQ[2], unit: ' Hz', precision: 1 })).appendTo(tr);

      if (valtable_obj.EVO_BYPMEASUREHIDDEN == 0)
      {
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Current Phase R"))).appendTo(tbody);
         $('<td />', { id: 'byp_curr1', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_CURR[0], unit: ' A', precision: 1 })).appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Current Phase S"))).appendTo(tbody);
         $('<td />', { id: 'byp_curr2', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_CURR[1], unit: ' A', precision: 1 })).appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Current Phase T"))).appendTo(tbody);
         $('<td />', { id: 'byp_curr3', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_CURR[2], unit: ' A', precision: 1 })).appendTo(tr);
      }
      else
      {
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Current Phase R"))).appendTo(tbody);
         $('<td />', { id: 'byp_curr1', align: 'left' }).append('---').appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Current Phase S"))).appendTo(tbody);
         $('<td />', { id: 'byp_curr2', align: 'left' }).append('---').appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Current Phase T"))).appendTo(tbody);
         $('<td />', { id: 'byp_curr3', align: 'left' }).append('---').appendTo(tr);
      }
    }
    else
    {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass Frequency"))).appendTo(tbody);
      $('<td />', { id: 'byp_freq', align: 'left' }).append(get_value({ value: valtable_obj.EX_BYP_FREQ[0], unit: ' Hz', precision: 1 })).appendTo(tr);
   }

    return table;
  }

  function get_inv_measures_table() // create Inverter Measures
  {
    var tr, td, table, tbody, thead;

    table = $('<table />', { id: 'byp_measures_table', 'class': 'table table-condensed  table-hover', width: '100%' });
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 2 }).css("text-decoration", "underline").append(i18n("Inverter Measures"))).appendTo(thead);

    if (outphases == 3) {
      //Inverter Voltage
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Inverter Voltage Phase R"))).appendTo(tbody);
      $('<td />', { id: 'inv_volt1', align: 'left' }).append(get_value({ value: valtable_obj.EX_INV_VOLT[0], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Inverter Voltage Phase S"))).appendTo(tbody);
      $('<td />', { id: 'inv_volt2', align: 'left' }).append(get_value({ value: valtable_obj.EX_INV_VOLT[1], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Inverter Voltage Phase T"))).appendTo(tbody);
      $('<td />', { id: 'inv_volt3', align: 'left' }).append(get_value({ value: valtable_obj.EX_INV_VOLT[2], unit: ' V', precision: 1 })).appendTo(tr);
    } else {
      //Inverter Voltage
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Inverter Voltage Phase R"))).appendTo(tbody);
      $('<td />', { id: 'inv_volt1', align: 'left' }).append(get_value({ value: valtable_obj.EX_INV_VOLT[0], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Inverter Voltage Phase S"))).appendTo(tbody);
      $('<td />', { id: 'inv_volt2', align: 'left' }).append('---').appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Inverter Voltage Phase T"))).appendTo(tbody);
      $('<td />', { id: 'inv_volt3', align: 'left' }).append('---').appendTo(tr);
    }
    //Inverter Freq
    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Inverter Frequency"))).appendTo(tbody);
    $('<td />', { id: 'inv_freq', align: 'left' }).append(get_value({ value: valtable_obj.EX_INV_FREQ[0], unit: ' Hz', precision: 1 })).appendTo(tr);

    return table;
  }

  function set_input_measures() {
    var top = $("#alarms_status_div_id").outerHeight(true) + 490;
    $("#measures_div_id").css('top', top);

    if (inphases == 3) {
      //Input Voltage
      $('#inp_volt1').text(get_value({ value: valtable_obj.INVOLT[0], unit: ' V', precision: 1 }));
      $('#inp_volt2').text(get_value({ value: valtable_obj.INVOLT[1], unit: ' V', precision: 1 }));
      $('#inp_volt3').text(get_value({ value: valtable_obj.INVOLT[2], unit: ' V', precision: 1 }));

      //input current
      $('#inp_cur1').text(get_value({ value: valtable_obj.INCURR[0], unit: ' A', precision: 1 }));
      $('#inp_cur2').text(get_value({ value: valtable_obj.INCURR[1], unit: ' A', precision: 1 }));
      $('#inp_cur3').text(get_value({ value: valtable_obj.INCURR[2], unit: ' A', precision: 1 }));
    } else {
      //Input Voltage
      $('#inp_volt1').text(get_value({ value: valtable_obj.INVOLT[0], unit: ' V', precision: 1 }));
      //input current
      $('#inp_cur1').text(get_value({ value: valtable_obj.INCURR[0], unit: ' A', precision: 1 }));
    }

    if (outphases == 3) {
      //Inverter Voltage
      $('#inv_volt1').text(get_value({ value: valtable_obj.EX_INV_VOLT[0], unit: ' V', precision: 1 }));
      $('#inv_volt2').text(get_value({ value: valtable_obj.EX_INV_VOLT[1], unit: ' V', precision: 1 }));
      $('#inv_volt3').text(get_value({ value: valtable_obj.EX_INV_VOLT[2], unit: ' V', precision: 1 }));
      //byp Voltage
      $('#byp_volt1').text(get_value({ value: valtable_obj.EX_BYP_VOLT[0], unit: ' V', precision: 1 }));
      $('#byp_volt2').text(get_value({ value: valtable_obj.EX_BYP_VOLT[1], unit: ' V', precision: 1 }));
      $('#byp_volt3').text(get_value({ value: valtable_obj.EX_BYP_VOLT[2], unit: ' V', precision: 1 }));

    } else {
      //Inverter Voltage
      $('#inv_volt1').text(get_value({ value: valtable_obj.EX_INV_VOLT[0], unit: ' V', precision: 1 }));
      //byp Voltage
      $('#byp_volt1').text(get_value({ value: valtable_obj.EX_BYP_VOLT[0], unit: ' V', precision: 1 }));
    }


    //Mains Frequency
    $('#inp_freq').text(get_value({ value: valtable_obj.INFREQ[0], unit: ' Hz', precision: 1 }));
    //Input Power
    $('#inp_power').text(get_value({ value: valtable_obj.EX_INP_WATT[0], unit: ' kVA', precision: 1 }));

    //Batt Voltage
    $('#batt_volt').text(get_value({ value: valtable_obj.BATTVOLT, unit: ' V', precision: 1 }));

    if (ups_protocol != ups_protocol_evo && ups_protocol != ups_protocol_evo2) {
      //Battery Voltage Neg
      $('#batt_volt_neg').text(get_value({ value: valtable_obj.EX_BATT_VOLTNEG, unit: ' V', precision: 1 }));
      //Battery Voltage Pos
      $('#batt_volt_pos').text(get_value({ value: valtable_obj.EX_BATT_VOLTPOS, unit: ' V', precision: 1 }));
    }

    if (ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo2) {
      //Battery Current
      $('#batt_cur').text(get_value({ value: valtable_obj.EX_BATT_CURRPOS, unit: ' A', precision: 1 }));
    } else {
      //Battery Current
      $('#batt_cur').text(get_value({ value: valtable_obj.CHARGECURR, unit: ' A', precision: 1 }));
      //Battery Current Neg
      $('#batt_cur_neg').text(get_value({ value: valtable_obj.EX_BATT_CURRNEG, unit: ' A', precision: 1 }));
      //Battery Current Pos
      $('#batt_cur_pos').text(get_value({ value: valtable_obj.EX_BATT_CURRPOS, unit: ' A', precision: 1 }));
    }

    //Battery Autonomy
    $('#batt_autotime').text(valtable_obj.AUTONOMTIME.toFixed(0) + ' min(' + valtable_obj.BATTCAP + ' %)');
    //Battery Temperature
    $('#batt_temp').html(get_batt_temp());

    //Bypass Values
    if (ups_protocol == ups_protocol_evo6)
    {
      $('#byp_freq1').text(get_value({ value: valtable_obj.EX_BYP_FREQ[0], unit: ' Hz', precision: 1 }));
      $('#byp_freq2').text(get_value({ value: valtable_obj.EX_BYP_FREQ[1], unit: ' Hz', precision: 1 }));
      $('#byp_freq3').text(get_value({ value: valtable_obj.EX_BYP_FREQ[2], unit: ' Hz', precision: 1 }));

      if (valtable_obj.EVO_BYPMEASUREHIDDEN == 0)
      {
         $('#byp_curr1').text(get_value({ value: valtable_obj.EX_BYP_CURR[0], unit: ' A', precision: 1 }));
         $('#byp_curr2').text(get_value({ value: valtable_obj.EX_BYP_CURR[1], unit: ' A', precision: 1 }));
         $('#byp_curr3').text(get_value({ value: valtable_obj.EX_BYP_CURR[2], unit: ' A', precision: 1 }));
      }
      else
      {
         $('#byp_curr1').text("---");
         $('#byp_curr2').text("---");
         $('#byp_curr3').text("---");
      }
    }
    else
    {
      $('#byp_freq').text(get_value({ value: valtable_obj.EX_BYP_FREQ[0], unit: ' Hz', precision: 1 }));

      //Inverter Frequency
      $('#inv_freq').text(get_value({ value: valtable_obj.EX_INV_FREQ[0], unit: ' Hz', precision: 1 }));
    }
  }

  function get_outp_measures_table() {
    var table, tbody;

    table = $('<table />', { id: 'inp_measures_table', 'class': 'table table-condensed', width: '100%' });
    tbody = $('<tbody />').appendTo(table);

    $('<tr />').append($('<td />', { align: 'left', width: '50%' }).append(get_output_measures_table())).appendTo(tbody);
    $('<tr />').append($('<td />', { align: 'left', width: '50%' }).append(get_info_table())).appendTo(tbody);
    return table;

  }

  function get_output_measures_table() // create output measures
  {
    var tr, td, table, tbody, thead;

    table = $('<table />', { id: 'mains_measures_table', 'class': 'table table-condensed  table-hover', width: '100%' });
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 2 }).css("text-decoration", "underline").append(i18n("Output Measures"))).appendTo(thead);

    if (outphases == 3) {
      //output Voltage
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Output Voltage Phase R"))).appendTo(tbody);
      $('<td />', { id: 'outp_volt1', align: 'left' }).append(get_value({ value: valtable_obj.OUTPUT_VOLT[0], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Voltage Phase S"))).appendTo(tbody);
      $('<td />', { id: 'outp_volt2', align: 'left' }).append(get_value({ value: valtable_obj.OUTPUT_VOLT[1], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Voltage Phase T"))).appendTo(tbody);
      $('<td />', { id: 'outp_volt3', align: 'left' }).append(get_value({ value: valtable_obj.OUTPUT_VOLT[2], unit: ' V', precision: 1 })).appendTo(tr);

      //output current
      if (valtable_obj.EVO_OUTMEASUREHIDDEN == 0)
      {
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase R"))).appendTo(tbody);
         $('<td />', { id: 'outp_cur1', align: 'left' }).append(get_value({ value: valtable_obj.EX_OUT_CURR[0], unit: ' A', precision: 1 })).appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase S"))).appendTo(tbody);
         $('<td />', { id: 'outp_cur2', align: 'left' }).append(get_value({ value: valtable_obj.EX_OUT_CURR[1], unit: ' A', precision: 1 })).appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase T"))).appendTo(tbody);
         $('<td />', { id: 'outp_cur3', align: 'left' }).append(get_value({ value: valtable_obj.EX_OUT_CURR[2], unit: ' A', precision: 1 })).appendTo(tr);
      }
      else
      {
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase R"))).appendTo(tbody);
         $('<td />', { id: 'outp_cur1', align: 'left' }).append("---").appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase S"))).appendTo(tbody);
         $('<td />', { id: 'outp_cur2', align: 'left' }).append("---").appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase T"))).appendTo(tbody);
         $('<td />', { id: 'outp_cur3', align: 'left' }).append("---").appendTo(tr);
      }

    } else {
      //output Voltage
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Output Voltage Phase R"))).appendTo(tbody);
      $('<td />', { id: 'outp_volt1', align: 'left' }).append(get_value({ value: valtable_obj.OUTPUT_VOLT[0], unit: ' V', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Voltage Phase S"))).appendTo(tbody);
      $('<td />', { id: 'outp_volt2', align: 'left' }).append('---').appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Voltage Phase T"))).appendTo(tbody);
      $('<td />', { id: 'outp_volt3', align: 'left' }).append('---').appendTo(tr);

      //output current
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase R"))).appendTo(tbody);
      $('<td />', { id: 'outp_cur1', align: 'left' }).append(get_value({ value: valtable_obj.EX_OUT_CURR[0], unit: ' A', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase S"))).appendTo(tbody);
      $('<td />', { id: 'outp_cur2', align: 'left' }).append('---').appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Current Phase T"))).appendTo(tbody);
      $('<td />', { id: 'outp_cur3', align: 'left' }).append('---').appendTo(tr);
    }

    //output Frequency
    if (ups_protocol == ups_protocol_evo6)
    {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Frequency"))).appendTo(tbody);
      $('<td />', { id: 'outp_freq1', align: 'left' }).append(get_value({ value: valtable_obj.OUTFREQ[0], unit: ' Hz', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Frequency"))).appendTo(tbody);
      $('<td />', { id: 'outp_freq2', align: 'left' }).append(get_value({ value: valtable_obj.OUTFREQ[1], unit: ' Hz', precision: 1 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Frequency"))).appendTo(tbody);
      $('<td />', { id: 'outp_freq3', align: 'left' }).append(get_value({ value: valtable_obj.OUTFREQ[2], unit: ' Hz', precision: 1 })).appendTo(tr);
    }
    else
    {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Frequency"))).appendTo(tbody);
      $('<td />', { id: 'outp_freq', align: 'left' }).append(get_value({ value: valtable_obj.OUTFREQ[0], unit: ' Hz', precision: 1 })).appendTo(tr);
       //output Power
       tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Power"))).appendTo(tbody);
      $('<td />', { id: 'outp_power', align: 'left' }).append(get_value({ value: valtable_obj.EX_OUT_WATT[0], unit: ' kVA', precision: 1 }) +
         ' ' + get_value({ value: valtable_obj.EVO_OUTPUTKW, unit: ' kW', precision: 1 })).appendTo(tr);
    }

    if (outphases == 3) {
      //output Load
      if (valtable_obj.EVO_OUTMEASUREHIDDEN == 0)
      {
         tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Output Load Phase R"))).appendTo(tbody);
         $('<td />', { id: 'outp_load1', align: 'left' }).append(get_value({ value: valtable_obj.OUTPOWER[0], unit: ' %', precision: 0 })).appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Load Phase S"))).appendTo(tbody);
         $('<td />', { id: 'outp_load2', align: 'left' }).append(get_value({ value: valtable_obj.OUTPOWER[1], unit: ' %', precision: 0 })).appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Load Phase T"))).appendTo(tbody);
         $('<td />', { id: 'outp_load3', align: 'left' }).append(get_value({ value: valtable_obj.OUTPOWER[2], unit: ' %', precision: 0 })).appendTo(tr);
      }
      else
      {
         tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Output Load Phase R"))).appendTo(tbody);
         $('<td />', { id: 'outp_load1', align: 'left' }).append("---").appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Load Phase S"))).appendTo(tbody);
         $('<td />', { id: 'outp_load2', align: 'left' }).append("---").appendTo(tr);
         tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Load Phase T"))).appendTo(tbody);
         $('<td />', { id: 'outp_load3', align: 'left' }).append("---").appendTo(tr);
      }
    } else {
      //output Load
      tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Output Load Phase R"))).appendTo(tbody);
      $('<td />', { id: 'outp_load1', align: 'left' }).append(get_value({ value: valtable_obj.OUTPOWER[0], unit: ' %', precision: 0 })).appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Load Phase S"))).appendTo(tbody);
      $('<td />', { id: 'outp_load2', align: 'left' }).append('---').appendTo(tr);
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Load Phase T"))).appendTo(tbody);
      $('<td />', { id: 'outp_load3', align: 'left' }).append('---').appendTo(tr);
    }
    if (ups_protocol == ups_protocol_evo6)
    {
       if (valtable_obj.EVO_OUTMEASUREHIDDEN == 0)
       {
          //output Power
          tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Power kVA"))).appendTo(tbody);
          $('<td />', { id: 'outp_power1', align: 'left' }).append(get_value({ value: valtable_obj.EX_OUT_VA[0], unit: ' kVA', precision: 1 })).appendTo(tr);

          tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Power kW"))).appendTo(tbody);
          $('<td />', { id: 'outp_power2', align: 'left' }).append(get_value({ value: valtable_obj.EX_OUT_WATT[0], unit: ' kW', precision: 1 })).appendTo(tr);
       }
       else
       {
          tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Power kVA"))).appendTo(tbody);
          $('<td />', { id: 'outp_power1', align: 'left' }).append("---").appendTo(tr);

          tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output Power kW"))).appendTo(tbody);
          $('<td />', { id: 'outp_power2', align: 'left' }).append("---").appendTo(tr);
       }
    }

    return table;
  }

  function get_info_table() // create output measures
  {
    var tr, td, table, tbody, thead;

    table = $('<table />', { id: 'mains_measures_table', 'class': 'table table-condensed  table-hover', width: '100%' });
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 2 }).css("text-decoration", "underline").append(i18n("Info"))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left', width: '200' }).append(i18n("Device Name"))).appendTo(tbody);
    $('<td />', { id: 'device_name', align: 'left' }).append(valtable_obj.EVO_NAME).appendTo(tr);

    if (ups_protocol != ups_protocol_evo6)
    {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Device Type"))).appendTo(tbody);
      $('<td />', { id: 'device_type', align: 'left' }).append(get_device_type()).appendTo(tr);
    }

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Device Size"))).appendTo(tbody);
    $('<td />', { id: 'device_size', align: 'left' }).append(get_value({ value: valtable_obj.EX_NOM_WATT, unit: ' kVA', precision: 0 })).appendTo(tr);


    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("UPS Serial Number"))).appendTo(tbody);
    $('<td />', { id: 'device_snr', align: 'left' }).append(valtable_obj.EVO_SERNO).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("OEM Serial Number"))).appendTo(tbody);
    $('<td />', { id: 'oem_snr', align: 'left' }).append(valtable_obj.EVO_OEMSERNO).appendTo(tr);

    if (ups_protocol != ups_protocol_evo6)
    {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery Size"))).appendTo(tbody);
      $('<td />', { id: 'batt_size', align: 'left' }).append(get_value({ value: valtable_obj.EVO_BATTSIZE, unit: ' Ah', precision: 0 })).appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Nominal Battery Autonomy"))).appendTo(tbody);
      $('<td />', { id: 'nomauto_time', align: 'left' }).append(get_value({ value: valtable_obj.EVO_NOMAUTONOM, unit: ' min', precision: 0 })).appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Nominal Input Voltage"))).appendTo(tbody);
      $('<td />', { id: 'nominp_volt', align: 'left' }).append(get_value({ value: valtable_obj.EX_NOM_VOLT, unit: ' V', precision: 0 })).appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Nominal Inverter Voltage"))).appendTo(tbody);
      $('<td />', { id: 'nominverter_volt', align: 'left' }).append(get_value({ value: valtable_obj.EVO_NOMINVVOLT, unit: ' V', precision: 0 })).appendTo(tr);
    }

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Nominal Bypass Voltage"))).appendTo(tbody);
    $('<td />', { id: 'nombyp_volt', align: 'left' }).append(get_value({ value: valtable_obj.EVO_NOMBYPVOLT, unit: ' V', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Nominal Output Voltage"))).appendTo(tbody);
    $('<td />', { id: 'nomoutp_volt', align: 'left' }).append(get_value({ value: valtable_obj.EX_NOM_OUTVOLT, unit: ' V', precision: 0 })).appendTo(tr);

    if (ups_protocol != ups_protocol_evo6)
    {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Nominal Input Frequency"))).appendTo(tbody);
      $('<td />', { id: 'nominp_freq', align: 'left' }).append(get_value({ value: valtable_obj.EX_NOM_FREQ, unit: ' Hz', precision: 0 })).appendTo(tr);
    }

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Nominal Bypass Frequency"))).appendTo(tbody);
    $('<td />', { id: 'nombyp_freq', align: 'left' }).append(get_value({ value: valtable_obj.EVO_NOMBYPFREQ, unit: ' Hz', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Device Time"))).appendTo(tbody);
    $('<td />', { id: 'dev_time', align: 'left' }).append(valtable_obj.CBSER_DATE + ' ' + valtable_obj.CBSER_TIME).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Device Temperature"))).appendTo(tbody);
    $('<td />', { id: 'dev_temp', align: 'left' }).append(get_dev_temp()).appendTo(tr);

    if (ups_protocol != ups_protocol_evo6)
    {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("ModBus Address"))).appendTo(tbody);
      $('<td />', { id: 'modbus_addr', align: 'left' }).append(valtable_obj.EVO_MODBUSADDR).appendTo(tr);
    }

    if (ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo2) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Firmware SSW"))).appendTo(tbody);
      $('<td />', { id: 'firmware_ssw', align: 'left' }).append('---').appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Firmware Rectifier"))).appendTo(tbody);
      $('<td />', { id: 'firmware_rectifier', align: 'left' }).append('---').appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Firmware Inverter"))).appendTo(tbody);
      $('<td />', { id: 'firmware_inverter', align: 'left' }).append('---').appendTo(tr);
    } else {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Firmware SSW"))).appendTo(tbody);
      $('<td />', { id: 'firmware_ssw', align: 'left' }).append(valtable_obj.EVO_FW_SSW).appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Firmware Rectifier"))).appendTo(tbody);
      $('<td />', { id: 'firmware_rectifier', align: 'left' }).append(valtable_obj.EVO_FW_RECT).appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Firmware Inverter"))).appendTo(tbody);
      $('<td />', { id: 'firmware_inverter', align: 'left' }).append(valtable_obj.EVO_FW_INV).appendTo(tr);
    }

    if (ups_protocol == ups_protocol_evo2) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Input Type"))).appendTo(tbody);
      $('<td />', { id: 'input_type', align: 'left' }).append(get_input_type()).appendTo(tr);
    }

    return table;
  }

  function set_output_measures() {
    if (outphases == 3) {
      //output Voltage
      $('#outp_volt1').text(get_value({ value: valtable_obj.OUTPUT_VOLT[0], unit: ' V', precision: 1 }));
      $('#outp_volt2').text(get_value({ value: valtable_obj.OUTPUT_VOLT[1], unit: ' V', precision: 1 }));
      $('#outp_volt3').text(get_value({ value: valtable_obj.OUTPUT_VOLT[2], unit: ' V', precision: 1 }));

      if (valtable_obj.EVO_OUTMEASUREHIDDEN == 0)
      {
         //output current
         $('#outp_cur1').text(get_value({ value: valtable_obj.EX_OUT_CURR[0], unit: ' A', precision: 1 }));
         $('#outp_cur2').text(get_value({ value: valtable_obj.EX_OUT_CURR[1], unit: ' A', precision: 1 }));
         $('#outp_cur3').text(get_value({ value: valtable_obj.EX_OUT_CURR[2], unit: ' A', precision: 1 }));
      }
      else
      {
         $('#outp_cur1').text("---");
         $('#outp_cur2').text("---");
         $('#outp_cur3').text("---");
      }
      if (ups_protocol == ups_protocol_evo6)
      {
         $('#outp_freq1').text(get_value({ value: valtable_obj.OUTFREQ[0], unit: ' Hz', precision: 1 }));
         $('#outp_freq2').text(get_value({ value: valtable_obj.OUTFREQ[1], unit: ' Hz', precision: 1 }));
         $('#outp_freq3').text(get_value({ value: valtable_obj.OUTFREQ[2], unit: ' Hz', precision: 1 }));
      }
      //output Load
      if (valtable_obj.EVO_OUTMEASUREHIDDEN == 0)
      {
         $('#outp_load1').text(get_value({ value: valtable_obj.OUTPOWER[0], unit: ' %', precision: 0 }));
         $('#outp_load2').text(get_value({ value: valtable_obj.OUTPOWER[1], unit: ' %', precision: 0 }));
         $('#outp_load3').text(get_value({ value: valtable_obj.OUTPOWER[2], unit: ' %', precision: 0 }));
      }
      else
      {
         $('#outp_load1').text("---");
         $('#outp_load2').text("---");
         $('#outp_load3').text("---");
      }

    } else {
      //output Voltage
      $('#outp_volt1').text(get_value({ value: valtable_obj.OUTPUT_VOLT[0], unit: ' V', precision: 1 }));
      //output current
      $('#outp_cur1').text(get_value({ value: valtable_obj.EX_OUT_CURR[0], unit: ' A', precision: 1 }));
      //output Load
      $('#outp_load1').text(get_value({ value: valtable_obj.OUTPOWER[0], unit: ' %', precision: 1 }));
    }

    if (ups_protocol != ups_protocol_evo6)
    {
      //output Frequency
      $('#outp_freq').text(get_value({ value: valtable_obj.OUTFREQ[0], unit: ' Hz', precision: 1 }));
      //output Power
      $('#outp_power').text(get_value({ value: valtable_obj.EX_OUT_WATT[0], unit: ' kVA', precision: 1 }) +
         ' ' + get_value({ value: valtable_obj.EVO_OUTPUTKW, unit: ' kW', precision: 1 }));
    }
    else
    {
      //output Power
      if (valtable_obj.EVO_OUTMEASUREHIDDEN == 0)
      {
         $('#outp_power1').text(get_value({ value: valtable_obj.EX_OUT_VA[0], unit: ' kVA', precision: 1 }));
         $('#outp_power2').text(get_value({ value: valtable_obj.EX_OUT_WATT[0], unit: ' kW', precision: 1 }));
      }
      else
      {
         $('#outp_power1').text("---");
         $('#outp_power2').text("---");
      }
    }

    //Infos
    $('#dev_time').text(valtable_obj.CBSER_DATE + ' ' + valtable_obj.CBSER_TIME);
    $('#dev_temp').html(get_dev_temp());
    $('#device_name').text(valtable_obj.EVO_NAME);
    $('#device_size').text(get_value({ value: valtable_obj.EX_NOM_WATT, unit: ' kVA', precision: 0 }));
    $('#device_snr').text(valtable_obj.EVO_SERNO);
    $('#oem_snr').text(valtable_obj.EVO_OEMSERNO);
    if (ups_protocol != ups_protocol_evo6)
    {
      $('#device_type').text(get_device_type());
      $('#batt_size').text(get_value({ value: valtable_obj.EVO_BATTSIZE, unit: ' Ah', precision: 0 }));
      $('#nomauto_time').text(get_value({ value: valtable_obj.EVO_NOMAUTONOM, unit: ' min', precision: 0 }));
      $('#nominp_volt').text(get_value({ value: valtable_obj.EX_NOM_VOLT, unit: ' V', precision: 0 }));
      $('#nominverter_volt').text(get_value({ value: valtable_obj.EVO_NOMINVVOLT, unit: ' V', precision: 0 }));
      $('#modbus_addr').text(valtable_obj.EVO_MODBUSADDR);
      $('#nominp_freq').text(get_value({ value: valtable_obj.EX_NOM_FREQ, unit: ' Hz', precision: 0 }));
    }
    $('#nombyp_volt').text(get_value({ value: valtable_obj.EVO_NOMBYPVOLT, unit: ' V', precision: 0 }));
    $('#nomoutp_volt').text(get_value({ value: valtable_obj.EX_NOM_OUTVOLT, unit: ' V', precision: 0 }));
    $('#nombyp_freq').text(get_value({ value: valtable_obj.EVO_NOMBYPFREQ, unit: ' Hz', precision: 0 }));

    if (ups_protocol != ups_protocol_evo && ups_protocol != ups_protocol_evo2) {
      $('#firmware_ssw').text(valtable_obj.EVO_FW_SSW);
      $('#firmware_rectifier').text(valtable_obj.EVO_FW_RECT);
      $('#firmware_inverter').text(valtable_obj.EVO_FW_INV);
    }

    if (ups_protocol == ups_protocol_evo2) {
      $('#input_type').text(get_input_type());
    }

  }

  function get_input_type() {
    if (valtable_obj.OUTPHASES == 3)
    return 'TRI-TRI';
    return 'TRI-MONO';
  }

  function get_status_table() {
    var tr, table, tbody, thead;

    table = $('<table />', { id: 'status_table', 'class': 'table table-condensed  table-hover' });
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 1 }).css("text-decoration", "underline").append(i18n("Statuses"))).appendTo(thead);

    if (valtable_obj.EVO_STATES[0] & 0x0001)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S1 Bypass Ok"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S1 Booster Ok"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_STATES[0] & 0x0002)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S2 Inverter Bypass Synchronized"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S2 Battery Ok"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_STATES[0] & 0x0004)
    {
      if (ups_protocol == ups_protocol_evo6)
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S3"))).appendTo(tbody);
      }
      else
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S3 Inverter Ok"))).appendTo(tbody);
      }
    }
    if (valtable_obj.EVO_STATES[0] & 0x0008)
    {
      if (ups_protocol == ups_protocol_evo6)
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S4"))).appendTo(tbody);
      }
      else
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S4 Inverter Feed Load"))).appendTo(tbody);
      }
    }
    if (valtable_obj.EVO_STATES[0] & 0x0010)
    {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo4)
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S5 Inverter Bypass Synchronized"))).appendTo(tbody);
      }
      else if (ups_protocol == ups_protocol_evo6)
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S5"))).appendTo(tbody);
      }
      else
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S5 Inverter Synchronized"))).appendTo(tbody);
      }
    }

    if (valtable_obj.EVO_STATES[0] & 0x0020)
    {
      if (ups_protocol == ups_protocol_evo6)
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S6"))).appendTo(tbody);
      }
      else
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S6 Bypass Ok"))).appendTo(tbody);
      }
    }
    if (valtable_obj.EVO_STATES[0] & 0x0040)
    {
      if (ups_protocol == ups_protocol_evo6)
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S7"))).appendTo(tbody);
      }
      else
      {
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S7 Bypass Feed Load"))).appendTo(tbody);
      }
    }

    if (valtable_obj.EVO_STATES[0] & 0x0080)
    {
      if (ups_protocol == ups_protocol_evo)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S8 Boost Charge"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo4)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S8 Inverter Master Sync"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S8 Inverter Master Groups Synchr."))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S8"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_STATES[0] & 0x0100) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo3)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S9 Inverter Master Sync"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo5 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S9"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S9 Slave Synchronized"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_STATES[0] & 0x0200) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S10"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S10 External Sync Active"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S10 Rectifier Standby"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_STATES[0] & 0x0400) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S11"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S11 Inverter Standby"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_STATES[0] & 0x0800) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S12"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S12 Battery Standby"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_STATES[0] & 0x1000) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S13"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S13 Battery Discharge"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S13 Battery in Charge"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_STATES[0] & 0x2000) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo ||
        ups_protocol == ups_protocol_evo3 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S14"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S14 Battery charge I"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S14 Battery Maintenance"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_STATES[0] & 0x4000) {
      if (ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S15 Battery charge U"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S15"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_STATES[0] & 0x8000) {
      if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S16 Green Conversion"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S16"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_STATES[1] & 0x0001) {
      if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S17 Line Interactive"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S17"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_STATES[1] & 0x0002) {
      if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S18 External Sync Inverter Synchr."))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S18"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_STATES[1] & 0x0004) {
      if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S19 External Sync Inhibited"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S19"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_STATES[1] & 0x0008) {
      if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S20 External Sync"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S20"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_STATES[1] & 0x0010)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S21"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x0020)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S22"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x0040)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S23"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x0080)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S24"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x0100)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S25"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x0200)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S26"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x0400)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S27"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x0800)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S28"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x1000)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S29"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x2000)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S30"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x4000)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S31"))).appendTo(tbody);
    if (valtable_obj.EVO_STATES[1] & 0x8000)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n("S32"))).appendTo(tbody);

    return table;
  }

  function get_alarms_table() {
    var tr, table, tbody, thead;

    table = $('<table />', { id: 'alarms_table', 'class': 'table table-condensed  table-hover' });
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 1 }).css("text-decoration", "underline").append(i18n("Alarms"))).appendTo(thead);

    if (valtable_obj.EVO_ALARMS[0] & 0x0001)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A1 SBCB open"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A1 Mains Fault"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0002)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A2 OSBCB open"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A2 Input Wrong Sequence"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0004)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A3 OCBS open"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A3 Booster Stopped"))).appendTo(tbody);
   }
    if (valtable_obj.EVO_ALARMS[0] & 0x0008)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A4 MBCB closed"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A4 Booster Fault"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0010)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A5 Bypass switch"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A5 DC Voltage Fault"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0020)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A6 EPO pressed"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A6 Battery in Test"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0040)
    {
      if (ups_protocol == ups_protocol_evo5)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A7 BCB Module Open"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A7 EPO bus closed"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A7 BCB Open"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0080)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A8 High temperature"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A8 Battery Discharge"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0100)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A9"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A9 Battery Autonomy End"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0200)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A10 Bypass wrong sequence"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A10 Battery Fault"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0400)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A11 Bypass fault"))).appendTo(tbody);
       else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A11 Short Circuit"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x0800)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A12 Bypass feed load"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A12 Stop Timeout Short Circuit"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x1000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A13 Retransfer blocked"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A13 Inverter Out Of Tolerance"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x2000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A14 Relay backfeed on"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A14 Bypass Wrong Sequence"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x4000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A15"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A15 Bypass Fault"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[0] & 0x8000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A16 Lost redundancy"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A16 Bypass Feed Load"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0001)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A17 Lost redundancy parallel cable"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A17 Retransfer Blocked"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0002)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A18 Parallel Cable Disconnected"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A18 MBCB Closed"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0004)
    {
      if (ups_protocol == ups_protocol_evo5)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A19 OCB Module Open"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A19 Parallel CAN error"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A19 OCB Open"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0008)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A20"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A20 Overload"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0010)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A21 Eeprom error"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A21 Thermal Image"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0020)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A22 Sending eeprom parameters error"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A22 Bypass Switch"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0040)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A23 Reception eeprom parameters error"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A23 EPO Pressed"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0080)
    {
      if (ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo3)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A24 High Temp Inv / DC Fuse Blown"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A24 High Temp Inv"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A24 Firmware error"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A24 High Temperature"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0100)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A25 Test mode error"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A25 Inverter Off"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0200)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A26"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A26 Communication Error"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0400)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A27"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A27 Eeprom Error"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x0800)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A28 Critic Fault"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A28 UPS Critic Fault"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x1000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A29"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A29 Maintenance Required"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x2000)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A30 Common Alarm"))).appendTo(tbody);
    if (valtable_obj.EVO_ALARMS[1] & 0x4000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A31 Starting sequence blocked"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A31 MBCB Bus Closed"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[1] & 0x8000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A32 Internal CAN error"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A32 EPO Bus Closed"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[2] & 0x0001)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A33"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A33 Asymmetric Load"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[2] & 0x0002)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A34"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A34 Service Required"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[2] & 0x0004)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A35"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A35 Diesel Mode / DX Cooling"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A35 Diesel Mode"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[2] & 0x0008)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A36 Communication Error RS485"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A36 DC Fast Shutdown"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[2] & 0x0010) {
      if (ups_protocol == ups_protocol_evo)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A37 High Temperature Rectifier"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A37 BCBb Open"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A37"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[2] & 0x0020)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A38"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A38 Inverter Feed Load"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[2] & 0x0040)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A39"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A39 Inverter Error Loop"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[2] & 0x0080)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A40"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A40 SSI Fault"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[2] & 0x0100) {
      if (ups_protocol == ups_protocol_evo2 ||
        ups_protocol == ups_protocol_evo3 ||
        ups_protocol == ups_protocol_evo4 ||
        ups_protocol == ups_protocol_evo5)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A41 Rectifier Error Loop"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A41"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A41 Booster Error Fault"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[2] & 0x0200) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A42"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A42 BCB General Open"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A42 Fuse Blown"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[2] & 0x0400) {
      if (ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A43"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A43 OCB General Open"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A43 Current Error Loop"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[2] & 0x0800) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A44"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A44 Module Configuration Error"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A44 Desaturation IGBT Inverter"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[2] & 0x1000) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A45"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A45 High Temperature SSW"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[2] & 0x2000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A46"))).appendTo(tbody);
      else
          $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A46 Lost Redundancy"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[2] & 0x4000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A47"))).appendTo(tbody);
      else
          $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A47 Sending Eeprom Parameters Error"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[2] & 0x8000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A48"))).appendTo(tbody);
      else
          $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A48 Reception Eeprom Parameters Error"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[3] & 0x0001)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A49"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A49 Test Mode Mismatch"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[3] & 0x0002) {
      if (ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A50"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A50 1 Parallel Cable Disconnected"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A50 SSW Blocked"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[3] & 0x0004)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A51"))).appendTo(tbody);
      else
          $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A51 Battery Temperature Out Of Tolerance"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[3] & 0x0008) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo3 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A52"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A52 Inverter Blocked"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A52 Under Voltage Lockout"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[3] & 0x0010)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A53"))).appendTo(tbody);
      else
          $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A53 Firmware Error"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[3] & 0x0020)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A54"))).appendTo(tbody);
      else
          $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A54 Parallel CAN Communication Error"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[3] & 0x0040)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A55"))).appendTo(tbody);
      else
          $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A55 Parallel Cable Disconnected"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[3] & 0x0080)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A56"))).appendTo(tbody);
      else
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A56 Mains Unbalanced"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[3] & 0x0100) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A57"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A57 Error External Sync"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A57 Input current unbalanced"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A57 Data Recording Stopped"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[3] & 0x0200) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A58"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A58 Inhibit External Sync"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A58 Inverter current unbalanced"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A58 Torch Mode"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[3] & 0x0400) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A59"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo4 || ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A59 Relay backfeed on"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A59 Varistors Tripped"))).appendTo(tbody);
    }


    if (valtable_obj.EVO_ALARMS[3] & 0x0800) {
      if (ups_protocol == ups_protocol_evo2 || ups_protocol == ups_protocol_evo || ups_protocol == ups_protocol_evo6)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A60"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A60 UHE Blocked"))).appendTo(tbody);
    }

    if (valtable_obj.EVO_ALARMS[3] & 0x1000) {
      if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A61 Power Supply Red. Lost"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A61"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[3] & 0x2000) {
      if (ups_protocol == ups_protocol_evo4)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A62 Overvoltage mains"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A62 Internal RS485 Error"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A62"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[3] & 0x4000)
    {
      if (ups_protocol == ups_protocol_evo6)
         $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A63"))).appendTo(tbody);
      else
          $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A63 Starting Sequence Blocked"))).appendTo(tbody);
    }
    if (valtable_obj.EVO_ALARMS[3] & 0x8000) {
      if (ups_protocol == ups_protocol_evo4)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A64 Undervoltage mains"))).appendTo(tbody);
      else if (ups_protocol == ups_protocol_evo5)
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A64 Battery Cabinets"))).appendTo(tbody);
      else
      $('<tr />').append($('<td />', { align: 'left' }).append(i18n("A64"))).appendTo(tbody);
    }

    return table;
  }

  function get_value(val_obj) {
    var val = null;
    if (val_obj.value == null || val_obj.value == -9999)
    return 'n/a';

    if (val_obj.unit == ' &deg;C') //Temperature?
    {
      return panes_api.get_temperature(val_obj.value, valtable_obj._tempUnit, val_obj.precision);
    }

    /*if(Math.round(val_obj.value) == val_obj.value)
       val = val.toString();
    else*/
    val = val_obj.value.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }

  function get_batt_temp() {
    if (valtable_obj.EVO_BATTTEMPPROBE == 1) {
      return get_value({ value: valtable_obj.TEMPDEG, unit: ' &deg;C', precision: 0 });
    }
    return '---';
  }

  function get_dev_temp() {
    if (valtable_obj.EVO_DEVTEMPPROBE == 1) {
      return get_value({ value: valtable_obj.AMBTEMP, unit: ' &deg;C', precision: 0 });
    }
    return '---';
  }

  function get_device_type() {
    if (valtable_obj.EVO_DEVTYPE == 0)
    return "UPS 50Hz";
    else if (valtable_obj.EVO_DEVTYPE == 1)
    return "UPS 60Hz";
    else if (valtable_obj.EVO_DEVTYPE == 2)
    return "FC 50Hz/60Hz";
    else if (valtable_obj.EVO_DEVTYPE == 3)
    return "FC 60Hz/50Hz";
    return "";
  }

  function get_epo_img(index) {
    var img_base = './image/astrid/',
    value = valtable_obj.EVO_MIMIC[index];

    switch (value) {
      case 0:
        return img_base += '0.gif';
      case 1:
        return img_base += 'r.gif';
      case 2:
        return img_base += 'r0500.gif';
      case 3:
        return img_base += 'r1000.gif';
    }

    return './image/astrid/' + '0.gif';
  }

  function get_ssb_mbcb_svr_img(index) {
    var img_base = './image/astrid/',
    value = valtable_obj.EVO_MIMIC[index];

    switch (value) {
      case 0:
        return img_base += '0.gif';
      case 1:
        return img_base += 'o.gif';
      case 2:
        return img_base += 'o0500.gif';
      case 3:
        return img_base += 'o1000.gif';
    }

    if (index == 5) //SSB
    {
      switch (value) {
        case 4:
          return img_base += 'r.gif';
        case 5:
          return img_base += 'g.gif';
        case 6:
          return img_base += 'o.gif';
        case 7:
          return img_base += 'r0500.gif';
        case 8:
          return img_base += 'r1000.gif';
        case 9:
          return img_base += 'g0500.gif';
        case 10:
          return img_base += 'g1000.gif';
        case 11:
          return img_base += 'o0500.gif';
        case 12:
          return img_base += 'o1000.gif';
      }
    }
    return './image/astrid/' + '0.gif';
  }



  function get_inp_byp_inv_img(index) {
    var img_base = './image/astrid/',
    value = valtable_obj.EVO_MIMIC[index];

    switch (value) {
      case 0:
        return img_base += '0.gif';
      case 1:
        return img_base += 'g.gif';
      case 2:
        return img_base += 'g0500.gif';
      case 3:
        return img_base += 'g1000.gif';
    }

    if (index == 4) //SSI
    {
      switch (value) {
        case 4:
          return img_base += 'r.gif';
        case 5:
          return img_base += 'g.gif';
        case 6:
          return img_base += 'o.gif';
        case 7:
          return img_base += 'r0500.gif';
        case 8:
          return img_base += 'r1000.gif';
        case 9:
          return img_base += 'g0500.gif';
        case 10:
          return img_base += 'g1000.gif';
        case 11:
          return img_base += 'o0500.gif';
        case 12:
          return img_base += 'o1000.gif';
      }
    }

    return './image/astrid/' + '0.gif';
  }


  function get_vdc_batt_ocb_img(index) {
    var img_base = './image/astrid/',
    value = valtable_obj.EVO_MIMIC[index];

    switch (value) {
      case 0:
        return img_base += '0.gif';
      case 4:
        return img_base += 'r.gif';
      case 5:
        return img_base += 'g.gif';
      case 6:
        return img_base += 'o.gif';
      case 7:
        return img_base += 'r0500.gif';
      case 8:
        return img_base += 'r1000.gif';
      case 9:
        return img_base += 'g0500.gif';
      case 10:
        return img_base += 'g1000.gif';
      case 11:
        return img_base += 'o0500.gif';
      case 12:
        return img_base += 'o1000.gif';
    }

    return './image/astrid/' + '0.gif';
  }


}(jQuery));