<?xml version="1.0"?>
<!--
   astridevo6event.xsl - Astrid EVO UPS Event logfile stylesheet.
   Copyright (c) 2018, Generex GmbH. All rights reserved.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" encoding="ISO-8859-1" indent="yes"/>

<!-- Root -->
<xsl:template match="/">
   <html>
      <head>
         <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"/>
         <title>Device History</title>
      </head>
      <body style="font-family:Arial,helvetica,sans-serif;font-size:12pt; background-color:#EEEEEE">
         <xsl:apply-templates />
      </body>
   </html>
</xsl:template>

<!-- UpsSettings -->
<xsl:template match="UpsSettings">
   <!-- Device History -->
   <div style="background-color:teal;color:white;padding:8px; width:800px; height:20px">
      <span style="font-weight:bold;color:white;font-size:14pt;">Device History</span>
   </div>
   <span style="font-size:8pt">generated <xsl:value-of select="FileDate"/>, <xsl:value-of select="FileTime"/></span>
   <br/><br/>
   <div style="background-color:gold;color:white;padding:4px;width:800px">
      <span style="font-weight:bold;color:white">Device Type<br/></span>
   </div>
   <br/>
   <!-- Device Type -->
   <table border="0">
   	<tr>
   		<td style="font-size:10pt">Model:</td>
   		<td style="font-size:10pt"><xsl:value-of select="Type" /></td>
   	</tr>
   	<tr>
   		<td style="font-size:10pt">Location: </td>
   		<td style="font-size:10pt"><xsl:value-of select="Location" /></td>
   	</tr>
   </table>
   <br/>
   <!-- Explicit skip other nodes -->
   <xsl:apply-templates select="UpsLog" />
</xsl:template>

<!-- UpsLog -->
<xsl:template match="UpsLog">
   <div style="background-color:gold;color:white;padding:4px;width:800px">
      <span style="font-weight:bold;color:white">Device Events<br/></span>
   </div>
   <br/>
   <div style="font-size:10pt">
      <table border="1" cellspacing="0" cellpadding="2" width="800">
         <tr>
         	<th style="font-size:8pt">No.</th>
         	<th style="font-size:8pt">Date</th>
         	<th style="font-size:8pt">Time</th>
         	<th style="font-size:8pt">Code</th>
         	<th style="font-size:8pt">Event</th>
         </tr>
         <xsl:apply-templates>
<!--            <xsl:sort select="concat(substring(Date,7,4),substring(Date,4,2),substring(Date,1,2))" order="ascending" />
-->
            <xsl:sort data-type="number" select="@id" order="ascending" />
   		</xsl:apply-templates>
      </table>
   </div>
</xsl:template>

<!-- UpsData -->
<xsl:template match="UpsData">
   <tr>
   	<td style="font-size:8pt;text-align:center;" align="center" valign="top"><xsl:value-of select="@id" /></td>
   	<td style="font-size:8pt;text-align:center;" align="center" valign="top"><xsl:value-of select="Date" /></td>
   	<td style="font-size:8pt" align="center" valign="top"><xsl:value-of select="Time" /></td>

   	<xsl:choose>
   		<xsl:when test="string-length(EventCode) != 0">
				<xsl:choose>
					<xsl:when test="EventCode &gt; 164">
						<td style="font-size:8pt" align="center" valign="top">*S<xsl:value-of select="EventCode - 164" /></td>
					</xsl:when>
					<xsl:when test="EventCode &gt; 100">
						<td style="font-size:8pt" align="center" valign="top">*A<xsl:value-of select="EventCode - 100" /></td>
					</xsl:when>
					<xsl:when test="EventCode &gt; 64">
						<td style="font-size:8pt" align="center" valign="top">S<xsl:value-of select="EventCode - 64" /></td>
					</xsl:when>
					<xsl:otherwise>
						<td style="font-size:8pt" align="center" valign="top">A<xsl:value-of select="EventCode" /></td>
					</xsl:otherwise>
				</xsl:choose>
   	   		<td style="font-size:8pt" align="left" valign="top">&#160;<xsl:value-of select="EventText" />
						<xsl:call-template name="EventText">
							<xsl:with-param name="EventCode" select='EventCode'/>
						</xsl:call-template>
					</td>
				</xsl:when>
			<xsl:otherwise>
   	   		<td style="font-size:8pt" align="left" valign="top">&#160;<xsl:value-of select="EventText" />
   	   		</td>
			</xsl:otherwise>
		</xsl:choose>
   </tr>
</xsl:template>

<xsl:template name="EventText">
	<xsl:param name="EventCode" select="'0'"/>
	<xsl:choose>
		<!--
			Alarms
		-->
		<xsl:when test="$EventCode = '1'"><xsl:text>SBCB open</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '101'"><xsl:text>SBCB open removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '2'"><xsl:text>OSBCB open</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '102'"><xsl:text>OSBCB open removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '3'"><xsl:text>OCBS open</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '103'"><xsl:text>OCBS open removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '4'"><xsl:text>MBCB closed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '104'"><xsl:text>MBCB closed removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '5'"><xsl:text>Bypass Switch</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '105'"><xsl:text>Bypass Switch removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '6'"><xsl:text>EPO pressed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '106'"><xsl:text>EPO pressed removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '7'"><xsl:text>EPO bus closed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '107'"><xsl:text>EPO bus closed removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '8'"><xsl:text>High temperature</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '108'"><xsl:text>High temperature removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '9'"><xsl:text>A9 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '109'"><xsl:text>A9 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '10'"><xsl:text>Bypass wrong sequence</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '110'"><xsl:text>Bypass wrong sequence removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '11'"><xsl:text>Bypass fault</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '111'"><xsl:text>Bypass fault removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '12'"><xsl:text>Bypass feed load</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '112'"><xsl:text>Bypass feed load removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '13'"><xsl:text>Retransfer blocked</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '113'"><xsl:text>Retransfer blocked removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '14'"><xsl:text>Relay backfeed on</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '114'"><xsl:text>Relay backfeed on removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '15'"><xsl:text>A15 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '115'"><xsl:text>A15 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '16'"><xsl:text>Lost redundancy</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '116'"><xsl:text>Lost redundancy removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '17'"><xsl:text>Lost redundancy parallel cable</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '117'"><xsl:text>Lost redundancy parallel cable removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '18'"><xsl:text>Parallel Cable Disconnected</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '118'"><xsl:text>Parallel Cable Disconnected removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '19'"><xsl:text>Parallel CAN error</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '119'"><xsl:text>Parallel CAN error removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '20'"><xsl:text>A20 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '120'"><xsl:text>A20 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '21'"><xsl:text>Eeprom error</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '121'"><xsl:text>Eeprom error removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '22'"><xsl:text>Sending eeprom parameters error</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '122'"><xsl:text>Sending eeprom parameters error removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '23'"><xsl:text>Reception eeprom parameters error</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '123'"><xsl:text>Reception eeprom parameters error removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '24'"><xsl:text>Firmware error</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '124'"><xsl:text>Firmware error removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '25'"><xsl:text>Test mode error</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '125'"><xsl:text>Test mode error removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '26'"><xsl:text>A26 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '126'"><xsl:text>A26 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '27'"><xsl:text>A27 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '127'"><xsl:text>A27 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '28'"><xsl:text>Critical fault</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '128'"><xsl:text>Critical fault removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '29'"><xsl:text>A29 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '129'"><xsl:text>A29 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '30'"><xsl:text>Common alarm</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '130'"><xsl:text>Common alarm removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '31'"><xsl:text>Starting sequence blocked</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '131'"><xsl:text>Starting sequence blocked removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '32'"><xsl:text>Internal CAN error</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '132'"><xsl:text>Internal CAN error removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '33'"><xsl:text>A33 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '133'"><xsl:text>A33 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '34'"><xsl:text>A34 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '134'"><xsl:text>A34 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '35'"><xsl:text>A35 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '135'"><xsl:text>A35 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '36'"><xsl:text>Communication Error RS485</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '136'"><xsl:text>Communication Error RS485 removed</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '37'"><xsl:text>A37 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '137'"><xsl:text>A37 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '38'"><xsl:text>A38 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '138'"><xsl:text>A38 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '39'"><xsl:text>A39 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '139'"><xsl:text>A39 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '40'"><xsl:text>A40 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '140'"><xsl:text>A40 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '41'"><xsl:text>A41 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '141'"><xsl:text>A41 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '42'"><xsl:text>A42 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '142'"><xsl:text>A42 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '43'"><xsl:text>A43 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '143'"><xsl:text>A43 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '44'"><xsl:text>A44 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '144'"><xsl:text>A44 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '45'"><xsl:text>A45 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '145'"><xsl:text>A45 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '46'"><xsl:text>A46 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '146'"><xsl:text>A46 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '47'"><xsl:text>A47 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '147'"><xsl:text>A47 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '48'"><xsl:text>A48 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '148'"><xsl:text>A48 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '49'"><xsl:text>A49 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '149'"><xsl:text>A49 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '50'"><xsl:text>A50 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '150'"><xsl:text>A50 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '51'"><xsl:text>A51 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '151'"><xsl:text>A51 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '52'"><xsl:text>A52 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '152'"><xsl:text>A52 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '53'"><xsl:text>A53 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '153'"><xsl:text>A53 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '54'"><xsl:text>A54 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '154'"><xsl:text>A54 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '55'"><xsl:text>A55 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '155'"><xsl:text>A55 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '56'"><xsl:text>A56 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '156'"><xsl:text>A56 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '57'"><xsl:text>A57 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '157'"><xsl:text>A57 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '58'"><xsl:text>A58 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '158'"><xsl:text>A58 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '59'"><xsl:text>A59 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '159'"><xsl:text>A59 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '60'"><xsl:text>A60 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '160'"><xsl:text>A60 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '61'"><xsl:text>A61 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '161'"><xsl:text>A61 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '62'"><xsl:text>A62 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '162'"><xsl:text>A62 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '63'"><xsl:text>A63 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '163'"><xsl:text>A63 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '64'"><xsl:text>A64 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '164'"><xsl:text>A64 NOT present</xsl:text></xsl:when>
		<!--
		  States
		-->
		<xsl:when test="$EventCode = '65'"><xsl:text>Bypass Ok present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '165'"><xsl:text>Bypass Ok NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '66'"><xsl:text>Inverter Bypass Synchronized present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '166'"><xsl:text>Inverter Bypass Synchronized NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '67'"><xsl:text>S3 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '167'"><xsl:text>S3 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '68'"><xsl:text>S4 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '168'"><xsl:text>S4 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '69'"><xsl:text>S5 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '169'"><xsl:text>S5 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '70'"><xsl:text>S6 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '170'"><xsl:text>S6 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '71'"><xsl:text>S7 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '171'"><xsl:text>S7 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '72'"><xsl:text>S8 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '172'"><xsl:text>S8 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '73'"><xsl:text>S9 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '173'"><xsl:text>S9 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '74'"><xsl:text>S10 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '174'"><xsl:text>S10 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '75'"><xsl:text>S11 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '175'"><xsl:text>S11 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '76'"><xsl:text>S12 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '176'"><xsl:text>S12 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '77'"><xsl:text>S13 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '177'"><xsl:text>S13 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '78'"><xsl:text>S14 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '178'"><xsl:text>S14 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '79'"><xsl:text>S15 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '179'"><xsl:text>S15 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '80'"><xsl:text>S16 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '180'"><xsl:text>S16 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '81'"><xsl:text>S17 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '181'"><xsl:text>S17 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '82'"><xsl:text>S18 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '182'"><xsl:text>S18 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '83'"><xsl:text>S19 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '183'"><xsl:text>S19 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '84'"><xsl:text>S20 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '184'"><xsl:text>S20 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '85'"><xsl:text>S21 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '185'"><xsl:text>S21 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '86'"><xsl:text>S22 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '186'"><xsl:text>S22 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '87'"><xsl:text>S23 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '187'"><xsl:text>S23 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '88'"><xsl:text>S24 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '188'"><xsl:text>S24 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '89'"><xsl:text>S25 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '189'"><xsl:text>S25 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '90'"><xsl:text>S26 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '190'"><xsl:text>S26 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '91'"><xsl:text>S27 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '191'"><xsl:text>S27 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '92'"><xsl:text>S28 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '192'"><xsl:text>S28 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '93'"><xsl:text>S29 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '193'"><xsl:text>S29 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '94'"><xsl:text>S30 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '194'"><xsl:text>S30 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '95'"><xsl:text>S31 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '195'"><xsl:text>S31 NOT present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '96'"><xsl:text>S32 present</xsl:text></xsl:when>
		<xsl:when test="$EventCode = '196'"><xsl:text>S32 NOT present</xsl:text></xsl:when>

		<xsl:otherwise><xsl:text>UNKNOWN CODE</xsl:text></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- EOS -->
</xsl:stylesheet>
