/*
   mega_3_4_panel.js - UPS MEG3/MEGA4 screen.
   Copyright (c) 2014, Generex GmbH. All rights reserved.
   Said.
*/

var mega_3_4_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  outpower_loadbars_created = false,
  css_obj,
  valtable_obj, report_obj, unms_obj,
  _oemViewName = null,
  _upsProtocol,
  is_salisec = false,
  x_pos = 10,
  y_pos = 10;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.length == 0) {
      return;
    }

    valtable_obj = data.ups.valtable;
    report_obj = data.report;

    if (_oemViewName == null) {
      if (data.ups._oemViewName)
      _oemViewName = data.ups._oemViewName.toLowerCase();
      else
      _oemViewName = valtable_obj._oemViewName.toLowerCase();

      if (valtable_obj._upsProtocol)
      _upsProtocol = valtable_obj._upsProtocol;
      else
      _upsProtocol = valtable_obj.CONNECT;
      is_salisec = _upsProtocol == -32604 || _upsProtocol == '80A4';
    }

    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }
    set_bg();
    set_input_values();
    set_output_values(); //Set Output values
    set_bypass(); // set Bypass panel
    set_battery(); //set Battery panel
    set_outpower_loadbars(); //Set outpower loadbars
    set_inverter(); //Set Inverter
    set_rectifier(); //Rectifier status
    if (valtable_obj._platform !== "ups_view")
    panes_api.set_rom_temp_values(valtable_obj); //set rom temp values
    set_footer();
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: '750px',
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_bg(); //background
    create_model_panel();

    create_input_panel(); //Input panel
    create_output_panel(); //Output panel
    create_bypass_panel(); //Bypass panel
    create_battery_panel(); //Battery panel
    create_inverter_panel(); //Inverter panel
    create_rectifier_panel(); //Rectifier panel

    create_outpower_loadbars(); //outpower loadbars
    if (valtable_obj._platform !== "ups_view")
    create_rom_temp(); //rom temp
    create_footer_pane();
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div, img;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 800, height: 720, border: 'solid 1px #808080', 'background-color': 'transparent' };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    img = $('<img />').attr({ 'id': 'bg_img_id', 'class': 'img-rounded', align: 'middle', width: 699, 'height': 369, src: get_bg_img() }).appendTo(img_div);
    img.css({ 'margin-top': 190, 'margin-left': 50 });
    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function set_bg() {
    var img = $('#bg_img_id');
    img.attr('src', get_bg_img());
  }

  function create_input_panel() //Input panel
  {
    var input_phases = valtable_obj.INPHASES ? valtable_obj.INPHASES : valtable_obj.EX_INP_NUMLINES,
    input_val = get_ph_1_3_vals(valtable_obj.INVOLT, valtable_obj.INCURR, valtable_obj.INFREQ, input_phases),
    fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, in_div;

    if (input_val.availables[0] == 0 & input_val.availables[1] == 0 & input_val.availables[2] == 0)
    return true;

    css_obj = { position: 'absolute', top: y_pos + 46, left: x_pos + 22 };

    in_div = $('<div/>', { id: 'input_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(in_div); // table-hover
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 4, align: 'left' }).append(i18n(lang_Input))).appendTo(thead);

    if (input_val.availables[0] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L1")).appendTo(tbody);
      if (!input_val.val_objs[0].values[0].empty())
      $('<td />', { id: 'input_volt1_id', align: 'left' }).append(input_val.val_objs[0].values[0]).appendTo(tr);

      if (!input_val.val_objs[1].values[0].empty())
      $('<td />', { id: 'input_cur1_id', align: 'left' }).append(input_val.val_objs[1].values[0]).appendTo(tr);

      if (!input_val.val_objs[2].values[0].empty())
      $('<td />', { id: 'input_freq1_id', align: 'left' }).append(input_val.val_objs[2].values[0]).appendTo(tr);
    }

    if (input_val.availables[1] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L2")).appendTo(tbody);
      if (!input_val.val_objs[0].values[1].empty())
      $('<td />', { id: 'input_volt2_id', align: 'left' }).append(input_val.val_objs[0].values[1]).appendTo(tr);

      if (!input_val.val_objs[1].values[1].empty())
      $('<td />', { id: 'input_cur2_id', align: 'left' }).append(input_val.val_objs[1].values[1]).appendTo(tr);
    }
    if (input_val.availables[2] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L3")).appendTo(tbody);
      if (!input_val.val_objs[0].values[2].empty())
      $('<td />', { id: 'input_volt3_id', align: 'left' }).append(input_val.val_objs[0].values[2]).appendTo(tr);

      if (!input_val.val_objs[1].values[2].empty())
      $('<td />', { id: 'input_cur3_id', align: 'left' }).append(input_val.val_objs[1].values[2]).appendTo(tr);
    }

    //if(valtable_obj.EX_INP_WATT != null)
    if (is_salisec) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Power'))).appendTo(tbody);
      $('<td />', { id: 'inp_power_0_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_INP_WATT, index: 0, unit: ' W', precision: 0 })).appendTo(tr);

      $('<td />', { id: 'inp_power_1_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_INP_WATT, index: 1, unit: ' W', precision: 0 })).appendTo(tr);

      $('<td />', { id: 'inp_power_2_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_INP_WATT, index: 2, unit: ' W', precision: 0 })).appendTo(tr);
    }

    //if(valtable_obj.EX_INP_LINEBADS != null)
    if (is_salisec) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Inp. bads'))).appendTo(tbody);
      $('<td />', { id: 'inp_linebads_id', align: 'left' }).
      append(get_value({ values: [valtable_obj.EX_INP_LINEBADS], index: 0, unit: '', precision: 0 })).appendTo(tr);
    }

    fragment.appendChild(in_div[0]);
    document.body.appendChild(fragment);
  }

  function set_input_values() {

    var input_phases = valtable_obj.INPHASES ? valtable_obj.INPHASES : valtable_obj.EX_INP_NUMLINES,
    input_val = get_ph_1_3_vals(valtable_obj.INVOLT, valtable_obj.INCURR, valtable_obj.INFREQ, input_phases);

    if (input_val.availables[0] != 0) {
      $('#input_volt1_id').text(input_val.val_objs[0].values[0]);
      $('#input_cur1_id').text(input_val.val_objs[1].values[0]);
      $('#input_freq1_id').text(input_val.val_objs[2].values[0]);
    }
    if (input_val.availables[1] != 0) {
      $('#input_volt2_id').text(input_val.val_objs[0].values[1]);
      $('#input_cur2_id').text(input_val.val_objs[1].values[1]);
    }
    if (input_val.availables[2] != 0) {
      $('#input_volt3_id').text(input_val.val_objs[0].values[2]);
      $('#input_cur3_id').text(input_val.val_objs[1].values[2]);
    }
    //if(valtable_obj.EX_INP_WATT != null)
    if (is_salisec) {
      $('#inp_power_0_id').text(get_value({ values: valtable_obj.EX_INP_WATT, index: 0, unit: ' W', precision: 0 }));
      $('#inp_power_1_id').text(get_value({ values: valtable_obj.EX_INP_WATT, index: 1, unit: ' W', precision: 0 }));
      $('#inp_power_2_id').text(get_value({ values: valtable_obj.EX_INP_WATT, index: 2, unit: ' W', precision: 0 }));
    }
    //if(valtable_obj.EX_INP_LINEBADS!= 0)
    if (is_salisec) {
      $('#inp_linebads_id').text(get_value({ values: [valtable_obj.EX_INP_LINEBADS], index: 0, unit: '', precision: 0 }));
    }
  }

  function create_output_panel() //Output panel
  {
    var output_phases = valtable_obj.OUTPHASES ? valtable_obj.OUTPHASES : valtable_obj.EX_OUT_NUMLINES,
    output_val = get_ph_1_3_vals(valtable_obj.OUTPUT_VOLT, valtable_obj.EX_OUT_CURR, valtable_obj.OUTFREQ, output_phases),
    output_div = null,
    val, tr, table, tbody, thead,
    fragment = document.createDocumentFragment();
    if (output_val.availables[0] == 0 & output_val.availables[1] == 0 & output_val.availables[2] == 0)
    return true;

    css_obj = { position: 'absolute', top: y_pos + 46, left: x_pos + 560 };

    output_div = $('<div/>', { id: 'output_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(output_div);

    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).append(i18n(lang_Output))).appendTo(thead);

    if (output_val.availables[0] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L1")).appendTo(tbody);
      if (!output_val.val_objs[0].values[0].empty())
      $('<td />', { 'id': 'out_volt1_id', align: 'left' }).append(output_val.val_objs[0].values[0]).appendTo(tr);

      if (!output_val.val_objs[1].values[0].empty())
      $('<td />', { id: 'out_cur1_id', align: 'left' }).append(output_val.val_objs[1].values[0]).appendTo(tr);

      if (!output_val.val_objs[2].values[0].empty())
      $('<td />', { id: 'out_freq1_id', align: 'left' }).append(output_val.val_objs[2].values[0]).appendTo(tr);
    }
    if (output_val.availables[1] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L2")).appendTo(tbody);
      if (!output_val.val_objs[0].values[1].empty())
      $('<td />', { id: 'out_volt2_id', align: 'left' }).append(output_val.val_objs[0].values[1]).appendTo(tr);

      if (!output_val.val_objs[1].values[1].empty())
      $('<td />', { id: 'out_cur2_id', align: 'left' }).append(output_val.val_objs[1].values[1]).appendTo(tr);
    }
    if (output_val.availables[2] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L3")).appendTo(tbody);
      if (!output_val.val_objs[0].values[2].empty())
      $('<td />', { id: 'out_volt3_id', align: 'left' }).append(output_val.val_objs[0].values[2]).appendTo(tr);

      if (!output_val.val_objs[1].values[2].empty())
      $('<td />', { id: 'out_cur3_id', align: 'left' }).append(output_val.val_objs[1].values[2]).appendTo(tr);
    }

    //if(valtable_obj.EX_OUT_WATT != null)
    if (is_salisec) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Power'))).appendTo(tbody);
      $('<td />', { id: 'out_power_0_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_OUT_WATT, index: 0, unit: ' W', precision: 0 })).appendTo(tr);

      $('<td />', { id: 'out_power_1_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_OUT_WATT, index: 1, unit: ' W', precision: 0 })).appendTo(tr);

      $('<td />', { id: 'out_power_2_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_OUT_WATT, index: 2, unit: ' W', precision: 0 })).appendTo(tr);
    }

    if (!is_salisec) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Static Switch'))).appendTo(tbody); //Static Switch
      $('<td />', { id: 'out_static_switch_id', align: 'left' }).append(get_out_static_switch()).appendTo(tr);
    }

    fragment.appendChild(output_div[0]);
    document.body.appendChild(fragment);
  }

  function set_output_values() //Set Output values
  {
    var output_phases = valtable_obj.OUTPHASES ? valtable_obj.OUTPHASES : valtable_obj.EX_OUT_NUMLINES,
    output_val = get_ph_1_3_vals(valtable_obj.OUTPUT_VOLT, valtable_obj.EX_OUT_CURR, valtable_obj.OUTFREQ, output_phases);

    if (output_val.availables[0] != 0) {
      $('#out_volt1_id').text(output_val.val_objs[0].values[0]);
      $('#out_cur1_id').text(output_val.val_objs[1].values[0]);
      $('#out_freq1_id').text(output_val.val_objs[2].values[0]);
    }
    if (output_val.availables[1] != 0) {
      $('#out_volt2_id').text(output_val.val_objs[0].values[1]);
      $('#out_cur2_id').text(output_val.val_objs[1].values[1]);
    }
    if (output_val.availables[2] != 0) {
      $('#out_volt3_id').text(output_val.val_objs[0].values[2]);
      $('#out_cur3_id').text(output_val.val_objs[1].values[2]);
    }
    //if(valtable_obj.EX_OUT_WATT != null)
    if (is_salisec) {
      $('#out_power_0_id').text(get_value({ values: valtable_obj.EX_OUT_WATT, index: 0, unit: ' W', precision: 0 }));
      $('#out_power_1_id').text(get_value({ values: valtable_obj.EX_OUT_WATT, index: 1, unit: ' W', precision: 0 }));
      $('#out_power_2_id').text(get_value({ values: valtable_obj.EX_OUT_WATT, index: 2, unit: ' W', precision: 0 }));
    }
    if (!is_salisec)
    $('#out_static_switch_id').text(get_out_static_switch()); //Static Switch
  }

  function create_bypass_panel() //Bypass panel
  {
    var tr, td, table, tbody, thead, batt_div, img, obj,
    fragment = document.createDocumentFragment(),
    bypass_val;
    if (valtable_obj.EX_BYP_VOLT != null && valtable_obj.EX_BYP_CURR != null &&
      valtable_obj.EX_BYP_FREQ != null && valtable_obj.EX_BYP_NUMLINES)
    bypass_val = get_ph_1_3_vals(valtable_obj.EX_BYP_VOLT, valtable_obj.EX_BYP_CURR, valtable_obj.EX_BYP_FREQ, valtable_obj.EX_BYP_NUMLINES);
    else {
      bypass_val = get_ph_1_3_vals(valtable_obj.BP_VOLT, valtable_obj.BP_CURRENT, valtable_obj.BP_FREQ, valtable_obj.INPHASES);
    }

    css_obj = { position: 'absolute', top: y_pos + 46, left: x_pos + 242 };
    if (is_salisec)
    css_obj.left = 316;
    attr_obj = { id: 'bypass_div_id' };
    bypass_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(bypass_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { align: 'left', colspan: 4 }).append(i18n(lang_Bypass))).appendTo(thead);

    if (bypass_val.availables[0] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L1")).appendTo(tbody);
      if (!bypass_val.val_objs[0].values[0].empty())
      $('<td />', { 'id': 'byp_volt1_id', align: 'left' }).append(bypass_val.val_objs[0].values[0]).appendTo(tr);

      if (!bypass_val.val_objs[1].values[0].empty())
      $('<td />', { id: 'byp_cur1_id', align: 'left' }).append(bypass_val.val_objs[1].values[0]).appendTo(tr);

      if (!bypass_val.val_objs[2].values[0].empty())
      $('<td />', { id: 'byp_freq1_id', align: 'left' }).append(bypass_val.val_objs[2].values[0]).appendTo(tr);
    }

    if (bypass_val.availables[1] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L2")).appendTo(tbody);
      if (!bypass_val.val_objs[0].values[1].empty())
      $('<td />', { id: 'byp_volt2_id', align: 'left' }).append(bypass_val.val_objs[0].values[1]).appendTo(tr);

      if (!bypass_val.val_objs[1].values[1].empty())
      $('<td />', { id: 'byp_cur2_id' }).append(bypass_val.val_objs[1].values[1]).appendTo(tr);
    }

    if (bypass_val.availables[2] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L3")).appendTo(tbody);
      if (!bypass_val.val_objs[0].values[2].empty())
      $('<td />', { id: 'byp_volt3_id', align: 'left' }).append(bypass_val.val_objs[0].values[2]).appendTo(tr);

      if (!bypass_val.val_objs[1].values[2].empty())
      $('<td />', { id: 'byp_cur3_id', align: 'left' }).append(bypass_val.val_objs[1].values[2]).appendTo(tr);
    }

    //if(valtable_obj.EX_BYP_WATT != null)
    if (is_salisec) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Power'))).appendTo(tbody);
      $('<td />', { id: 'byp_power_0_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_BYP_WATT, index: 0, unit: ' W', precision: 0 })).appendTo(tr);

      $('<td />', { id: 'byp_power_1_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_BYP_WATT, index: 1, unit: ' W', precision: 0 })).appendTo(tr);

      $('<td />', { id: 'byp_power_2_id', align: 'left' }).
      append(get_value({ values: valtable_obj.EX_BYP_WATT, index: 2, unit: ' W', precision: 0 })).appendTo(tr);
    }

    if (!is_salisec) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Bypass Breaker'))).appendTo(tbody);
      $('<td />', { id: 'byp_breaker_id', align: 'left' }).append(get_byp_breaker_status()).appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Bypass AC Power'))).appendTo(tbody);
      td = $('<td />').appendTo(tr);
      obj = get_byp_ac_power_status();
      img = $('<img />').attr({ 'id': 'byp_ac_power_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);


      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Inverter Operating'))).appendTo(tbody);
      td = $('<td />').appendTo(tr);
      obj = get_inverter_operating_status();
      img = $('<img />').attr({ 'id': 'byp_inv_operating_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Bypass Frequency Fail'))).appendTo(tbody);
      td = $('<td />').appendTo(tr);
      obj = get_bypass_status(4);
      img = $('<img />').attr({ 'id': 'byp_freq_fail_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);
    }

    fragment.appendChild(bypass_div[0]);
    document.body.appendChild(fragment);
  }

  function set_bypass() // set Bypass panel
  {
    var img, obj, bypass_val;

    if (!is_salisec) {
      obj = get_bypass_status(4);
      img = $('#byp_freq_fail_id');
      img.attr({ src: obj.src, title: obj.title });

      obj = get_inverter_operating_status();
      img = $('#byp_inv_operating_id');
      img.attr({ src: obj.src, title: obj.title });

      obj = get_byp_ac_power_status();
      img = $('#byp_ac_power_id');
      img.attr({ src: obj.src, title: obj.title });
      $('#byp_breaker_id').text(get_byp_breaker_status());
    }

    if (valtable_obj.EX_BYP_VOLT != null && valtable_obj.EX_BYP_CURR != null &&
      valtable_obj.EX_BYP_FREQ != null && valtable_obj.EX_BYP_NUMLINES)
    bypass_val = get_ph_1_3_vals(valtable_obj.EX_BYP_VOLT, valtable_obj.EX_BYP_CURR, valtable_obj.EX_BYP_FREQ, valtable_obj.EX_BYP_NUMLINES);
    else
    bypass_val = get_ph_1_3_vals(valtable_obj.BP_VOLT, valtable_obj.BP_CURRENT, valtable_obj.BP_FREQ, valtable_obj.INPHASES);
    if (bypass_val.availables[0] != 0) {
      $('#byp_volt1_id').text(bypass_val.val_objs[0].values[0]);
      $('#byp_cur1_id').text(bypass_val.val_objs[1].values[0]);
      $('#byp_freq1_id').text(bypass_val.val_objs[2].values[0]);
    }
    if (bypass_val.availables[1] != 0) {
      $('#byp_volt2_id').text(bypass_val.val_objs[0].values[1]);
      $('#byp_cur2_id').text(bypass_val.val_objs[1].values[1]);
    }
    if (bypass_val.availables[2] != 0) {
      $('#byp_volt3_id').text(bypass_val.val_objs[0].values[2]);
      $('#byp_cur3_id').text(bypass_val.val_objs[1].values[2]);
    }
    //if(valtable_obj.EX_BYP_WATT != null)
    if (is_salisec) {
      $('#byp_power_0_id').text(get_value({ values: valtable_obj.EX_BYP_WATT, index: 0, unit: ' W', precision: 0 }));
      $('#byp_power_1_id').text(get_value({ values: valtable_obj.EX_BYP_WATT, index: 1, unit: ' W', precision: 0 }));
      $('#byp_power_2_id').text(get_value({ values: valtable_obj.EX_BYP_WATT, index: 2, unit: ' W', precision: 0 }));
    }
  }

  function create_battery_panel() //Battery panel
  {
    var tr, td, table, tbody, thead, batt_div, img, obj,
    fragment = document.createDocumentFragment();

    css_obj = { position: 'absolute', top: y_pos + 500, left: x_pos + 278 }; //, width:130, height:100
    if (is_salisec)
    css_obj.left = 322;
    attr_obj = { id: 'battery_div_id' };
    batt_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(batt_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { align: 'left', colspan: 2 }).append(i18n(lang_Battery) + ' ' + i18n('Status'))).appendTo(thead);

    if (!is_salisec) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Status'))).appendTo(tbody); //Battery Status
      td = $('<td />').appendTo(tr);
      obj = get_batt_status();
      img = $('<img />').attr({ 'id': 'batt_status_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Low Battery Shutdown'))).appendTo(tbody); //Low Battery Status
      td = $('<td />').appendTo(tr);
      obj = get_low_batt_shut();
      img = $('<img />').attr({ 'id': 'low_batt_shut_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Charge Status'))).appendTo(tbody); //Battery Charge Status
      $('<td />', { id: 'batt_charge_status_id', align: 'left' }).append(get_batt_charge_status()).appendTo(tr);
    }

    if ((valtable_obj.EX_BATT_VOLTPOS != null && valtable_obj.EX_BATT_VOLTNEG != null) &&
      (valtable_obj.EX_BATT_VOLTPOS != -9999 && valtable_obj.EX_BATT_VOLTNEG != -9999)) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append('Pos.' + i18n(lang_Voltage))).appendTo(tbody);
      $('<td />', { id: 'batt_volt_pos_id' }).
      append(get_value({ values: [valtable_obj.EX_BATT_VOLTPOS], index: 0, unit: ' V', precision: 1 })).appendTo(tr);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append('Neg.' + i18n(lang_Voltage))).appendTo(tbody);
      $('<td />', { id: 'batt_volt_neg_id' }).
      append(get_value({ values: [valtable_obj.EX_BATT_VOLTNEG], index: 0, unit: ' V', precision: 1 })).appendTo(tr);
    } else {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Voltage))).appendTo(tbody);
      $('<td />', { id: 'batt_volt_id', align: 'left' }).
      append(get_value({ values: [valtable_obj.BATTVOLT], index: 0, unit: ' V', precision: 0 })).appendTo(tr);
    }

    if (valtable_obj.MEGA3_RECT_STATE != null) {
      tr = $('<tr />').appendTo(tbody);
      td = $('<td />', { id: 'batt_curr_txt_id', align: 'left' }).appendTo(tr);
      if ((valtable_obj.MEGA3_RECT_STATE & (1 << 2)) == (1 << 2))
      td.append(i18n('Discharge') + ' ' + i18n(lang_Current));
      else
      td.append(i18n('Charge') + ' ' + i18n(lang_Current));

      $('<td />', { id: 'batt_curr_id', align: 'left' }).
      append(get_value({ values: [valtable_obj.BATT_CURR_A], index: 0, unit: ' A', precision: 1 })).appendTo(tr);
    } else if (valtable_obj.EX_BATT_CURRPOS != null) {
      tr = $('<tr />').appendTo(tbody);
      td = $('<td />', { id: 'batt_curr_txt_id', align: 'left' }).append(i18n(lang_Current)).appendTo(tr);
      $('<td />', { id: 'batt_curr_id', align: 'left' }).
      append(get_value({ values: [valtable_obj.EX_BATT_CURRPOS], index: 0, unit: ' A', precision: 1 })).appendTo(tr);
    }

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Time))).appendTo(tbody);
    $('<td />', { id: 'batt_autotime_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.AUTONOMTIME], index: 0, unit: ' Min', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Battery_Capacity_short))).appendTo(tbody);
    $('<td />', { id: 'batt_cap_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.BATTCAP], index: 0, unit: ' %', precision: 0 })).appendTo(tr);

    if (valtable_obj.EX_BATT_SECONBATT != null) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Seconds'))).appendTo(tbody);
      $('<td />', { id: 'batt_seconds_id', align: 'left' }).
      append(get_value({ values: [valtable_obj.EX_BATT_SECONBATT], index: 0, unit: ' Sec', precision: 0 })).appendTo(tr);
    }
    fragment.appendChild(batt_div[0]);
    document.body.appendChild(fragment);
  }

  function set_battery() //set Battery panel
  {
    var img, obj;

    if (!is_salisec) {
      obj = get_batt_status();
      img = $('#batt_status_id');
      img.attr({ src: obj.src, title: obj.title }); //Battery Status

      obj = get_low_batt_shut();
      img = $('#low_batt_shut_img_id');
      img.attr({ src: obj.src, title: obj.title }); //Low Battery Status

      $('#batt_charge_status_id').text(get_batt_charge_status()); //Battery Charge Status
    }

    if ((valtable_obj.EX_BATT_VOLTPOS != null && valtable_obj.EX_BATT_VOLTNEG != null) &&
      (valtable_obj.EX_BATT_VOLTPOS != -9999 && valtable_obj.EX_BATT_VOLTNEG != -9999)) {
      $('#batt_volt_pos_id').text(get_value({ values: [valtable_obj.EX_BATT_VOLTPOS], index: 0, unit: ' V', precision: 1 }));
      $('#batt_volt_neg_id').text(get_value({ values: [valtable_obj.EX_BATT_VOLTNEG], index: 0, unit: ' V', precision: 1 }));
    } else
    $('#batt_volt_id').text(get_value({ values: [valtable_obj.BATTVOLT], index: 0, unit: ' V', precision: 0 }));

    if (valtable_obj.MEGA3_RECT_STATE != null) {
      if ((valtable_obj.MEGA3_RECT_STATE & (1 << 2)) == (1 << 2))
      $('#batt_curr_txt_id').text(i18n('Discharge') + ' ' + i18n(lang_Current));
      else
      $('#batt_curr_txt_id').text(i18n('Charge') + ' ' + i18n(lang_Current));

      $('#batt_curr_id').text(get_value({ values: [valtable_obj.BATT_CURR_A], index: 0, unit: ' A', precision: 1 }));
    } else if (valtable_obj.EX_BATT_CURRPOS != null) {
      $('#batt_curr_id').text(get_value({ values: [valtable_obj.EX_BATT_CURRPOS], index: 0, unit: ' A', precision: 1 }));
    }


    $('#batt_autotime_id').text(get_value({ values: [valtable_obj.AUTONOMTIME], index: 0, unit: ' Min', precision: 0 }));
    $('#batt_cap_id').text(get_value({ values: [valtable_obj.BATTCAP], index: 0, unit: ' %', precision: 0 }));

    if (valtable_obj.EX_BATT_SECONBATT != null)
    $('#batt_seconds_id').text(get_value({ values: [valtable_obj.EX_BATT_SECONBATT], index: 0, unit: ' Sec', precision: 0 }));
  }


  function create_inverter_panel() //Inverter panel
  {
    var tr, td, table, tbody, thead, batt_div, img, obj,
    fragment = document.createDocumentFragment();

    if (is_salisec)
    return true;

    css_obj = { position: 'absolute', top: y_pos + 500, left: x_pos + 560 }; //, width:130, height:100
    attr_obj = { id: 'inverter_div_id' };
    batt_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(batt_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { align: 'left', colspan: 2 }).append(lang_Inverter + ' Status')).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Emergency Stop (EPO)'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_inverter_status(6);
    img = $('<img />').attr({ 'id': 'inv_emergency_stop_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('High DC Shutdown'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_inverter_status(5);
    img = $('<img />').attr({ 'id': 'inv_high_dc_shut_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Bypass Breaker on Shutdown'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_inverter_status(4);
    img = $('<img />').attr({ 'id': 'inv_byp_breaker_shut_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Over Load Shutdown'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_inverter_status(3);
    img = $('<img />').attr({ 'id': 'inv_overload_shut_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Inverter O/P Fail Shutdown'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_inverter_status(2);
    img = $('<img />').attr({ 'id': 'inv_op_fail_shut_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Over Temperature Shutdown'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_inverter_status(1);
    img = $('<img />').attr({ 'id': 'inv_overtemp_shut_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Short Circuit Shutdown'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_inverter_status(0);
    img = $('<img />').attr({ 'id': 'inv_short_circuit_shut_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    fragment.appendChild(batt_div[0]);
    document.body.appendChild(fragment);
  }

  function set_inverter() //Set Inverter
  {
    var img, obj;

    if (is_salisec)
    return true;

    obj = get_inverter_status(6);
    img = $('#inv_emergency_stop_id');
    img.attr({ src: obj.src, title: obj.title });

    obj = get_inverter_status(5);
    img = $('#inv_high_dc_shut_img_id');
    img.attr({ src: obj.src, title: obj.title });

    obj = get_inverter_status(4);
    img = $('#inv_byp_breaker_shut_img_id');
    img.attr({ src: obj.src, title: obj.title });

    obj = get_inverter_status(3);
    img = $('#inv_overload_shut_img_id');
    img.attr({ src: obj.src, title: obj.title });

    obj = get_inverter_status(2);
    img = $('#inv_op_fail_shut_img_id');
    img.attr({ src: obj.src, title: obj.title });

    obj = get_inverter_status(1);
    img = $('#inv_overtemp_shut_img_id');
    img.attr({ src: obj.src, title: obj.title });

    obj = get_inverter_status(0);
    img = $('#inv_short_circuit_shut_img_id');
    img.attr({ src: obj.src, title: obj.title });
  }

  function create_rectifier_panel() //Rectifier panel
  {

    var tr, td, table, tbody, thead, batt_div, img, obj,
    fragment = document.createDocumentFragment();

    if (is_salisec)
    return true;

    css_obj = { position: 'absolute', top: y_pos + 500, left: x_pos + 22 };
    attr_obj = { id: 'rectifier_div_id' };
    rectifier_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(rectifier_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { align: 'left', colspan: 2 }).append(i18n(lang_Rectifier) + ' ' + i18n('Status'))).appendTo(thead);


    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Rectifier Operating'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_rect_operating_status();
    img = $('<img />').attr({ 'id': 'rect_operating_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Rotation Error'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_rect_rot_err_status();
    img = $('<img />').attr({ 'id': 'rect_rot_err_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Power Status'))).appendTo(tbody);
    $('<td />', { id: 'rect_power_status_id' }).append(get_rect_power_status()).appendTo(tr);

    fragment.appendChild(rectifier_div[0]);
    document.body.appendChild(fragment);
  }

  function set_rectifier() //Rectifier status
  {
    var img, obj;

    if (is_salisec)
    return true;

    obj = get_rect_operating_status();
    $('#rect_operating_img_id').attr({ src: obj.src, title: obj.title });

    obj = get_rect_rot_err_status();
    $('#rect_rot_err_img_id').attr({ src: obj.src, title: obj.title });

    $('#rect_power_status_id').text(get_rect_power_status());
  }

  function get_rect_operating_status() {
    var bit_val = 1;
    if ((valtable_obj.MEGA3_RECT_STATE & bit_val) == bit_val)
    return { src: './image/bacs2/b_green.gif', title: 'Yes' };
    return { src: './image/bacs2/b_red.gif', title: 'No' };
  }

  function get_rect_power_status() {
    var bit_val = 1 << 2;
    if ((valtable_obj.MEGA3_RECT_STATE & bit_val) == bit_val)
    return i18n('Back Up');
    return 'AC ' + i18n('Normal');
  }

  function get_out_static_switch() {
    var bit_val = 1 << 1;
    if ((valtable_obj.MEGA3_UPS_STATE & bit_val) == bit_val)
    return i18n('Inverter');
    return i18n('Bypass');
  }


  function get_rect_rot_err_status() {
    var bit_val = 1 << 6;
    if ((valtable_obj.MEGA3_RECT_STATE & bit_val) == bit_val)
    return { src: './image/bacs2/b_red.gif', title: 'Yes' };
    return { src: './image/bacs2/b_grey.gif', title: 'No' };
  }

  function get_bypass_status(bit) {
    var bit_val = 1 << bit;
    if ((valtable_obj.MEGA3_INV_STATE & bit_val) == bit_val)
    return { src: './image/bacs2/b_red.gif', title: 'Yes' };
    return { src: './image/bacs2/b_grey.gif', title: 'No' };
  }

  function get_inverter_operating_status() {
    var bit_val = 1;
    if ((valtable_obj.MEGA3_UPS_STATE & bit_val) == bit_val)
    return { src: './image/bacs2/b_green.gif', title: 'Yes' };
    return { src: './image/bacs2/b_red.gif', title: 'No' };
  }

  function get_inverter_status(bit) {
    var bit_val = 1 << bit;
    if ((valtable_obj.MEGA3_INV_STATE & bit_val) == bit_val)
    return { src: './image/bacs2/b_red.gif', title: 'Yes' };
    return { src: './image/bacs2/b_grey.gif', title: 'No' };
  }

  function get_batt_status() {
    var bit_val = 1 << 4;
    if ((valtable_obj.MEGA3_RECT_STATE & bit_val) == bit_val)
    return { src: './image/bacs2/b_red.gif', title: 'Low Battery' };
    return { src: './image/bacs2/b_green.gif', title: 'Battery Normal' };
  }

  function get_low_batt_shut() {
    var bit_val = 1 << 5;
    if ((valtable_obj.MEGA3_RECT_STATE & bit_val) == bit_val)
    return { src: './image/bacs2/b_red.gif', title: i18n('Yes') };
    return { src: './image/bacs2/b_grey.gif', title: i18n('No') };
  }

  function get_batt_charge_status() {
    var bit_val = 1 << 1;
    if ((valtable_obj.MEGA3_RECT_STATE & bit_val) == bit_val)
    return i18n('Boost Charge');
    return i18n('Float Charge');
  }

  function get_byp_breaker_status() {
    var bit_val = 1 << 3;
    if ((valtable_obj.MEGA3_UPS_STATE & bit_val) == bit_val)
    return i18n('On');
    return i18n('Open');
  }

  function get_byp_ac_power_status() {

    var bit_val = 1 << 2;
    if ((valtable_obj.MEGA3_UPS_STATE & bit_val) == bit_val)
    return { src: './image/bacs2/b_green.gif', title: 'Normal' };
    return { src: './image/bacs2/b_red.gif', title: 'Abnormal' };
  }


  function get_bg_img() {
    var bit_val;

    if (_oemViewName == 'mega3') {
      bit_val = 1 << 3; //powerfail
      if ((valtable_obj.STATUS & bit_val) == bit_val)
      return './image/mega/mega_bb.png';
      bit_val = 1 << 0; //bypass
      if ((valtable_obj.STATUS & bit_val) == bit_val)
      return './image/mega/mega_byb.png';
      /*bit_val = 1 << 3;//ext_bypass_betrieb
      if((valtable_obj.MEGA3_UPS_STATE & bit_val) == bit_val)
      	return './image/mega/mega_byb.png';*/
      bit_val = 1 << 6; //testact
      if ((valtable_obj.STATUS & bit_val) == bit_val)
      return './image/mega/mega_tb.png';
      bit_val = 1 << 2; //normal betrieb
      if ((valtable_obj.STATUS & bit_val) == bit_val)
      return './image/mega/mega_nb.png';
      return './image/mega/mega_3_4.png';
    } else if (_oemViewName == 'mega4') {
      bit_val = 1 << 3; //powerfail
      if ((valtable_obj.STATUS & bit_val) == bit_val)
      return './image/mega/mega4_bb.png';
      bit_val = 1 << 0; //bypass
      if ((valtable_obj.STATUS & bit_val) == bit_val)
      return './image/mega/mega4_byb.png';
      bit_val = 1 << 3; //ext_bypass_betrieb
      if ((valtable_obj.MEGA3_UPS_STATE & bit_val) == bit_val)
      return './image/mega/mega4_extbyb.png';
      bit_val = 1 << 6; //testact
      if ((valtable_obj.STATUS & bit_val) == bit_val)
      return './image/mega/mega4_tb.png';
      bit_val = 1 << 2; //normal betrieb
      if ((valtable_obj.STATUS & bit_val) == bit_val)
      return './image/mega/mega4_nb.png';
      return './image/mega/mega_3_4.png';
    }
    return './image/mega/mega_3_4.png';
  }

  function get_ph_1_3_vals(volt, cur, freq, phases) {
    var val_obj, val;
    l_1_3_vals = {
      availables: [0, 0, 0], //L1-L3
      val_objs: [
        { unit: ' V', precision: 0, values: ['', '', ''] },
        { unit: ' A', precision: 2, values: ['', '', ''] },
        { unit: ' Hz', precision: 2, values: ['', '', ''] }
      ]
    };
    volt = volt || [];
    cur = cur || [], freq = freq || [];
    $.each([volt, cur, freq], function (index, values) {
      val_obj = l_1_3_vals.val_objs[index];
      $.each(values, function (i, val) {
        if (i < phases) {
          val = values[i];
          if (val != -9999) {
            if (values === freq & (i == 1 || i == 2)) {

            } else
            l_1_3_vals.availables[i] = 1;

            if (Math.round(val) == val)
            val = val.toString();
            else
            val = val.toFixed(val_obj.precision);
            val += val_obj.unit;
            val_obj.values[i] = val;
          }
        }
      });
    });
    return l_1_3_vals;
  }

  function get_value(val_obj) {
    if (!val_obj.values || (val_obj.values.length <= val_obj.index))
    return 'N/A';
    var val = val_obj.values[val_obj.index];
    if (val == null || val_obj.values[val_obj.index] == -9999)
    return 'N/A';

    if (Math.round(val) == val)
    val = val.toString();
    else
    val = val.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }


  function create_model_panel() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 800 }; // 'background-color': '#3a87ad'
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active' }).append(valtable_obj.MODEL).appendTo(model_div);
  }

  function set_outpower_loadbars() //outpower loadbars
  {
    if (valtable_obj.OUTPOWER == null)
    return true;
    if (valtable_obj.OUTPOWER[0] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[0], 'loadbar1_id');
    if ((valtable_obj.OUTPHASES > 1) && valtable_obj.OUTPOWER[1] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[1], 'loadbar2_id');
    if ((valtable_obj.OUTPHASES > 2) && valtable_obj.OUTPOWER[2] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[2], 'loadbar3_id');
  }

  function create_outpower_loadbars() //outpower loadbars
  {
    if (valtable_obj.OUTPOWER == null)
    return true;
    outpower_loadbars_created = true;

    if (valtable_obj.OUTPOWER[0] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[0], id: 'loadbar1_id', left: x_pos + 568, top: y_pos + 396, title: 'L1', scaler: 1 });
    if ((valtable_obj.OUTPHASES > 1) && valtable_obj.OUTPOWER[1] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[1], id: 'loadbar2_id', left: x_pos + 568, top: y_pos + 428, title: 'L2', scaler: 0 });
    if ((valtable_obj.OUTPHASES > 2) && valtable_obj.OUTPOWER[2] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[2], id: 'loadbar3_id', left: x_pos + 568, top: y_pos + 460, title: 'L3', scaler: 0 });
  }

  function create_rom_temp() //rom temp
  {
    var fragment = document.createDocumentFragment(),
    rom_temp_div;
    css_obj = { position: 'absolute', top: y_pos + 316, left: x_pos + 22 };
    rom_temp_div = $('<div/>').attr({ id: 'rom_temp_div_id' }).css(css_obj);
    panes_api.create_rom_temp_pane(valtable_obj, { id: 'rom_temp_table_id', 'class': 'table table-condensed table-hover' }).appendTo(rom_temp_div);
    fragment.appendChild(rom_temp_div[0]);
    document.body.appendChild(fragment);
  }

}(jQuery));