/*
   rectifier_panel.js - rectifier screen.
   Copyright (c) 2013, Generex GmbH. All rights reserved.
   Said.
*/

var rectifier_api = (function ($) {

  var oid = get_oid_from_url(),
  pannes_created = false,
  check_bowser = true,
  err_div = null,
  css_obj, attr_obj,
  valtable_obj, report_obj, unms_obj,
  cb = null,
  inphases = null,
  outphases = null,
  status, tempmax, tempdeg,
  x_pos = 10,
  y_pos = 10;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: 10, left: 10, width: 698, display: 'none', 'z-index': 10 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function update(data) {
    if (data.length == 0) {
      return;
    }

    set_variable(data);
    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }
    set_input_values(); ////Input values
    set_battery_values(); //Battery value
    set_rectifier_value(); //set rectifier values
    set_iby_ire_inv_rec_batt(); //SET IBY, IRE, SSI, INVERTER, RECTIFIER and BATTERY	pannes
    set_ups_status(); //set UPS status
    //if(valtable_obj._platform !== "ups_view")
    panes_api.set_rom_temp_values(valtable_obj); //set rom temp values
    set_footer();
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
      }, { //css
        position: 'absolute',
        top: '390px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function set_variable(data) {
    valtable_obj = data.ups.valtable;
    report_obj = data.report;

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    status = valtable_obj.STATUS;
    tempmax = valtable_obj.TMPMAX;
    tempdeg = valtable_obj.TEMPDEG;
    level = valtable_obj.LEVEL;

    if (valtable_obj.INPHASES != null)
    inphases = valtable_obj.INPHASES;
    else
    inphases = valtable_obj.PHASES;

    if (valtable_obj.OUTPHASES != null)
    outphases = valtable_obj.OUTPHASES;
    else
    outphases = valtable_obj.PHASES;
  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_bg(); //background
    create_input_pane(); //Input table
    create_battery_pane(); //Battery panel
    create_rectifier_pane(); //create Rectifier panel
    create_iby_ire_inv_batt(); //create IBY, IRE, RECTIFIER and BATTERY	pannes
    create_status_pane(); //UPS status
    create_model_panes();
    if (valtable_obj._platform !== "ups_view")
    create_rom_temp(); //rom temp
    create_footer_pane();
  }


  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 698, height: 348, border: 'solid 1px #808080' };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'bg_img_id', 'class': 'img-rounded', width: 696, 'height': 346, src: './image/ups/rectifier.png' }).appendTo(img_div);
    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function create_model_panes() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 698 }; // 'background-color': '#3a87ad'
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active' }).append(valtable_obj.MODEL).appendTo(model_div);
  }




  function create_input_pane() //Input table
  {
    var input_val = get_ph_1_3_vals(valtable_obj.INVOLT, valtable_obj.INCURR, valtable_obj.INFREQ, inphases),
    fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, in_div;

    if (input_val.availables[0] == 0 & input_val.availables[1] == 0 & input_val.availables[2] == 0)
    return true;

    css_obj = { position: 'absolute', top: y_pos + 86, left: x_pos + 8 };

    attr_obj = { id: 'input_div_id' };
    in_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(in_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 3 }).append(lang_Input)).appendTo(thead);

    if (inphases == 1)
    table.css('margin-top', '18px');

    if (input_val.availables[0] != 0) {
      tr = $('<tr />').append($('<td />').append("L1:")).appendTo(tbody);
      if (!input_val.val_objs[0].values[0].empty())
      $('<td />', { id: 'input_volt1_id' }).append(input_val.val_objs[0].values[0]).appendTo(tr);

      if (!input_val.val_objs[1].values[0].empty())
      $('<td />', { id: 'input_cur1_id' }).append(input_val.val_objs[1].values[0]).appendTo(tr);

      if (!input_val.val_objs[2].values[0].empty())
      $('<td />', { id: 'input_freq1_id' }).append(input_val.val_objs[2].values[0]).appendTo(tr);

    }
    if (input_val.availables[1] != 0) {
      tr = $('<tr />').append($('<td />').append("L2:")).appendTo(tbody);
      if (!input_val.val_objs[0].values[1].empty())
      $('<td />', { id: 'input_volt2_id' }).append(input_val.val_objs[0].values[1]).appendTo(tr);

      if (!input_val.val_objs[1].values[1].empty())
      $('<td />', { id: 'input_cur2_id' }).append(input_val.val_objs[1].values[1]).appendTo(tr);
    }
    if (input_val.availables[2] != 0) {
      tr = $('<tr />').append($('<td />').append("L3:")).appendTo(tbody);
      if (!input_val.val_objs[0].values[2].empty())
      $('<td />', { id: 'input_volt3_id' }).append(input_val.val_objs[0].values[2]).appendTo(tr);

      if (!input_val.val_objs[1].values[2].empty())
      $('<td />', { id: 'input_cur3_id' }).append(input_val.val_objs[1].values[2]).appendTo(tr);
    }

    fragment.appendChild(in_div[0]);
    document.body.appendChild(fragment);
  }

  function set_input_values() {
    var input_val = get_ph_1_3_vals(valtable_obj.INVOLT, valtable_obj.INCURR, valtable_obj.INFREQ, inphases);
    if (input_val.availables[0] == 0 & input_val.availables[1] == 0 & input_val.availables[2] == 0)
    return true;

    if (input_val.availables[0] != 0) {
      $('#input_volt1_id').text(input_val.val_objs[0].values[0]);
      $('#input_cur1_id').text(input_val.val_objs[1].values[0]);
      $('#input_freq1_id').text(input_val.val_objs[2].values[0]);
    }
    if (input_val.availables[1] != 0) {
      $('#input_volt2_id').text(input_val.val_objs[0].values[1]);
      $('#input_cur2_id').text(input_val.val_objs[1].values[1]);
    }
    if (input_val.availables[2] != 0) {
      $('#input_volt3_id').text(input_val.val_objs[0].values[2]);
      $('#input_cur3_id').text(input_val.val_objs[1].values[2]);
    }
  }

  function create_rectifier_pane() //create Rectifier panel
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, rec_div;

    css_obj = { position: 'absolute', top: y_pos + 180, left: x_pos + 302, align: 'center', overflow: 'hidden' };

    rec_div = $('<div/>').attr({ id: 'rectifier_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(rec_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 3 }).append(lang_Rectifier)).appendTo(thead);

    tr = $('<tr />').append($('<td />').append(lang_Voltage + ":")).appendTo(tbody);
    $('<td />', { id: 'rec_volt_id' }).
    append(get_value({ values: valtable_obj.OUTPUT_VOLT, index: 0, unit: ' V', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />').append(lang_Current + ":")).appendTo(tbody);
    $('<td />', { id: 'rec_cur_id' }).
    append(get_value({ values: valtable_obj.EX_OUT_CURR, index: 0, unit: ' A', precision: 2 })).appendTo(tr);

    fragment.appendChild(rec_div[0]);
    document.body.appendChild(fragment);
  }

  function set_rectifier_value() //set rectifier values
  {
    $('#rec_volt_id').text(get_value({ values: valtable_obj.OUTPUT_VOLT, index: 0, unit: ' V', precision: 0 }));
    $('#rec_cur_id').text(get_value({ values: valtable_obj.EX_OUT_CURR, index: 0, unit: ' A', precision: 0 }));
  }


  function create_battery_pane() //create battery panel
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, batt_div;

    css_obj = { position: 'absolute', top: y_pos + 180, left: x_pos + 432, align: 'center', overflow: 'hidden' };
    batt_div = $('<div/>').attr({ id: 'battery_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(batt_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 3 }).append(lang_Battery)).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(lang_Voltage + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_volt_id' }).
    append(get_value({ values: [valtable_obj.BATTVOLT], index: 0, unit: ' V', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(lang_Current + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_cur_id' }).
    append(get_value({ values: [valtable_obj.EX_BATT_CURRPOS], index: 0, unit: ' A', precision: 2 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(lang_Temperature_short + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_temp_id' }).
    append(get_value({ values: [valtable_obj.TEMPDEG], index: 0, unit: ' &#176;C', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(lang_ChargeMode + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_chargemode_id' }).
    append(get_batt_chargemode()).appendTo(tr);

    fragment.appendChild(batt_div[0]);
    document.body.appendChild(fragment);
  }

  function set_battery_values() //set Battery values
  {
    $('#batt_volt_id').text(get_value({ values: [valtable_obj.BATTVOLT], index: 0, unit: ' V', precision: 0 }));
    $('#batt_cur_id').text(get_value({ values: [valtable_obj.EX_BATT_CURRPOS], index: 0, unit: ' A', precision: 0 }));
    $('#batt_temp_id').html(get_value({ values: [valtable_obj.TEMPDEG], index: 0, unit: ' &#176;C', precision: 0 }));
    $('#batt_chargemode_id').text(get_batt_chargemode());
  }

  function get_batt_chargemode() {
    if (valtable_obj.EX_OUT_SOURCE == 0)
    return lang_Automatic;
    if (valtable_obj.EX_OUT_SOURCE == 1)
    return lang_Float;
    if (valtable_obj.EX_OUT_SOURCE == 2)
    return lang_Equalize;
    if (valtable_obj.EX_OUT_SOURCE == 3)
    return lang_Boost;
    return 'N/A';
  }

  function create_iby_ire_inv_batt() //create IBY, IRE, RECTIFIER and BATTERY pannes
  {
    var div, fragment = document.createDocumentFragment();
    css_obj = { position: 'absolute', top: y_pos + 133, left: x_pos + 548, width: 24, height: 10, overflow: 'hidden' };

    if ((status & 16384) != 16384 && (status & 4) != 4) //IBY commlost and active
    css_obj['background-color'] = '#DC3632'; //red
    else
    css_obj['background-color'] = 'rgb(40, 134, 59)'; //green
    div = $('<div/>').attr({ id: 'iby_div_id', 'class': 'img-rounded' }).css(css_obj);
    fragment.appendChild(div[0]);

    css_obj = { position: 'absolute', top: y_pos + 133, left: x_pos + 220, width: 24, height: 10, overflow: 'hidden' };
    if ((status & 8) == 8 || (status & 128) == 128) //IRE powerfail or input-high
    css_obj['background-color'] = '#DC3632'; //red
    else
    css_obj['background-color'] = 'rgb(40, 134, 59)'; //green
    div = $('<div/>').attr({ id: 'ire_div_id', 'class': 'img-rounded' }).css(css_obj);
    fragment.appendChild(div[0]);

    document.body.appendChild(fragment);


    if ((status & 8) == 8) //RECTIFIER powerfail
    panes_api.create_img_panel('rec_img_id', './image/ups/grw.gif', y_pos + 296, x_pos + 114, 50, 50, 0);
    else
    panes_api.create_img_panel('rec_img_id', './image/ups/grgr.gif', y_pos + 296, x_pos + 114, 50, 50, 0);

    if ((status & 8) == 8) //BATTERY powerfail
    panes_api.create_img_panel('batt_img_id', './image/ups/Batgrv.gif', y_pos + 426, x_pos + 114, 50, 50, 0);
    else if ((status & 16) == 16 || (status & 1024) == 1024) // batterylow batterybad
    panes_api.create_img_panel('batt_img_id', './image/ups/Batrv.gif', y_pos + 426, x_pos + 114, 50, 50, 0);
    else
    panes_api.create_img_panel('batt_img_id', './image/ups/Batgev.gif', y_pos + 426, x_pos + 114, 50, 50, 0);
  }

  function set_iby_ire_inv_rec_batt() //set values
  {
    if ((status & 16384) != 16384 && (status & 4) != 4) //IBY commlost and active
    $('#iby_div_id').css('background-color', '#DC3632'); //red
    else
    $('#iby_div_id').css('background-color', 'rgb(40, 134, 59)'); //green


    if ((status & 8) == 8 || (status & 128) == 128) //IRE powerfail or input-high
    $('#ire_div_id').css('background-color', '#DC3632'); //red
    else
    $('#ire_div_id').css('background-color', 'rgb(40, 134, 59)'); //green

    if ((status & 8) == 8) //RECTIFIER powerfail
    $('#rec_img_id').attr('src', './image/ups/grw.gif');
    else
    $('#rec_img_id').attr('src', './image/ups/grgr.gif');

    if ((status & 8) == 8) //BATTERY powerfail
    $('#batt_img_id').attr('src', './image/ups/Batgrv.gif');
    else if ((status & 16) == 16 || (status & 1024) == 1024) // batterylow batterybad
    $('#batt_img_id').attr('src', './image/ups/Batrv.gif');
    else
    $('#batt_img_id').attr('src', './image/ups/Batgev.gif');
  }

  function create_status_pane() //UPS status
  {
    var status_div = $('<div/>');
    css_obj = { position: 'absolute', top: y_pos + 46, left: x_pos + 600, align: 'center', overflow: 'hidden' };
    $(status_div).css(css_obj);
    $('<h4 />').append($('<span />', { id: 'ups_status_id', 'class': get_status_class() }).append('Status')).appendTo(status_div);
    status_div.appendTo(document.body);
  }

  function set_ups_status() //set UPS status
  {
    $('#ups_status_id').attr('class', get_status_class());
  }

  function get_status_class() {
    if (status == 4)
    return 'label label-success';
    else
    return 'label label-danger';
  }

  function create_rom_temp() //rom temp
  {
    var fragment = document.createDocumentFragment(),
    rom_temp_div;
    css_obj = { position: 'absolute', top: y_pos + 216, left: x_pos + 8 };
    rom_temp_div = $('<div/>').attr({ id: 'rom_temp_div_id' }).css(css_obj);
    panes_api.create_rom_temp_pane(valtable_obj, { id: 'rom_temp_table_id', 'class': 'table table-condensed table-hover' }).appendTo(rom_temp_div);
    fragment.appendChild(rom_temp_div[0]);
    document.body.appendChild(fragment);
  }

  function get_ph_1_3_vals(volt, cur, freq, phases) {
    var val_obj, val;
    l_1_3_vals = {
      availables: [0, 0, 0], //L1-L3
      val_objs: [
        { unit: ' V', precision: 0, values: ['', '', ''] },
        { unit: ' A', precision: 2, values: ['', '', ''] },
        { unit: ' Hz', precision: 2, values: ['', '', ''] }
      ]
    };
    volt = volt || [];
    cur = cur || [], freq = freq || [];
    $.each([volt, cur, freq], function (index, values) {
      val_obj = l_1_3_vals.val_objs[index];
      $.each(values, function (i, val) {
        if (i < phases) {
          val = values[i];
          if (val != -9999) {
            if (values === freq & (i == 1 || i == 2)) {} else
            l_1_3_vals.availables[i] = 1;

            if (Math.round(val) == val)
            val = val.toString();
            else
            val = val.toFixed(val_obj.precision);
            val += val_obj.unit;
            val_obj.values[i] = val;
          }
        }
      });
    });
    return l_1_3_vals;
  }

  function get_value(val_obj) {
    if (!val_obj.values || (val_obj.values.length <= val_obj.index))
    return 'N/A';
    var val = val_obj.values[val_obj.index];
    if (val == null || val_obj.values[val_obj.index] == -9999)
    return 'N/A';

    if (Math.round(val) == val)
    val = val.toString();
    else
    val = val.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }

}(jQuery));