/*
   s2s_panel.js - S2S screen.
   Copyright (c) 2014-2016, Generex GmbH. All rights reserved.
   Said, UW.
*/

var s2s_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  css_obj, attr_obj,
  valtable_obj, report_obj, unms_obj,
  x_pos = 10,
  y_pos = 10;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.ups == null) {
      return;
    }

    var refresh
    valtable_obj = data.ups.valtable;
    report_obj = data.report;

    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }

    set_sts_led();
    set_input_src_1(); //Set Input Source 1
    set_input_src_2(); //Set Input Source 2
    set_syn_ballance(); //Set Phase synchron and balance measurements
    set_outpower_loadbars(); //outpower loadbars
    if (valtable_obj._platform !== "ups_view")
    panes_api.set_rom_temp_values(valtable_obj); //set rom temp values
    set_footer();
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: '470px',
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_bg(); //background
    create_model_panes();
    create_sts_led();
    create_input_src_1_pane() //Input Source 1
    create_input_src_2_pane() //Input Source 2
    create_syn_ballance_pane(); //Phase synchron and balance measurements
    create_outpower_loadbars(); //outpower loadbars
    if (valtable_obj._platform !== "ups_view")
    create_rom_temp(); //rom temp
    create_footer_pane();
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 950, height: 446, border: 'solid 1px #808080', align: 'center' };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').css({ display: 'block', 'margin-left': 'auto', 'margin-right': 'auto' }).
    attr({ 'id': 'bg_img_id', 'class': 'img-rounded', src: './image/sts/s2s.png', align: 'middle' }).appendTo(img_div);

    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function create_model_panes() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 950 };
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active' }).append(valtable_obj.MODEL).appendTo(model_div);
  }

  function create_sts_led() {
    var fragment = document.createDocumentFragment(),
    div, img, src;

    //Preferred 1
    css_obj = { position: 'absolute', top: y_pos + 64, left: x_pos + 342, width: 100, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('PREFERRED 1');
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 62;
    css_obj.left = x_pos + 322;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_pref_led(13);
    $('<img />').attr({ 'id': 'byp_1_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //Preferred 2
    css_obj = { position: 'absolute', top: y_pos + 380, left: x_pos + 342, width: 100, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('PREFERRED 2');
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 378;
    css_obj.left = x_pos + 322;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_pref_led(14);
    $('<img />').attr({ 'id': 'byp_2_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //Source 1
    css_obj = { position: 'absolute', top: y_pos + 146, left: x_pos + 335, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('SOURCE 1');
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 126;
    css_obj.left = x_pos + 360;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_src_led(3);
    $('<img />').attr({ 'id': 'source_1_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //Source 2
    css_obj = { position: 'absolute', top: y_pos + 334, left: x_pos + 335, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('SOURCE 2');
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 314;
    css_obj.left = x_pos + 360;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_src_led(4);
    $('<img />').attr({ 'id': 'source_2_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //switch 1
    css_obj = { position: 'absolute', top: y_pos + 110, left: x_pos + 517, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('SS1');
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 126;
    css_obj.left = x_pos + 550;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_switch_led(5);
    $('<img />').attr({ 'id': 'switch_1_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //switch 2
    css_obj = { position: 'absolute', top: y_pos + 334, left: x_pos + 517, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('SS2');
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 314;
    css_obj.left = x_pos + 550;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_switch_led(6);
    $('<img />').attr({ 'id': 'switch_2_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //alarm led
    css_obj.top = y_pos + 224;
    css_obj.left = x_pos + 550;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_alarm_led();
    $('<img />').attr({ 'id': 'alarm_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //output led
    css_obj.top = y_pos + 224;
    css_obj.left = x_pos + 652;
    css_obj.width = 17;
    css_obj.height = 17;
    div = $('<div/>').css(css_obj);
    src = get_output_led();
    $('<img />').attr({ 'id': 'output_img', 'class': 'img-rounded', width: 16, 'height': 16, src: src }).appendTo(div);
    fragment.appendChild(div[0]);

    //warn img
    css_obj.top = y_pos + 220;
    css_obj.left = x_pos + 510;
    css_obj.width = 26;
    css_obj.height = 30;
    div = $('<div/>').css(css_obj);
    $('<img />').attr({ 'class': 'img-rounded', width: 24, 'height': 28, src: './image/sts/warn.png' }).appendTo(div);
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 152;
    css_obj.left = x_pos + 551;
    css_obj.width = 16;
    css_obj.height = 64;
    div = $('<div/>').css(css_obj);
    $('<img />').attr({ 'class': 'img-rounded', width: 16, 'height': 63, src: './image/sts/warn_p_o.png' }).appendTo(div);
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 246;
    css_obj.left = x_pos + 551;
    css_obj.width = 16;
    css_obj.height = 64;
    div = $('<div/>').css(css_obj);
    $('<img />').attr({ 'class': 'img-rounded', width: 16, 'height': 63, src: './image/sts/warn_p_u.png' }).appendTo(div);
    fragment.appendChild(div[0]);


    //Charge Text
    css_obj = { position: 'absolute', top: y_pos + 210, left: x_pos + 720, width: 80, height: 18, color: '#3F5987', 'font-size': ' 13px', 'font-weight': 'bold' };
    div = $('<div/>').css(css_obj);
    div.append('CHARGE');
    fragment.appendChild(div[0]);
    document.body.appendChild(fragment);
  }

  function set_sts_led() {
    var src;
    //Preferred 1
    src = get_pref_led(13);
    $('#byp_1_img').attr('src', src);
    //Preferred 2
    src = get_pref_led(14);
    $('#byp_2_img').attr('src', src);
    //Source 1
    src = get_src_led(3);
    $('#source_1_img').attr('src', src);
    //Source 2
    src = get_src_led(4);
    $('#source_2_img').attr('src', src);
    //switch 1
    src = get_switch_led(5);
    $('#switch_1_img').attr('src', src);
    //switch 2
    src = get_switch_led(6);
    $('#switch_2_img').attr('src', src);
    //alarm led
    src = get_alarm_led();
    $('#alarm_img').attr('src', src);
    //output led
    src = get_output_led();
    $('#output_img').attr('src', src);
  }

  function create_input_src_1_pane() //Input Source 1
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, div;

    css_obj = { position: 'absolute', top: y_pos + 86, left: x_pos + 28 };

    div = $('<div/>', { id: 'input_src_1' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 3 }).append(i18n(lang_Input) + ' ' + i18n('source') + ' 1')).appendTo(thead);

    tr = $('<tr />').append($('<td />').append("L1:")).appendTo(tbody);

    td = $('<td />', { id: 'src_1_volt_1', align: 'left' }).
    append(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_1, index: 0, unit: ' V', precision: 1 })).appendTo(tr);

    td = $('<td />', { id: 'src_1_freq_1', align: 'left' }).
    append(get_value({ values: [valtable_obj.SOCO_INPFREQ_NET_1], index: 0, unit: ' Hz', precision: 1 })).appendTo(tr);

    tr = $('<tr />').append($('<td />').append("L2:")).appendTo(tbody);
    td = $('<td />', { id: 'src_1_volt_2', align: 'left' }).
    append(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_1, index: 1, unit: ' V', precision: 1 })).appendTo(tr);

    tr = $('<tr />').append($('<td />').append("L3:")).appendTo(tbody);
    td = $('<td />', { id: 'src_1_volt_3', align: 'left' }).
    append(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_1, index: 2, unit: ' V', precision: 1 })).appendTo(tr);

    fragment.appendChild(div[0]);
    document.body.appendChild(fragment);
  }

  function set_input_src_1() //Set Input Source 1
  {
    $('#src_1_volt_1').
    text(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_1, index: 0, unit: ' V', precision: 1 }));

    $('#src_1_freq_1').
    text(get_value({ values: [valtable_obj.SOCO_INPFREQ_NET_1], index: 0, unit: ' Hz', precision: 1 }));

    $('#src_1_volt_2').
    text(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_1, index: 1, unit: ' V', precision: 1 }));

    $('#src_1_volt_3').
    text(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_1, index: 2, unit: ' V', precision: 1 }));
  }

  function create_input_src_2_pane() //Input Source 2
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, div;

    css_obj = { position: 'absolute', top: y_pos + 268, left: x_pos + 28 };

    div = $('<div/>', { id: 'input_src_2' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 3 }).append(i18n(lang_Input) + ' ' + i18n('source') + ' 2')).appendTo(thead);

    tr = $('<tr />').append($('<td />').append("L1:")).appendTo(tbody);

    td = $('<td />', { id: 'src_2_volt_1', align: 'left' }).
    append(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_2, index: 0, unit: ' V', precision: 1 })).appendTo(tr);

    td = $('<td />', { id: 'src_2_freq_1', align: 'left' }).
    append(get_value({ values: [valtable_obj.SOCO_INPFREQ_NET_2], index: 0, unit: ' Hz', precision: 1 })).appendTo(tr);

    tr = $('<tr />').append($('<td />').append("L2:")).appendTo(tbody);
    td = $('<td />', { id: 'src_2_volt_2', align: 'left' }).
    append(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_2, index: 1, unit: ' V', precision: 1 })).appendTo(tr);

    tr = $('<tr />').append($('<td />').append("L3:")).appendTo(tbody);
    td = $('<td />', { id: 'src_2_volt_3', align: 'left' }).
    append(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_2, index: 2, unit: ' V', precision: 1 })).appendTo(tr);

    fragment.appendChild(div[0]);
    document.body.appendChild(fragment);
  }

  function set_input_src_2() //Set Input Source 2
  {
    $('#src_2_volt_1').
    text(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_2, index: 0, unit: ' V', precision: 1 }));

    $('#src_2_freq_1').
    text(get_value({ values: [valtable_obj.SOCO_INPFREQ_NET_2], index: 0, unit: ' Hz', precision: 1 }));

    $('#src_2_volt_2').
    text(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_2, index: 1, unit: ' V', precision: 1 }));

    $('#src_2_volt_3').
    text(get_value({ values: valtable_obj.SOCO_INPVOLT_NET_2, index: 2, unit: ' V', precision: 1 }));
  }

  function create_output_pane() //Output
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, div;

    css_obj = { position: 'absolute', top: y_pos + 86, left: x_pos + 790 };

    div = $('<div/>', { id: 'output' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 3 }).append(i18n(lang_Output))).appendTo(thead);

    tr = $('<tr />').append($('<td />').append("L1:")).appendTo(tbody);

    td = $('<td />', { id: 'output_volt_1', align: 'left' }).
    append(get_value({ values: valtable_obj.OUTPUT_VOLT, index: 0, unit: ' V', precision: 1 })).appendTo(tr);

    td = $('<td />', { id: 'output_curr_1', align: 'left' }).
    append(get_value({ values: valtable_obj.EX_OUT_CURR, index: 0, unit: ' A', precision: 2 })).appendTo(tr);

    tr = $('<tr />').append($('<td />').append("L2:")).appendTo(tbody);

    td = $('<td />', { id: 'output_volt_2', align: 'left' }).
    append(get_value({ values: valtable_obj.OUTPUT_VOLT, index: 1, unit: ' V', precision: 1 })).appendTo(tr);

    td = $('<td />', { id: 'output_curr_2', align: 'left' }).
    append(get_value({ values: valtable_obj.EX_OUT_CURR, index: 1, unit: ' A', precision: 2 })).appendTo(tr);

    tr = $('<tr />').append($('<td />').append("L3:")).appendTo(tbody);

    td = $('<td />', { id: 'output_volt_3', align: 'left' }).
    append(get_value({ values: valtable_obj.OUTPUT_VOLT, index: 2, unit: ' V', precision: 1 })).appendTo(tr);

    td = $('<td />', { id: 'output_curr_3', align: 'left' }).
    append(get_value({ values: valtable_obj.EX_OUT_CURR, index: 2, unit: ' A', precision: 2 })).appendTo(tr);

    fragment.appendChild(div[0]);
    document.body.appendChild(fragment);
  }

  function set_output() //Set Output
  {
    $('#output_volt_1').
    text(get_value({ values: valtable_obj.OUTPUT_VOLT, index: 0, unit: ' V', precision: 1 }));

    $('#output_curr_1').
    text(get_value({ values: valtable_obj.EX_OUT_CURR, index: 0, unit: ' A', precision: 2 }));

    $('#output_volt_2').
    text(get_value({ values: valtable_obj.OUTPUT_VOLT, index: 1, unit: ' V', precision: 1 }));

    $('#output_curr_2').
    text(get_value({ values: valtable_obj.EX_OUT_CURR, index: 1, unit: ' A', precision: 2 }));

    $('#output_volt_3').
    text(get_value({ values: valtable_obj.OUTPUT_VOLT, index: 2, unit: ' V', precision: 1 }));

    $('#output_curr_3').
    text(get_value({ values: valtable_obj.EX_OUT_CURR, index: 2, unit: ' A', precision: 2 }));
  }

  function create_syn_ballance_pane() //Phase synchron and balance measurements
  {
    var fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, div;

    css_obj = { position: 'absolute', top: y_pos + 180, left: x_pos + 260 };

    div = $('<div/>', { id: 'output' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 2 }).append(i18n('Measurements'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append('S1 ' + i18n('phase balance') + ':')).appendTo(tbody);
    td = $('<td />', { id: 'phase_balance_1', align: 'left' }).
    append(get_value({ values: [valtable_obj.STS_S1BALANCE], index: 0, unit: ' ', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append('S2 ' + i18n('phase balance') + ':')).appendTo(tbody);
    td = $('<td />', { id: 'phase_balance_2', align: 'left' }).
    append(get_value({ values: [valtable_obj.STS_S2BALANCE], index: 0, unit: ' ', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Synchron angle") + ":")).appendTo(tbody);
    td = $('<td />', { id: 'synchron_angle', align: 'left' }).
    append(get_value({ values: [valtable_obj.STS_SYNCANGLE], index: 0, unit: ' ', precision: 2 })).appendTo(tr);

    fragment.appendChild(div[0]);
    document.body.appendChild(fragment);
  }

  function set_syn_ballance() //Set Phase synchron and balance measurements
  {
    $('#phase_balance_1').
    text(get_value({ values: [valtable_obj.STS_S1BALANCE], index: 0, unit: ' ', precision: 0 }));

    $('#phase_balance_2').
    text(get_value({ values: [valtable_obj.STS_S2BALANCE], index: 0, unit: ' ', precision: 0 }));

    $('#synchron_angle').
    text(get_value({ values: [valtable_obj.STS_SYNCANGLE], index: 0, unit: ' ', precision: 2 }));
  }

  function create_outpower_loadbars() //outpower loadbars
  {
    if (valtable_obj.OUTPOWER == null)
    return true;
    outpower_loadbars_created = true;

    if (valtable_obj.OUTPOWER[0] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[0], id: 'loadbar1_id', left: x_pos + 730, top: y_pos + 308, title: 'L1', scaler: 1 });
    if (valtable_obj.OUTPOWER[1] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[1], id: 'loadbar2_id', left: x_pos + 730, top: y_pos + 338, title: 'L2', scaler: 0 });
    if (valtable_obj.OUTPOWER[2] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[2], id: 'loadbar3_id', left: x_pos + 730, top: y_pos + 368, title: 'L3', scaler: 0 });
  }

  function set_outpower_loadbars() //outpower loadbars
  {
    if (valtable_obj.OUTPOWER == null)
    return true;
    if (valtable_obj.OUTPOWER[0] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[0], 'loadbar1_id');
    if (valtable_obj.OUTPOWER[1] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[1], 'loadbar2_id');
    if (valtable_obj.OUTPOWER[2] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[2], 'loadbar3_id');
  }

  function get_src_led(bit_nr) {
    var bit_val = 1 << bit_nr;
    if (valtable_obj.STS_STATUS == null)
    return './image/bacs2/b_grey.gif';
    if (valtable_obj.STS_STATUS & bit_val)
    return './image/bacs2/b_green.gif';
    return './image/bacs2/b_grey.gif';
  }

  function get_pref_led(bit_nr) {
    var bit_val = 1 << bit_nr;
    if (valtable_obj.STS_STATUS == null)
    return './image/bacs2/b_grey.gif';
    if (valtable_obj.STS_STATUS & bit_val)
    return './image/bacs2/b_green.gif';
    return './image/bacs2/b_grey.gif';
  }

  function get_switch_led(bit_nr) {
    var bit_val = 1 << bit_nr;
    if (valtable_obj.STS_STATUS == null)
    return './image/bacs2/b_grey.gif';
    if (valtable_obj.STS_STATUS & bit_val)
    return './image/bacs2/b_green.gif';
    return './image/bacs2/b_grey.gif';
  }

  function get_alarm_led() {
    if (valtable_obj.STS_STATUS == null)
    return './image/bacs2/b_grey.gif';
    if (valtable_obj.STS_STATUS & 0x200)
    return './image/bacs2/b_flashred.gif';
    return './image/bacs2/b_grey.gif';
  }

  function get_output_led() {
    if (valtable_obj.STS_STATUS == null)
    return './image/bacs2/b_grey.gif';
    if (valtable_obj.STS_STATUS & 0x1000)
    return './image/bacs2/b_grey.gif';
    return './image/bacs2/b_green.gif';
  }

  function get_value(val_obj) {
    if (!val_obj.values || (val_obj.values.length <= val_obj.index))
    return 'N/A';
    var val = val_obj.values[val_obj.index];
    if (val == null || val_obj.values[val_obj.index] == -9999)
    return 'N/A';

    if (Math.round(val) == val)
    val = val.toString();
    else
    val = val.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }

  function create_rom_temp() //rom temp
  {
    var fragment = document.createDocumentFragment(),
    rom_temp_div;
    css_obj = { position: 'absolute', top: y_pos + 350, left: x_pos + 170 };
    rom_temp_div = $('<div/>').attr({ id: 'rom_temp_div_id' }).css(css_obj);
    panes_api.create_rom_temp_pane(valtable_obj, { id: 'rom_temp_table_id', 'class': 'table table-condensed table-hover' }).appendTo(rom_temp_div);
    fragment.appendChild(rom_temp_div[0]);
    document.body.appendChild(fragment);
  }

}(jQuery));