/*
   sensorman_panel.js - Sensor Manager screen.
   Copyright (c) 2016, Generex GmbH. All rights reserved.
   Said.
*/

var sensorman_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  css_obj,
  sensor_obj, report_obj, unms_obj,
  num_dig_inputs = 4,
  num_outlets = 4,
  x_pos = 5,
  y_pos = 5,
  c_options = {
    series: {
      lines: { show: true },
      bars: {
        show: true,
        barWidth: 0.6,
        align: 'center',
        lineWidth: 0,
        fill: true,
        fillColor: { colors: [{ opacity: 1 }, { opacity: 1 }, { opacity: 1 }, { opacity: 1 }] }
      },
      color: '#52B245'
    },
    xaxis: { ticks: [], tickLength: 0 },
    yaxis: { min: 0, max: 0 },
    legend: {
      show: false
    },
    grid: { backgroundColor: 'white', borderWidth: 1, tickColor: 'black' }
  };


  var req_params = null,

  sensor_cmd_option = {
    data: {},
    data_type: 'text',
    success: sensor_cmd_update,
    error: err_funct
  },
  sensor_cmd_settings = { methode: "POST", xhttp_methode_override: 'PUT', req_payload_json: true },
  ctl_url = get_url("api/devices/sensor/control");

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    if (oid != null) {
      req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    } else {
      req_params = utils_api.get_req_params(utils_api.device_sensorman, oid);
    }

    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
    enable_bnt();
  }

  function update(data) {
    if (err_div)
    err_div.css('display', 'none');
    enable_bnt();

    set_variable(data);
    jqmodule.refresh(cb, 10 * 1000);

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data, sensor_obj.deviceType);

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      disable_cmd_butt();
      return true;
    }

    set_analog_inp_values();
    set_digit_inp_panel(); // Set Digital Input Alarms
    set_outlets(); // set Outlets Panel
    disable_cmd_butt();
    set_footer();

  }

  function disable_cmd_butt() {
    if (unms_obj != null) {
      $("#outlets_div_id :button").attr("disabled", true);
      $("#digit_inp_div_id :button").attr("disabled", true);

      for (var index = 0; index < 8; ++index) {
        $("#analog_input_ack_" + index).attr("disabled", true);
      }
    }
  }

  function create_panes() {
    create_bg(); //background
    create_model_panes();
    create_analog_inp_values();
    create_digit_inp_panel(); // create Digital Input Alarms
    create_outlets_panel(); // create Outlets Panel

    if (unms_obj != null) {
      $("#outlets_div_id :button").attr("disabled", true);
      $("#digit_inp_div_id :button").attr("disabled", true);
    }

    create_footer_pane();
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    bg_div;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 980, height: 459, border: 'solid 1px #808080' };
    bg_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);

    fragment.appendChild(bg_div[0]);
    document.body.appendChild(fragment);
  }

  function create_model_panes() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 980, 'z-index': 10 };
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active', id: 'model_name_id' }).appendTo(model_div);
    var deviceName = sensor_obj.deviceType;
    if (deviceName === "SensorMan2") {
      deviceName = "SensorManager II";
    }
    a.append(deviceName + ' (Firmware: ' + (sensor_obj.SM2_FIRMWARE / 100).toFixed(2) + ')');
  }

  function create_analog_inp_values() {
    var left = 34;
    for (var index = 0; index < 8; ++index) {
      create_analog_inp_value(left, index);

      //Alarm marker
      if (sensor_obj.SM2_USE_ANALOG_ALARM_HI & (1 << index))
      create_alarm_marker('SM2_ANALOG_HI_THRES', index, left, i18n('Analog High Alarm'), '#FF0000');

      if (sensor_obj.SM2_USE_ANALOG_PREALARM_HI & (1 << index))
      create_alarm_marker('SM2_ANALOG_HI_PREALARMVAL', index, left, i18n('Analog High PreAlarm'), '#ee8800');

      if (sensor_obj.SM2_USE_ANALOG_ALARM_LO & (1 << index))
      create_alarm_marker('SM2_ANALOG_LO_THRES', index, left, i18n('Analog Low Alarm'), '#FF0000');

      if (sensor_obj.SM2_USE_ANALOG_PREALARM_LO & (1 << index))
      create_alarm_marker('SM2_ANALOG_LO_PREALARMVAL', index, left, i18n('Analog Low PreAlarm'), '#ee8800');

      left += 120;
    }
  }

  function create_analog_inp_value(left, index) {
    var fragment = document.createDocumentFragment(),
    data = new Array(),
    analog_input_div = null,
    title_div, butt_div, button;

    c_options.yaxis = { min: sensor_obj.SM2_ANALOG_LO_RANGE[index], max: sensor_obj.SM2_ANALOG_HI_RANGE[index] };
    c_options.xaxis.ticks.length = 0;
    c_options.series.color = get_analog_inp_color(index);

    css_obj = {
      position: 'absolute',
      top: 70,
      left: left,
      width: 100,
      height: 45,
      'background-color': 'white',
      align: 'left',
      'text-align': 'left',
      'font-weight': 'bold'
    };
    title_div = $('<div/>', { id: 'analog_input_name_' + index }).css(css_obj).append(sensor_obj['SM_A' + (index + 1) + 'NAME']);
    fragment.appendChild(title_div[0]);

    css_obj = {
      position: 'absolute',
      'top': 120,
      left: left,
      width: 80,
      height: 300,
      'background-color': 'white',
      'align': 'center'
    };
    analog_input_div = $('<div/>').attr({ id: 'analog_input_' + index }).css(css_obj);
    fragment.appendChild(analog_input_div[0]);

    css_obj = {
      position: 'absolute',
      'top': 430,
      left: left + 26,
      width: 40,
      height: 30,
      'background-color': 'white',
      'align': 'center'
    };
    butt_div = $('<div/>').css(css_obj);

    button = $('<button>', { id: "analog_input_ack_" + index, 'class': "btn btn-default btn-sm" }).append(i18n('Ack')).appendTo(butt_div);
    button.css({ display: get_analog_inp_ack_display(index) });

    button.click(function (event) {
      var id = $(this).attr('id');
      id = parseInt(id.substr("analog_input_ack_".length, id.length - 2));

      disable_bnt();
      sensor_cmd_option.data = { code: 'aack', params: { sensor: id } };
      jqmodule.ajax(ctl_url, sensor_cmd_option, sensor_cmd_settings);

      event.preventDefault();
    });

    fragment.appendChild(butt_div[0]);

    document.body.appendChild(fragment);

    data.push({
      label: 'analog_input' + index,
      data: [
        [0, sensor_obj.SM2_ANALOG[index].toFixed(0)]
      ]
    });
    c_options.xaxis.ticks.push([0, sensor_obj.SM2_ANALOG[index].toFixed(0) + ' ' + sensor_obj['SM2_UNIT' + (index + 1) + 'x']]);

    $.plot(analog_input_div, data, c_options);
  }

  function sensor_cmd_update() {
    //if(err_div)
    //err_div.css('display', 'none');
    //enable_bnt();
  }

  function enable_bnt() {
    if (oid != null) {
      return;
    }

    document.body.style.cursor = 'auto';
    $("button").removeAttr("disabled");
  }

  function disable_bnt() {
    if (err_div)
    err_div.css('display', 'none');

    $("button").attr("disabled", "disabled");
    document.body.disable = true;
    document.body.style.cursor = 'wait';
  }

  function set_analog_inp_values() {
    var left = 34;
    for (var index = 0; index < 8; ++index) {
      set_analog_inp_value(index);

      $('#analog_input_name_' + index).text(sensor_obj['SM_A' + (index + 1) + 'NAME']);

      $('#SM2_ANALOG_HI_THRES' + '_' + index).remove();
      $('#SM2_ANALOG_HI_PREALARMVAL' + '_' + index).remove();
      $('#SM2_ANALOG_LO_THRES' + '_' + index).remove();
      $('#SM2_ANALOG_LO_PREALARMVAL' + '_' + index).remove();

      //Alarm marker
      if (sensor_obj.SM2_USE_ANALOG_ALARM_HI & (1 << index))
      create_alarm_marker('SM2_ANALOG_HI_THRES', index, left, i18n('Analog High Alarm'), '#FF0000');

      if (sensor_obj.SM2_USE_ANALOG_PREALARM_HI & (1 << index))
      create_alarm_marker('SM2_ANALOG_HI_PREALARMVAL', index, left, i18n('Analog High PreAlarm'), '#ee8800');

      if (sensor_obj.SM2_USE_ANALOG_ALARM_LO & (1 << index))
      create_alarm_marker('SM2_ANALOG_LO_THRES', index, left, i18n('Analog Low Alarm'), '#FF0000');

      if (sensor_obj.SM2_USE_ANALOG_PREALARM_LO & (1 << index))
      create_alarm_marker('SM2_ANALOG_LO_PREALARMVAL', index, left, i18n('Analog Low PreAlarm'), '#ee8800');

      left += 120;

    }
  }

  function set_analog_inp_value(index) {
    var data = new Array();

    c_options.yaxis = { min: sensor_obj.SM2_ANALOG_LO_RANGE[index], max: sensor_obj.SM2_ANALOG_HI_RANGE[index] };
    c_options.xaxis.ticks.length = 0;
    c_options.series.color = get_analog_inp_color(index);
    data.push({
      label: 'analog_input' + index,
      data: [
        [0, sensor_obj.SM2_ANALOG[index].toFixed(0)]
      ]
    });
    c_options.xaxis.ticks.push([0, sensor_obj.SM2_ANALOG[index].toFixed(0) + ' ' + sensor_obj['SM2_UNIT' + (index + 1) + 'x']]);

    $.plot('#analog_input_' + index, data, c_options);
    $('#analog_input_ack_' + index).css({ display: get_analog_inp_ack_display(index) });

    $('#analog_input_name_' + index).text(sensor_obj['ADIO_M' + (index + 1) + 'NAME']);
  }

  function get_analog_inp_color(index) {
    var maske = 1 << index;

    if (((sensor_obj.SM2_ANALOG_HI_ALARM & maske) && (sensor_obj.SM2_USE_ANALOG_ALARM_HI & maske)) ||
      ((sensor_obj.SM2_ANALOG_LO_ALARM & maske) && (sensor_obj.SM2_USE_ANALOG_ALARM_LO & maske))) {
      if (sensor_obj.SM2_ANALOG_ACK_ALARM & maske)
      return '#9932cc'; /*#ee8800';//orange*/
      return '#ee0000'; //rot
    } //if
    else {
      var analogInputVal = sensor_obj.SM2_ANALOG[index],
      analogHighPreAlarmVal = sensor_obj.SM2_ANALOG_HI_PREALARMVAL[index],
      analogLowPreAlarmVal = sensor_obj.SM2_ANALOG_LO_PREALARMVAL[index],

      useAnalogPreAlarmHigh = sensor_obj.SM2_USE_ANALOG_PREALARM_HI,
      useAnalogPreAlarmLow = sensor_obj.SM2_USE_ANALOG_PREALARM_LO;

      if ((useAnalogPreAlarmHigh & maske) && (analogInputVal > analogHighPreAlarmVal)) //analogPreAlarmHigh
      {
        return '#ee8800'; //orange /*'#eeee00';//Gelb*/
      } else if ((useAnalogPreAlarmLow & maske) && (analogInputVal < analogLowPreAlarmVal)) //analogPreAlarmLow
      {
        return '#ee8800'; //orange /*'#eeee00';//Gelb*/
      }

      return '#52B245';
    }
  }

  function create_alarm_marker(val_str, index, left, title, color) {
    var fragment = document.createDocumentFragment(),
    div;

    var val = sensor_obj[val_str][index] - sensor_obj.SM2_ANALOG_LO_RANGE[index],
    top = (val * 280) / (sensor_obj.SM2_ANALOG_HI_RANGE[index] - sensor_obj.SM2_ANALOG_LO_RANGE[index]); //300
    top = (400 - top);

    css_obj = {
      position: 'absolute',
      top: top,
      left: left + 23,
      width: 54,
      height: 4,
      'background-color': color,
      'z-index': 20,
      border: '1px solid black'
    };

    div = $('<div/>', { id: val_str + '_' + index, title: title }).css(css_obj);
    fragment.appendChild(div[0]);

    document.body.appendChild(fragment);
  }

  function create_digit_inp_panel() // create Digital Input Alarms
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, digit_inp_div, button, img;

    css_obj = { position: 'absolute', top: y_pos + 480, left: x_pos + 2, width: 480, border: 'solid 1px #808080' };

    digit_inp_div = $('<div/>', { id: 'digit_inp_div_id', 'class': 'img-rounded' }).css(css_obj);

    table = $('<table />', { id: 'digit_inp_table', 'class': 'table table-condensed' }).appendTo(digit_inp_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<td />', { colspan: 4, align: 'center', 'text-align': 'center' }).css({ color: 'white', 'background-color': '#315284' }).append("Digital Input Alarms")).appendTo(thead);


    tr = $('<tr />').appendTo(thead);
    tr.append($('<th />', { align: 'left' }).append(''));
    tr.append($('<th />', { align: 'left' }).append(i18n('Name')));
    tr.append($('<th />', { align: 'left' }).append(i18n('Alarm')));
    tr.append($('<th />', { align: 'left' }).append(i18n('ACK')));

    for (var index = 0; index < num_dig_inputs; ++index) {
      tr = $('<tr />').appendTo(tbody);
      $('<td />', { id: 'digit_inp_index_' + index, align: 'left' }).append(index + 1).appendTo(tr);
      $('<td />', { id: 'digit_inp_name_' + index, align: 'left' }).append(sensor_obj['SM_D' + (index + 1) + 'NAME']).appendTo(tr);

      $('<img />', { 'id': 'digit_inp_alarm_' + index, width: 16, 'height': 16, src: get_digit_inp_img(index) }).
      appendTo($('<td />', { align: 'left' }).appendTo(tr));

      button = $('<button>', { id: "digit_input_ack_" + index, 'class': "btn btn-default btn-sm" }).append('Ack');
      button.css({ display: get_digit_inp_ack_display(index) });

      button.click(function (event) {
        var id = $(this).attr('id');
        id = parseInt(id.substr("digit_input_ack_".length, id.length - 2));

        disable_bnt();
        sensor_cmd_option.data = { code: 'dack', params: { sensor: id } };
        jqmodule.ajax(ctl_url, sensor_cmd_option, sensor_cmd_settings);

        event.preventDefault();
      });

      $('<td />', { align: 'left' }).append(button).appendTo(tr);
    }


    fragment.appendChild(digit_inp_div[0]);
    document.body.appendChild(fragment);
  }

  function set_digit_inp_panel() // Set Digital Input Alarms
  {
    for (var index = 0; index < num_dig_inputs; ++index) {
      $('#digit_inp_name_' + index).text(sensor_obj['SM_D' + (index + 1) + 'NAME']);
      $('#digit_inp_alarm_' + index).attr('src', get_digit_inp_img(index));
      $('#digit_input_ack_' + index).css('display', get_digit_inp_ack_display(index));
    }
  }

  function create_outlets_panel() // create Outlets Panel
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, outlets_div, button, img, butt_obj;

    css_obj = { position: 'absolute', top: y_pos + 480, left: x_pos + 500, width: 480, border: 'solid 1px #808080' };

    outlets_div = $('<div/>', { id: 'outlets_div_id', 'class': 'img-rounded' }).css(css_obj);

    table = $('<table />', { id: 'digit_inp_table', 'class': 'table table-condensed' }).appendTo(outlets_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<td />', { colspan: 4, align: 'center', 'text-align': 'center' }).css({ color: 'white', 'background-color': '#315284' }).append(i18n("Outlets"))).appendTo(thead);


    tr = $('<tr />').appendTo(thead);
    tr.append($('<th />', { align: 'left' }).append(''));
    tr.append($('<th />', { align: 'left' }).append(i18n('Name')));
    tr.append($('<th />', { align: 'left' }).append(i18n('Status')));
    tr.append($('<th />', { align: 'left' }).append(i18n('Switch On')));

    for (var index = 0; index < num_outlets; ++index) {
      tr = $('<tr />').appendTo(tbody);
      $('<td />', { id: 'outlets_index_' + index, align: 'left' }).append(index + 1).appendTo(tr);
      $('<td />', { id: 'outlets_name_' + index, align: 'left' }).append(sensor_obj['SM_O' + (index + 1) + 'NAME']).appendTo(tr);

      $('<img />', { 'id': 'outlets_status_' + index, width: 16, 'height': 16, src: get_outlets_status_img(index) }).
      appendTo($('<td />', { align: 'left' }).appendTo(tr));

      butt_obj = get_outlets_butt_attr(index);
      button = $('<button>', { id: "outlet_switch_on_" + index, 'class': "btn btn-default btn-sm" }).append(butt_obj.txt);
      if (butt_obj.disable) {
        button.attr("disabled", "disabled");
      }

      button.click(function (event) {
        var id = $(this).attr('id');
        id = parseInt(id.substr("outlet_switch_on_".length, id.length - 2));
        var maske = 1 << id;
        on = sensor_obj.SM2_DIGITAL_OUT & maske ? 0 : 1,

        disable_bnt();
        sensor_cmd_option.data = { code: 'out', params: { outlet: id, on: on } };
        jqmodule.ajax(ctl_url, sensor_cmd_option, sensor_cmd_settings);

        event.preventDefault();
      });

      $('<td />', { align: 'left' }).append(button).appendTo(tr);
    }

    fragment.appendChild(outlets_div[0]);
    document.body.appendChild(fragment);
  }

  function set_outlets() // set Outlets Panel
  {
    var butt_obj, button;

    for (var index = 0; index < num_outlets; ++index) {
      $('#outlets_name_' + index).text(sensor_obj['SM_O' + (index + 1) + 'NAME']);

      $('#outlets_status_' + index).attr('src', get_outlets_status_img(index));

      butt_obj = get_outlets_butt_attr(index);
      button = $('#outlet_switch_on_' + index).text(butt_obj.txt);
      if (butt_obj.disable) {
        button.attr("disabled", "disabled");
      } else
      button.removeAttr("disabled");
    }

  }

  function get_digit_inp_ack_display(index) {
    var maske = 1 << index;

    if ((sensor_obj.SM2_DIGITAL_IN & maske) && !(sensor_obj.SM2_DIGITAL_ACK & maske)) {
      return 'block';
    }
    return 'none';
  }

  function get_digit_inp_img(index) {
    var maske = 1 << index;
    if (sensor_obj.SM2_USE_DIGITAL_ALARM & maske) {
      if (sensor_obj.SM2_DIGITAL_IN & maske) {
        if (sensor_obj.SM2_DIGITAL_ACK & maske)
        return './image/bacs2/b_yellow.gif';
        else
        return './image/bacs2/b_red.gif';
      } else
      return './image/bacs2/b_green.gif';
    }

    return './image/bacs2/b_grey.gif';
  }

  function get_analog_inp_ack_display(index) {
    var maske = 1 << index;
    if ((sensor_obj.SM2_ANALOG_ALARMS & maske) &&
      (
        ((sensor_obj.SM2_ANALOG_HI_ALARM & maske) && (sensor_obj.SM2_USE_ANALOG_ALARM_HI & maske)) ||
        ((sensor_obj.SM2_ANALOG_LO_ALARM & maske) && (sensor_obj.SM2_USE_ANALOG_ALARM_LO & maske))
      )) {
      if (sensor_obj.SM2_ANALOG_ACK_ALARM & maske)
      return 'none';
      return 'block';
    }
    return 'none';

  }

  function get_outlets_status_img(index) {
    var maske = 1 << index;

    if ((sensor_obj.SM2_DIGITAL_OUT & maske) || (sensor_obj.SM2_MARKER_ALARM & maske))
    return './image/bacs2/b_green.gif';
    return './image/bacs2/b_grey.gif';
  }

  function get_outlets_butt_attr(index) {
    var maske = 1 << index;

    if (sensor_obj.SM2_MARKER_ALARM & maske) {
      return { txt: "Set By Alarm", disable: true };
    } else {
      if (sensor_obj.SM2_DIGITAL_OUT & maske)
      return { txt: "Switch Off", disable: false };
      else
      return { txt: "Switch On", disable: false };
    }
  }

  function create_footer_pane() {
    if (!oid || !unms_obj) {
      return true;
    }

    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: sensor_obj.deviceType == 'SiteManager' ? '900px' : '790px',
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function set_variable(data) {
    if (oid != null) //UNMS?
    {
      sensor_obj = data.ups.valtable;
    } else {
      sensor_obj = data.sensor;
    }

    if (sensor_obj.deviceType === "SiteManager") {
      num_dig_inputs = num_outlets = 8;
    } else {
      num_dig_inputs = num_outlets = 4;
    }

    report_obj = data.report;

    for (var index = 0; index < sensor_obj.SM2_ANALOG.length; ++index) {
      if (sensor_obj['SM2_UNIT' + (index + 1) + 'x'] === '°F') {
        sensor_obj.SM2_ANALOG[index] = Math.round(sensor_obj.SM2_ANALOG[index] * 1.8) + 32.0;
        sensor_obj.SM2_ANALOG_HI_THRES[index] = Math.round(sensor_obj.SM2_ANALOG_HI_THRES[index] * 1.8) + 32.0;
        sensor_obj.SM2_ANALOG_HI_PREALARMVAL[index] = Math.round(sensor_obj.SM2_ANALOG_HI_PREALARMVAL[index] * 1.8) + 32.0;
        sensor_obj.SM2_ANALOG_LO_THRES[index] = Math.round(sensor_obj.SM2_ANALOG_LO_THRES[index] * 1.8) + 32.0;
        sensor_obj.SM2_ANALOG_LO_PREALARMVAL[index] = Math.round(sensor_obj.SM2_ANALOG_LO_PREALARMVAL[index] * 1.8) + 32.0;
        sensor_obj.SM2_ANALOG_LO_RANGE[index] = Math.round(sensor_obj.SM2_ANALOG_LO_RANGE[index] * 1.8) + 32.0;
        sensor_obj.SM2_ANALOG_HI_RANGE[index] = Math.round(sensor_obj.SM2_ANALOG_HI_RANGE[index] * 1.8) + 32.0;
      }
    }
  }




}(jQuery));