/*
   sielemm_panel.js - Multimeter (EMM) screen.
   Copyright (c) 2013, Generex GmbH. All rights reserved.
   Said.
*/

var sielemm_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  outpower_loadbars_created = false,
  css_obj,
  valtable_obj, report_obj, unms_obj,
  x_pos = 10,
  y_pos = 10;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 550, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.ups == null) {
      return;
    }

    valtable_obj = data.ups.valtable;
    report_obj = data.report;
    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }
    set_sielemm_values();
    if (valtable_obj._platform !== "ups_view")
    panes_api.set_rom_temp_values(valtable_obj); //set rom temp values
    set_footer();
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
      }, { //css
        position: 'absolute',
        top: '470px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }


  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_bg(); //background
    create_model_panes();
    create_sielemm_values_panel();
    if (valtable_obj._platform !== "ups_view")
    create_rom_temp(); //rom temp
    create_footer_pane();
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 550, height: 338, border: 'solid 1px #808080' };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function create_sielemm_values_panel() {
    var fragment = document.createDocumentFragment(),
    sielemm_values_div, tr, table, tbody, thead;
    css_obj = { position: 'absolute', left: x_pos, margin: '0px auto', padding: '80px', width: 550 };

    sielemm_values_div = $('<div/>', { id: 'sielemm_values_div_id' }).css(css_obj); //, 'class':'rounded'
    table = $('<table />', { 'class': 'table table-bordered', width: '60%', height: '60%', align: 'center' }).appendTo(sielemm_values_div);
    //table.css('background-color', '#FFFFFF');
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 2 }).append('EMM ' + i18n('System Values'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Power Factor"))).appendTo(tbody);
    $('<td />', { id: 'sielemm_pwrfrac_id', align: 'left' }).append(get_value({ values: [valtable_obj.SIELEMM_PWRFAC], index: 0, unit: '', precision: 0 })).appendTo(tr);


    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("3-Phase System Cosphi"))).appendTo(tbody);
    $('<td />', { id: 'sielemm_cosphi_id', align: 'left' }).append(get_value({ values: [valtable_obj.SIELEMM_COSPHI], index: 0, unit: '', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("3-Phase System Current"))).appendTo(tbody);
    $('<td />', { id: 'sielemm_curr_id', align: 'left' }).append(get_value({ values: valtable_obj.INCURR, index: 0, unit: ' A', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("3-Phase System Voltage"))).appendTo(tbody);
    $('<td />', { id: 'sielemm_volt_id', align: 'left' }).append(get_value({ values: valtable_obj.INVOLT, index: 0, unit: ' V', precision: 0 })).appendTo(tr);

    fragment.appendChild(sielemm_values_div[0]);
    document.body.appendChild(fragment);
  }

  function set_sielemm_values() {
    $('#sielemm_pwrfrac_id').text(get_value({ values: [valtable_obj.SIELEMM_PWRFAC], index: 0, unit: '', precision: 0 }));
    $('#sielemm_cosphi_id').text(get_value({ values: [valtable_obj.SIELEMM_COSPHI], index: 0, unit: '', precision: 0 }));
    $('#sielemm_curr_id').text(get_value({ values: valtable_obj.INCURR, index: 0, unit: ' A', precision: 0 }));
    $('#sielemm_volt_id').text(get_value({ values: valtable_obj.INVOLT, index: 0, unit: ' V', precision: 0 }));
  }

  function get_value(val_obj) {
    if (!val_obj.values || (val_obj.values.length <= val_obj.index))
    return 'N/A';
    var val = val_obj.values[val_obj.index];
    if (val == null || val_obj.values[val_obj.index] == -9999)
    return 'N/A';

    if (Math.round(val) == val)
    val = val.toString();
    else
    val = val.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }

  function create_model_panes() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 550 };
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active' }).append(valtable_obj.MODEL).appendTo(model_div);
  }

  function create_rom_temp() //rom temp
  {
    var fragment = document.createDocumentFragment(),
    rom_temp_div;
    css_obj = { position: 'absolute', top: y_pos + 226, left: x_pos + 10 };
    rom_temp_div = $('<div/>').attr({ id: 'rom_temp_div_id' }).css(css_obj);
    panes_api.create_rom_temp_pane(valtable_obj, { id: 'rom_temp_table_id', 'class': 'table table-condensed table-hover' }).appendTo(rom_temp_div);
    fragment.appendChild(rom_temp_div[0]);
    document.body.appendChild(fragment);
  }

}(jQuery));