/*
   sielsolardsp_panel.js- Siel Solar DSP screen.
   Copyright (c) 2013-2018, Generex GmbH. All rights reserved.
   Said.
*/

var sielsolardsp_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null, //Callback Obj
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  css_obj,
  valtable_obj, report_obj, unms_obj,
  inphases = null,
  outphases = null,
  x_pos = 5,
  y_pos = 5,
  status_div = null;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.ups == null) {
      return;
    }

    set_variable(data);
    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }
    set_footer();
    set_location();
    set_system_values();
    set_grid_values();
    set_cells_values();
    create_status_pane(); //SOLAR INVERTER Status
    set_summary_values();
    set_solar_prodgraph();
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: '490px',
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function set_variable(data) {
    valtable_obj = data.ups.valtable;
    report_obj = data.report;

    valtable_obj._tempUnit = valtable_obj._tempUnit || 0; //0 = Celsius

    if (valtable_obj.INPHASES != null)
    inphases = valtable_obj.INPHASES;
    else
    inphases = valtable_obj.PHASES;

    if (valtable_obj.OUTPHASES != null)
    outphases = valtable_obj.OUTPHASES;
    else
    outphases = valtable_obj.PHASES;
  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_footer_pane();
    create_bg(); //background
    create_location_pane();
    create_model_panes();
    create_system_pane();
    create_grid_pane();
    create_cells_pane();
    create_status_pane();
    create_solar_prodgraph_pane(); //SOLAR graph
    create_summary_pane(); //SOLAR INVERTER Summary 
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 700, height: 1010, border: 'solid 1px #808080' };
    img_div = $('<div/>', { 'class': 'img-rounded', 'id': 'bg_id' }).css(css_obj);
    $('<img />').attr({ 'id': 'bg_img_id', 'class': 'img-rounded', width: 600, 'height': 227, src: './image/siel/panel.png' }).
    css({ position: 'absolute', margin: 50, 'margin-left': 44, 'margin-top': 38, top: 0, left: 0, right: 0, bottom: 0 }).appendTo(img_div);
    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function create_model_panes() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 700 }; // 'background-color': '#3a87ad'
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active' }).append(valtable_obj.MODEL).appendTo(model_div);
  }

  function create_location_pane() {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, loc_div;

    css_obj = { position: 'absolute', top: y_pos + 240, left: x_pos + 20, width: 660 };

    loc_div = $('<div/>', { id: 'loc_div_id', 'class': 'img-rounded' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(loc_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />').css({ 'text-align': 'left' }).append(i18n('Location') + ':')).appendTo(thead);

    tr = $('<tr />').appendTo(tbody);
    $('<td />', { id: 'location_id', align: 'left' }).css('pading', 30).appendTo(tr);

    fragment.appendChild(loc_div[0]);
    document.body.appendChild(fragment);
    set_location();
  }

  function set_location() {
    if (!valtable_obj.LOCATION.empty())
    $('#location_id').html('&nbsp;&nbsp;&nbsp;' + valtable_obj.LOCATION);
    else
    $('#location_id').html('&nbsp;&nbsp;&nbsp;' + i18n('Unknown'));
  }

  function create_system_pane() //SOLAR INVERTER System
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, sys_div;

    css_obj = { position: 'absolute', top: y_pos + 310, left: x_pos + 20, width: 660, border: 'solid 1px #808080' };

    sys_div = $('<div/>', { id: 'sys_div_id', 'class': 'img-rounded' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(sys_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).css({ 'text-align': 'center', 'text-decoration': 'underline' }).append(i18n('SOLAR INVERTER System'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Produced energy"))).appendTo(tbody);
    $('<td />', { id: 'produced_energy_id', align: 'left' }).appendTo(tr);
    $('<td />', { align: 'left' }).append(i18n("Production")).appendTo(tr);
    $('<td />', { id: 'production_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Generated POWER"))).appendTo(tbody);
    $('<td />', { id: 'generated_power_id', align: 'left' }).appendTo(tr);
    $('<td />', { align: 'left' }).append(i18n("Running Time	 hours")).appendTo(tr);
    $('<td />', { id: 'running_time_hours_id', align: 'left' }).appendTo(tr);

    fragment.appendChild(sys_div[0]);
    document.body.appendChild(fragment);
    set_system_values();
  }

  function set_system_values() // set SOLAR INVERTER System
  {
    $('#produced_energy_id').text(valtable_obj.SIEL_ENERGYSTR + ' MWh');
    $('#production_id').text(valtable_obj.OUTPOWER[0].toFixed(0) + ' %');

    $('#generated_power_id').text(valtable_obj.SIEL_GENPOWER.toFixed(1) + ' kW');
    $('#running_time_hours_id').text(valtable_obj.SIEL_RUNTIME.toFixed(0) + ' ' + i18n('hours'));
  }

  function create_grid_pane() //SOLAR INVERTER Grid
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, solar_div;

    css_obj = { position: 'absolute', top: y_pos + 415, left: x_pos + 20, width: 660, border: 'solid 1px #808080' };

    solar_div = $('<div/>', { id: 'solar_div_id', 'class': 'img-rounded' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(solar_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 6 }).css({ 'text-align': 'center', 'text-decoration': 'underline' }).append(i18n('SOLAR INVERTER Grid'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Produced energy"))).appendTo(tbody);
    $('<td />', { id: 'solar_produced_energy_id', align: 'left' }).appendTo(tr);
    $('<td />', { align: 'left' }).append(i18n("Phase voltage")).appendTo(tr);
    $('<td />', { id: 'phase_voltage1_id', align: 'left' }).appendTo(tr);
    $('<td />', { id: 'phase_voltage2_id', align: 'left' }).appendTo(tr);
    $('<td />', { id: 'phase_voltage3_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Grid frequency"))).appendTo(tbody);
    $('<td />', { id: 'grid_frequency_id', align: 'left' }).appendTo(tr);
    $('<td />', { align: 'left' }).append(i18n("Phase current")).appendTo(tr);
    $('<td />', { id: 'phase_current1_id', align: 'left' }).appendTo(tr);
    $('<td />', { id: 'phase_current2_id', align: 'left' }).appendTo(tr);
    $('<td />', { id: 'phase_current3_id', align: 'left' }).appendTo(tr);


    fragment.appendChild(solar_div[0]);
    document.body.appendChild(fragment);
    set_grid_values();
  }

  function set_grid_values() // set SOLAR INVERTER Grid
  {
    $('#solar_produced_energy_id').text(valtable_obj.SIEL_ENERGYSTR + ' MWh');

    $('#phase_voltage1_id').text('L1:' + valtable_obj.OUTPUT_VOLT[0].toFixed(0) + ' V');
    $('#phase_voltage2_id').text('L1:' + valtable_obj.OUTPUT_VOLT[1].toFixed(0) + ' V');
    $('#phase_voltage3_id').text('L1:' + valtable_obj.OUTPUT_VOLT[2].toFixed(0) + ' V');

    $('#grid_frequency_id').text(valtable_obj.OUTFREQ[0].toFixed(1) + ' Hz');

    $('#phase_current1_id').text('L1:' + valtable_obj.OUTPUTCURRENT[0].toFixed(0) + ' A');
    $('#phase_current2_id').text('L1:' + valtable_obj.OUTPUTCURRENT[1].toFixed(0) + ' A');
    $('#phase_current3_id').text('L1:' + valtable_obj.OUTPUTCURRENT[2].toFixed(0) + ' A');
  }

  function create_cells_pane() //SOLAR INVERTER Cells
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, cells_div;

    css_obj = { position: 'absolute', top: y_pos + 520, left: x_pos + 20, width: 660, border: 'solid 1px #808080' };

    cells_div = $('<div/>', { id: 'cells_div_id', 'class': 'img-rounded' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(cells_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).css({ 'text-align': 'center', 'text-decoration': 'underline' })
      .append(i18n('SOLAR INVERTER Cells'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Cell Voltage"))).appendTo(tbody);
    $('<td />', { id: 'cell_Voltage_id', align: 'left' }).appendTo(tr);
    $('<td />', { align: 'left' }).append(i18n("Cell Temperature")).appendTo(tr);
    $('<td />', { id: 'cell_temperature_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Cell Current"))).appendTo(tbody);
    $('<td />', { id: 'cell_urrent_id', align: 'left' }).appendTo(tr);
    $('<td />', { align: 'left' }).append(i18n("Radiation2")).appendTo(tr);
    $('<td />', { id: 'radiation2_id', align: 'left' }).appendTo(tr);


    fragment.appendChild(cells_div[0]);
    document.body.appendChild(fragment);
    set_cells_values();
  }

  function set_cells_values() // set SOLAR INVERTER Cells
  {
    $('#cell_Voltage_id').text(valtable_obj.SIEL_CELLVOLT.toFixed(0) + ' V');
    $('#cell_temperature_id').html(panes_api.get_temperature(valtable_obj.SIEL_CELLTEMP, valtable_obj._tempUnit, 0));

    $('#cell_urrent_id').text(valtable_obj.SIEL_CELLCURR.toFixed(0) + ' A');
    $('#radiation2_id').html(valtable_obj.SIEL_RADIATIONB.toFixed(0) + ' W/m&sup2;');
  }

  function create_status_pane() //SOLAR INVERTER Status	
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead;

    if (status_div != null) {
      status_div.remove();
    }

    css_obj = { position: 'absolute', top: y_pos + 625, left: x_pos + 20, width: 660, border: 'solid 1px #808080' };

    status_div = $('<div/>', { id: 'status_div_id', 'class': 'img-rounded' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed' }).appendTo(status_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 3 }).css({ 'text-align': 'center', 'text-decoration': 'underline' })
      .append(i18n('SOLAR INVERTER Status	'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Alarms"))).appendTo(tbody);
    $('<td />', { align: 'left' }).append(i18n("Anomaly")).appendTo(tr);
    $('<td />', { align: 'left' }).append(i18n("Status")).appendTo(tr);

    tr = $('<tr />').appendTo(tbody);
    $('<td />', { align: 'left' }).append(get_dsp_alarms_table()).appendTo(tr);
    $('<td />', { align: 'left' }).append(get_dsp_anomaly_table()).appendTo(tr);
    $('<td />', { align: 'left' }).append(get_dsp_dsp_status_table()).appendTo(tr);

    fragment.appendChild(status_div[0]);
    document.body.appendChild(fragment);

  }

  function get_dsp_alarms_table() {
    var table = $('<table />', { 'class': 'table table-condensed table-hover' }),
    tbody = $('<tbody />').appendTo(table);

    if ((valtable_obj.SIEL_STATUSBYTES[0] & 0x02) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Desaturation Inverter')));
    if ((valtable_obj.SIEL_STATUSBYTES[0] & 0x04) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Fast Current Limitation'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[0] & 0x40) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Overtemperature Inverter'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[0] & 0x80) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('No DSP-Signaling Communication'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[1] & 0x02) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Desaturation Converter'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[1] & 0x04) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Fast Current Limitation Converter'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[1] & 0x08) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Converter Blocked'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[1] & 0x40) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('No DSP-EEPROM Communication'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[2] & 0x01) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Isolation Loss'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[2] & 0x02) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('External Protection'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[2] & 0x20) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Emergency Power Off'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[3] & 0x10) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Overvoltage Bus DC'))).appendTo(tbody);

    return table;
  }

  function get_dsp_anomaly_table() {
    var table = $('<table />', { 'class': 'table table-condensed table-hover' }),
    tbody = $('<tbody />').appendTo(table);

    if ((valtable_obj.SIEL_STATUSBYTES[0] & 0x10) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Grid Frequency Out Of Range'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[0] & 0x20) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Grid Voltage Out Of Range'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[1] & 0x10) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Radiation Low'))).appendTo(tbody);

    return table;
  }

  function get_dsp_dsp_status_table() {
    var table = $('<table />', { 'class': 'table table-condensed table-hover' }),
    tbody = $('<tbody />').appendTo(table);

    if ((valtable_obj.SIEL_STATUSBYTES[1] & 0x01) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Inverter Connected To Grid'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[1] & 0x80) != 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Automatic Mode'))).appendTo(tbody);
    else
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Manual Mode'))).appendTo(tbody);

    if ((valtable_obj.SIEL_STATUSBYTES[2] & 0x80) == 0)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Operator Present'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[4] & 0x02) == 0x02)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Inverter Reset'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[4] & 0x04) == 0x04)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Inverter Disabled'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[4] & 0x08) == 0x08)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Inverter Enabled'))).appendTo(tbody);
    if ((valtable_obj.SIEL_STATUSBYTES[4] & 0x10) == 0x10)
    $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Inverter Genereating'))).appendTo(tbody);

    return table;
  }

  function create_solar_prodgraph_pane() //SOLAR graph
  {
    var fragment = document.createDocumentFragment(),
    img, div, css_img;

    css_obj = { position: 'absolute', top: y_pos + 172, left: x_pos + 126, width: 12, height: 10, 'background-color': 'transparent' };

    for (var index = 0; index < 10; ++index) {
      div = $('<div/>').css(css_obj);
      css_img = { position: 'absolute', margin: 0, 'margin-left': 0, top: 0, left: 0, right: 0, bottom: 0 };
      img = $('<img />', { 'id': 'graph_img_' + index, width: 10, 'height': 10, src: './image/piller/ledweiss14x14.gif' }).css(css_img).appendTo(div);
      fragment.appendChild(div[0]);
      css_obj.left += 38;
    }

    css_obj.left = x_pos + 123;
    css_obj.top = y_pos + 125;
    div = $('<div/>').css(css_obj);
    img = $('<img />', { width: 10, 'height': 10, src: './image/piller/ledweiss14x14.gif' }).css(css_img).appendTo(div);
    fragment.appendChild(div[0]);
    img = $('<img />', { 'id': 'solar_off_img', width: 10, 'height': 10, src: './image/piller/ledweiss14x14.gif' }).css(css_img).appendTo(div);
    fragment.appendChild(div[0]);

    css_obj.top = y_pos + 148;
    div = $('<div/>').css(css_obj);
    img = $('<img />', { width: 10, 'height': 10, src: './image/piller/ledweiss14x14.gif' }).css(css_img).appendTo(div);
    fragment.appendChild(div[0]);
    img = $('<img />', { 'id': 'solar_on_img', width: 10, 'height': 10, src: './image/piller/ledweiss14x14.gif' }).css(css_img).appendTo(div);
    fragment.appendChild(div[0]);

    css_obj.left = x_pos + 467;
    css_obj.top = y_pos + 91;
    div = $('<div/>').css(css_obj);
    img = $('<img />', { width: 10, 'height': 10, src: './image/piller/ledweiss14x14.gif' }).css(css_img).appendTo(div);
    fragment.appendChild(div[0]);
    img = $('<img />', { 'id': 'solar_alarm_img', width: 10, 'height': 10, src: './image/piller/ledweiss14x14.gif' }).css(css_img).appendTo(div);
    fragment.appendChild(div[0]);

    document.body.appendChild(fragment);
    set_solar_prodgraph();
  }

  function set_solar_prodgraph() //set SOLAR graph
  {
    var fragment = document.createDocumentFragment(),
    img, div, css_img;

    css_obj = { position: 'absolute', top: y_pos + 182, left: x_pos + 100, width: 12, height: 10, 'background-color': 'transparent' };

    for (var index = 1; index <= 10; ++index) {
      if (valtable_obj.OUTPOWER[0] >= index * 10)
      $('#graph_img_' + (index - 1)).attr('src', './image/piller/ledgruen14x14.gif');
      else
      $('#graph_img_' + (index - 1)).attr('src', './image/piller/ledweiss14x14.gif');
    }

    if (valtable_obj.SIEL_STATUSBYTES[4] & 0x06)
    $('#solar_off_img').attr('src', './image/siel/o.png');
    else if ((valtable_obj.SIEL_STATUSBYTES[4] & 0x18) && (valtable_obj.SIEL_STATUSBYTES[1] & 0x01))
    $('#solar_off_img').attr('src', './image/siel/oa.gif');
    else
    $('#solar_off_img').attr('src', './image/piller/ledweiss14x14.gif');

    if ((valtable_obj.SIEL_STATUSBYTES[4] & 0x10) && !(valtable_obj.SIEL_STATUSBYTES[1] & 0x01))
    $('#solar_on_img').attr('src', './image/piller/ledgruen14x14.gif');
    else if ((valtable_obj.SIEL_STATUSBYTES[4] & 0x18) && (valtable_obj.SIEL_STATUSBYTES[1] & 0x01))
    $('#solar_on_img').attr('src', './image/siel/ga.gif');
    else
    $('#solar_on_img').attr('src', './image/piller/ledweiss14x14.gif');

    if (!(valtable_obj.SIEL_STATUSBYTES[0] & 0x08))
    $('#solar_alarm_img').attr('src', './image/siel/r.png');
    else
    $('#solar_alarm_img').attr('src', './image/piller/ledweiss14x14.gif');
  }

  function create_summary_pane() //SOLAR INVERTER Summary 
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, summary_div,
    status_div = $("#status_div_id");

    css_obj = { position: 'absolute', top: status_div.height() + 645, left: x_pos + 20, width: 660, border: 'solid 1px #808080' };

    summary_div = $('<div/>', { id: 'summary_div_id', 'class': 'img-rounded' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(summary_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 2 }).css({ 'text-align': 'center', 'text-decoration': 'underline' })
      .append(i18n('Summary'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Power put in Grid"))).appendTo(tbody);
    $('<td />', { id: 'power_put_in_grid_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Produced Energy"))).appendTo(tbody);
    $('<td />', { id: 'summary_produced_energy_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Avoided CO2 Emissions"))).appendTo(tbody);
    $('<td />', { id: 'avoided_co_emissionsid', align: 'left' }).appendTo(tr);

    fragment.appendChild(summary_div[0]);
    document.body.appendChild(fragment);
    set_summary_values();
  }

  function set_summary_values() // set  INVERTER Summary
  {
    var status_div = $("#status_div_id"),
    summary_div = $("#summary_div_id"),
    offset = status_div.offset(),

    v = 0,
    mw = valtable_obj.SIEL_ENERGYMW,
    kw = valtable_obj.SIEL_ENERGYKW;

    if (kw > 9999.0)
    kw = 9999.0;

    v = mw * 1000.0 + kw / 10.0;

    if (v >= 1000.0)
    $('#summary_produced_energy_id').text((v / 1000.0).toFixed(1) + ' MWh');
    else
    $('#summary_produced_energy_id').text(v.toFixed(1) + ' KWh');

    v = (mw * 1000.0 + kw / 10.0) * 0.531;
    if (v >= 1000.0)
    $('#avoided_co_emissionsid').text((v / 1000.0).toFixed(1) + ' tons');
    else
    $('#avoided_co_emissionsid').text(v.toFixed(1) + '  kg');

    $('#power_put_in_grid_id').text(valtable_obj.SIEL_GENPOWER.toFixed(1) + ' KW');

    summary_div.css('top', status_div.height() + offset.top + 15);

    $('#bg_id').css('height', summary_div.height() + summary_div.offset().top + 15);

  }


}(jQuery));