/*
   sitemon_panel.js - Site Monitor screen.
   Copyright (c) 2013, Generex GmbH. All rights reserved.
   Said.
*/

var sitemon_api = (function ($) {
  var smon_oid = get_oid_from_url(),
    info_url = get_url('script/nmsView.dll?infoxml' + smon_oid),
    cur_info_inp_nr = null,
    cb = null,
    err_div = null,
    pannes_created = false,
    add_action = true,
    css_obj, sitemon_cmd_active = false,
    check_bowser = true,
    y_pos = 10,
    x_pos = 10,
    sensor_obj, report_obj, unms_obj,
    user = null,

    status = { inactive: 0, ok: 1, warning: 2, danger: 3 },
    req_params = null,
    sitemon_cmd_option = {
      data: {},
      data_type: 'json',
      success: sitemon_cmd_update,
      error: ack_err_funct
    },
    sensor_cmd_settings = { methode: "POST", xhttp_methode_override: 'PUT', req_payload_json: true },
    ctl_url = get_url("api/devices/sensor/control"),
    sitemon_cmd_inf_option = {
      data: {},
      data_type: 'xml',
      success: sitemon_info_cmd_update,
      error: err_funct
    };

  /*public functions*/
  return {
    init: init,
    smon_info_cmd: smon_info_cmd,
    smon_ack_cmd: smon_ack_cmd,
    smon_output_on_off_cmd: smon_output_on_off_cmd
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    if (smon_oid != null) {
      req_params = utils_api.get_req_params(utils_api.device_ups, smon_oid);
    } else {
      req_params = utils_api.get_req_params(utils_api.device_sensorman, smon_oid);
      for (var i = 0; i < 64; ++i) {
        $('#input_inf_' + i + '_id').css('display', 'none');
      }
    }

    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: smon_oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function enable_bnt() {
    document.body.style.cursor = 'auto';
    $("button").removeAttr("disabled");
  }

  function disable_bnt() {
    if (err_div)
      err_div.css('display', 'none');

    $("button").attr("disabled", "disabled");
    document.body.disable = true;
    document.body.style.cursor = 'wait';
  }


  function ack_err_funct(response) {
    enable_bnt();

    if (smon_oid == null) {
      jqmodule.refresh(cb, 10 * 1000);
      panes_api.display_err({ response: response, oid: smon_oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
      return true;
    }

    var response_html = $(response.responseText),
      access_denied = response_html.find('#access-denied');

    document.getElementById('cmd_loading_id').style['display'] = 'none';

    if (access_denied.length > 0) {
      alert(i18n('You have no permission for this operation') + '!');
      return true;
    }
    top.main.location.href = "../../nmsView.dll?" + smon_oid;
  }

  function create_footer_pane() {
    if (!smon_oid || !unms_obj)
      return true;

    footer_api.create({ //Attr
        id: 'panel2'
      }, { //css
        position: 'absolute',
        top: '790px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!smon_oid || !unms_obj)
      return true;
    footer_api.set(unms_obj);
  }

  function update(data) {

    if (sitemon_cmd_active == true) {
      return true;
    }

    report_obj = data.report;
    if (smon_oid != null) //UNMS?
    {
      sensor_obj = data.ups.valtable;
      device_type = sensor_obj.COM2_DEV_TYPE;
      user = report_obj.user;
    } else {
      sensor_obj = data.sensor;
      device_type = sensor_obj.deviceType;
    }

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    jqmodule.refresh(cb, report_obj.refresh * 1000);

    if (!pannes_created) {
      create_footer_pane();
      create_dialog(null, 'info_dialog_div_id', '300');
      pannes_created = true;
    }

    if (err_div) {
      err_div.css('display', 'none');
    }

    enable_bnt();

    if (window.menu_api != null) {
      menu_api.update(data);
    }

    set_input_img(0, 0);
    set_input_img(8, 1);
    set_input_img(16, 2);
    set_input_img(24, 3);
    set_input_img(32, 4);
    set_input_img(40, 5);
    set_input_img(48, 6);
    set_input_img(56, 7);

    set_ack_butt(0, 0);
    set_ack_butt(8, 1);
    set_ack_butt(16, 2);
    set_ack_butt(24, 3);
    set_ack_butt(32, 4);
    set_ack_butt(40, 5);
    set_ack_butt(48, 6);
    set_ack_butt(56, 7);

    set_input_txt();

    set_outputs_img();
    set_outputs_butt();
    set_output_txt();
    if (add_action) {
      add_action = false;
    }


    if (pannes_created) {
      set_footer();
    }
  }


  function set_input_img(start_id, index) {
    var src = null,
      input_img_id = null,
      sm_led, sm_led_id = null,
      id = 0,
      inp_status;

    for (var i = 0; i < 8; ++i) {
      inp_status = get_input_status(i, index);
      id = start_id + i;
      input_img_id = "input_img_" + id + "_id";
      sm_led_id = "sm_led_" + id + "_id";
      sm_led = $('#' + sm_led_id);

      if (inp_status == status.inactive)
        src = "./image/bacs2/b_grey.gif";
      else {
        if (inp_status == status.ok)
          src = "./image/bacs2/b_green.gif";
        else {
          if (inp_status == status.warning)
            src = "./image/bacs2/b_yellow.gif";
          else
            src = "./image/bacs2/b_red.gif";
        }
      }
      sm_led.attr('src', src);
      if (add_action)
        sm_led.bind({
          mouseover: function (event) {
            var tooltipX = event.pageX - 8,
              tooltipY = event.pageY + 8;
            $('#sitemon_tt_id').css({ top: tooltipY, left: tooltipX, display: 'block' });
          },
          mouseout: function (event) {
            $('#sitemon_tt_id').css({ display: 'none' });
          }
        });

      $('#' + input_img_id).attr('src', src);
    }
  }

  function set_input_txt() {
    var input_txt_id = null,
      imput_name, i;
    for (i = 0; i < 64; ++i) {
      input_txt_id = 'input_txt_' + i + '_id';
      if (i < 10)
        imput_name = 'SMON_0' + i + 'NAME';
      else
        imput_name = 'SMON_' + i + 'NAME';
      $('#' + input_txt_id).text(sensor_obj[imput_name]);
    }
  }

  function set_ack_butt(start_id, index) {
    var src = null,
      ack_butt = null,
      ack_butt_id = null,
      id = 0,
      inp_status = null;
    if (smon_oid != null && (user == null || user.empty())) {
      return true;
    }

    for (var i = 0; i < 8; ++i) {
      inp_status = get_input_status(i, index);
      id = start_id + i;
      ack_butt_id = "input_ack_" + id + "_id";
      ack_butt = $('#' + ack_butt_id);

      if (inp_status == status.inactive) {
        ack_butt.css('display', 'none'); //grey
      } else {
        if (inp_status == status.ok) {
          ack_butt.css('display', 'none'); //green
        } else {
          if (inp_status == status.warning) {
            ack_butt.css('display', 'none'); //yellow
          } else //status.danger
          {
            ack_butt.css('display', 'block'); //red
          }
        }
      }
    }
  }

  function set_outputs_img() {
    var src = null,
      output_img = null,
      outp_status = 0;

    for (var i = 0; i < 8; ++i) {
      outp_status = get_output_status(i);
      output_img = $('#' + "output_img_" + i + "_id")

      if (outp_status == status.inactive) {
        src = "./image/bacs2/b_grey.gif";
      } else {
        if (outp_status == status.ok) {
          src = "./image/bacs2/b_grey.gif"; //off
        } else if (outp_status == status.danger) {
          src = "./image/bacs2/b_green.gif"; //on
        }
      }

      output_img.attr('src', src);
      if (add_action) {
        output_img.bind({
          mouseover: function (event) {
            var tooltipX = event.pageX - 8,
              tooltipY = event.pageY + 8;
            $('#sitemon_tt_output_id').css({ top: tooltipY, left: tooltipX, display: 'block' });
          },
          mouseout: function (event) {
            $('#sitemon_tt_output_id').css({ display: 'none' });
          }
        });
      }
    }
  }

  function set_outputs_butt() {
    var output_butt = null,
      outp_status = 0;

    for (var i = 0; i < 8; ++i) {
      outp_status = get_output_status(i);
      output_butt = $('#' + "output_action_" + i + "_id")

      if (outp_status == status.inactive) {
        output_butt.attr('disabled', true);
      } else {
        output_butt.attr('disabled', false);
        if (outp_status == status.ok) {
          output_butt.text(i18n('Switch On'));
        } else if (outp_status == status.danger) {
          output_butt.text(i18n('Switch Off'));
        }
      }

    }
  }

  function set_output_txt() {
    var output_txt_id = null,
      output_name, i = 0;
    for (; i < 8; ++i) {
      output_txt_id = 'output_txt_' + i + '_id';
      output_name = 'ADIO_O' + i + 'NAME';
      $('#' + output_txt_id).text(sensor_obj[output_name]);
    }
  }

  function get_output_status(index) {
    var bit_val = 1 << index,
      disabled = sensor_obj.SMON2_OUTPUT_DISABLED,
      outp_status = sensor_obj.SMON2_OUTPUT_DIG;

    if (disabled & bit_val) {
      return status.inactive; //grey
    } else if (outp_status & bit_val) {
      return status.danger; //red
    }
    return status.ok; //green
  }

  function get_input_status(input_nr, index) {
    var bit_val = 1 << input_nr,
      active = sensor_obj.SMON2_ACTIVE[index],
      inp_status = sensor_obj.SMON2_STATUS[index],
      ack = sensor_obj.SMON2_ACK[index];

    if ((active & bit_val) == 0)
      return status.inactive; //grey
    else {
      if ((inp_status & bit_val) == 0)
        return status.ok; //green
      else {
        if ((ack & bit_val) == bit_val)
          return status.warning; //yellow
        else
          return status.danger; //red
      }
    }
  }

  function smon_ack_cmd(input_nr) {
    disable_bnt();
    sitemon_cmd_active = true;

    if (smon_oid != null) { //unms
      var sitemon_cmd_parameters =
        "upscmd=UPS_EXE_COMMAND [20004][" + input_nr + "]&user=" + user + "&pass=&refoid=" + smon_oid +
        "&cmdmsg=test" + "&redirect=./nmsview.dll?" + smon_oid + "&json=ups";
      var url = get_url('script/nmsView.dll?' + sitemon_cmd_parameters);

      return jqmodule.ajax(url, sitemon_cmd_option);
    }

    sitemon_cmd_option.data = { code: 'dack', params: { sensor: input_nr - 1 } };
    jqmodule.ajax(ctl_url, sitemon_cmd_option, sensor_cmd_settings);
  }

  function smon_output_on_off_cmd(input_nr) {
    var outp_status = get_output_status(input_nr),
      on = 0;

    if (outp_status == status.ok) {
      on = 1;
    }

    disable_bnt();
    sitemon_cmd_active = true;

    sitemon_cmd_option.data = { code: 'out', params: { outlet: input_nr, on: on } };
    jqmodule.ajax(ctl_url, sitemon_cmd_option, sensor_cmd_settings);

  }

  function sitemon_cmd_update(data) {
    sitemon_cmd_active = false;
    document.getElementById('cmd_loading_id').style['display'] = 'none';
    if (smon_oid != null && data != null) {
      update(data);
    }

  }

  function smon_info_cmd(inp_nr) {
    sitemon_cmd_active = true;
    cur_info_inp_nr = inp_nr;
    jqmodule.ajax(info_url, sitemon_cmd_inf_option);
  }

  function sitemon_info_cmd_update(xml_data) {
    sitemon_cmd_active = false;
    $(':button').removeAttr('disabled');
    document.getElementById('cmd_loading_id').style['display'] = 'none';

    var data = $(xml_data),
      infos_name = "",
      infos_value = "",
      infos_array = null,
      infos = data.find('infos'),
      index = -1;

    $('info', infos).each(function () {
      info = $(this);
      infos_name = info.find('name').text();
      infos_value = info.find('value').text();
      if (infos_name == cur_info_inp_nr) {
        if ((index = infos_value.indexOf('[')) != -1) {
          var val_array = infos_value.split(' ');
          var url = val_array[0].substring(index + 1);
          var win = window.open(url, "_blank", "toolbar=yes, scrollbars=yes, resizable=yes, top=500, left=500, width=500, height=600");
          return false;
        } else {
          var input_txt_id = null,
            imput_name;
          input_txt_id = 'input_txt_' + cur_info_inp_nr + '_id';
          if (cur_info_inp_nr < 10)
            imput_name = 'SMON_0' + (cur_info_inp_nr - 1) + 'NAME';
          else
            imput_name = 'SMON_' + (cur_info_inp_nr - 1) + 'NAME';
          $('#ui-dialog-title-info_dialog_div_id').text(data.find('value[name=' + imput_name + ']').attr('val'));
          $('#info_txt_id').text(infos_value);
          $('#info_dialog_div_id').dialog('open');
          return false;
        }
      }
    });
  }

  function create_dialog(ok_func, div_id, w) {
    (function ($) {
      $('#' + div_id).dialog({
        autoOpen: false,
        width: w,
        modal: true,
        closeOnEscape: false,
        /*buttons:
        {
          OK: function() {
            $(this).dialog('close');
            if(ok_func != null)
              ok_func();
          },
          Cancel: function() {
            $(this).dialog('close');
          }
        },*/
        overlay: { opacity: 0.5 },
        show: "blind"
      });
      $("span.ui-dialog-title").css({ "color": "white" });
    })(jQuery);
  }

}(jQuery));