/*
   ups_panel.js - UPS default screen.
   Copyright (c) 2017, Generex GmbH. All rights reserved.
   UW.
*/

var snmp_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  outpower_loadbars_created = false,
  css_obj, attr_obj,
  valtable_obj, report_obj, unms_obj,
  inphases = null,
  outphases = null,
  status, tempmax, tempdeg, overload = 0,
  plattform = get_plattform(),
  ups_id = 0,
  ups_protocol = 0,
  prot_snmp = 0x803A,
  bg_height, bg_width;
  x_pos = 10, y_pos = 10;

  var status_obj = [

    { bit: 0x0008, txt: "The UPS is drawing power from the batteries" },
    { bit: 0x0010, txt: "The remaining battery run-time is low" },
    { bit: 0x0400, txt: "One or more batteries have been determined to require replacement" },
    { bit: 0x0020, txt: "A temperature is out of tolerance" },
    { bit: 0x0080, txt: "An input condition is out of tolerance" },
    { bit: 0x0100, txt: "The output load exceeds the UPS output capacity" },
    { bit: 0x2000, txt: "A general fault in the UPS has been detected" },
    { bit: 0x4000, txt: "A problem has been encountered in the communications between the agent and the UPS" },
    { bit: 0x0200, txt: "Inverter error" },
    { bit: 0x1000, txt: "Inverter warning" },
    { bit: 0x0002, txt: "UPS is in shutdown mode" },
    { bit: 0x0001, txt: "The Bypass is presently engaged on the UPS" },
    { bit: 0x0040, txt: "A test is in progress" },
    { bit: 0x0004, txt: "UPS Output active" },
    { bit: 0x0800, txt: "UPS in ECO mode" }
  ];

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 62 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.ups == null) {
      return;
    }

    set_variable(data);
    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }
    set_input_values(); ////Input values
    set_output_values(); //Output values
    set_battery_value(); //Battery value
    set_iby_ire_ssi_inv_rec_batt(); //SET IBY, IRE, SSI, INVERTER, RECTIFIER and BATTERY pannes
    set_ups_status(); //set UPS status
    set_outpower_loadbars(); //outpower loadbars
    set_model_name();
    set_sys_mod_status();

    if (plattform !== "ups_view")
    panes_api.set_rom_temp_values(valtable_obj); //set rom temp values
    set_footer();
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: '510px',
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function set_variable(data) {
    valtable_obj = data.ups.valtable;
    report_obj = data.report;

    status = valtable_obj.upsGenerexState;
    tempmax = 50;
    tempdeg = valtable_obj.upsBatteryTemperature;
    level = valtable_obj.LEVEL;

    if (valtable_obj._upsProtocol == null) {
      ups_protocol = valtable_obj.CONNECT & 0XFFFF;
    } else {
      ups_protocol = valtable_obj._upsProtocol;
    }

    bg_height = 480;
    bg_width = 818;

    inphases = valtable_obj.upsInputNumLines;
    outphases = valtable_obj.upsOutputNumLines;

    if (valtable_obj.upsOutputPercentLoad != null) {
      if (outphases > 2) {
        if ((valtable_obj.upsOutputPercentLoad[0] > 100) || (valtable_obj.upsOutputPercentLoad[1] > 100) || (valtable_obj.upsOutputPercentLoad[2] > 100))
        overload = 1;
        else
        overload = 0;
      } else {
        if (valtable_obj.upsOutputPercentLoad > 100)
        overload = 1;
        else
        overload = 0;
      }
    }
  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_bg(); //background
    create_input_pane(); //Input table
    create_output_pane(); //Outnput   panel
    create_battery_pane(); //Battery panel
    create_iby_ire_ssi_inv_rec_batt(); //create IBY, IRE, SSI, INVERTER, RECTIFIER and BATTERY pannes
    create_status_pane(); //UPS status
    create_model_panes();
    create_outpower_loadbars(); //outpower loadbars
    if (plattform !== utils_api.plattform_ups_view) {
      create_rom_temp(); //rom temp
    }
    create_footer_pane();
    create_sys_mod_status_panel();
  }

  function create_bg() ///home/generex/prj/cs141/webapp/devices/webif/lib/ups/image/ups/bgn_module.png
  {
    var fragment = document.createDocumentFragment(),
    img_div;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: bg_width, height: bg_height, border: 'solid 1px #808080' };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    $('<img />').attr({ 'id': 'bg_img_id', 'class': 'img-rounded', width: 816, 'height': 459, src: './image/ups/bg_ups.png' }).appendTo(img_div);
    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function create_model_panes() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: bg_width, 'z-index': 40 }; // 'background-color': '#3a87ad'
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active', id: 'model_name_id' }).appendTo(model_div);
    set_model_name();
  }

  function create_input_pane() //Input table
  {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, in_div;

    css_obj = { position: 'absolute', top: y_pos + 176, left: x_pos + 8 };

    in_div = $('<div/>', { id: 'input_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover', 'id': 'inptable' }).appendTo(in_div); // table-hover
    table.css('display', 'none');
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).append(i18n(lang_Input))).appendTo(thead);

    if (inphases == 1)
    table.css('margin-top', '22px');

    tr = $('<tr />', { 'id': 'inptrl1' }).append($('<td />').append("L1:")).appendTo(tbody);
    $('<td />', { id: 'input_volt1_id' }).appendTo(tr);
    $('<td />', { id: 'input_cur1_id' }).appendTo(tr);
    $('<td />', { id: 'input_freq1_id' }).appendTo(tr);

    tr = $('<tr />', { 'id': 'inptrl2' }).append($('<td />').append("L2:")).appendTo(tbody);
    $('<td />', { id: 'input_volt2_id' }).appendTo(tr);
    $('<td />', { id: 'input_cur2_id' }).appendTo(tr);

    tr = $('<tr />', { 'id': 'inptrl3' }).append($('<td />').append("L3:")).appendTo(tbody);
    $('<td />', { id: 'input_volt3_id' }).appendTo(tr);
    $('<td />', { id: 'input_cur3_id' }).appendTo(tr);

    fragment.appendChild(in_div[0]);
    document.body.appendChild(fragment);
    set_input_values();
  }

  function set_input_values() {
    var input_val = get_ph_1_3_vals(valtable_obj.upsInputVoltage, valtable_obj.upsInputCurrent, valtable_obj.upsInputFrequency, inphases);

    if (ups_id == 0) {
      if (input_val.availables[0] == 0 & input_val.availables[1] == 0 & input_val.availables[2] == 0) {
        $('#inptable').css('display', 'none');
        return true;
      }
    }
    $('#inptable').css('display', 'block');

    if (input_val.availables[0] != 0) {
      $('#inptrl1').css('display', 'block');
      $('#input_volt1_id').text(input_val.val_objs[0].values[0]);
      $('#input_cur1_id').text(input_val.val_objs[1].values[0]);
      $('#input_freq1_id').text(input_val.val_objs[2].values[0]);
    } else {
      $('#inptrl1').css('display', 'none');
    }

    if (input_val.availables[1] != 0) {
      $('#inptrl2').css('display', 'block');
      $('#input_volt2_id').text(input_val.val_objs[0].values[1]);
      $('#input_cur2_id').text(input_val.val_objs[1].values[1]);
    } else {
      $('#inptrl2').css('display', 'none');
    }

    if (input_val.availables[2] != 0) {
      $('#inptrl3').css('display', 'block');
      $('#input_volt3_id').text(input_val.val_objs[0].values[2]);
      $('#input_cur3_id').text(input_val.val_objs[1].values[2]);
    } else {
      $('#inptrl3').css('display', 'none');
    }
  }

  function create_output_pane() //Output
  {
    var output_div = null,
    tr, table, tbody, thead,
    fragment = document.createDocumentFragment();

    css_obj = { position: 'absolute', top: y_pos + 176, left: x_pos + 610 };

    output_div = $('<div/>', { id: 'output_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover', 'id': 'outtable' }).appendTo(output_div);
    table.css('display', 'none');
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).append(i18n(lang_Output))).appendTo(thead);

    if (outphases == 1)
    table.css('margin-top', '22px');

    tr = $('<tr />', { 'id': 'outtrl1' }).append($('<td />').append("L1:")).appendTo(tbody);
    $('<td />', { 'id': 'out_volt1_id' }).appendTo(tr);
    $('<td />', { id: 'out_cur1_id' }).appendTo(tr);
    $('<td />', { id: 'out_freq1_id' }).appendTo(tr);

    tr = $('<tr />', { 'id': 'outtrl2' }).append($('<td />').append("L2:")).appendTo(tbody);
    $('<td />', { id: 'out_volt2_id' }).appendTo(tr);
    $('<td />', { id: 'out_cur2_id' }).appendTo(tr);

    tr = $('<tr />', { 'id': 'outtrl3' }).append($('<td />').append("L3:")).appendTo(tbody);
    $('<td />', { id: 'out_volt3_id' }).appendTo(tr);
    $('<td />', { id: 'out_cur3_id' }).appendTo(tr);

    fragment.appendChild(output_div[0]);
    document.body.appendChild(fragment);
    set_output_values();
  }

  function set_output_values() //Output values
  {
    var output_val = get_ph_1_3_vals(valtable_obj.upsOutputVoltage, valtable_obj.upsOutputCurrent, valtable_obj.upsOutputFrequency, outphases);

    if (ups_id == 0) {
      if (output_val.availables[0] == 0 & output_val.availables[1] == 0 & output_val.availables[2] == 0) {
        $('#outtable').css('display', 'none');
        return true;
      }
    }

    $('#outtable').css('display', 'block');
    if (output_val.availables[0] != 0) {
      $('#outtrl1').css('display', 'block');
      $('#out_volt1_id').text(output_val.val_objs[0].values[0]);
      $('#out_cur1_id').text(output_val.val_objs[1].values[0]);
      $('#out_freq1_id').text(output_val.val_objs[2].values[0]);
    } else {
      $('#outtrl1').css('display', 'none');
    }

    if (output_val.availables[1] != 0) {
      $('#outtrl2').css('display', 'block');
      $('#out_volt2_id').text(output_val.val_objs[0].values[1]);
      $('#out_cur2_id').text(output_val.val_objs[1].values[1]);
    } else {
      $('#outtrl2').css('display', 'none');
    }

    if (output_val.availables[2] != 0) {
      $('#outtrl3').css('display', 'block');
      $('#out_volt3_id').text(output_val.val_objs[0].values[2]);
      $('#out_cur3_id').text(output_val.val_objs[1].values[2]);
    } else {
      $('#outtrl3').css('display', 'none');
    }
  }

  function create_battery_pane() //Battery panel
  {
    var val, tr, table, tbody, thead, batt_div,
    fragment = document.createDocumentFragment();

    css_obj = { position: 'absolute', top: y_pos + 360, left: x_pos + 260 }; //, width:130, height:100
    attr_obj = { id: 'battery_div_id' };
    batt_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(batt_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 2 }).append(i18n(lang_Battery))).appendTo(thead);
    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Voltage) + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_volt_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.upsBatteryVoltage], index: 0, unit: ' V', precision: 2 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Time) + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_autotime_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.upsEstimatedMinutesRemaining], index: 0, unit: ' Min', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Battery_Capacity_short) + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_cap_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.upsEstimatedChargeRemaining], index: 0, unit: ' %', precision: 0 })).appendTo(tr);

    fragment.appendChild(batt_div[0]);
    document.body.appendChild(fragment);
  }

  function set_battery_value() //set Battery value
  {
    $('#batt_volt_id').text(get_value({ values: [valtable_obj.upsBatteryVoltage], index: 0, unit: ' V', precision: 2 }));
    $('#batt_autotime_id').text(get_value({ values: [valtable_obj.upsEstimatedMinutesRemaining], index: 0, unit: ' Min', precision: 0 }));
    $('#batt_cap_id').text(get_value({ values: [valtable_obj.upsEstimatedChargeRemaining], index: 0, unit: ' %', precision: 0 }));
  }

  function get_ph_1_3_vals(volt, cur, freq, phases) {
    var val_obj, val;
    l_1_3_vals = {
      availables: [0, 0, 0], //L1-L3
      val_objs: [
        { unit: ' V', precision: 0, values: ['', '', ''] },
        { unit: ' A', precision: 2, values: ['', '', ''] },
        { unit: ' Hz', precision: 1, values: ['', '', ''] }
      ]
    };
    volt = volt || [];
    cur = cur || [], freq = freq || [];

    if (phases == 1) {
      l_1_3_vals.availables[0] = 1;
      l_1_3_vals.val_objs[0].values[0] = get_value({ values: [volt], index: 0, unit: ' V', precision: 0 });
      l_1_3_vals.val_objs[1].values[0] = get_value({ values: [cur], index: 0, unit: ' A', precision: 2 });
      l_1_3_vals.val_objs[2].values[0] = get_value({ values: [freq], index: 0, unit: ' Hz', precision: 1 });
    } else {
      $.each([volt, cur, freq], function (index, values) {
        val_obj = l_1_3_vals.val_objs[index];
        $.each(values, function (i, val) {
          if (i < phases) {
            val = values[i];
            if ((ups_protocol != prot_snmp && val != -9999) || (ups_protocol == prot_snmp && val != -1)) {
              if (values === freq && (i == 1 || i == 2)) {} else
              l_1_3_vals.availables[i] = 1;

              val = val.toFixed(val_obj.precision);
              val += val_obj.unit;
              val_obj.values[i] = val;
            }
          }
        });
      });
    }
    return l_1_3_vals;
  }

  function get_value(val_obj) {
    if (!val_obj.values || (val_obj.values.length <= val_obj.index))
    return '';
    var val = val_obj.values[val_obj.index];
    if (val == null || val.length == 0)
    return '';
    if (val_obj.values[val_obj.index] == -9999)
    return 'N/A';
    if (ups_protocol == prot_snmp && val_obj.values[val_obj.index] == -1)
    return 'N/A';

    val = val.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }

  function create_iby_ire_ssi_inv_rec_batt() //create IBY, IRE, SSI, INVERTER, RECTIFIER and BATTERY  pannes
  {
    var div, fragment = document.createDocumentFragment();
    css_obj = { position: 'absolute', top: y_pos + 229, left: x_pos + 548, width: 24, height: 10, overflow: 'hidden' };

    if (valtable_obj.EX_EXTSTATUS != null && (valtable_obj.EX_EXTSTATUS & (0x2000 | 0x400))) // load off
    css_obj['background-color'] = '#DC3632'; //red
    else if ((status & 16384) != 16384 && (status & 4) != 4) //IBY commlost and active
    css_obj['background-color'] = '#DC3632'; //red
    else
    css_obj['background-color'] = 'rgb(40, 134, 59)'; //'#52B245';//green rgb(40, 134, 59)
    div = $('<div/>').attr({ id: 'iby_div_id', 'class': 'img-rounded' }).css(css_obj);
    fragment.appendChild(div[0]);

    css_obj = { position: 'absolute', top: y_pos + 229, left: x_pos + 220, width: 24, height: 10, overflow: 'hidden' };
    if ((status & 8) == 8 || (status & 128) == 128) //IRE powerfail or input-high
    css_obj['background-color'] = '#DC3632'; //red
    else
    css_obj['background-color'] = 'rgb(40, 134, 59)'; //#52B245';//green
    div = $('<div/>').attr({ id: 'ire_div_id', 'class': 'img-rounded' }).css(css_obj);
    fragment.appendChild(div[0]);

    //bypass led
    css_obj = { position: 'absolute', top: y_pos + 150, left: x_pos + 220, width: 24, height: 10, overflow: 'hidden' };
    if (status & 8) //SSI powerfail
    css_obj['background-color'] = 'gray';
    else if (status & 1) //bypass
    css_obj['background-color'] = '#52B245'; //green
    else if (valtable_obj.EX_EXTSTATUS & 0x0200) //UPS_AB_BYPASSBAD The Bypass is out of tolerance
    css_obj['background-color'] = '#FF0000'; //red
    else
    css_obj['background-color'] = '#FFF500';

    div = $('<div/>').attr({ id: 'by_led_div_id', 'class': 'img-rounded' }).css(css_obj);
    fragment.appendChild(div[0]);

    document.body.appendChild(fragment);

    if (status & 8) //SSI powerfail
    panes_api.create_img_panel('ssi_img_id', './image/ups/ssww.gif', x_pos + 372, y_pos + 130, 50, 50, 0);
    else if (status & 1) //bypass
    panes_api.create_img_panel('ssi_img_id', './image/ups/sswgr.gif', x_pos + 372, y_pos + 130, 50, 50, 0);
    else if (valtable_obj.EX_EXTSTATUS & 0x0200) //UPS_AB_BYPASSBAD The Bypass is out of tolerance
    panes_api.create_img_panel('ssi_img_id', './image/ups/sswr.gif', x_pos + 372, y_pos + 130, 50, 50, 0);
    else
    panes_api.create_img_panel('ssi_img_id', './image/ups/sswge.gif', x_pos + 372, y_pos + 130, 50, 50, 0);

    if ((status & 512) == 512 //INVERTER inverterfail
      ||
      (status & 4096) == 4096 //inverterwarn
      ||
      (status & 256) == 256 //outputhigh
      ||
      (status & 32) == 32 //overtemp
      ||
      (overload == 1)) //overload
    panes_api.create_img_panel('inv_img_id', './image/ups/wrr.gif', x_pos + 458, y_pos + 210, 50, 50, 0);

    else if ((level != 0) && ((tempdeg != null) && (tempdeg != -9999) && (tempmax != null)) && (tempdeg > tempmax)) //overtemp1
    panes_api.create_img_panel('inv_img_id', './image/ups/wrr.gif', x_pos + 458, y_pos + 210, 50, 50, 0);

    else if ((status & 1) == 1) //bypass
    panes_api.create_img_panel('inv_img_id', './image/ups/wrge.gif', x_pos + 458, y_pos + 210, 50, 50, 0);
    else
    panes_api.create_img_panel('inv_img_id', './image/ups/wrgr.gif', x_pos + 458, y_pos + 210, 50, 50, 0);

    if ((status & 8) == 8) //RECTIFIER powerfail
    panes_api.create_img_panel('rec_img_id', './image/ups/grw.gif', x_pos + 286, y_pos + 210, 50, 50, 0);
    else
    panes_api.create_img_panel('rec_img_id', './image/ups/grgr.gif', x_pos + 286, y_pos + 210, 50, 50, 0);

    if ((status & 8) == 8) //BATTERY powerfail
    panes_api.create_img_panel('batt_img_id', './image/ups/Batgrv.gif', x_pos + 372, y_pos + 294, 50, 50, 0);
    else if ((status & 16) == 16 || (status & 1024) == 1024) // batterylow batterybad
    panes_api.create_img_panel('batt_img_id', './image/ups/Batrv.gif', x_pos + 372, y_pos + 294, 50, 50, 0);
    else
    panes_api.create_img_panel('batt_img_id', './image/ups/Batgev.gif', x_pos + 372, y_pos + 294, 50, 50, 0);
  }

  function set_iby_ire_ssi_inv_rec_batt() //SET IBY, IRE, SSI, INVERTER, RECTIFIER and BATTERY  pannes
  {
    if (valtable_obj.EX_EXTSTATUS != null && (valtable_obj.EX_EXTSTATUS & (0x2000 | 0x400))) // load off
    $('#iby_div_id').css('background-color', '#DC3632'); //red
    else if ((status & 16384) != 16384 && (status & 4) != 4) //IBY commlost and active
    $('#iby_div_id').css('background-color', '#DC3632'); //red
    else
    $('#iby_div_id').css('background-color', 'rgb(40, 134, 59)'); //green

    if ((status & 8) == 8 || (status & 128) == 128) //IRE powerfail or input-high
    $('#ire_div_id').css('background-color', '#DC3632'); //red
    else
    $('#ire_div_id').css('background-color', 'rgb(40, 134, 59)'); //green

    if ((status & 8) == 8) //SSI powerfail
    $('#ssi_img_id').attr('src', './image/ups/ssww.gif');
    else if ((status & 1) == 1) //bypass
    $('#ssi_img_id').attr('src', './image/ups/sswgr.gif');
    else if (valtable_obj.EX_EXTSTATUS & 0x0200) //UPS_AB_BYPASSBAD The Bypass is out of tolerance
    $('#ssi_img_id').attr('src', './image/ups/sswr.gif');
    else
    $('#ssi_img_id').attr('src', './image/ups/sswge.gif');

    if ((status & 512) == 512 //INVERTER inverterfail
      ||
      (status & 4096) == 4096 //inverterwarn
      ||
      (status & 256) == 256 //outputhigh
      ||
      (status & 32) == 32 //overtemp
      ||
      (overload == 1)) //overload
    $('#inv_img_id').attr('src', './image/ups/wrr.gif');

    else if ((level != 0) && ((tempdeg != null) && (tempdeg != "-9999") && (tempmax != null)) && (tempdeg > tempmax)) //overtemp1
    $('#inv_img_id').attr('src', './image/ups/wrr.gif');
    else if ((status & 1) == 1) //bypass
    $('#inv_img_id').attr('src', './image/ups/wrge.gif');
    else
    $('#inv_img_id').attr('src', './image/ups/wrgr.gif');

    if ((status & 8) == 8) //RECTIFIER powerfail
    $('#rec_img_id').attr('src', './image/ups/grw.gif');
    else
    $('#rec_img_id').attr('src', './image/ups/grgr.gif');

    if ((status & 8) == 8) //BATTERY powerfail
    $('#batt_img_id').attr('src', './image/ups/Batgrv.gif');
    else if ((status & 16) == 16 || (status & 1024) == 1024) // batterylow batterybad
    $('#batt_img_id').attr('src', './image/ups/Batrv.gif');
    else
    $('#batt_img_id').attr('src', './image/ups/Batgev.gif');

    //bypass led
    if ((ups_protocol == 0x80F9) && (ups_id != 0)) // $$MBSALIRM Salicru (oem82) UPS "RM" modular
    return true;
    if (status & 8) //SSI powerfail
    $('#by_led_div_id').css('background-color', 'gray'); //gray #F1F1F2
    else if (status & 1) //bypass
    $('#by_led_div_id').css('background-color', '#52B245'); //green
    else if (valtable_obj.EX_EXTSTATUS & 0x0200) //UPS_AB_BYPASSBAD The Bypass is out of tolerance
    $('#by_led_div_id').css('background-color', '#FF0000'); //red
    else
    $('#by_led_div_id').css('background-color', '#FFF500'); //gelb

  }

  function create_status_pane() //UPS status
  {
    var status_div = $('<div/>'),
    status_span;
    css_obj = { position: 'absolute', top: y_pos + 50, left: x_pos + 710, align: 'center', overflow: 'hidden' };

    $(status_div).css(css_obj);
    status_span = $('<span />', { id: 'ups_status_id', 'class': get_status_class(), title: i18n('Click to see Status Text') }).append(i18n('Status'));
    status_span.css('cursor', 'pointer');
    status_span.click(function (event) //visibility: hidden
      {
        var sys_mod_status_txt_div = $('#sys_mod_status_txt_div'),
        display = sys_mod_status_txt_div.css('display') == 'none' ? 'block' : 'none';
        sys_mod_status_txt_div.css({ display: display });
      });

    $('<h4 />').append(status_span).appendTo(status_div);
    status_div.appendTo(document.body);
  }

  function set_ups_status() //set UPS status
  {
    $('#ups_status_id').attr('class', get_status_class());
  }

  function get_status_class() {
    if (status & 0xF7BA)
    return 'label label-danger';

    if (status & 0x41)
    return 'label label-warning';

    return 'label label-success';
  }

  function create_outpower_loadbars() //outpower loadbars
  {
    var fragment = document.createDocumentFragment(),
    div;

    if (valtable_obj.upsOutputPercentLoad == null)
    return true;

    outpower_loadbars_created = true;

    if (outphases == 1) {
      panes_api.create_loadbar_pane({ value: valtable_obj.upsOutputPercentLoad, id: 'loadbar1_id', left: x_pos + 564, top: y_pos + 336, title: 'L1', scaler: 1 });
    } else {
      panes_api.create_loadbar_pane({ value: valtable_obj.upsOutputPercentLoad[0], id: 'loadbar1_id', left: x_pos + 564, top: y_pos + 336, title: 'L1', scaler: 1 });
      if (outphases > 1)
      panes_api.create_loadbar_pane({ value: valtable_obj.upsOutputPercentLoad[1], id: 'loadbar2_id', left: x_pos + 564, top: y_pos + 366, title: 'L2', scaler: 0 });
      if (outphases > 2)
      panes_api.create_loadbar_pane({ value: valtable_obj.upsOutputPercentLoad[2], id: 'loadbar3_id', left: x_pos + 564, top: y_pos + 396, title: 'L3', scaler: 0 });
    }
    css_obj = { position: 'absolute', top: y_pos + 310, left: x_pos + 540, width: 250, height: 120, 'background-color': $(document.body).css('background-color'), 'z-index': 20 };
    div = $('<div/>').attr({ id: 'loadbars' }).css(css_obj);
    fragment.appendChild(div[0]);

    document.body.appendChild(fragment);
    set_outpower_loadbars();
  }

  function set_outpower_loadbars() //outpower loadbars
  {
    if (valtable_obj.upsOutputPercentLoad == null)
    return true;
    if (outphases == 1) {
      if (valtable_obj.upsOutputPercentLoad != -9999) {
        panes_api.set_loabar_value(valtable_obj.upsOutputPercentLoad, 'loadbar1_id');
        $('#loadbars').css('display', 'none');
      } else {
        $('#loadbars').css('display', 'block');
      }
    } else {
      if (valtable_obj.upsOutputPercentLoad[0] != -9999) {
        panes_api.set_loabar_value(valtable_obj.upsOutputPercentLoad[0], 'loadbar1_id');
      }
      if ((outphases > 1) && valtable_obj.upsOutputPercentLoad[1] != -9999) {
        panes_api.set_loabar_value(valtable_obj.upsOutputPercentLoad[1], 'loadbar2_id');
      }
      if ((outphases > 2) && valtable_obj.upsOutputPercentLoad[2] != -9999) {
        panes_api.set_loabar_value(valtable_obj.upsOutputPercentLoad[2], 'loadbar3_id');
      }

      if ((valtable_obj.upsOutputPercentLoad[0] != -9999) || (valtable_obj.upsOutputPercentLoad[1] != -9999) || (valtable_obj.upsOutputPercentLoad[2] != -9999)) {
        $('#loadbars').css('display', 'none');
      } else {
        $('#loadbars').css('display', 'block');
      }
    }
  }

  function create_rom_temp() //rom temp
  {
    var fragment = document.createDocumentFragment(),
    rom_temp_div;
    css_obj = { position: 'absolute', top: y_pos + 306, left: x_pos + 8 };
    rom_temp_div = $('<div/>').attr({ id: 'rom_temp_div_id' }).css(css_obj);
    panes_api.create_rom_temp_pane(valtable_obj, { id: 'rom_temp_table_id', 'class': 'table table-condensed table-hover' }).appendTo(rom_temp_div);
    fragment.appendChild(rom_temp_div[0]);
    document.body.appendChild(fragment);
  }

  function create_sys_mod_status_panel() {
    var fragment = document.createDocumentFragment(),
    tr, tr, table, tbody, a,
    title = i18n("Status") + ":" + valtable_obj.upsIdentModel,
    status_txt_array = get_sys_mod_status_txt(),
    sys_mod_status_txt_div;

    css_obj = {
      position: 'absolute',
      top: y_pos + 72,
      left: x_pos + 36,
      align: 'center',
      'background-color': '#F1F1F1',
      display: 'none',
      border: 'solid 1px black'
    };

    sys_mod_status_txt_div = $('<div/>', { id: 'sys_mod_status_txt_div', 'class': 'img-rounded' }).css(css_obj);

    if (ups_id != 0)
    title += " [" + i18n("Module") + " " + ups_id + "]";

    a = $('<a/>', { 'class': 'list-group-item active', id: 'status_model_name_id' }).append(title).appendTo(sys_mod_status_txt_div);
    a.css('height', 30);
    table = $('<table />', { 'class': 'table table-condensed', id: 'sys_mod_status_txt_table' }).appendTo(sys_mod_status_txt_div); // table-hover
    table.css({ 'background-color': '#F1F1F1' })
    tbody = $('<tbody />', { id: 'sys_mod_status_txt_table_body' }).appendTo(table);
    $.each(status_txt_array, function (index, status_txt) {
      tr = $('<tr />').appendTo(tbody);
      td = $('<td />', { 'align': 'left' }).append(status_txt).appendTo(tr);
    });

    fragment.appendChild(sys_mod_status_txt_div[0]);
    document.body.appendChild(fragment);
    new utils_api.draggable('sys_mod_status_txt_div');
  }

  function set_sys_mod_status() {
    var tr, td,
    title = i18n("Status") + ":" + valtable_obj.upsIdentModel,
    tbody = $('#sys_mod_status_txt_table_body'),
    status_txt_array = get_sys_mod_status_txt();

    if (ups_id != 0)
    title += " [" + i18n("Module") + " " + ups_id + "]";

    $('#status_model_name_id').text(title);

    tbody.empty();
    $.each(status_txt_array, function (index, status_txt) {
      tr = $('<tr />').appendTo(tbody);
      td = $('<td />', { 'align': 'left' }).append(status_txt).appendTo(tr);
    });
  }


  function get_sys_mod_status_txt() {
    var status_txt_array = [];
    $.each(status_obj, function (index, status_obj) {
      if (status_obj.bit & valtable_obj.upsGenerexState) {
        status_txt_array.push(i18n(status_obj.txt));
      }
    });
    return status_txt_array;
  }

  function get_module_status_class(module_index) {
    var bit_val = 1 << module_index;
    if ((valtable_obj.RAWSTATEG & bit_val) == bit_val)
    return "btn btn-sm btn-danger";
    return "btn btn-sm btn-default";
  }

  function set_model_name() {
    var model_name = valtable_obj.upsIdentModel;
    if (ups_id != 0)
    model_name += " [" + i18n("Module") + " " + ups_id + "]";
    $('#model_name_id').html(model_name);
  }
}(jQuery));