<?xml version="1.0"?>
<!--
   vh_panel.xsl - UPS screen for General Electric (GE VH model).
   Copyright (c) 2008, Generex GmbH. All rights reserved.
   Said Raqui
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <!-- Methods -->
  <!--Header-->
  <xsl:template name="vh_panel-header">
    <xsl:call-template name="app-header">
      <xsl:with-param name="top" select="10"/>
      <xsl:with-param name="left" select="25"/>
    </xsl:call-template>
  </xsl:template>

  <!--Footer-->
  <xsl:template name="vh_panel-footer" >
    <xsl:call-template name="app-footer" >
      <xsl:with-param name="top" select="430"/>
      <xsl:with-param name="left" select="10"/>
      <xsl:with-param name="width" select="752"/>
      <xsl:with-param name="height" select="70"/>
    </xsl:call-template>
  </xsl:template>
  <!--Menu-->
  <xsl:template name="vh_panel-menu">
    <xsl:call-template name="app-menu">
      <xsl:with-param name="top" select="428"/>
      <xsl:with-param name="left" select="0"/>
      <xsl:with-param name="width" select="0"/>
      <xsl:with-param name="height" select="0"/>
      <xsl:with-param name="class" select="'XBold_black'"/>
    </xsl:call-template>
  </xsl:template>


  <!--Body-->
  <xsl:template name="vh_panel-body">
    <div id="master" style="position:absolute;top:10px;left:10px;">
      <xsl:apply-templates />
    </div>
    <xsl:call-template name="IEpixelBugfixCall"/>
    <xsl:call-template name="js_refresh_call">
      <xsl:with-param	 name="timeout" select="1000*//report/@refresh"/>
    </xsl:call-template>
  </xsl:template>

  <!-- Implementation -->
  <xsl:template match="values">
    <xsl:call-template name="background">
      <xsl:with-param name="imagepath" select="'./lib/ups/image/ge/Standard_vh.png'"/>
      <xsl:with-param name="x" select="'0'"/>
      <xsl:with-param name="y" select="'0'"/>
      <xsl:with-param name="w" select="'752'"/>
      <xsl:with-param name="h" select="'399'"/>
      <xsl:with-param name="border" select="0"/>
      <xsl:with-param name="id" select="'background'"/>
    </xsl:call-template>
    <div style="color:black; font-weight:bold; font-size:9pt">
      <!-- Manufacturer -->
      <xsl:variable name="manufacturer" select="value[@name='CP4_MANUFACTURER']/@val"/>
      <xsl:call-template name="paneText">
        <xsl:with-param name="x" select="60" />
        <xsl:with-param name="y" select="34" />
        <xsl:with-param name="w" select="200" />
        <xsl:with-param name="h" select="30" />
        <xsl:with-param name="align" select="'left'" />
        <xsl:with-param name="value" select="concat('Manufacturer:&#160;&#160;&#160;&#160;',$manufacturer)" />
        <xsl:with-param name="name" select="'manufacturer_id'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('manufacturer_id', ['Manufacturer','<xsl:value-of select="concat(':&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;',$manufacturer)" />']);</script>

      <!-- Model -->
      <xsl:variable name="model" select="value[@name='CP4_MODEL']/@val"/>
      <xsl:call-template name="paneText">
        <xsl:with-param name="x" select="60" />
        <xsl:with-param name="y" select="50" />
        <xsl:with-param name="w" select="200" />
        <xsl:with-param name="h" select="17" />
        <xsl:with-param name="align" select="'left'" />
        <xsl:with-param name="value" select="concat('Model:&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;',$model)" />
        <xsl:with-param name="name" select="'model_id'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('model_id', ['Model','<xsl:value-of select="concat(':&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;',$model)" />']);</script>

      <!-- Power rating -->
      <xsl:variable name="power_rating" select="value[@name='CP4_NOMPOWER']/@val"/>
      <xsl:call-template name="paneText">
        <xsl:with-param name="x" select="60" />
        <xsl:with-param name="y" select="66" />
        <xsl:with-param name="w" select="200" />
        <xsl:with-param name="h" select="17" />
        <xsl:with-param name="align" select="'left'" />
        <xsl:with-param name="unit" select="'VA'" />
        <xsl:with-param name="value" select="concat('Power rating:&#160;&#160;&#160;&#160;&#160;',substring-before($power_rating,'.'))" />
        <xsl:with-param name="name" select="'power_rating_id'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('power_rating_id', ['Power rating','<xsl:value-of select="concat(':&#160;&#160;&#160;&#160;&#160;',substring-before($power_rating,'.'))" />', ' VA']);</script>

      <!-- Firmware -->
      <xsl:variable name="firmware" select="value[@name='CP4_SERIALNO']/@val"/>
      <xsl:call-template name="paneText">
        <xsl:with-param name="x" select="60" />
        <xsl:with-param name="y" select="82" />
        <xsl:with-param name="w" select="263" />
        <xsl:with-param name="h" select="17" />
        <xsl:with-param name="align" select="'left'" />
        <xsl:with-param name="value" select="concat('Serial number:&#160;&#160;&#160;',$firmware)" />
        <xsl:with-param name="name" select="'serial_number_id'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('serial_number_id', ['Serial number','<xsl:value-of select="concat(':&#160;&#160;&#160;',$firmware)" />']);</script>
    </div>
    <!-- STATUS (Alar Condition) -->
    <xsl:variable name="alarm" >
      <xsl:call-template name="get_alarm_condition"/>
    </xsl:variable>
    <!-- COMMON ALARM -->
    <div id="alarm_1_id" style="position: absolute; left: 534px; top: 305px; width: 33px; height: 12px; color:#3341AA; font-weight:bold; font-size:9pt">
      <script type="text/javascript"> translate_text('alarm_1_id', 'Alarm');</script>
   </div>
    <div style="position: absolute; left: 534px; top: 290px; width: 33px; height: 12px">
      <xsl:choose>
        <xsl:when test="0!=$alarm">
          <img border="1" src="./lib/ups/image/ups/led33x12red.gif" />
        </xsl:when>
        <xsl:otherwise>
          <img border="1" src="./lib/ups/image/ups/led33x12gr.gif" />
        </xsl:otherwise>
      </xsl:choose>
    </div>

    <!-- Output Power-->
    <xsl:variable name="outpower" select="value[@name='OUTPOWER']/@val"/>
    <!-- LOAD BAR-->
    <div id="load_b_1_id" style="position: absolute; left: 668px; top: 32px; width: 33px; height: 12px; color:#3341AA; font-weight:bold; font-size:9pt">
      <script type="text/javascript"> translate_text('load_b_1_id', '<xsl:value-of select="$lang-Load"/>');</script>
    </div>
    <div style="color:#3341AA; font-weight:bold; font-size:9pt">
      <xsl:call-template name="Loadbar">
        <xsl:with-param name="load" select="value[@name='OUTPOWER']/@val"/>
        <xsl:with-param name="x" select="'670'"/>
        <xsl:with-param name="y" select="'52'"/>
        <xsl:with-param name="yOffset" select="'8'"/>
        <xsl:with-param name="border" select="'1'"/>
        <xsl:with-param name="scale" select="'1'"/>
        <xsl:with-param name="title" select="concat(substring-before($outpower,'.'),'%')"/>
        <xsl:with-param name="textcolor" select="'#3341AA'"/>
      </xsl:call-template>
    </div>
    <!-- OUTPUT_VOLT Output Volt -->
    <div id="output_1_id" style="position: absolute; left: 545px; top: 170px; width: 33px; height: 12px; color:#3341AA; font-weight:bold; font-size:9pt">
      <script type="text/javascript"> translate_text('output_1_id', 'Output');</script>
    </div>
    <div style="color:black; font-weight:bold; font-size:9pt">
      <!--  Output Volt (OUTPUT_VOLT) -->
      <xsl:variable name="output_volt" select="value[@name='OUTPUT_VOLT']/@val"/>
      <!-- OUTPUT_POW variables -->
      <!--output power values -->
      <xsl:variable name="output_pow">
        <xsl:call-template name="power_val">
          <xsl:with-param name="value" select="value[@name='OUTPUT_POW']/@val" />
        </xsl:call-template>
      </xsl:variable>
      <!--output power unit (OUTPUT_POW)-->
      <xsl:variable name="output_pow_unit">
        <xsl:call-template name="power_unit">
          <xsl:with-param name="value" select="value[@name='OUTPUT_POW']/@val" />
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="t_width">
        <xsl:choose>
          <xsl:when test="value[@name='SOLAWROC']/@val &lt; 0 and $output_pow &lt;0">
            <xsl:value-of select="114"/>
          </xsl:when>
          <xsl:when test="string-length(value[@name='SOLAWROC']/@val)=0 and string-length($output_pow)=0">
            <xsl:value-of select="65"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="160"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:call-template name="paneRow1Col3_vh">
        <xsl:with-param name="x" select="540" />
        <xsl:with-param name="y" select="230" />
        <xsl:with-param name="w" select="$t_width" />
        <xsl:with-param name="h" select="40" />
        <xsl:with-param name="title" select="'L'"/>
        <xsl:with-param name="value1" select="substring-before($output_volt,'.')"/>
        <xsl:with-param name="value2" select="value[@name='SOLAWROC']/@val"/>
        <xsl:with-param name="value3" select="$output_pow"/>
        <xsl:with-param name="unit1" select="'V'"/>
        <xsl:with-param name="unit2" select="'A'"/>
        <xsl:with-param name="unit3" select="$output_pow_unit"/>
        <xsl:with-param name="precision1" select="-1"/>
        <xsl:with-param name="precision2" select="1"/>
        <xsl:with-param name="precision3" select="1"/>
      </xsl:call-template>
      <!-- OUTFREQ Out Frequence -->
      <xsl:variable name="out_freq" select="value[@name='OUTFREQ']/@val"/>
      <xsl:call-template name="paneRow1_ge">
        <xsl:with-param name="xT" select="540"/>
        <xsl:with-param name="yT" select="200"/>
        <xsl:with-param name="wT" select="20"/>
        <xsl:with-param name="hT" select="20"/>
        <xsl:with-param name="xOff" select="0"/>
        <xsl:with-param name="w" select="64"/>
        <xsl:with-param name="h" select="21"/>
        <xsl:with-param name="alignT" select="'left'"/>
        <xsl:with-param name="text" select="'f'" />
        <xsl:with-param name="value"  select="$out_freq" />
        <xsl:with-param name="unit" select="'Hz'"/>
        <xsl:with-param name="precision"  select="1"/>
        <xsl:with-param name="visibility" select="'visible'"/>
      </xsl:call-template>
      <!-- Service -->
      <xsl:variable name="service">
        <xsl:call-template name="bit">
          <xsl:with-param name="val" select="value[@name='STATUS']/@val"/>
          <xsl:with-param name="bit" select="$bit10"/>
        </xsl:call-template>
      </xsl:variable>
      <div id="service_id" style="position: absolute; left: 584px; top: 305px; width: 33px; height: 12px; color:#3341AA; font-weight:bold; font-size:9pt">
         <script type="text/javascript"> translate_text('service_id', 'Service');</script>
      </div>
      <div style="position: absolute; left: 584px; top: 290px; width: 33px; height: 12px">
        <xsl:choose>
          <xsl:when test="1=$service">
            <img border="1" src="./lib/ups/image/ups/led33x12yellow.gif" />
          </xsl:when>
          <xsl:otherwise>
            <img border="1" src="./lib/ups/image/ups/led33x12gr.gif" />
          </xsl:otherwise>
        </xsl:choose>
      </div>
      <!-- CP4_OPSOURCE (Output source) -->
      <xsl:variable name="outsource" select="value[@name='CP4_OPSOURCE']/@val"/>
      <!-- Output -->
      <div id="output_2_id" style="position: absolute; left: 635px; top: 305px; width: 33px; height: 12px; color:#3341AA; font-weight:bold; font-size:9pt">
         <script type="text/javascript"> translate_text('output_2_id', 'Output');</script>
      </div>
      <div style="position: absolute; left: 635px; top: 290px; width: 33px; height: 12px">
        <xsl:choose>
          <xsl:when test="2=$outsource">
            <img border="1" src="./lib/ups/image/ups/led33x12red.gif" />
          </xsl:when>
          <xsl:when test="1=$outsource or 4=$outsource">
            <img border="1" src="./lib/ups/image/ups/led33x12yellow.gif" />
          </xsl:when>
          <xsl:otherwise>
            <img border="1" src="./lib/ups/image/ups/led33x12gr.gif" />
          </xsl:otherwise>
        </xsl:choose>
      </div>
      <!--output source values -->
      <xsl:variable name="op_source_val">
        <xsl:choose>
          <xsl:when test="1=$outsource">Other </xsl:when>
          <xsl:when test="2=$outsource">None </xsl:when>
          <xsl:when test="3=$outsource">Normal </xsl:when>
          <xsl:when test="4=$outsource">Bypass </xsl:when>
          <xsl:when test="5=$outsource">Battery </xsl:when>
          <xsl:when test="6=$outsource">Booster </xsl:when>
          <xsl:when test="7=$outsource">Reducer </xsl:when>
          <xsl:otherwise>None</xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <!--output source  -->
      <xsl:call-template name="paneRow">
        <xsl:with-param name="xT" select="540"/>
        <xsl:with-param name="yT" select="215"/>
        <xsl:with-param name="wT" select="50"/>
        <xsl:with-param name="hT" select="20"/>
        <xsl:with-param name="xOff" select="0"/>
        <xsl:with-param name="w" select="20"/>
        <xsl:with-param name="h" select="21"/>
        <xsl:with-param name="alignT" select="'left'"/>
        <xsl:with-param name="text" select="$lang-Source" />
        <xsl:with-param name="value"  select="$op_source_val" />
        <xsl:with-param name="visibility" select="'visible'"/>
        <xsl:with-param name="name" select="'out_src_1_'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('out_src_1_0', '<xsl:value-of select="$lang-Source"/>');</script>
      <script type="text/javascript"> translate_text('out_src_1_1', '<xsl:value-of select="$op_source_val"/>');</script>
    </div>

    <!-- Battery Volt-->
    <div id="batt_1" style="position: absolute; left: 220px; top: 240px; width: 33px; height: 12px; color:#3341AA; font-weight:bold; font-size:9pt">
      <script type="text/javascript"> translate_text('batt_1', 'Battery');</script>
   </div>
    <div style="color:black; font-weight:bold; font-size:9pt">
      <xsl:variable name="battvolt" select="value[@name='BATTVOLT']/@val"/>
      <xsl:call-template name="paneRow1_ge">
        <xsl:with-param name="xT" select="220"/>
        <xsl:with-param name="yT" select="255"/>
        <xsl:with-param name="wT" select="50"/>
        <xsl:with-param name="hT" select="20"/>
        <xsl:with-param name="xOff" select="0"/>
        <xsl:with-param name="w" select="60"/>
        <xsl:with-param name="h" select="21"/>
        <xsl:with-param name="alignT" select="'left'"/>
        <xsl:with-param name="text" select="'Ubatt'" />
        <xsl:with-param name="value"  select="$battvolt" />
        <xsl:with-param name="unit" select="'V'"/>
        <xsl:with-param name="precision"  select="1"/>
        <xsl:with-param name="visibility" select="'visible'"/>
        <xsl:with-param name="name" select="'ubatt_1'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('ubatt_10', ['Ubatt', ':']);</script>
      <!-- Power fail -->
      <xsl:variable name="power_fail">
        <xsl:call-template name="bit">
          <xsl:with-param name="val" select="value[@name='STATUS']/@val"/>
          <xsl:with-param name="bit" select="$bit3"/>
        </xsl:call-template>
      </xsl:variable>
      <!-- Battery current-->
      <xsl:variable name="battery_curr" select="value[@name='BATTERYCURRENT']/@val"/>
      <xsl:if test="string-length($battery_curr) != 0">
        <xsl:call-template name="paneRow1_ge">
          <xsl:with-param name="xT" select="220"/>
          <xsl:with-param name="yT" select="270"/>
          <xsl:with-param name="wT" select="50"/>
          <xsl:with-param name="hT" select="80"/>
          <xsl:with-param name="xOff" select="1"/>
          <xsl:with-param name="w" select="60"/>
          <xsl:with-param name="h" select="21"/>
          <xsl:with-param name="alignT" select="'left'"/>
          <xsl:with-param name="text" select="'Ibatt'" />
          <xsl:with-param name="value"  select="$battery_curr" />
          <xsl:with-param name="unit" select="'A'"/>
          <xsl:with-param name="precision"  select="1"/>
          <xsl:with-param name="power_fail"  select="$power_fail"/>
          <xsl:with-param name="name" select="'ibatt_1'" />
        </xsl:call-template>
        <script type="text/javascript"> translate_text('ibatt_10', ['Ibatt', ':']);</script>
      </xsl:if>
      <!-- Temperature-->
      <xsl:variable name="temp_yT">
        <xsl:choose>
          <xsl:when test="string-length($battery_curr) = 0">
            <xsl:value-of select="270"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="285"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:variable name="temp" select="value[@name='TEMPDEG']/@val"/>
      <xsl:call-template name="paneRow1_ge">
        <xsl:with-param name="xT" select="220"/>
        <xsl:with-param name="yT" select="$temp_yT"/>
        <xsl:with-param name="wT" select="50"/>
        <xsl:with-param name="hT" select="80"/>
        <xsl:with-param name="xOff" select="1"/>
        <xsl:with-param name="w" select="60"/>
        <xsl:with-param name="h" select="21"/>
        <xsl:with-param name="alignT" select="'left'"/>
        <xsl:with-param name="text" select="$lang-Temperature-short" />
        <xsl:with-param name="value"  select="$temp" />
        <xsl:with-param name="unit" select="'&#176;C'"/>
        <xsl:with-param name="precision"  select="-1"/>
        <xsl:with-param name="visibility" select="'visible'"/>
        <xsl:with-param name="name" select="'batt_temp_'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('batt_temp_0', ['Temp', ':']);</script>

      <!--Battery capacity -->
      <xsl:variable name="battcap" select="value[@name='BATTCAP']/@val"/>
      <xsl:call-template name="paneRow1_ge">
        <xsl:with-param name="xT" select="220"/>
        <xsl:with-param name="yT" select="$temp_yT+15"/>
        <xsl:with-param name="wT" select="50"/>
        <xsl:with-param name="hT" select="20"/>
        <xsl:with-param name="xOff" select="0"/>
        <xsl:with-param name="w" select="60"/>
        <xsl:with-param name="h" select="60"/>
        <xsl:with-param name="alignT" select="'left'"/>
        <xsl:with-param name="text" select="'Charge'" />
        <xsl:with-param name="value"  select="$battcap" />
        <xsl:with-param name="unit" select="'&#160;%'"/>
        <xsl:with-param name="precision"  select="-1"/>
        <xsl:with-param name="visibility" select="'visible'"/>
        <xsl:with-param name="name" select="'batt_charge_'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('batt_charge_0', ['Charge', ':']);</script>

      <!--Runtime -->
      <xsl:variable name="autonomtime" select="value[@name='AUTONOMTIME']/@val"/>
      <xsl:call-template name="paneRow1_ge">
        <xsl:with-param name="xT" select="220"/>
        <xsl:with-param name="yT" select="$temp_yT+30"/>
        <xsl:with-param name="wT" select="50"/>
        <xsl:with-param name="hT" select="20"/>
        <xsl:with-param name="xOff" select="0"/>
        <xsl:with-param name="w" select="60"/>
        <xsl:with-param name="h" select="21"/>
        <xsl:with-param name="alignT" select="'left'"/>
        <xsl:with-param name="text" select="'Runtime'" />
        <xsl:with-param name="value"  select="$autonomtime" />
        <xsl:with-param name="unit" select="'Min'"/>
        <xsl:with-param name="precision"  select="-1"/>
        <xsl:with-param name="visibility" select="'visible'"/>
        <xsl:with-param name="name" select="'batt_runtime_'" />
      </xsl:call-template>
      <script type="text/javascript"> translate_text('batt_runtime_0', ['Runtime', ':']);</script>
    </div>
    <div style="position: absolute; left: 122px; top: 175px; width: 33px; height: 12px; color:#3341AA; font-weight:bold; font-size:9pt">Mains</div>
    <!--width-->
    <xsl:variable name="width">
      <xsl:choose>
        <xsl:when test="string-length(value[@name='INPUTCURRENT']/@val)=0 or string-length(value[@name='INVOLT']/@val)=0">
          <xsl:value-of select="72"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="110"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <!-- Input Volt and INPUTCURRENT" -->
    <xsl:call-template name="paneRow1Col3_vh">
      <xsl:with-param name="x" select="120" />
      <xsl:with-param name="y" select="210" />
      <xsl:with-param name="w" select="$width" />
      <xsl:with-param name="h" select="40" />
      <xsl:with-param name="title" select="'L'"/>
      <xsl:with-param name="value1" select="substring-before(value[@name='INVOLT']/@val,'.')"/>
      <xsl:with-param name="value2" select="value[@name='INPUTCURRENT']/@val"/>
      <xsl:with-param name="value3" select="' '"/>
      <xsl:with-param name="unit1" select="'V'"/>
      <xsl:with-param name="unit2" select="'A'"/>
      <xsl:with-param name="precision1" select="-1"/>
      <xsl:with-param name="precision2" select="1"/>
      <xsl:with-param name="precision3" select="0"/>
    </xsl:call-template>
    <div style="color:black; font-weight:bold; font-size:9pt">
      <!-- In Frequence -->
      <xsl:variable name="in_freq" select="value[@name='INFREQ']/@val"/>
      <xsl:call-template name="paneRow1_ge">
        <xsl:with-param name="xT" select="122"/>
        <xsl:with-param name="yT" select="195"/>
        <xsl:with-param name="wT" select="20"/>
        <xsl:with-param name="hT" select="20"/>
        <xsl:with-param name="xOff" select="0"/>
        <xsl:with-param name="w" select="64"/>
        <xsl:with-param name="h" select="21"/>
        <xsl:with-param name="alignT" select="'left'"/>
        <xsl:with-param name="text" select="'f'" />
        <xsl:with-param name="value"  select="$in_freq" />
        <xsl:with-param name="unit" select="'Hz'"/>
        <xsl:with-param name="precision"  select="1"/>
        <xsl:with-param name="visibility" select="'visible'"/>
      </xsl:call-template>
    </div>

    <!-- Alarm condition -->
    <!--upsAlarmBatteryBad-->
    <xsl:variable name="upsAlarmBatteryBad">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit0"/>
      </xsl:call-template>
    </xsl:variable>
    <!--OnBattery-->
    <xsl:variable name="upsAlarmOnBattery">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit1"/>
      </xsl:call-template>
    </xsl:variable>
    <!--LowBattery-->
    <xsl:variable name="upsAlarmLowBattery">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit2"/>
      </xsl:call-template>
    </xsl:variable>
    <!--DepletedBattery-->
    <xsl:variable name="upsAlarmDepletedBattery">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit3"/>
      </xsl:call-template>
    </xsl:variable>
    <!--TempBad-->
    <xsl:variable name="upsAlarmTempBad">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit4"/>
      </xsl:call-template>
    </xsl:variable>
    <!--InputBad-->
    <xsl:variable name="upsAlarmInputBad">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit5"/>
      </xsl:call-template>
    </xsl:variable>
    <!--OutputBad-->
    <xsl:variable name="upsAlarmOutputBad">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit6"/>
      </xsl:call-template>
    </xsl:variable>
    <!--OutputOverload-->
    <xsl:variable name="upsAlarmOutputOverload">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit7"/>
      </xsl:call-template>
    </xsl:variable>
    <!--OnBypass-->
    <xsl:variable name="upsAlarmOnBypass">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit8"/>
      </xsl:call-template>
    </xsl:variable>
    <!--BypassBad-->
    <xsl:variable name="upsAlarmBypassBad">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit9"/>
      </xsl:call-template>
    </xsl:variable>
    <!--OutputOffAsRequested -->
    <xsl:variable name="upsAlarmOutputOffAsRequested">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit10"/>
      </xsl:call-template>
    </xsl:variable>
    <!--UpsOffAsRequested -->
    <xsl:variable name="upsAlarmUpsOffAsRequested">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit11"/>
      </xsl:call-template>
    </xsl:variable>
    <!--ChargerFailed  -->
    <xsl:variable name="upsAlarmChargerFailed">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit12"/>
      </xsl:call-template>
    </xsl:variable>
    <!--UpsOutputOff -->
    <xsl:variable name="upsAlarmUpsOutputOff">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit13"/>
      </xsl:call-template>
    </xsl:variable>
    <!--UpsSystemOff-->
    <xsl:variable name="upsAlarmUpsSystemOff">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit14"/>
      </xsl:call-template>
    </xsl:variable>
    <!--FanFailure -->
    <xsl:variable name="upsAlarmFanFailure">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit15"/>
      </xsl:call-template>
    </xsl:variable>
    <!--FuseFailure -->
    <xsl:variable name="upsAlarmFuseFailure">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit16"/>
      </xsl:call-template>
    </xsl:variable>
    <!--GeneralFault  -->
    <xsl:variable name="upsAlarmGeneralFault">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit17"/>
      </xsl:call-template>
    </xsl:variable>
    <!--DiagnosticTestFailed -->
    <xsl:variable name="upsAlarmDiagnosticTestFailed">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit18"/>
      </xsl:call-template>
    </xsl:variable>
    <!--CommunicationsLost -->
    <xsl:variable name="upsAlarmCommunicationsLost">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit19"/>
      </xsl:call-template>
    </xsl:variable>
    <!--AwaitingPower-->
    <xsl:variable name="upsAlarmAwaitingPower">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit20"/>
      </xsl:call-template>
    </xsl:variable>
    <!--ShutdownPending-->
    <xsl:variable name="upsAlarmShutdownPending">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit21"/>
      </xsl:call-template>
    </xsl:variable>
    <!--ShutdownImminent-->
    <xsl:variable name="upsAlarmShutdownImminent">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit22"/>
      </xsl:call-template>
    </xsl:variable>
    <!--TestInProgress-->
    <xsl:variable name="upsAlarmTestInProgress">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit23"/>
      </xsl:call-template>
    </xsl:variable>
    <!--ReceptacleOff-->
    <xsl:variable name="upsAlarmReceptacleOff">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit24"/>
      </xsl:call-template>
    </xsl:variable>
    <!--VoltageOnOutput-->
    <xsl:variable name="upsAlarmVoltageOnOutput">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit25"/>
      </xsl:call-template>
    </xsl:variable>
    <!--OvervoltageOnDCLink-->
    <xsl:variable name="upsAlarmOvervoltageOnDCLink">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit26"/>
      </xsl:call-template>
    </xsl:variable>
    <!--InputCircuitFailure-->
    <xsl:variable name="upsAlarmInputCircuitFailure">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit27"/>
      </xsl:call-template>
    </xsl:variable>
    <!--ChargeConverterError-->
    <xsl:variable name="upsAlarmChargeConverterError">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit28"/>
      </xsl:call-template>
    </xsl:variable>
    <!--BypassDefect-->
    <xsl:variable name="upsAlarmBypassDefect">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit29"/>
      </xsl:call-template>
    </xsl:variable>
    <!--PhaseWrong-->
    <xsl:variable name="upsAlarmPhaseWrong">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit30"/>
      </xsl:call-template>
    </xsl:variable>
    <!--EPROMError -->
    <xsl:variable name="upsAlarmEPROMError">
      <xsl:call-template name="bit">
        <xsl:with-param name="val" select="$alarm"/>
        <xsl:with-param name="bit" select="$bit31"/>
      </xsl:call-template>
    </xsl:variable>


    <!--Alarm Panel -->
    <xsl:if test="$alarm &gt; 0">
      <xsl:call-template name="alarm_panel">
        <xsl:with-param name="upsAlarmBatteryBad" select="$upsAlarmBatteryBad" />
        <xsl:with-param name="upsAlarmOnBattery" select="$upsAlarmOnBattery" />
        <xsl:with-param name="upsAlarmLowBattery" select="$upsAlarmLowBattery" />
        <xsl:with-param name="upsAlarmDepletedBattery" select="$upsAlarmDepletedBattery" />
        <xsl:with-param name="upsAlarmTempBad" select="$upsAlarmTempBad" />
        <xsl:with-param name="upsAlarmInputBad" select="$upsAlarmInputBad" />
        <xsl:with-param name="upsAlarmOutputBad" select="$upsAlarmOutputBad" />
        <xsl:with-param name="upsAlarmOutputOverload" select="$upsAlarmOutputOverload" />
        <xsl:with-param name="upsAlarmOnBypass" select="$upsAlarmOnBypass" />
        <xsl:with-param name="upsAlarmBypassBad" select="$upsAlarmBypassBad" />
        <xsl:with-param name="upsAlarmOutputOffAsRequested" select="$upsAlarmOutputOffAsRequested" />
        <xsl:with-param name="upsAlarmUpsOffAsRequested" select="$upsAlarmUpsOffAsRequested" />
        <xsl:with-param name="upsAlarmChargerFailed" select="$upsAlarmChargerFailed" />
        <xsl:with-param name="upsAlarmUpsOutputOff" select="$upsAlarmUpsOutputOff" />
        <xsl:with-param name="upsAlarmUpsSystemOff" select="$upsAlarmUpsSystemOff" />
        <xsl:with-param name="upsAlarmFanFailure" select="$upsAlarmFanFailure" />
        <xsl:with-param name="upsAlarmFuseFailure" select="$upsAlarmFuseFailure" />
        <xsl:with-param name="upsAlarmGeneralFault" select="$upsAlarmGeneralFault" />
        <xsl:with-param name="upsAlarmDiagnosticTestFailed" select="$upsAlarmDiagnosticTestFailed" />
        <xsl:with-param name="upsAlarmCommunicationsLost" select="$upsAlarmCommunicationsLost" />
        <xsl:with-param name="upsAlarmAwaitingPower" select="$upsAlarmAwaitingPower" />
        <xsl:with-param name="upsAlarmShutdownPending" select="$upsAlarmShutdownPending" />
        <xsl:with-param name="upsAlarmShutdownImminent" select="$upsAlarmShutdownImminent" />
        <xsl:with-param name="upsAlarmTestInProgress" select="$upsAlarmTestInProgress" />
        <xsl:with-param name="upsAlarmReceptacleOff" select="$upsAlarmReceptacleOff" />
        <xsl:with-param name="upsAlarmVoltageOnOutput" select="$upsAlarmVoltageOnOutput" />
        <xsl:with-param name="upsAlarmOvervoltageOnDCLink" select="$upsAlarmOvervoltageOnDCLink" />
        <xsl:with-param name="upsAlarmInputCircuitFailure" select="$upsAlarmInputCircuitFailure" />
        <xsl:with-param name="upsAlarmChargeConverterError" select="$upsAlarmChargeConverterError" />
        <xsl:with-param name="upsAlarmBypassDefect" select="$upsAlarmBypassDefect" />
        <xsl:with-param name="upsAlarmPhaseWrong" select="$upsAlarmPhaseWrong" />
        <xsl:with-param name="upsAlarmEPROMError" select="$upsAlarmEPROMError" />
        <xsl:with-param name="top" select="'340'" />
      </xsl:call-template>
    </xsl:if>


  </xsl:template>
  <!-- EOS -->
</xsl:stylesheet>
