/*
   xanto6_panel.js - XANTO 6000 – 10000, 1/1 screen.
   Copyright (c) 2013-2017, Generex GmbH. All rights reserved.
   Said.
*/
var xanto6_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null, //Callback Obj
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  css_obj,
  valtable_obj, report_obj, unms_obj,
  inphases = null,
  outphases = null,
  x_pos = 5,
  y_pos = 5;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.ups == null) {
      return;
    }

    set_variable(data);
    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }
    set_bg();
    set_status_txt();
    set_input_values();
    set_output_values();
    set_battery_value();
    set_ups_status_info();
    set_external_battery_value();
    draw_bar(valtable_obj.BATTCAP, 'batt_cap_bar', 42);
    draw_bar(valtable_obj.OUTPOWER[0], 'batt_load_bar', 596);

    set_footer();


  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: '490px',
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function set_variable(data) {
    valtable_obj = data.ups.valtable;
    report_obj = data.report;

    if (valtable_obj.INPHASES != null)
    inphases = valtable_obj.INPHASES;
    else
    inphases = valtable_obj.PHASES;

    if (valtable_obj.OUTPHASES != null)
    outphases = valtable_obj.OUTPHASES;
    else
    outphases = valtable_obj.PHASES;
  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_footer_pane();
    create_bg(); //background
    create_model_panes();
    create_status_pane();
    create_input_pane();
    create_output_pane();
    create_battery_pane();
    create_ups_status_info_pane();
    create_external_battery_pane();
    draw_bar(valtable_obj.BATTCAP, 'batt_cap_bar', 42);
    draw_bar(valtable_obj.OUTPOWER[0], 'batt_load_bar', 596);
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div, img;
    css_obj = { position: 'absolute', top: y_pos + 30, left: x_pos, width: 674, height: 670, border: 'solid 1px #808080', align: 'left' };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    img = $('<img />').attr({ 'id': 'bg_img_id', 'class': 'img-rounded', width: 650, 'height': 325, src: './image/online/bg_normal.png', align: 'left' }).appendTo(img_div);
    img.css({ 'margin-top': y_pos + 40, 'margin-left': x_pos + 5 });
    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
    set_bg();
  }

  function create_model_panes() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 674, 'z-index': 40 }; // 'background-color': '#3a87ad'
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active', id: 'model_name_id' }).append(valtable_obj.MODEL).appendTo(model_div);
  }

  function create_status_pane() {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, status_div;

    css_obj = { position: 'absolute', top: y_pos + 48, left: x_pos + 110 };

    status_div = $('<div/>', { id: 'status_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed', 'id': 'status_table' }).appendTo(status_div);
    tbody = $('<tbody />').appendTo(table);

    tr = $('<tr />').append($('<td />').css({ 'font-size': '14px', 'font-weight': 'bold' }).append(i18n("Status") + ":")).appendTo(tbody);
    $('<td />', { id: 'status_txt_id' }).appendTo(tr);

    fragment.appendChild(status_div[0]);
    document.body.appendChild(fragment);
    set_status_txt();
  }

  function create_input_pane() {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, in_div;

    css_obj = { position: 'absolute', top: y_pos + 280, left: x_pos + 110, color: 'white' };

    in_div = $('<div/>', { id: 'input_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed', 'id': 'inptable' }).appendTo(in_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).append(i18n('Input'))).appendTo(thead);

    tr = $('<tr />', { 'id': 'inptrl1' }).append($('<td />').append("L1:")).appendTo(tbody);
    $('<td />', { id: 'input_volt1_id' }).appendTo(tr);
    $('<td />', { id: 'input_freq1_id' }).appendTo(tr);

    fragment.appendChild(in_div[0]);
    document.body.appendChild(fragment);
    set_input_values();
  }

  function set_input_values() {
    $('#input_volt1_id').text(valtable_obj.INVOLT[0].toFixed(0) + ' V');
    $('#input_freq1_id').text(valtable_obj.INFREQ[0].toFixed(2) + ' Hz');
  }

  function create_output_pane() {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, out_div;

    css_obj = { position: 'absolute', top: y_pos + 280, left: x_pos + 410, color: 'white' };

    out_div = $('<div/>', { id: 'output_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed', 'id': 'outputtable' }).appendTo(out_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).append(i18n('Output'))).appendTo(thead);

    tr = $('<tr />').append($('<td />').append("L1:")).appendTo(tbody);
    $('<td />', { id: 'output_volt1_id', align: 'left' }).appendTo(tr);
    $('<td />', { id: 'output_freq1_id', align: 'left' }).appendTo(tr);
    tr = $('<tr />').append($('<td />').append("")).appendTo(tbody);
    $('<td />', { id: 'output_cur1_id', align: 'left' }).appendTo(tr);
    $('<td />', { id: 'output_pow1_id', align: 'left' }).appendTo(tr);

    fragment.appendChild(out_div[0]);
    document.body.appendChild(fragment);
    set_output_values();
  }

  function set_output_values() {
    $('#output_volt1_id').text(valtable_obj.OUTPUT_VOLT[0].toFixed(0) + ' V');
    $('#output_freq1_id').text(valtable_obj.OUTFREQ[0].toFixed(2) + ' Hz');
    $('#output_cur1_id').text(valtable_obj.EX_OUT_CURR[0].toFixed(2) + ' A');
    $('#output_pow1_id').text((valtable_obj.EX_OUT_CURR[0] * valtable_obj.OUTPUT_VOLT[0]).toFixed(0) + ' W');
  }

  function create_battery_pane() {
    var val, tr, table, tbody, thead, batt_div,
    fragment = document.createDocumentFragment();

    css_obj = { position: 'absolute', top: y_pos + 375, left: x_pos + 35 }; //, width:130, height:100
    attr_obj = { id: 'battery_div_id' };
    batt_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(batt_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 2 }).append(i18n('Battery'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Status") + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_status_id', align: 'left' }).append(get_batt_status()).appendTo(tr); //TODO

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Voltage) + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_volt_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.BATTVOLT], index: 0, unit: ' V', precision: 2 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Autonomy Time") + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_autotime_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.AUTONOMTIME], index: 0, unit: ' Min', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Battery_Capacity_short) + ":")).appendTo(tbody);
    $('<td />', { id: 'batt_cap_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.BATTCAP], index: 0, unit: ' %', precision: 0 })).appendTo(tr);

    if (valtable_obj.EX_BATT_SECONBATT != null) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Time in battery' + ':'))).appendTo(tbody);
      $('<td />', { id: 'batt_seconds_id', align: 'left' }).
      append(get_value({ values: [valtable_obj.EX_BATT_SECONBATT], index: 0, unit: ' Sec', precision: 0 })).appendTo(tr);
    }
    fragment.appendChild(batt_div[0]);
    document.body.appendChild(fragment);
  }

  function set_battery_value() {
    $('#batt_status_id').text(get_batt_status()); //TODO
    $('#batt_volt_id').text(get_value({ values: [valtable_obj.BATTVOLT], index: 0, unit: ' V', precision: 2 }));

    $('#batt_autotime_id').text(get_value({ values: [valtable_obj.AUTONOMTIME], index: 0, unit: ' Min', precision: 0 }));
    $('#batt_cap_id').text(get_value({ values: [valtable_obj.BATTCAP], index: 0, unit: ' %', precision: 0 }));

    if (valtable_obj.EX_BATT_SECONBATT != null)
    $('#batt_seconds_id').text(get_value({ values: [valtable_obj.EX_BATT_SECONBATT], index: 0, unit: ' Sec', precision: 0 }));
  }

  function create_external_battery_pane() {
    var val, tr, table, tbody, ext_batt_div,
    fragment = document.createDocumentFragment();

    css_obj = { position: 'absolute', top: y_pos + 505, left: x_pos + 35 };
    attr_obj = { id: 'ext_batt_div_id' };
    ext_batt_div_id = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(ext_batt_div_id);
    tbody = $('<tbody />').appendTo(table);

    tr = $('<tr />').append($('<td />').css({ 'font-size': '14px', 'font-weight': 'bold' }).append(i18n("External Battery Packs") + ":")).appendTo(tbody);
    $('<td />', { id: 'ext_batt_status_id' }).appendTo(tr);


    fragment.appendChild(ext_batt_div_id[0]);
    document.body.appendChild(fragment);
    set_external_battery_value()
  }

  function set_external_battery_value() {
    $('#ext_batt_status_id').text(valtable_obj.PREXT_NOMEXTCNTBATT);
  }

  function create_ups_status_info_pane() {
    var fragment = document.createDocumentFragment(),
    tr, table, tbody, thead, info_div;

    css_obj = { position: 'absolute', top: y_pos + 375, left: x_pos + 260 };

    info_div = $('<div/>', { id: 'ups_info_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover', 'id': 'infotable' }).appendTo(info_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).append(i18n('UPS Status Information'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Serial number") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_sr_nr_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Firmware version") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_fw_ver_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Output voltage set") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_output_volt_set_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Temperature") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_temp_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Auto-restart") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_auto_restart_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Buzzer") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_buzzer_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery deep discharge protection") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_batt_disch_prot_id', align: 'left' }).appendTo(tr);


    $('<td />', { id: 'shutdowntime_prog_output_sock_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Battery disconnected warning") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_batt_disc_warn_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("EPO") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_epo_id', align: 'left' }).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n("Bypass") + ":")).appendTo(tbody);
    $('<td />', { id: 'ups_bypass_id', align: 'left' }).appendTo(tr);

    fragment.appendChild(info_div[0]);
    document.body.appendChild(fragment);
    set_ups_status_info();
  }

  function set_ups_status_info() {
    $('#ups_sr_nr_id').text(valtable_obj.PREXT_NOMUPSID);
    $('#ups_fw_ver_id').text(valtable_obj.PREXT_NOMFIRMWARE);
    $('#ups_output_volt_set_id').text(valtable_obj.PREXT_MISCOUTVOLTSET);
    $('#ups_temp_id').html(panes_api.get_temperature(valtable_obj.PREXT_MISCTEMP[0], valtable_obj._tempUnit, 0));
    $('#ups_auto_restart_id').text(is_on('r') ? 'ON' : 'OFF');
    $('#ups_buzzer_id').text(is_on('a') ? 'ON' : 'OFF');
    $('#ups_batt_disch_prot_id').text(valtable_obj.PREXT_AUTONOMYLIMITSETTING != 9999 ? 'ON' : 'OFF');

    $('#ups_batt_disc_warn_id').text(is_on('0') ? 'ON' : 'OFF');
    $('#ups_epo_id').text(valtable_obj.PREXT_MISCEPOLOGIC ? 'Active Closed' : 'Active Opened');
    $('#ups_bypass_id').text(is_on('o') ? 'ON' : 'OFF');
  }

  function is_on(flag) {
    var enabled_flags, disabled_flags,
    index = valtable_obj.PREXT_MISCFLAGS.indexOf('D');
    if (index == -1) {
      return false;
    }
    enabled_flags = valtable_obj.PREXT_MISCFLAGS.substr(0, index);
    disabled_flags = valtable_obj.PREXT_MISCFLAGS.substr(index, valtable_obj.PREXT_MISCFLAGS.length - index);

    if (enabled_flags.indexOf(flag) != -1) {
      return true;
    }

    return false;
  }

  function draw_bar(value, id, left) {
    var fragment = document.createDocumentFragment(),
    bar_div, div, i, count, rest;

    $('#' + id).remove();
    count = parseInt((value / 25));
    rest = value % 25;

    css_obj = { position: 'absolute', top: y_pos + 85, left: left, width: 43, height: 196, align: 'center', 'background-color': 'transparent' };
    bar_div = $('<div/>', { id: id, 'class': 'img-rounded' }).css(css_obj);

    css_obj = { position: 'relative', top: 172, left: 10, width: 23, height: 35, border: 'solid 1px #808080', align: 'center', 'background-color': 'white' };
    for (i = 0; i < count; ++i) {
      div = $('<div/>', { id: id + '_' + i, 'class': 'img-rounded' }).css(css_obj).appendTo(bar_div);
      css_obj.top -= 84;
    }

    if (rest) {

      css_obj.height = Math.round((rest * 35) / 25);
      css_obj.top += (35 - css_obj.height);
      div = $('<div/>', { id: id + '_' + i, 'class': 'img-rounded' }).css(css_obj).appendTo(bar_div);
    }

    fragment.appendChild(bar_div[0]);
    document.body.appendChild(fragment);
  }

  function set_status_txt() {
    var status_txt = 'Normal mode';

    if (valtable_obj.STATUS & 0x0008) //"The UPS is drawing power from the batteries"}
    status_txt = 'Battery mode';

    else if (valtable_obj.STATUS & 0x0001) //"The Bypass is presently engaged on the UPS"
    status_txt = 'Bypass mode';

    else if (valtable_obj.PREXT_UPSSTAT == 0x53) //Standbybetrieb
    status_txt = 'Stand-by mode';

    else if (is_on('e')) //UPS in ECO mode
    status_txt = 'Eco mode';

    else if (valtable_obj.PREXT_UPSSTAT == 0x43) //Converter mode
    status_txt = 'Converter mode';

    $('#status_txt_id').text(status_txt);

  }

  function set_bg() {
    var src = './image/online/bg_normal.png';

    if (valtable_obj.STATUS & 0x0008) //"The UPS is drawing power from the batteries"
    src = './image/online/bg_battery.png';

    else if (valtable_obj.STATUS & 0x0001) //"The Bypass is presently engaged on the UPS"
    src = './image/online/bg_bypass.png';

    else if (valtable_obj.PREXT_UPSSTAT == 0x53) //Standbybetrieb
    src = './image/online/bg_standby.png';

    else if (is_on('e')) //UPS in ECO mode
    src = './image/online/bg_eco.png';

    else if (valtable_obj.PREXT_UPSSTAT == 0x43) //Converter mode
    src = './image/online/bg_freq.png';

    $('#bg_img_id').attr('src', src);

  }

  function get_batt_status() {
    var status = 'Battery ok';

    if (valtable_obj.PREXT_BATTSTATUS & 0x1)
    return i18n('Battery disconnected');
    if (valtable_obj.PREXT_BATTSTATUS & 0x2)
    return i18n('Battery overcharged');
    if (valtable_obj.PREXT_BATTSTATUS & 0x4)
    return i18n('Low battery');
    if (valtable_obj.PREXT_BATTSTATUS & 0x8)
    return i18n('Battery replace alarm');

    return status;
  }

  function get_value(val_obj) {
    if (!val_obj.values || (val_obj.values.length <= val_obj.index))
    return 'N/A';
    var val = val_obj.values[val_obj.index];
    if (val == null || val_obj.values[val_obj.index] == -9999)
    return 'N/A';

    if (Math.round(val) == val)
    val = val.toString();
    else
    val = val.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }

}(jQuery));