/*
   xonl_panel.js - XONL screen.
   Copyright (c) 2012, Generex GmbH. All rights reserved.
   Said.
*/

var xonl_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  err_div = null,
  valtable_obj,
  report_obj,
  log_entries,
  unms_obj,
  pannes_created = false,
  check_bowser = true,
  css_obj,
  Protocol_xonl12b = 32986,
  //log_event_pane attr/css
  evt_css_obj = {
    position: 'absolute',
    top: 15,
    'left': 270,
    width: 540,
    height: 136,
    'background': 'white',
    align: 'center',
    'overflow-x': 'scroll',
    'overflow-y': 'scroll',
    'border': '1 solid #405080'
  },
  evt_attObj = { id: 'log_div_id', 'class': 'tdSmall8_black' };

  var c_options = {
    series: {
      lines: { show: true },
      bars: {
        show: true,
        barWidth: 0.6,
        align: 'center',
        lineWidth: 0,
        fill: true,
        fillColor: { colors: [{ opacity: 1 }, { opacity: 1 }, { opacity: 1 }, { opacity: 1 }] }
      },
      color: '#52B245'
    },
    xaxis: { ticks: [], tickLength: 0 },
    yaxis: { min: 0, max: 0 },
    legend: { show: false },
    grid: { backgroundColor: 'white', borderWidth: 1, tickColor: 'white' }
  };

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: 12, left: 14, width: 724, display: 'none', 'z-index': 10 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.length == 0) {
      return;
    }

    if (err_div)
    err_div.css('display', 'none');

    valtable_obj = data.ups.valtable;
    log_entries = data.ups.log_entries;
    if (log_entries != null)
    log_entries = log_entries.reverse();
    report_obj = data.report;
    jqmodule.refresh(cb, report_obj.refresh * 1000);

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      utils_api.setTitle(valtable_obj._platform);
      create_pannes(); //create screen.
      return;
    }
    set_ups_values(); //set ups values
    set_segment_status(); //set segment status
    if (log_entries != null)
    panes_api.create_log_event_pane(log_entries, evt_attObj, evt_css_obj); //create log events pane.
    set_ups_chart();
    set_footer();
    //set_outpower_loadbars();//outpower loadbars
  }

  function create_pannes() //create screen.
  {
    //create_logo_pane();
    create_model_pane(); //create model pane
    create_segment_status_pane(); //create segment status pane
    create_ups_values_panes(); //create ups values panes
    if (log_entries != null)
    panes_api.create_log_event_pane(log_entries, evt_attObj, evt_css_obj); //create log events pane.
    create_ups_chart(); //create ups chart
    create_footer_pane();
  }

  function create_logo_pane() {
    var fragment = document.createDocumentFragment(),
    logo_div, tr, td, table, tbody;
    css_obj = { position: 'absolute', 'top': 15, 'left': 15, 'width': 231, 'height': 136, 'border': '1px solid #405080', 'align': 'center' };
    logo_div = $('<div/>').attr({ id: 'logo_div_id', 'class': 'LargeBold' }).css(css_obj);
    //UPS Chart title
    tbody = $('<tbody />');
    table = $('<table/>', { 'align': 'center', cellpadding: 0, cellspacing: 0, width: '100%', height: '40%', 'text-align': 'center' }).css({ 'background-color': 'black' });
    tr = $('<tr />', { 'class': 'tdMediumWhiteBold2', height: 18, width: '100%' }).css({ 'background-color': '#405080', 'cellspacing': 0, 'color': 'white' });
    td = $('<td />', { 'align': 'left' }).append(i18n(lang_Model) + ': ' + valtable_obj.MODEL).appendTo(tr);
    tr.appendTo(tbody);
    $('<tr />').append($('<td />', { 'align': 'center' }).append($('<img border="0" src="../img/logos.gif" width="200" height="120"/>'))).appendTo(tbody);
    tbody.appendTo(table);
    table.appendTo(logo_div);
    fragment.appendChild(logo_div[0]);
    document.body.appendChild(fragment);
  }

  function create_ups_values_panes() //create ups values panes
  {
    var table_attr, table_c, tbody_c, table, tbody, tr, td;

    table_attr = { id: 'ups_statustable_id', 'class': 'XBold_black', width: '96%', 'align': 'left', cellpadding: 1, cellspacing: 1, 'text-align': 'center' };
    table_c = $('<table/>');
    tbody_c = $('<tbody />');

    tr_c = $('<tr />');
    td_c = $('<td />');
    td_c.appendTo(tr_c);
    tr_c.appendTo(tbody_c);
    tbody_c.appendTo(table_c);
    table_c.appendTo(main_div);

    //ups status text
    table = $('<table/>', table_attr);
    tbody = $('<tbody />');
    tr = $('<tr/>').append($('<td />', { 'align': 'center', 'colspan': '3' }).css('text-decoration', 'underline').append(lang_UPS));
    tr.appendTo(tbody);
    //ups nominal model
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n('Nominal Model') + ':')).append($('<td />', { 'align': 'right' }).append(valtable_obj.XONL_NOMMODEL)).appendTo(tbody);
    //ups status text
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_UPS_Status) + ':'));
    td = $('<td />', { 'id': 'ups_status_txt_id', 'align': 'center' }).css({ 'background-color': get_ups_status_bg() }).append(get_ups_status_txt()).appendTo(tr);
    tr.appendTo(tbody);
    $('<hr size="2" align="center" color="#3F5987"></hr>').appendTo($('<td/>', { colspan: '4' }).appendTo($('<tr/>').appendTo(tbody)));
    tbody.appendTo(table);
    table.appendTo(td_c);

    //Mains Input
    tr_c = $('<tr />');
    td_c = $('<td />');
    td_c.appendTo(tr_c);
    tr_c.appendTo(tbody_c);
    table_attr['id'] = 'main_input_id';
    table = $('<table/>', table_attr);
    tbody = $('<tbody />');
    tr = $('<tr/>').append($('<td />', { 'align': 'center', 'colspan': '4' }).css('text-decoration', 'underline').append(lang_Mains_Input));
    tr.appendTo(tbody);

    //Input voltage
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Voltage) + ':'));
    td = $('<td />', { 'id': 'input_volt1_id', 'align': 'right' }).append(valtable_obj.INVOLT[0].toFixed(0) + ' V').appendTo(tr);
    if (valtable_obj.INPHASES > 1)
    td = $('<td />', { 'id': 'input_volt2_id', 'align': 'right' }).append(valtable_obj.INVOLT[1].toFixed(0) + ' V').appendTo(tr);
    if (valtable_obj.INPHASES > 2)
    td = $('<td />', { 'id': 'input_volt3_id', 'align': 'right' }).append(valtable_obj.INVOLT[2].toFixed(0) + ' V').appendTo(tr);
    tr.appendTo(tbody);
    //Input Frequency
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Frequency) + ':'));
    td = $('<td />', { 'id': 'input_freq1_id', 'align': 'right' }).append(valtable_obj.INFREQ[0].toFixed(1) + ' Hz').appendTo(tr);
    if (valtable_obj.INPHASES > 1 && valtable_obj.INFREQ[1] != -9999.00)
    td = $('<td />', { 'id': 'input_freq2_id', 'align': 'right' }).append(valtable_obj.INFREQ[1].toFixed(1) + ' Hz').appendTo(tr);
    if (valtable_obj.INPHASES > 2 && valtable_obj.INFREQ[1] != -9999.00)
    td = $('<td />', { 'id': 'input_freq3_id', 'align': 'right' }).append(valtable_obj.INFREQ[2].toFixed(1) + ' Hz').appendTo(tr);
    tr.appendTo(tbody);
    $('<hr size="2" align="center" color="#3F5987"></hr>').appendTo($('<td/>', { colspan: '4' }).appendTo($('<tr/>').appendTo(tbody)));
    tbody.appendTo(table);
    table.appendTo(td_c);

    //Battery
    tr_c = $('<tr />');
    td_c = $('<td />');
    td_c.appendTo(tr_c);
    tr_c.appendTo(tbody_c);
    table_attr['id'] = 'battery_table_id';
    table = $('<table/>', table_attr);
    tbody = $('<tbody />');
    tr = $('<tr/>').append($('<td />', { 'align': 'center', 'colspan': '3' }).css('text-decoration', 'underline').append(i18n(lang_Battery)));
    tr.appendTo(tbody);
    //Battery status text
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Status) + ':')); //TODO
    td = $('<td />', { 'id': 'batt_status_txt_id', 'align': 'left' }).css({ 'background-color': get_batt_status_bg() }).append(get_batt_status_txt()).appendTo(tr);
    tr.appendTo(tbody);
    //Battery test status text
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n('Test-Status') + ':'));
    td = $('<td />', { 'id': 'batt_teststatus_txt_id', 'align': 'left' }).css({ 'background-color': get_batt_teststatus_bg() }).append(get_batt_teststatus_txt()).appendTo(tr);
    tr.appendTo(tbody);
    //Battery Autonomy time
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(lang_Autonomy_time + ':'));
    td = $('<td />', { 'id': 'batt_autonomy_time_id', 'align': 'right' }).append(valtable_obj.AUTONOMTIME.toFixed(0) + ' Min').appendTo(tr);
    tr.appendTo(tbody);
    //Battery Capacity
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Capacity) + ':'));
    td = $('<td />', { 'id': 'batt_capacity_id', 'align': 'right' }).append(valtable_obj.BATTCAP.toFixed(0) + ' %').appendTo(tr);
    tr.appendTo(tbody);
    //Battery Voltage
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Voltage) + ':'));
    td = $('<td />', { 'id': 'batt_volt_id', 'align': 'right' }).append(valtable_obj.BATTVOLT.toFixed(0) + ' V').appendTo(tr);
    tr.appendTo(tbody);
    //Battery Voltage positive
    /*tr = $('<tr/>').append($('<td />', {'align':'left'}).append(lang_Voltage_pos + ':'));
    td = $('<td />',{'id': 'batt_volt_pos_id', 'align':'right'}).append(valtable_obj.EX_BATT_VOLTPOS.toFixed(0) + ' V').appendTo(tr);
    tr.appendTo(tbody);
    //Battery Voltage negative
    tr = $('<tr/>').append($('<td />', {'align':'left'}).append(lang_Voltage_neg + ':'));
    td = $('<td />',{'id': 'batt_volt_neg_id', 'align':'right'}).append(valtable_obj.EX_BATT_VOLTNEG.toFixed(0) + ' V').appendTo(tr);
    tr.appendTo(tbody);*/

    //Battery Temperature
    if (valtable_obj._upsProtocol == Protocol_xonl12b) {
      tr = $('<tr/>').append($('<td />', { align: 'left' }).append(i18n(lang_Temperature) + ':'));
      td = $('<td />', { 'id': 'batt_temp_id', 'align': 'right' }).append(valtable_obj.TEMPDEG.toFixed(0) + ' &#176;C').appendTo(tr);
      tr.appendTo(tbody);
    }

    $('<hr size="2" align="center" color="#3F5987"></hr>').appendTo($('<td/>', { colspan: '4' }).appendTo($('<tr/>').appendTo(tbody)));
    tbody.appendTo(table);
    table.appendTo(td_c);

    //Output
    tr_c = $('<tr />');
    td_c = $('<td />');
    td_c.appendTo(tr_c);
    tr_c.appendTo(tbody_c);
    table_attr['id'] = 'output_table_id';
    table = $('<table/>', table_attr);
    tbody = $('<tbody />');
    tr = $('<tr/>').append($('<td />', { 'align': 'center', 'colspan': '3' }).css('text-decoration', 'underline').append(i18n(lang_Output)));
    tr.appendTo(tbody);
    //Output Voltage
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Voltage) + ':'));
    td = $('<td />', { 'id': 'output_volt1_id', 'align': 'right' }).append(valtable_obj.OUTPUT_VOLT[0].toFixed(0) + ' V').appendTo(tr);
    if (valtable_obj.OUTPHASES > 1)
    td = $('<td />', { 'id': 'output_volt2_id', 'align': 'right' }).append(valtable_obj.OUTPUT_VOLT[1].toFixed(0) + ' V').appendTo(tr);
    if (valtable_obj.OUTPHASES > 2)
    td = $('<td />', { 'id': 'output_volt3_id', 'align': 'right' }).append(valtable_obj.OUTPUT_VOLT[2].toFixed(0) + ' V').appendTo(tr);
    tr.appendTo(tbody);
    if (valtable_obj.EX_OUT_CURR != null && valtable_obj.EX_OUT_CURR[0] != -9999) {
      //Output Current
      tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Current) + ':'));
      td = $('<td />', { 'id': 'output_curr1_id', 'align': 'right' }).append(valtable_obj.EX_OUT_CURR[0].toFixed(1) + ' A').appendTo(tr);
      if (valtable_obj.OUTPHASES > 1)
      td = $('<td />', { 'id': 'output_curr2_id', 'align': 'right' }).append(valtable_obj.EX_OUT_CURR[1].toFixed(1) + ' A').appendTo(tr);
      if (valtable_obj.OUTPHASES > 2)
      td = $('<td />', { 'id': 'output_curr3_id', 'align': 'right' }).append(valtable_obj.EX_OUT_CURR[2].toFixed(1) + ' A').appendTo(tr);
      tr.appendTo(tbody);
    }
    //Output Frequency
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Frequency) + ':'));
    td = $('<td />', { 'id': 'output_freq1_id', 'align': 'right' }).append(valtable_obj.OUTFREQ[0].toFixed(1) + ' Hz').appendTo(tr);
    if (valtable_obj.OUTPHASES > 1)
    td = $('<td />', { 'id': 'output_freq2_id', 'align': 'right' }).append(valtable_obj.OUTFREQ[1].toFixed(1) + ' Hz').appendTo(tr);
    if (valtable_obj.OUTPHASES > 2)
    td = $('<td />', { 'id': 'output_freq3_id', 'align': 'right' }).append(valtable_obj.OUTFREQ[2].toFixed(1) + ' Hz').appendTo(tr);
    tr.appendTo(tbody);
    //Output Load
    tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Load) + ':'));
    td = $('<td />', { 'id': 'output_load1_id', 'align': 'right' }).append(valtable_obj.OUTPOWER[0].toFixed(0) + ' %').appendTo(tr);
    if (valtable_obj.OUTPHASES > 1)
    td = $('<td />', { 'id': 'output_load2_id', 'align': 'right' }).append(valtable_obj.OUTPOWER[1].toFixed(0) + ' %').appendTo(tr);
    if (valtable_obj.OUTPHASES > 1)
    td = $('<td />', { 'id': 'output_load3_id', 'align': 'right' }).append(valtable_obj.OUTPOWER[2].toFixed(0) + ' %').appendTo(tr);
    tr.appendTo(tbody);

    if (valtable_obj.EX_OUT_WATT != null && valtable_obj.EX_OUT_WATT[0] != -9999) {
      //Output Load Watt
      tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Load) + ' (Watt):'));
      td = $('<td />', { 'id': 'output_load_1_w_id', 'align': 'right' }).append(valtable_obj.EX_OUT_WATT[0].toFixed(0) + ' W').appendTo(tr);
      if (valtable_obj.OUTPHASES > 1)
      td = $('<td />', { 'id': 'output_load_2_w_id', 'align': 'right' }).append(valtable_obj.EX_OUT_WATT[1].toFixed(0) + ' W').appendTo(tr);
      if (valtable_obj.OUTPHASES > 1)
      td = $('<td />', { 'id': 'output_load3_w_id', 'align': 'right' }).append(valtable_obj.EX_OUT_WATT[2].toFixed(0) + ' W').appendTo(tr);
      tr.appendTo(tbody);
    }

    if (valtable_obj.EX_OUT_VA != null && valtable_obj.EX_OUT_VA[0] != -9999) {
      //Output Load VA
      tr = $('<tr/>').append($('<td />', { 'align': 'left' }).append(i18n(lang_Load) + ' (VA):'));
      td = $('<td />', { 'id': 'output_load_1_va_id', 'align': 'right' }).append(valtable_obj.EX_OUT_VA[0].toFixed(0) + ' VA').appendTo(tr);
      if (valtable_obj.OUTPHASES > 1)
      td = $('<td />', { 'id': 'output_load_2_va_id', 'align': 'right' }).append(valtable_obj.EX_OUT_VA[1].toFixed(0) + ' VA').appendTo(tr);
      if (valtable_obj.OUTPHASES > 1)
      td = $('<td />', { 'id': 'output_load3_va_id', 'align': 'right' }).append(valtable_obj.EX_OUT_VA[2].toFixed(0) + ' VA').appendTo(tr);
      tr.appendTo(tbody);
    }
    tbody.appendTo(table);
    table.appendTo(td_c);
  }

  function set_ups_values() //set ups values
  {
    // set ups status text
    $('#ups_status_txt_id').css({ 'background-color': get_ups_status_bg() }).text(get_ups_status_txt());

    //set Input voltage
    $('#input_volt1_id').text(valtable_obj.INVOLT[0].toFixed(0) + ' V');
    if (valtable_obj.INPHASES > 1)
    $('#input_volt2_id').text(valtable_obj.INVOLT[1].toFixed(0) + ' V');
    if (valtable_obj.INPHASES > 2)
    $('#input_volt3_id').text(valtable_obj.INVOLT[2].toFixed(0) + ' V');
    //set Input Frequency
    $('#input_freq1_id').text(valtable_obj.INFREQ[0].toFixed(1) + ' Hz');
    if (valtable_obj.INPHASES > 1)
    $('#input_freq2_id').text(valtable_obj.INFREQ[1].toFixed(1) + ' Hz');
    if (valtable_obj.INPHASES > 2)
    $('#input_freq3_id').text(valtable_obj.INFREQ[2].toFixed(1) + ' Hz');

    //Battery
    //set Battery status text
    $('#batt_status_txt_id').css({ 'background-color': get_batt_status_bg() }).text(get_batt_status_txt());
    //set Battery test status text
    $('#batt_teststatus_txt_id').css({ 'background-color': get_batt_teststatus_bg() }).text(get_batt_teststatus_txt());
    //set Battery Autonomy time
    $('#batt_autonomy_time_id').text(valtable_obj.AUTONOMTIME.toFixed(0) + ' Min');
    //Battery Capacity
    $('#batt_capacity_id').text(valtable_obj.BATTCAP.toFixed(0) + ' %');
    //set Battery Voltage
    $('#batt_volt_id').text(valtable_obj.BATTVOLT.toFixed(0) + ' V');
    //set Battery Voltage positive
    $('#batt_volt_pos_id').text(valtable_obj.EX_BATT_VOLTPOS.toFixed(0) + ' V');
    //set Battery Voltage negative
    $('#batt_volt_neg_id').text(valtable_obj.EX_BATT_VOLTNEG.toFixed(0) + ' V');
    //set Battery Temperature
    if (valtable_obj._upsProtocol == Protocol_xonl12b) {
      $('#batt_temp_id').val(valtable_obj.TEMPDEG.toFixed(0) + ' &#176;C');
    }

    //Output
    //set Output Voltage
    $('#output_volt1_id').text(valtable_obj.OUTPUT_VOLT[0].toFixed(0) + ' V');
    if (valtable_obj.OUTPHASES > 1)
    $('#output_volt2_id').text(valtable_obj.OUTPUT_VOLT[1].toFixed(0) + ' V');
    if (valtable_obj.OUTPHASES > 2)
    $('#output_volt3_id').append(valtable_obj.OUTPUT_VOLT[2].toFixed(0) + ' V');

    //setOutput Current
    if (valtable_obj.EX_OUT_CURR != null && valtable_obj.EX_OUT_CURR[0] != -9999) {
      $('#output_curr1_id').text(valtable_obj.EX_OUT_CURR[0].toFixed(1) + ' A');
      if (valtable_obj.OUTPHASES > 1)
      $('#output_curr2_id').text(valtable_obj.EX_OUT_CURR[1].toFixed(1) + ' A');
      if (valtable_obj.OUTPHASES > 2)
      $('#output_curr3_id').text(valtable_obj.EX_OUT_CURR[2].toFixed(1) + ' A');
    }

    //set Output Frequency
    $('#output_freq1_id').text(valtable_obj.OUTFREQ[0].toFixed(1) + ' Hz');
    if (valtable_obj.OUTPHASES > 1)
    $('#output_freq2_id').text(valtable_obj.OUTFREQ[1].toFixed(1) + ' Hz');
    if (valtable_obj.OUTPHASES > 2)
    $('#output_freq3_id').text(valtable_obj.OUTFREQ[2].toFixed(1) + ' Hz');

    //set Output Load
    $('#output_load1_id').text(valtable_obj.OUTPOWER[0].toFixed(0) + ' %');
    if (valtable_obj.OUTPHASES > 1)
    $('#output_load2_id').text(valtable_obj.OUTPOWER[1].toFixed(0) + ' %');
    if (valtable_obj.OUTPHASES > 2)
    $('#output_load3_id').text(valtable_obj.OUTPOWER[2].toFixed(0) + ' %');

    if (valtable_obj.EX_OUT_WATT != null && valtable_obj.EX_OUT_WATT[0] != -9999) {
      //set Output Load Wat
      $('#output_load_1_w_id').text(valtable_obj.EX_OUT_WATT[0].toFixed(0) + ' W');
      if (valtable_obj.OUTPHASES > 1)
      $('#output_load_2_w_id').text(valtable_obj.EX_OUT_WATT[1].toFixed(0) + ' W');
      if (valtable_obj.OUTPHASES > 2)
      $('#output_load3_w_id').text(valtable_obj.EX_OUT_WATT[2].toFixed(0) + ' W');
    }

    if (valtable_obj.EX_OUT_VA != null && valtable_obj.EX_OUT_VA[0] != -9999) {
      //set Output Load VA
      $('#output_load_1_va_id').text(valtable_obj.EX_OUT_VA[0].toFixed(0) + ' VA');
      if (valtable_obj.OUTPHASES > 1)
      $('#output_load_2_va_id').text(valtable_obj.EX_OUT_VA[1].toFixed(0) + ' VA');
      if (valtable_obj.OUTPHASES > 2)
      $('#output_load3_va_id').text(valtable_obj.EX_OUT_VA[2].toFixed(0) + ' VA');
    }
  }

  function create_model_pane() //create model pane
  {
    var fragment = document.createDocumentFragment(),
    table, tbody, tr, td;
    css_obj = {
      position: 'absolute',
      'top': 15,
      'left': 12,
      'width': 232,
      'height': 644,
      'align': 'center',
      'border': '1px solid #405080'
    }; //, 'border-top-width': '20px'
    main_div = $('<div/>').attr({ id: 'main_div_id' }).css(css_obj);

    table = $('<table/>', { id: 'outlet_table_id', 'class': 'tdMediumWhiteBold2' }).css({
      width: '100%',
      'height': 8,
      'align': 'top',
      'background-color': '#405080',
      cellpadding: 0,
      cellspacing: 0,
      'text-align': 'center'
    });
    tbody = $('<tbody />');
    //segment text
    tr = $('<tr/>', { 'align': 'center' })
    tr.css({ 'background-color': '#405080', 'color': 'white' })
    tr.append($('<td />').append(i18n(lang_Model) + ' : ' + valtable_obj.MODEL));

    tr.appendTo(tbody);
    tbody.appendTo(table);
    table.appendTo(main_div);

    fragment.appendChild(main_div[0]);
    document.body.appendChild(fragment);
  }

  function create_segment_status_pane() //create segment status pane
  {
    var outlet_div, table, tbody, tr, td, outlet1_img, outlet2_img;
    if ((valtable_obj.OUTLET_EXISTMASK == null) || (valtable_obj.OUTLET_EXISTMASK == 0))
    return;

    table = $('<table/>', { id: 'outlet_table_id', 'class': 'XBold_black' }).css({
      width: '94%',
      'align': 'left',
      cellpadding: 1,
      cellspacing: 1,
      'text-align': 'center'
    });
    tbody = $('<tbody />');
    //segment text
    tr = $('<tr/>', { width: '100%', 'align': 'left' });
    tr.append($('<td />').append(i18n(lang_Load_segment)));

    //segment status
    if ((valtable_obj.OUTLET_EXISTMASK & 1) == 1) //outlet 1
    {

      if ((valtable_obj.OUTLET_ONOFFMASK & 1) == 1)
      $('<td class="btn" style="font-size:10px;"><span><span id = "outlet1_id" style="background: #52B245;cursor:text">1</span></span></td>')
      .appendTo($('<td/>').appendTo(tr));
      else
      $('<td class="btn" style="font-size:10px;"><span><span id = "outlet1_id" style="background: #CCCCCC;cursor:text">1</span></span></td')
      .appendTo($('<td/>').appendTo(tr));
    }
    if ((valtable_obj.OUTLET_EXISTMASK & 2) == 2) //outlet 2
    {
      if ((valtable_obj.OUTLET_ONOFFMASK & 2) == 2)
      $('<td class="btn" style="font-size:10px;"><span><span id = "outlet2_id" style="background: #52B245;cursor:text">2</span></span></td>')
      .appendTo($('<td/>').appendTo(tr));
      else
      $('<td class="btn" style="font-size:10px;"><span><span id = "outlet2_id" style="background: #CCCCCC;cursor:text">2</span></span></td>')
      .appendTo($('<td/>').appendTo(tr));
    }
    tr.appendTo(tbody);

    tr = $('<tr/>');
    tr.append($('<td colspan="3"><hr size="2" align="center" color="#3F5987"></td>'));
    tr.appendTo(tbody);

    tbody.appendTo(table);
    table.appendTo(main_div);
  }

  function set_segment_status() //set segment status
  {
    if (valtable_obj.OUTLET_EXISTMASK == 0)
    return;
    //segment status
    if ((valtable_obj.OUTLET_EXISTMASK & 1) == 1) //outlet 1
    {
      if ((valtable_obj.OUTLET_ONOFFMASK & 1) == 1)
      $('#outlet1_id').css('background', '#52B245');
      else
      $('#outlet1_id').css('background', '#CCCCCC');
    }
    if ((valtable_obj.OUTLET_EXISTMASK & 2) == 2) //outlet 2
    {
      if ((valtable_obj.OUTLET_ONOFFMASK & 2) == 2)
      $('#outlet2_id').css('background', '#52B245');
      else
      $('#outlet2_id').css('background', '#CCCCCC');
    }
  }

  function create_ups_chart() {
    var fragment = document.createDocumentFragment(),
    ups_chart_div, tr, td, table, tbody;
    css_obj = { position: 'absolute', 'top': 160, 'left': 270, 'width': 540, 'height': 500, 'border': '1px solid #405080', 'align': 'center' };

    ups_chart_div = $('<div/>').attr({ id: 'ups_chart_id', 'class': 'LargeBold' }).css(css_obj);

    //UPS Chart title
    tbody = $('<tbody />');
    table = $('<table/>', { 'align': 'center', cellpadding: 0, cellspacing: 0, width: '100%', 'text-align': 'center' });
    tr = $('<tr />', { 'class': 'tdMediumWhiteBold2', height: 24, width: '100%' }).css({ 'background-color': '#405080', 'cellspacing': 0, 'color': 'white' });
    td = $('<td />', { 'align': 'center' }).append(i18n('UPS Chart'));
    td.appendTo(tr);
    tr.appendTo(tbody);
    tbody.appendTo(table);
    table.appendTo(ups_chart_div);

    //chart buttons
    tbody = $('<tbody />');
    table = $('<table/>', { 'align': 'center', cellpadding: 2, cellspacing: 4, 'text-align': 'center' }).css('margin-top', '6px');
    tr = $('<tr />');
    //Input
    td = $('<td />', { 'class': 'btn' }).css('cursor', 'hand');
    td.append($('<span><span>' + i18n(lang_Input) + '</span></span>')).appendTo(tr);
    td.click(function () { switch_chart(1); });
    td = $('<td />').append('&nbsp;&nbsp;').appendTo(tr);

    //Output
    td = $('<td />', { 'class': 'btn' }).css('cursor', 'hand');
    td.append($('<span><span>' + i18n(lang_Output) + '</span></span>')).appendTo(tr);
    td.click(function () { switch_chart(2); });
    td = $('<td />').append('&nbsp;&nbsp;').appendTo(tr);
    //Battery
    td = $('<td />', { 'class': 'btn' }).css('cursor', 'hand');
    td.append($('<span><span>' + i18n(lang_Battery) + '</span></span>')).appendTo(tr);
    td.click(function () { switch_chart(3); });
    td = $('<td />').append('&nbsp;&nbsp;').appendTo(tr);

    tr.appendTo(tbody);
    tbody.appendTo(table);
    table.appendTo(ups_chart_div);

    fragment.appendChild(ups_chart_div[0]);
    document.body.appendChild(fragment);

    create_ups_input_chart();
    create_ups_output_chart();
    create_ups_batt_chart();
  }

  function set_ups_chart() {
    set_ups_input_chart();
    set_ups_output_chart();
    set_ups_batt_chart();
  }

  function create_ups_input_chart() {
    var fragment = document.createDocumentFragment(),
    input_div, ups_input_chart_parent_div, tbody, table, tr, td;
    var css_title_obj;
    var data = new Array();
    c_options.xaxis.ticks.length = 0;

    if (valtable_obj.INPHASES != 1)
    css_obj = { position: 'absolute', 'top': 218, 'left': 316, 'width': 466, 'height': 440, 'background-color': 'white', 'align': 'center', 'visibility': 'visibile', 'overflow': 'hidden' };
    else
    css_obj = { position: 'absolute', 'top': 218, 'left': 320, 'width': 446, 'height': 440, 'background-color': 'white', 'align': 'center', 'visibility': 'visibile', 'overflow': 'hidden' };

    //input chart parent div
    ups_input_chart_parent_div = $('<div/>').attr({ id: 'ups_input_chart_parent_div', 'class': 'XBold_black' }).css(css_obj);
    fragment.appendChild(ups_input_chart_parent_div[0]);
    document.body.appendChild(fragment);

    //Input Voltage
    css_obj = { position: 'absolute', 'top': 60, 'left': 24, 'width': 80, 'height': 300, 'background-color': 'white', 'align': 'center' };
    if (valtable_obj.INPHASES != 1) {
      css_obj.width = 160;
      table = $('<table/>', { 'class': 'Medium', 'align': 'left', cellpadding: 3, cellspacing: 4, 'text-align': 'center', 'width': '100%' })
      .css({ 'margin-top': '30px', 'margin-left': '32px' });
    } else {
      table = $('<table/>', { 'class': 'Medium', 'align': 'left', cellpadding: 3, cellspacing: 4, 'text-align': 'center', 'width': '100%' })
      .css({ 'margin-top': '20px', 'margin-left': '12px' });

    }
    c_options.yaxis = { min: 90, max: 270 };

    //output chart titles

    tbody = $('<tbody />');
    tr = $('<tr />');
    td = $('<td />', { 'align': 'left' }).append('&nbsp;&nbsp;&nbsp;' + i18n(lang_Input_Voltage)).appendTo(tr);
    td = $('<td />', { 'align': 'center' }).append(lang_Input_Frequency).appendTo(tr);
    td = $('<td />', { 'align': 'left' }).append(lang_Autonomy_time).appendTo(tr);
    tr.appendTo(tbody);
    tbody.appendTo(table);
    table.appendTo(ups_input_chart_parent_div);

    //input voltage
    input_div = panes_api.create_div({ id: 'ups_involt_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_input_chart_parent_div);
    //input voltage 1
    data.push({ label: i18n('input volt') + '1', data: [
        [0, valtable_obj.INVOLT[0].toFixed(0)]
      ] });
    c_options.xaxis.ticks.push([0, valtable_obj.INVOLT[0].toFixed(0) + '&nbsp;V']);

    if (valtable_obj.INPHASES > 1) //input voltage 2
    {
      data.push({ label: i18n('input volt') + '2', data: [
          [1, valtable_obj.INVOLT[1].toFixed(0)]
        ] });
      c_options.xaxis.ticks.push([1, valtable_obj.INVOLT[1].toFixed(0) + '&nbsp;V']);

    }
    if (valtable_obj.INPHASES > 2) //input voltage 3
    {
      data.push({ label: i18n('input volt') + '3', data: [
          [2, valtable_obj.INVOLT[2].toFixed(0)]
        ] });
      c_options.xaxis.ticks.push([2, valtable_obj.INVOLT[2].toFixed(0) + '&nbsp;V']);
    }
    $.plot(input_div, data, c_options);

    //Input Frequency
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    if (valtable_obj.INPHASES != 1)
    css_obj.left += 200;
    else
    css_obj.left += 160;

    css_obj.width = 80;
    c_options.yaxis = { min: 40, max: 70 };
    input_div = panes_api.create_div({ id: 'ups_infreq_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_input_chart_parent_div);
    c_options.xaxis.ticks[0] = [0, valtable_obj.INFREQ[0].toFixed(1) + '&nbsp;Hz'];
    $.plot(input_div, [{ label: 'Input freq', data: [
        [0, valtable_obj.INFREQ[0].toFixed(1)]
      ] }], c_options);

    //input AUTONOMTIME
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    if (valtable_obj.INPHASES != 1)
    css_obj.left += 130;
    else
    css_obj.left += 150;
    c_options.yaxis = { min: 0, max: 100 };
    input_div = panes_api.create_div({ id: 'ups_in_autotime_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_input_chart_parent_div);
    c_options.xaxis.ticks[0] = [0, valtable_obj.AUTONOMTIME.toFixed(0) + '&nbsp;Min'];
    $.plot($(input_div), [{ label: i18n('Autonomy time'), data: [
        [0, valtable_obj.AUTONOMTIME.toFixed(0)]
      ] }], c_options);
  }

  function set_ups_input_chart() {
    var data = new Array();
    c_options.xaxis.ticks.length = 0;

    //input voltage
    c_options.yaxis = { min: 90, max: 270 };
    //input voltage 1
    data.push({ label: i18n('input volt') + '1', data: [
        [0, valtable_obj.INVOLT[0].toFixed(0)]
      ] });
    c_options.xaxis.ticks.push([0, valtable_obj.INVOLT[0].toFixed(0) + '&nbsp;V']);

    if (valtable_obj.INPHASES > 1) //input voltage 2
    {
      data.push({ label: i18n('input volt') + '2', data: [
          [1, valtable_obj.INVOLT[1].toFixed(0)]
        ] });
      c_options.xaxis.ticks.push([1, valtable_obj.INVOLT[1].toFixed(0) + '&nbsp;V']);

    }
    if (valtable_obj.INPHASES > 2) //input voltage 3
    {
      data.push({ label: i18n('input volt') + '3', data: [
          [2, valtable_obj.INVOLT[2].toFixed(0)]
        ] });
      c_options.xaxis.ticks.push([2, valtable_obj.INVOLT[2].toFixed(0) + '&nbsp;V']);
    }
    $.plot($('#ups_involt_chart_div_id'), data, c_options);

    //Input Frequency
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    c_options.yaxis = { min: 40, max: 70 };
    c_options.xaxis.ticks[0] = [0, valtable_obj.INFREQ[0].toFixed(1) + '&nbsp;Hz'];
    $.plot($('#ups_infreq_chart_div_id'), [{ label: i18n('Input freq'), data: [
        [0, valtable_obj.INFREQ[0].toFixed(1)]
      ] }], c_options);

    //input AUTONOMTIME
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    c_options.yaxis = { min: 0, max: 100 };
    c_options.xaxis.ticks[0] = [0, valtable_obj.AUTONOMTIME.toFixed(0) + '&nbsp;Min'];
    $.plot($('#ups_in_autotime_chart_div_id'), [{ label: i18n('Autonomy time'), data: [
        [0, valtable_obj.AUTONOMTIME.toFixed(0)]
      ] }], c_options);
  }

  function create_ups_output_chart() {
    var fragment = document.createDocumentFragment(),
    output_div, ups_output_chart_parent_div, tbody, table, tr, td;
    var data = new Array();
    c_options.xaxis.ticks.length = 0;

    if (valtable_obj.OUTPHASES != 1)
    css_obj = { position: 'absolute', 'top': 218, 'left': 316, 'width': 466, 'height': 440, 'background-color': 'white', 'align': 'center', 'visibility': 'hidden', 'overflow': 'hidden' };
    else
    css_obj = { position: 'absolute', 'top': 218, 'left': 320, 'width': 446, 'height': 440, 'background-color': 'white', 'align': 'center', 'visibility': 'hidden', 'overflow': 'hidden' };

    //output chart parent div
    ups_output_chart_parent_div = $('<div/>').attr({ id: 'ups_output_chart_parent_div', 'class': 'XBold_black' }).css(css_obj);
    fragment.appendChild(ups_output_chart_parent_div[0]);
    document.body.appendChild(fragment);

    //output Voltage
    css_obj = { position: 'absolute', 'top': 60, 'left': 24, 'width': 80, 'height': 300, 'background-color': 'white', 'align': 'center' };
    if (valtable_obj.OUTPHASES != 1) {
      css_obj.width = 160;
      table = $('<table/>', { 'class': 'Medium', 'align': 'left', cellpadding: 3, cellspacing: 4, 'text-align': 'center', 'width': '100%' })
      .css({ 'margin-top': '20px', 'margin-left': '26px' });
    } else {
      table = $('<table/>', { 'class': 'Medium', 'align': 'left', cellpadding: 3, cellspacing: 4, 'text-align': 'center', 'width': '100%' })
      .css({ 'margin-top': '20px', 'margin-left': '12px' });
    }
    c_options.yaxis = { min: 90, max: 270 };

    //output chart titles
    tbody = $('<tbody />');
    tr = $('<tr />');
    td = $('<td />', { 'align': 'left' }).append('&nbsp;&nbsp;&nbsp;' + i18n(lang_Output_Voltage)).appendTo(tr);
    td = $('<td />', { 'align': 'center' }).append(i18n(lang_Output_Frequency)).appendTo(tr);
    td = $('<td />', { 'align': 'center' }).append(i18n(lang_Autonomy_time)).appendTo(tr);
    tr.appendTo(tbody);
    tbody.appendTo(table);
    table.appendTo(ups_output_chart_parent_div);

    //output voltage 1
    output_div = panes_api.create_div({ id: 'ups_outvolt_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_output_chart_parent_div);

    data.push({ label: i18n('output volt') + '1', data: [
        [0, valtable_obj.OUTPUT_VOLT[0].toFixed(0)]
      ] });
    c_options.xaxis.ticks.push([0, valtable_obj.OUTPUT_VOLT[0].toFixed(0) + '&nbsp;V']);

    if (valtable_obj.OUTPHASES > 1) //output voltage 2
    {
      data.push({ label: i18n('output volt') + '2', data: [
          [1, valtable_obj.OUTPUT_VOLT[0].toFixed(0)]
        ] });
      c_options.xaxis.ticks.push([1, valtable_obj.OUTPUT_VOLT[1].toFixed(0) + '&nbsp;V']);
    }

    if (valtable_obj.OUTPHASES > 2) //output voltage 3
    {
      data.push({ label: i18n('output volt') + '3', data: [
          [2, valtable_obj.OUTPUT_VOLT[0].toFixed(0)]
        ] });
      c_options.xaxis.ticks.push([2, valtable_obj.OUTPUT_VOLT[2].toFixed(0) + '&nbsp;V']);
    }

    $.plot(output_div, data, c_options);

    //output Frequency
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    if (valtable_obj.OUTPHASES != 1)
    css_obj.left += 200;
    else
    css_obj.left += 160;

    css_obj.width = 80;
    c_options.yaxis = { min: 40, max: 70 };
    output_div = panes_api.create_div({ id: 'ups_outfreq_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_output_chart_parent_div);
    c_options.xaxis.ticks[0] = [0, valtable_obj.OUTFREQ[0].toFixed(1) + '&nbsp;Hz'];
    $.plot(output_div, [{ label: i18n('Output freq'), data: [
        [0, valtable_obj.OUTFREQ[0].toFixed(1)]
      ] }], c_options);

    //output AUTONOMTIME
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    if (valtable_obj.OUTPHASES != 1)
    css_obj.left += 130;
    else
    css_obj.left += 150;
    c_options.yaxis = { min: 0, max: 100 };
    output_div = panes_api.create_div({ id: 'ups_out_autotime_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_output_chart_parent_div);
    c_options.xaxis.ticks[0] = [0, valtable_obj.AUTONOMTIME.toFixed(0) + '&nbsp;Min'];
    $.plot(output_div, [{ label: i18n('Autonomy time'), data: [
        [0, valtable_obj.AUTONOMTIME.toFixed(0)]
      ] }], c_options);
  }

  function set_ups_output_chart() {
    var data = new Array();
    c_options.xaxis.ticks.length = 0;

    //output Voltage
    c_options.yaxis = { min: 90, max: 270 };
    //output voltage 1
    data.push({ label: i18n('output volt') + '1', data: [
        [0, valtable_obj.OUTPUT_VOLT[0].toFixed(0)]
      ] });
    c_options.xaxis.ticks.push([0, valtable_obj.OUTPUT_VOLT[0].toFixed(0) + '&nbsp;V']);

    if (valtable_obj.OUTPHASES > 1) //output voltage 2
    {
      data.push({ label: i18n('output volt') + '2', data: [
          [1, valtable_obj.OUTPUT_VOLT[0].toFixed(0)]
        ] });
      c_options.xaxis.ticks.push([1, valtable_obj.OUTPUT_VOLT[1].toFixed(0) + '&nbsp;V']);
    }

    if (valtable_obj.OUTPHASES > 2) //output voltage 3
    {
      data.push({ label: i18n('output volt') + '3', data: [
          [2, valtable_obj.OUTPUT_VOLT[0].toFixed(0)]
        ] });
      c_options.xaxis.ticks.push([2, valtable_obj.OUTPUT_VOLT[2].toFixed(0) + '&nbsp;V']);
    }

    $.plot($('#ups_outvolt_chart_div_id'), data, c_options);

    //output Frequency
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    c_options.yaxis = { min: 40, max: 70 };
    c_options.xaxis.ticks[0] = [0, valtable_obj.OUTFREQ[0].toFixed(1) + '&nbsp;Hz'];
    $.plot($('#ups_outfreq_chart_div_id'), [{ label: i18n('Output freq'), data: [
        [0, valtable_obj.OUTFREQ[0].toFixed(1)]
      ] }], c_options);

    //output AUTONOMTIME
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    c_options.yaxis = { min: 0, max: 100 };
    c_options.xaxis.ticks[0] = [0, valtable_obj.AUTONOMTIME.toFixed(0) + '&nbsp;Min'];
    $.plot($('#ups_out_autotime_chart_div_id'), [{ label: i18n('Autonomy time'), data: [
        [0, valtable_obj.AUTONOMTIME.toFixed(0)]
      ] }], c_options);
  }

  function create_ups_batt_chart() {
    var fragment = document.createDocumentFragment(),
    ups_battery_chart_div, ups_battery_chart_parent_div;
    var css_title_obj;
    var data = new Array();
    c_options.xaxis.ticks.length = 0;

    css_obj = { position: 'absolute', 'top': 218, 'left': 320, 'width': 446, 'height': 440, 'background-color': 'white', 'align': 'center', 'visibility': 'hidden', 'overflow': 'hidden' };
    css_title_obj = { position: 'absolute', 'top': 24, 'left': 50, 'width': 68, 'height': 40, 'background-color': 'white', 'align': 'left', 'overflow': 'hidden' };

    //battery chart parent div
    ups_battery_chart_parent_div = $('<div/>').attr({ id: 'ups_battery_chart_parent_div', 'class': 'XBold_black' }).css(css_obj);
    fragment.appendChild(ups_battery_chart_parent_div[0]);
    document.body.appendChild(fragment);

    css_obj = { position: 'absolute', 'top': 60, 'left': 24, 'width': 80, 'height': 300, 'background-color': 'white', 'align': 'center' };
    //battery chart titles
    tbody = $('<tbody />');
    table = $('<table/>', { 'class': 'Medium', 'align': 'left', cellpadding: 3, cellspacing: 4, 'text-align': 'center', 'width': '100%' })
    .css({ 'margin-top': '20px', 'margin-left': '12px' });
    tr = $('<tr />');
    td = $('<td />', { 'align': 'left' }).append('&nbsp;' + i18n(lang_Battery_Voltage)).appendTo(tr);
    td = $('<td />', { 'align': 'center' }).append(i18n(lang_Battery_Capacity)).appendTo(tr);
    td = $('<td />', { 'align': 'center' }).append(i18n(lang_Autonomy_time)).appendTo(tr);
    tr.appendTo(tbody);
    tbody.appendTo(table);
    table.appendTo(ups_battery_chart_parent_div);

    //battery voltage
    c_options.yaxis = { min: 10, max: 600 };
    ups_battery_chart_div = panes_api.create_div({ id: 'ups_battvolt_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_battery_chart_parent_div);
    c_options.xaxis.ticks[0] = [0, valtable_obj.BATTVOLT.toFixed(0) + '&nbsp;V'];
    $.plot(ups_battery_chart_div, [{ label: i18n('voltage'), data: [
        [0, valtable_obj.BATTVOLT.toFixed(0)]
      ] }], c_options);

    //battery capacity
    css_obj.left += 160;
    css_obj.width = 80;

    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    c_options.yaxis = { min: 0, max: 100 };
    ups_battery_chart_div = panes_api.create_div({ id: 'ups_battcapacity_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_battery_chart_parent_div);
    c_options.xaxis.ticks[0] = [0, valtable_obj.BATTCAP.toFixed(1) + '&nbsp;%'];
    $.plot(ups_battery_chart_div, [{ label: i18n('battery capacity'), data: [
        [0, valtable_obj.BATTCAP.toFixed(0)]
      ] }], c_options);

    //Battery AUTONOMTIME
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    css_obj.left += 150;
    c_options.yaxis = { min: 0, max: 100 };
    ups_battery_chart_div = panes_api.create_div({ id: 'ups_batt_autotime_chart_div_id', 'class': 'XBold_black' }, css_obj, ups_battery_chart_parent_div);
    c_options.xaxis.ticks[0] = [0, valtable_obj.AUTONOMTIME.toFixed(0) + '&nbsp;Min'];
    $.plot(ups_battery_chart_div, [{ label: i18n('Autonomy time'), data: [
        [0, valtable_obj.AUTONOMTIME.toFixed(0)]
      ] }], c_options);
  }

  function set_ups_batt_chart() {
    var data = new Array();
    c_options.xaxis.ticks.length = 0;

    //battery voltage
    c_options.yaxis = { min: 10, max: 600 };
    c_options.xaxis.ticks[0] = [0, valtable_obj.BATTVOLT.toFixed(0) + '&nbsp;V'];
    $.plot($('#ups_battvolt_chart_div_id'), [{ label: i18n('voltage'), data: [
        [0, valtable_obj.BATTVOLT.toFixed(0)]
      ] }], c_options);

    //battery capacity
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    c_options.yaxis = { min: 0, max: 100 };
    c_options.xaxis.ticks[0] = [0, valtable_obj.BATTCAP.toFixed(1) + '&nbsp;%'];
    $.plot($('#ups_battcapacity_chart_div_id'), [{ label: i18n('battery capacity'), data: [
        [0, valtable_obj.BATTCAP.toFixed(0)]
      ] }], c_options);

    //Battery AUTONOMTIME
    data.length = 0;
    c_options.xaxis.ticks.length = 0;
    css_obj.left += 150;
    c_options.yaxis = { min: 0, max: 100 };
    c_options.xaxis.ticks[0] = [0, valtable_obj.AUTONOMTIME.toFixed(0) + '&nbsp;Min'];
    $.plot($('#ups_batt_autotime_chart_div_id'), [{ label: i18n('Autonomy time'), data: [
        [0, valtable_obj.AUTONOMTIME.toFixed(0)]
      ] }], c_options);
  }

  function switch_chart(to) {
    if (to == 1) {
      $('#ups_output_chart_parent_div').css('visibility', 'hidden');
      $('#ups_battery_chart_parent_div').css('visibility', 'hidden');
      $('#ups_input_chart_parent_div').css('visibility', 'visible');
    } else if (to == 2) {
      $('#ups_input_chart_parent_div').css('visibility', 'hidden');
      $('#ups_battery_chart_parent_div').css('visibility', 'hidden');
      $('#ups_output_chart_parent_div').css('visibility', 'visible');
    } else if (to == 3) {
      $('#ups_input_chart_parent_div').css('visibility', 'hidden');
      $('#ups_output_chart_parent_div').css('visibility', 'hidden');
      $('#ups_battery_chart_parent_div').css('visibility', 'visible');
    }
  }

  function get_batt_status_txt() //get battery status text
  {
    if ((valtable_obj.STATUS & 64) == 64)
    return lang_Battery_Testing;
    if ((valtable_obj.STATUS & 16) == 16)
    return lang_Battery_LOW;
    if ((valtable_obj.STATUS & 1024) == 1024)
    return lang_Battery_Bad;
    if ((valtable_obj.XONL_BATTSTATE & 3) == 3)
    return lang_Battery_Floating;
    if ((valtable_obj.XONL_BATTSTATE & 1) == 1)
    return lang_Battery_Charging;
    if ((valtable_obj.XONL_BATTSTATE & 2) == 2)
    return lang_Battery_Discharging;
    if ((valtable_obj.XONL_BATTSTATE & 4) == 4)
    return lang_Battery_Resting;
    return lang_Battery_Normal
  }

  function get_batt_status_bg() //get battery status text background
  {
    if ((valtable_obj.STATUS & 16) == 16)
    return '#eeee00';
    if ((valtable_obj.STATUS & 1024) == 1024)
    return '#ee0000'; //rot
    if ((valtable_obj.XONL_BATTSTATE & 3) == 3 ||
      (valtable_obj.XONL_BATTSTATE & 4) == 4)
    return '#52B245'; //gruen
    if ((valtable_obj.STATUS & 64) == 64 ||
      (valtable_obj.XONL_BATTSTATE & 2) == 2)
    return '#eeee00'; //gelb
    if ((valtable_obj.XONL_BATTSTATE & 1) == 1) {
      if (valtable_obj.BATTCAP < 90)
      return '#eeee00'; //gelb
    }

    return '#52B245';
  }

  function get_ups_status_txt() //get ups status text
  {
    if ((valtable_obj.STATUS & 1) == 1)
    return i18n(lang_UPS_Bypass_Operation);
    if ((valtable_obj.STATUS & 2) == 2)
    return i18n(lang_UPS_OFF);
    if ((valtable_obj.STATUS & 8) == 8)
    return i18n(lang_UPS_Battery_Operation);
    if ((valtable_obj.STATUS & 4) == 4)
    return i18n(lang_UPS_Normal_Operation);
    return i18n(lang_UPS_Normal_Operation);
  }

  function get_ups_status_bg() //get ups status text background
  {
    if ((valtable_obj.STATUS & 1) == 1)
    return '#eeee00';
    if ((valtable_obj.STATUS & 2) == 2)
    return '#ee0000';
    if ((valtable_obj.STATUS & 8) == 8)
    return '#eeee00';
    if ((valtable_obj.STATUS & 4) == 4)
    return '#52B245';
    return '#52B245';
  }

  function get_batt_teststatus_txt() //get battery teststatus text
  {
    if (valtable_obj.BATTERY_STATE == 16)
    return i18n('Running');
    else if (valtable_obj.BATTERY_STATE == 1)
    return i18n('Passed');
    else if (valtable_obj.BATTERY_STATE == 32)
    return i18n('Cancelled');
    else if (valtable_obj.BATTERY_STATE == 4)
    return i18n('Failed');
    return i18n('N/A');
  }

  function get_batt_teststatus_bg() //get battery status text background
  {
    if (valtable_obj.BATTERY_STATE == 4)
    return '#EE0000';
    else if (valtable_obj.BATTERY_STATE == 32)
    return '#00EE00';
    return '#52B245';
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
      }, { //css
        position: 'absolute',
        top: '700px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }
}(jQuery)); /* init xonl api*/