/*
   xonlag_panel.js - UPS XONL12B und C fuer AGPower 
   Copyright (c) 2017, Generex GmbH. All rights reserved.
*/

var xonlag_api = (function ($) {
  var oid = get_oid_from_url(),
  cb = null,
  pannes_created = false,
  err_div = null,
  check_bowser = true,
  outpower_loadbars_created = false,
  css_obj,
  valtable_obj, report_obj, unms_obj,
  _oemViewName = null,
  _upsProtocol,
  x_pos = 10,
  y_pos = 10;

  var req_params = null;

  /*public functions*/
  return {
    init: init
  };

  function init() {
    if (check_bowser && !utils_api.check_bowser()) {
      $('#loading_id').css('display', 'none');
      panes_api.create_br_check_panel(this, browser_check_ok);
      return true;
    }
    create_err_msg_panel();

    req_params = utils_api.get_req_params(utils_api.device_ups, oid);
    cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
  }

  function browser_check_ok() {
    check_bowser = false;
    init();
  }

  function create_err_msg_panel() {
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 791, display: 'none', 'z-index': 22 };
    err_div = panes_api.create_err_panel({ id: 'error_div', 'class': 'alert alert-danger' }, css_obj);
  }

  function err_funct(response) {
    jqmodule.refresh(cb, 10 * 1000);
    panes_api.display_err({ response: response, oid: oid, err_div: err_div, err_msg_div_id: 'error_msg_div' });
  }

  function update(data) {
    if (data.length == 0) {
      return;
    }

    valtable_obj = data.ups.valtable;
    report_obj = data.report;

    if (_oemViewName == null) {
      if (data.ups._oemViewName)
      _oemViewName = data.ups._oemViewName.toLowerCase();
      else
      _oemViewName = valtable_obj._oemViewName.toLowerCase();

      if (valtable_obj._upsProtocol)
      _upsProtocol = valtable_obj._upsProtocol;
      else
      _upsProtocol = valtable_obj.CONNECT;
    }

    jqmodule.refresh(cb, report_obj.refresh * 1000);
    if (err_div)
    err_div.css('display', 'none');

    if (window.menu_api != null)
    menu_api.update(data);

    unms_obj = get_unms_obj(data);
    if (unms_obj != null) {
      info_head_api.update(unms_obj);
    }

    if (!pannes_created) {
      pannes_created = true;
      create_panes();
      return false;
    }
    set_bg();
    set_input_values();
    set_output_values(); //Set Output values
    set_bypass(); // set Bypass panel
    set_battery(); //set Battery panel
    set_outpower_loadbars(); //Set outpower loadbars
    set_rectifier(); //Rectifier status
    if (valtable_obj._platform !== "ups_view")
    panes_api.set_rom_temp_values(valtable_obj); //set rom temp values
    set_footer();
  }

  function create_footer_pane() {
    if (!oid || !unms_obj)
    return true;
    footer_api.create({ //Attr
        id: 'panel2'
        //'class':'unmsFooter'
      }, { //css
        position: 'absolute',
        top: '750px',
        left: '74px'
      },
      unms_obj
    );
  }

  function set_footer() {
    if (!oid || !unms_obj)
    return true;
    footer_api.set(unms_obj);
  }

  function create_panes() {
    utils_api.setTitle(valtable_obj._platform);
    create_bg(); //background
    create_model_panel();

    create_input_panel(); //Input panel
    create_output_panel(); //Output panel
    create_bypass_panel(); //Bypass panel
    create_battery_panel(); //Battery panel
    create_rectifier_panel(); //Rectifier panel

    create_outpower_loadbars(); //outpower loadbars
    if (valtable_obj._platform !== "ups_view")
    create_rom_temp(); //rom temp
    create_footer_pane();
  }

  function create_bg() {
    var fragment = document.createDocumentFragment(),
    img_div, img;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, width: 800, height: 620, border: 'solid 1px #808080', 'background-color': 'transparent' };
    img_div = $('<div/>', { 'class': 'img-rounded' }).css(css_obj);
    img = $('<img />').attr({ 'id': 'bg_img_id', 'class': 'img-rounded', align: 'middle', width: 699, 'height': 369, src: get_bg_img() }).appendTo(img_div);
    img.css({ 'margin-top': 110, 'margin-left': 20 });
    fragment.appendChild(img_div[0]);
    document.body.appendChild(fragment);
  }

  function set_bg() {
    var img = $('#bg_img_id');
    img.attr('src', get_bg_img());
  }

  function create_input_panel() //Input panel
  {
    var input_phases = valtable_obj.INPHASES ? valtable_obj.INPHASES : valtable_obj.EX_INP_NUMLINES,
    input_val = get_ph_1_3_vals(valtable_obj.INVOLT, valtable_obj.INCURR, valtable_obj.INFREQ, input_phases),
    fragment = document.createDocumentFragment(),
    val, tr, table, tbody, thead, in_div;

    if (input_val.availables[0] == 0 & input_val.availables[1] == 0 & input_val.availables[2] == 0)
    return true;

    css_obj = { position: 'absolute', top: y_pos + 46, left: x_pos + 22 };

    in_div = $('<div/>', { id: 'input_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(in_div); // table-hover
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);

    tr = $('<tr />').append($('<th />', { colspan: 4, align: 'left' }).append(i18n(lang_Input))).appendTo(thead);

    if (input_val.availables[0] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L1")).appendTo(tbody);
      if (!input_val.val_objs[0].values[0].empty())
      $('<td />', { id: 'input_volt1_id', align: 'left' }).append(input_val.val_objs[0].values[0]).appendTo(tr);
      if (!input_val.val_objs[2].values[0].empty())
      $('<td />', { id: 'input_freq1_id', align: 'left' }).append(input_val.val_objs[2].values[0]).appendTo(tr);
    }
    if (input_val.availables[1] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L2")).appendTo(tbody);
      if (!input_val.val_objs[0].values[1].empty())
      $('<td />', { id: 'input_volt2_id', align: 'left' }).append(input_val.val_objs[0].values[1]).appendTo(tr);
    }
    if (input_val.availables[2] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L3")).appendTo(tbody);
      if (!input_val.val_objs[0].values[2].empty())
      $('<td />', { id: 'input_volt3_id', align: 'left' }).append(input_val.val_objs[0].values[2]).appendTo(tr);
    }

    fragment.appendChild(in_div[0]);
    document.body.appendChild(fragment);
  }

  function set_input_values() {

    var input_phases = valtable_obj.INPHASES ? valtable_obj.INPHASES : valtable_obj.EX_INP_NUMLINES,
    input_val = get_ph_1_3_vals(valtable_obj.INVOLT, valtable_obj.INCURR, valtable_obj.INFREQ, input_phases);

    if (input_val.availables[0] != 0) {
      $('#input_volt1_id').text(input_val.val_objs[0].values[0]);
      $('#input_freq1_id').text(input_val.val_objs[2].values[0]);
    }
    if (input_val.availables[1] != 0) {
      $('#input_volt2_id').text(input_val.val_objs[0].values[1]);
    }
    if (input_val.availables[2] != 0) {
      $('#input_volt3_id').text(input_val.val_objs[0].values[2]);
    }
  }

  function create_output_panel() //Output panel
  {
    var output_phases = valtable_obj.OUTPHASES ? valtable_obj.OUTPHASES : valtable_obj.EX_OUT_NUMLINES,
    output_val = get_ph_1_3_vals(valtable_obj.OUTPUT_VOLT, valtable_obj.EX_OUT_CURR, valtable_obj.OUTFREQ, output_phases),
    output_div = null,
    val, tr, table, tbody, thead,
    fragment = document.createDocumentFragment();
    if (output_val.availables[0] == 0 & output_val.availables[1] == 0 & output_val.availables[2] == 0)
    return true;

    css_obj = { position: 'absolute', top: y_pos + 46, left: x_pos + 560 };

    output_div = $('<div/>', { id: 'output_div_id' }).css(css_obj);
    table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(output_div);

    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { colspan: 4 }).append(i18n(lang_Output))).appendTo(thead);

    if (output_val.availables[0] != 0) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L1")).appendTo(tbody);
      if (!output_val.val_objs[0].values[0].empty())
      $('<td />', { 'id': 'out_volt1_id', align: 'left' }).append(output_val.val_objs[0].values[0]).appendTo(tr);
      if (!output_val.val_objs[2].values[0].empty())
      $('<td />', { id: 'out_freq1_id', align: 'left' }).append(output_val.val_objs[2].values[0]).appendTo(tr);
    }

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Load'))).appendTo(tbody);
    $('<td />', { id: 'out_power_0_id', align: 'left' }).
    append(get_value({ values: valtable_obj.EX_OUT_WATT, index: 0, unit: ' W', precision: 0 })).appendTo(tr);
    $('<td />', { id: 'out_va_0_id', align: 'left' }).
    append(get_value({ values: valtable_obj.EX_OUT_VA, index: 0, unit: ' VA', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' })).appendTo(tbody);
    $('<td />', { id: 'out_curr_0_id', align: 'left' }).
    append(get_value({ values: valtable_obj.EX_OUT_CURR, index: 0, unit: ' A', precision: 1 })).appendTo(tr);
    $('<td />', { id: 'out_load_0_id', align: 'left' }).
    append(get_value({ values: valtable_obj.OUTPOWER, index: 0, unit: ' %', precision: 0 })).appendTo(tr);

    fragment.appendChild(output_div[0]);
    document.body.appendChild(fragment);
  }

  function set_output_values() //Set Output values
  {
    var output_phases = valtable_obj.OUTPHASES ? valtable_obj.OUTPHASES : valtable_obj.EX_OUT_NUMLINES,
    output_val = get_ph_1_3_vals(valtable_obj.OUTPUT_VOLT, valtable_obj.EX_OUT_CURR, valtable_obj.OUTFREQ, output_phases);

    if (output_val.availables[0] != 0) {
      $('#out_volt1_id').text(output_val.val_objs[0].values[0]);
      $('#out_freq1_id').text(output_val.val_objs[2].values[0]);
    }
    $('#out_power_0_id').text(get_value({ values: valtable_obj.EX_OUT_WATT, index: 0, unit: ' W', precision: 0 }));
    $('#out_va_0_id').text(get_value({ values: valtable_obj.EX_OUT_VA, index: 0, unit: ' VA', precision: 0 }));
    $('#out_curr_0_id').text(get_value({ values: valtable_obj.EX_OUT_CURR, index: 0, unit: ' A', precision: 1 }));
    $('#out_load_0_id').text(get_value({ values: valtable_obj.OUTPOWER, index: 0, unit: ' %', precision: 0 }));
  }

  function create_bypass_panel() //Bypass panel
  {
    var tr, td, table, tbody, thead, batt_div, img, obj,
    fragment = document.createDocumentFragment(),
    bypass_val = get_ph_1_3_vals(valtable_obj.EX_BYP_VOLT, valtable_obj.EX_BYP_CURR, valtable_obj.EX_BYP_FREQ, valtable_obj.EX_BYP_NUMLINES);

    if (bypass_val.availables[0] != 0) {
      css_obj = { position: 'absolute', top: y_pos + 46, left: x_pos + 290 };
      attr_obj = { id: 'bypass_div_id' };
      bypass_div = $('<div/>').attr(attr_obj).css(css_obj);
      table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(bypass_div);
      tbody = $('<tbody />').appendTo(table);
      thead = $('<thead />').appendTo(table);
      tr = $('<tr />').append($('<th />', { align: 'left', colspan: 4 }).append(i18n(lang_Bypass))).appendTo(thead);

      tr = $('<tr />').append($('<td />', { align: 'left' }).append("L1")).appendTo(tbody);
      if (!bypass_val.val_objs[0].values[0].empty())
      $('<td />', { 'id': 'byp_volt1_id', align: 'left' }).append(bypass_val.val_objs[0].values[0]).appendTo(tr);
      if (!bypass_val.val_objs[2].values[0].empty())
      $('<td />', { id: 'byp_freq1_id', align: 'left' }).append(bypass_val.val_objs[2].values[0]).appendTo(tr);

      fragment.appendChild(bypass_div[0]);
      document.body.appendChild(fragment);
    }
  }

  function set_bypass() // set Bypass panel
  {
    var img, obj, bypass_val = get_ph_1_3_vals(valtable_obj.EX_BYP_VOLT, valtable_obj.EX_BYP_CURR, valtable_obj.EX_BYP_FREQ, valtable_obj.EX_BYP_NUMLINES);
    if (bypass_val.availables[0] != 0) {
      $('#byp_volt1_id').text(bypass_val.val_objs[0].values[0]);
      $('#byp_freq1_id').text(bypass_val.val_objs[2].values[0]);
    }
  }

  function create_battery_panel() //Battery panel
  {
    var tr, td, table, tbody, thead, batt_div, img, obj,
    fragment = document.createDocumentFragment();

    css_obj = { position: 'absolute', top: y_pos + 430, left: x_pos + 278 }; //, width:130, height:100
    attr_obj = { id: 'battery_div_id' };
    batt_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(batt_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { align: 'left', colspan: 2 }).append(i18n(lang_Battery) + ' ' + i18n('Status'))).appendTo(thead);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Status'))).appendTo(tbody); //Battery Status
    td = $('<td />').appendTo(tr);
    obj = get_batt_status();
    img = $('<img />').attr({ 'id': 'batt_status_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Voltage))).appendTo(tbody);
    $('<td />', { id: 'batt_volt_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.BATTVOLT], index: 0, unit: ' V', precision: 0 })).appendTo(tr);

    if (valtable_obj.EX_BATT_CURRPOS != null) {
      tr = $('<tr />').appendTo(tbody);
      td = $('<td />', { id: 'batt_curr_txt_id', align: 'left' }).append(i18n(lang_Current)).appendTo(tr);
      $('<td />', { id: 'batt_curr_id', align: 'left' }).
      append(get_value({ values: [valtable_obj.EX_BATT_CURRPOS], index: 0, unit: ' A', precision: 1 })).appendTo(tr);
    }

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Time))).appendTo(tbody);
    $('<td />', { id: 'batt_autotime_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.AUTONOMTIME], index: 0, unit: ' Min', precision: 0 })).appendTo(tr);

    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n(lang_Battery_Capacity_short))).appendTo(tbody);
    $('<td />', { id: 'batt_cap_id', align: 'left' }).
    append(get_value({ values: [valtable_obj.BATTCAP], index: 0, unit: ' %', precision: 0 })).appendTo(tr);

    if (valtable_obj.EX_BATT_SECONBATT != null) {
      tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Seconds'))).appendTo(tbody);
      $('<td />', { id: 'batt_seconds_id', align: 'left' }).
      append(get_value({ values: [valtable_obj.EX_BATT_SECONBATT], index: 0, unit: ' Sec', precision: 0 })).appendTo(tr);
    }
    fragment.appendChild(batt_div[0]);
    document.body.appendChild(fragment);
  }

  function set_battery() //set Battery panel
  {
    var img, obj;

    obj = get_batt_status();
    img = $('#batt_status_id');
    img.attr({ src: obj.src, title: obj.title }); //Battery Status
    $('#batt_volt_id').text(get_value({ values: [valtable_obj.BATTVOLT], index: 0, unit: ' V', precision: 0 }));
    if (valtable_obj.EX_BATT_CURRPOS != null) {
      $('#batt_curr_id').text(get_value({ values: [valtable_obj.EX_BATT_CURRPOS], index: 0, unit: ' A', precision: 1 }));
    }
    $('#batt_autotime_id').text(get_value({ values: [valtable_obj.AUTONOMTIME], index: 0, unit: ' Min', precision: 0 }));
    $('#batt_cap_id').text(get_value({ values: [valtable_obj.BATTCAP], index: 0, unit: ' %', precision: 0 }));
    if (valtable_obj.EX_BATT_SECONBATT != null)
    $('#batt_seconds_id').text(get_value({ values: [valtable_obj.EX_BATT_SECONBATT], index: 0, unit: ' Sec', precision: 0 }));
  }

  function create_rectifier_panel() //Rectifier panel
  {

    var tr, td, table, tbody, thead, batt_div, img, obj,
    fragment = document.createDocumentFragment();

    css_obj = { position: 'absolute', top: y_pos + 430, left: x_pos + 22 };
    attr_obj = { id: 'rectifier_div_id' };
    rectifier_div = $('<div/>').attr(attr_obj).css(css_obj);
    table = table = $('<table />', { 'class': 'table table-condensed table-hover' }).appendTo(rectifier_div);
    tbody = $('<tbody />').appendTo(table);
    thead = $('<thead />').appendTo(table);
    tr = $('<tr />').append($('<th />', { align: 'left', colspan: 2 }).append(i18n(lang_Rectifier) + ' ' + i18n('Status'))).appendTo(thead);
    tr = $('<tr />').append($('<td />', { align: 'left' }).append(i18n('Rectifier Operating'))).appendTo(tbody);
    td = $('<td />').appendTo(tr);
    obj = get_rect_operating_status();
    img = $('<img />').attr({ 'id': 'rect_operating_img_id', align: 'left', width: 16, height: 16, src: obj.src, title: obj.title }).appendTo(td);

    fragment.appendChild(rectifier_div[0]);
    document.body.appendChild(fragment);
  }

  function set_rectifier() //Rectifier status
  {
    var img, obj;
    obj = get_rect_operating_status();
    $('#rect_operating_img_id').attr({ src: obj.src, title: obj.title });
  }

  function get_rect_operating_status() {
    var bit_val = 1 << 2;
    if ((valtable_obj.STATUS & bit_val) == bit_val)
    return { src: './image/bacs2/b_green.gif', title: 'Yes' };
    return { src: './image/bacs2/b_red.gif', title: 'No' };
  }

  function get_batt_status() {
    var bit_val = 1 << 5;
    if ((valtable_obj.STATUS & bit_val) == bit_val)
    return { src: './image/bacs2/b_red.gif', title: 'Low Battery' };
    return { src: './image/bacs2/b_green.gif', title: 'Battery Normal' };
  }

  function get_bg_img() {
    var bit_val;

    bit_val = 1 << 3; //powerfail
    if ((valtable_obj.STATUS & bit_val) == bit_val)
    return './image/mega/mega_bb_b.png';
    bit_val = 1 << 0; //bypass
    if ((valtable_obj.STATUS & bit_val) == bit_val)
    return './image/mega/mega_byb_b.png';
    bit_val = 1 << 6; //testact
    if ((valtable_obj.STATUS & bit_val) == bit_val)
    return './image/mega/mega_tb_b.png';
    bit_val = 1 << 2; //normal betrieb
    if ((valtable_obj.STATUS & bit_val) == bit_val)
    return './image/mega/mega_nb_b.png';
    return './image/mega/mega_3_4_b.png';
  }

  function get_ph_1_3_vals(volt, cur, freq, phases) {
    var val_obj, val;
    l_1_3_vals = {
      availables: [0, 0, 0], //L1-L3
      val_objs: [
        { unit: ' V', precision: 0, values: ['', '', ''] },
        { unit: ' A', precision: 2, values: ['', '', ''] },
        { unit: ' Hz', precision: 2, values: ['', '', ''] }
      ]
    };
    volt = volt || [];
    cur = cur || [], freq = freq || [];
    $.each([volt, cur, freq], function (index, values) {
      val_obj = l_1_3_vals.val_objs[index];
      $.each(values, function (i, val) {
        if (i < phases) {
          val = values[i];
          if (val != -9999) {
            if (values === freq & (i == 1 || i == 2)) {

            } else
            l_1_3_vals.availables[i] = 1;

            if (Math.round(val) == val)
            val = val.toString();
            else
            val = val.toFixed(val_obj.precision);
            val += val_obj.unit;
            val_obj.values[i] = val;
          }
        }
      });
    });
    return l_1_3_vals;
  }

  function get_value(val_obj) {
    if (!val_obj.values || (val_obj.values.length <= val_obj.index))
    return 'N/A';
    var val = val_obj.values[val_obj.index];
    if (val == null || val_obj.values[val_obj.index] == -9999)
    return 'N/A';

    if (Math.round(val) == val)
    val = val.toString();
    else
    val = val.toFixed(val_obj.precision);
    val += val_obj.unit;
    return val;
  }


  function create_model_panel() {
    var model_div, a;
    css_obj = { position: 'absolute', top: y_pos, left: x_pos, align: 'center', width: 800 }; // 'background-color': '#3a87ad'
    attr_obj = { id: 'model_div_id', 'class': 'list-group' };
    model_div = panes_api.create_div(attr_obj, css_obj);
    a = $('<a/>', { 'class': 'list-group-item active' }).append(valtable_obj.MODEL).appendTo(model_div);
  }

  function set_outpower_loadbars() //outpower loadbars
  {
    if (valtable_obj.OUTPOWER == null)
    return true;
    if (valtable_obj.OUTPOWER[0] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[0], 'loadbar1_id');
    if ((valtable_obj.OUTPHASES > 1) && valtable_obj.OUTPOWER[1] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[1], 'loadbar2_id');
    if ((valtable_obj.OUTPHASES > 2) && valtable_obj.OUTPOWER[2] != -9999)
    panes_api.set_loabar_value(valtable_obj.OUTPOWER[2], 'loadbar3_id');
  }

  function create_outpower_loadbars() //outpower loadbars
  {
    if (valtable_obj.OUTPOWER == null)
    return true;
    outpower_loadbars_created = true;

    if (valtable_obj.OUTPOWER[0] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[0], id: 'loadbar1_id', left: x_pos + 568, top: y_pos + 396, title: 'L1', scaler: 1 });
    if ((valtable_obj.OUTPHASES > 1) && valtable_obj.OUTPOWER[1] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[1], id: 'loadbar2_id', left: x_pos + 568, top: y_pos + 428, title: 'L2', scaler: 0 });
    if ((valtable_obj.OUTPHASES > 2) && valtable_obj.OUTPOWER[2] != -9999.00)
    panes_api.create_loadbar_pane({ value: valtable_obj.OUTPOWER[2], id: 'loadbar3_id', left: x_pos + 568, top: y_pos + 460, title: 'L3', scaler: 0 });
  }

  function create_rom_temp() //rom temp
  {
    var fragment = document.createDocumentFragment(),
    rom_temp_div;
    css_obj = { position: 'absolute', top: y_pos + 316, left: x_pos + 22 };
    rom_temp_div = $('<div/>').attr({ id: 'rom_temp_div_id' }).css(css_obj);
    panes_api.create_rom_temp_pane(valtable_obj, { id: 'rom_temp_table_id', 'class': 'table table-condensed table-hover' }).appendTo(rom_temp_div);
    fragment.appendChild(rom_temp_div[0]);
    document.body.appendChild(fragment);
  }

}(jQuery));