/*
   utils.js - screen utils.
   Copyright (c) 2012, Generex GmbH. All rights reserved.
   Said.
*/

var utils_api = (function () {
  var ua = navigator.userAgent,
  plattform_ups_view = "ups_view",
  plattform_unms = "unms",
  plattform_cs141 = "cs141",
  plattform_cs121 = "cs121",
  device_ups = "ups",
  device_bacs = "bacs",
  device_aux = "aux",
  device_buzzer = "buzzer",
  device_sensorman = "sensor",
  evt_category = [
    "Test,",
    "Event,",
    "AntiEvent,",
    "System,",
    "Heartbeat,",
    "User,",
    "Scheduler,"
  ];

  /*public functions*/
  return {
    formatDate: formatDate,
    setTitle: setTitle,
    openCmdWin: openCmdWin,
    openSiteWin: openSiteWin,
    onKeyPressNumbers: onKeyPressNumbers,
    check_bowser: check_bowser,
    get_req_params: get_req_params,
    get_url_params: get_url_params,
    device_ups: device_ups,
    device_bacs: device_bacs,
    device_aux: device_aux,
    device_buzzer: device_buzzer,
    device_sensorman: device_sensorman,
    plattform_ups_view: plattform_ups_view,
    plattform_unms: plattform_unms,
    plattform_cs141: plattform_cs141,
    plattform_cs121: plattform_cs121,
    draggable: draggable,
    confirm_action: confirm_action,
    rem_category_from_evt: rem_category_from_evt
  };

  function confirm_action(txt) {
    return window.confirm(txt);
  }

  function get_url_params() {
    var vars = [],
    hash,
    i = 0,
    href = window.location.href,
    hashes = href.slice(href.indexOf('?') + 1).split('&')
    len = hashes.length;
    for (i = 0; i < len; i++) {
      hash = hashes[i].split('=');
      vars.push(hash[0]);
      vars[hash[0]] = hash[1];
    }
    return vars;
  }

  function get_req_params(device_type, oid) {
    var req_params = null,
    plattform = get_plattform(); //get plattform name

    if (plattform !== plattform_cs141) {
      if (device_type === device_ups) {
        return req_params = {
          url: oid ? get_url("script/nmsView.dll?" + oid + "&json=" + device_type) : get_url("data.cgi"),
          data: oid ? {} : { "json": "ups", "log_entries": 5 },
          data_type: 'json',
          methode: "POST",
          refresh_tm: 10
        };
      }
      return req_params = {
        url: oid ? get_url("script/nmsView.dll?" + oid + "&json=" + device_type) : get_url("data.cgi"),
        data: oid ? {} : { "json": "bacs" },
        data_type: 'json',
        methode: "POST",
        refresh_tm: 10
      };
    } //plattform !== plattform_cs141

    return req_params = {
      url: get_url("api/devices/" + device_type + "/report"),
      data: {},
      data_type: 'json',
      methode: "GET",
      refresh_tm: 10
    };
  }

  function openCmdWin(w, h, title, win, cmd) {
    var x = screen.availWidth / 2 - w / 2;
    var y = screen.availHeight / 2 - h / 2;

    var url = get_url("data.cgi") /*get the server url*/ ;
    url += "?";
    url = url.concat(cmd);
    if (win != null && !win.closed) {
      x = win.screenLeft;
      y = win.screenTop;
      win.close();
    }
    var size = 'width=' + w + ',height=' + h;
    var pos = ',left=' + x + ',top=' + y + ',screenX=' + x + ',screenY=' + y;
    win = window.open(url, "", size + pos + ',scrollbars=1,resizable=1,location=yes');
    //win.document.name = title;//IE Bug
    win.focus();
    return win;
  }

  function openSiteWin(w, h, title, win, site) {
    var x = screen.availWidth / 2 - w / 2;
    var y = screen.availHeight / 2 - h / 2;
    var url = "http://" + window.location.host;
    url = url.concat('/' + site);
    title = "'" + title + "'";

    if (win != null && !win.closed) {
      win.close();
    }
    var size = 'width=' + w + ',height=' + h;
    var pos = ',left=' + x + ',top=' + y + ',screenX=' + x + ',screenY=' + y;
    win = window.open(url, "", size + pos + ',scrollbars=1,resizable=1');
    //win.document.name = title;//IE Bug
    win.focus();
    return win;
  }

  function formatDate(date, formatString) {
    if (date instanceof Date) {
      var months = new Array("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec");
      var yyyy = date.getFullYear();
      var yy = yyyy.toString().substring(2);
      var m = date.getMonth() + 1;
      var mm = m < 10 ? "0" + m : m;
      var mmm = months[m - 1];
      var d = date.getDate();
      var dd = d < 10 ? "0" + d : d;

      var h = date.getHours();
      var hh = h < 10 ? "0" + h : h;
      var n = date.getMinutes();
      var nn = n < 10 ? "0" + n : n;
      var s = date.getSeconds();
      var ss = s < 10 ? "0" + s : s;

      formatString = formatString.replace(/hh/i, hh);
      formatString = formatString.replace(/h/i, h);
      formatString = formatString.replace(/nn/i, nn);
      formatString = formatString.replace(/n/i, n);
      formatString = formatString.replace(/ss/i, ss);
      formatString = formatString.replace(/s/i, s);
      formatString = formatString.replace(/yyyy/i, yyyy);
      formatString = formatString.replace(/yy/i, yy);
      formatString = formatString.replace(/mmm/i, mmm);
      formatString = formatString.replace(/mm/i, mm);
      formatString = formatString.replace(/m/i, m);
      formatString = formatString.replace(/dd/i, dd);
      formatString = formatString.replace(/d/i, d);

      return formatString;
    } else {
      return "";
    }
  }

  function onKeyPressNumbers(e) {
    var key = window.event ? e.keyCode : e.which;
    var keychar = String.fromCharCode(key);
    reg = /\D/;
    return !reg.test(keychar);
  }

  function setTitle(platform) {
    if (platform != null && platform == "ups_view")
    parent.document.title = "UPS View Web client";
  }

  function check_bowser() {
    var os_br_ver = [{
        os_name: 'Windows',
        browsers: [
          { name: 'chrome', min_ver: 45 },
          { name: 'firefox', min_ver: 47 },
          //{name:'opera', min_ver:12},
          //{name:'safari', min_ver:5.1},
          { name: 'msie', min_ver: 10 }
        ]
      },
      {
        os_name: 'MacOS',
        browsers: [
          { name: 'chrome', min_ver: 45 },
          { name: 'firefox', min_ver: 47 },
          //{name:'opera', min_ver:12},
          { name: 'safari', min_ver: 9.1 }
        ]
      },
      {
        os_name: 'Linux',
        browsers: [
          { name: 'chrome', min_ver: 45 },
          { name: 'firefox', min_ver: 45 }
        ]
      }
    ],
    os_name = get_os_name(),
    browser = get_browser(),
    result = false;
    //alert("UA:" + ua + " browser:"+ browser.name + " version:" + browser.version);

    $.each(os_br_ver, function (index, br_obj) {
      if (os_name === br_obj.os_name) {
        $.each(br_obj.browsers, function (i, br) {
          if (br.name === browser.name) {
            if (browser.version >= br.min_ver)
            result = true;
            return false;
          }
        });
      }
    });
    return result;
  }

  function get_os_name() {
    if (ua.indexOf('Win') != -1)
    return 'Windows';
    if (ua.indexOf('Mac') != -1)
    return 'MacOS';
    if (ua.indexOf('Linux') != -1)
    return 'Linux';
    return '';
  }

  function get_browser() {
    var ie = /(msie|trident|edge)/i.test(ua),
    chrome = /chrome/i.test(ua),
    safari = /safari/i.test(ua) && !chrome,
    firefox = /firefox/i.test(ua),
    webkitVersion = /version\/(\d+(\.\d+)?)/i,
    firefoxVersion = /firefox\/(\d+(\.\d+)?)/i;

    if (ie) {
      if (ua.indexOf('Trident/') != -1) {
        var version = parseFloat(ua.match(/(Trident\/)(\d+(\.\d+)?)/i)[2]);
        if (version >= 7) {
          return { name: 'msie', version: 11 };
        }
        return { name: 'msie', version: 0 };
      }
      return { name: 'msie', version: parseFloat(ua.match(/(msie |rv:|Edge\/)(\d+(\.\d+)?)/i)[2]) };
    }
    if (chrome)
    return { name: 'chrome', version: parseFloat(ua.match(/chrome\/(\d+(\.\d+)?)/i)[1]) };
    if (safari)
    return { name: 'safari', version: parseFloat(ua.match(webkitVersion)[1]) };
    if (firefox)
    return { name: 'firefox', version: parseFloat(ua.match(firefoxVersion)[1]) };
    return { name: '', version: '' };
  }

  function rem_category_from_evt(text_id) {
    var index = 0,
    i = 0,
    element = document.getElementById(text_id);
    if (!element) {
      return;
    }

    for (; i < evt_category.length; ++i) {
      if ((index = element.innerText.indexOf(evt_category[i])) == 0) {
        element.innerText = element.innerText.substring(evt_category[i].length);
        return true;
      }
    }

  }

  function draggable(id) {
    var el = document.getElementById(id),
    isDragReady = false,
    dragoffset = {
      x: 0,
      y: 0
    };
    this.init = function () {
      el.style.position = "absolute";
      el.style.cursor = "move";
      this.events();
    };

    //events for the element
    this.events = function () {
      var self = this;
      _on(el, 'mousedown', function (e) {
        isDragReady = true;
        //corssbrowser mouse pointer values
        e.pageX = e.pageX || e.clientX + (document.documentElement.scrollLeft ?
          document.documentElement.scrollLeft :
          document.body.scrollLeft);
        e.pageY = e.pageY || e.clientY + (document.documentElement.scrollTop ?
          document.documentElement.scrollTop :
          document.body.scrollTop);
        dragoffset.x = e.pageX - el.offsetLeft;
        dragoffset.y = e.pageY - el.offsetTop;
      });
      _on(document, 'mouseup', function () {
        isDragReady = false;
      });
      _on(document, 'mousemove', function (e) {
        if (isDragReady) {
          e.pageX = e.pageX || e.clientX + (document.documentElement.scrollLeft ?
            document.documentElement.scrollLeft :
            document.body.scrollLeft);
          e.pageY = e.pageY || e.clientY + (document.documentElement.scrollTop ?
            document.documentElement.scrollTop :
            document.body.scrollTop);
          el.style.top = (e.pageY - dragoffset.y) + "px";
          el.style.left = (e.pageX - dragoffset.x) + "px";
        }
      });
    };
    //cross browser event Helper function
    var _on = function (el, event, fn) {
      document.attachEvent ? el.attachEvent('on' + event, fn) : el.addEventListener(event, fn, !0);
    };
    this.init();
  };

})();

var xsl_ajax_api = (function () {
  var oid = get_oid_from_url(),
  plattform = get_plattform(),
  req_params = null,
  cb = null,
  active_ups_id = 0,
  xslt_doc = null,
  responseText = "",
  response = '',
  err_div = null;

  return {
    init: function () {
      req_params = get_req_params();
      cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
    },
    set_active_ups_id: function (ups_id) {
      if (plattform == utils_api.plattform_cs141) {
        active_ups_id = ups_id;
        update(response, responseText);
        return true;
      }
      //plattform_unms
      jqmodule.unsubscribe(cb);
      req_params = get_req_params();
      cb = jqmodule.subscribe(this, { update: update, error: err_funct }, req_params);
    }
  };

  function update(resp, respText) {
    var report = null,
    refresh_tm = 10;

    response = resp;
    responseText = respText;

    try {
      report = response.documentElement.getElementsByTagName('report')[0];
      refresh_tm = parseInt(report.getAttribute('refresh'));
      jqmodule.refresh(cb, refresh_tm * 1000);
      display_data(response, responseText);
    } catch (e) {
      err_funct({ responseText: e.message });
      return true;
    }
  }


  function create_err_panel(attr_obj, css_obj) {
    return err_div;
  }

  function err_funct(response) {
    document.location.href = document.location.href;
  }

  function display_data(response, responseText) {
    var xsltProcessor = null,
    xml_doc = null,
    transformed = null,
    iframe = null,
    iframe_doc = null;

    xml_doc = response;

    if (xslt_doc == null) {
      get_xslt_doc(xml_doc);
    }

    if (!window['XSLTProcessor']) // Trasformation for IE
    {
      var xslt = new ActiveXObject("Msxml2.XSLTemplate.3.0");

      xslt.stylesheet = xslt_doc;
      xml_doc = string_to_xml_doc(responseText);
      set_selected_ups_id(xml_doc);
      xsltProcessor = xslt.createProcessor();
      xsltProcessor.input = xml_doc;
      //xsltProcessor.addParameter("message", "1");
      xsltProcessor.transform();
      transformed = xsltProcessor.output;
    } else // Transformation for non-IE
    {
      var xmldom = null,
      serializer = null;

      xsltProcessor = new XSLTProcessor();
      xsltProcessor.importStylesheet(xslt_doc);
      set_selected_ups_id(xml_doc);
      xmldom = xsltProcessor.transformToDocument(xml_doc);
      serializer = new XMLSerializer();
      transformed = serializer.serializeToString(xmldom.documentElement);
    }

    transformed = transformed.replace("xsl_ajax_api.init();", "");
    transformed = transformed.split("&lt;!--").join("");
    transformed = transformed.split("--&gt;").join("");
    transformed = transformed.split("&lt;").join("<");
    transformed = transformed.split("&gt;").join(">");
    transformed = transformed.split("&amp;").join("&");

    iframe = document.createElement("iframe");
    iframe.style.cssText = "position:absolute;width:0px;height:0px;left:-9999px;display:none; visibility:hidden";
    iframe.id = 'xsl_ajax_iframe';
    document.body.appendChild(iframe);

    iframe.onload = function () {
      iframe_doc = iframe.contentDocument;
      window.pageCount = iframe.contentWindow.pageCount;
      window.panelCount = iframe.contentWindow.panelCount;
      window.panelArray = iframe.contentWindow.panelArray;
      document.body.parentNode.replaceChild(iframe_doc.body.cloneNode(true), document.body);
      iframe.parentNode.removeChild(iframe);
    }


    iframe_doc = iframe.document;
    if (iframe.contentDocument)
    iframe_doc = iframe.contentDocument;
    else if (iframe.contentWindow)
    iframe_doc = iframe.contentWindow.document;
    else if (iframe.ownerDocument)
    iframe_doc = iframe.ownerDocument;

    if (iframe_doc) {
      // Put the content in the iframe
      iframe_doc.open();
      iframe_doc.writeln(transformed);
      iframe_doc.close();
    }

  }

  function set_selected_ups_id(xml_doc) {
    var values = xml_doc.documentElement.getElementsByTagName('values')[0],
    childNodes = null;

    if (!window['XSLTProcessor']) // Trasformation for IE
    {
      childNodes = values.childNodes
    } else {
      childNodes = values.children;
    }

    for (var i = 0; i < childNodes.length; i++) {
      if (childNodes[i].getAttribute('name') == "_selected_ups_id") {
        childNodes[i].setAttribute('val', "" + active_ups_id);
      }
    }
  }

  function string_to_xml_doc(xml_str) {
    if (window.ActiveXObject !== undefined &&
      new window.ActiveXObject("Microsoft.XMLDOM")
    ) {
      var xml_doc = new window.ActiveXObject("Microsoft.XMLDOM");
      xml_doc.async = "false";
      xml_doc.loadXML(xml_str);
      return xml_doc;
    } else if (document.implementation && document.implementation.createDocument) {
      return (new window.DOMParser()).parseFromString(xml_str, "text/xml");
    }
  }

  function get_xslt_doc(xml_doc) {
    var stylesheet, items, xslt_file;
    //extract the stylesheet so we can load it manually

    for (var i = 0; i < xml_doc.childNodes.length; i++) {
      if (xml_doc.childNodes[i].nodeName == 'xml-stylesheet') {
        stylesheet = xml_doc.childNodes[i].data;
        break;
      }
    }

    items = stylesheet.split('=');
    xslt_file = items[items.length - 1];
    xslt_file = xslt_file.replace(/'/g, "");
    xslt_file = xslt_file.replace(/"/g, "");

    if (window.ActiveXObject !== undefined && //Internet Explorer
      new window.ActiveXObject("Msxml2.FreeThreadedDOMDocument.3.0")
    ) {
      xslt_doc = new window.ActiveXObject("Msxml2.FreeThreadedDOMDocument.3.0");
      xslt_doc.async = false;
      xslt_doc.onreadystatechange = function () {
        if (xslt_doc.readyState != 4) return false;
      };

      xslt_doc.load(get_url(xslt_file));
    } else {
      jqmodule.ajax(get_url(xslt_file), {
        data: {},
        data_type: 'xml',
        success: function (xslt_data) {
          xslt_doc = xslt_data;
          return xslt_doc;
        },
        error: err_funct
      }, { methode: "GET", async: false });
    }
    return xslt_doc;
  }

  function get_req_params() {
    return {
      url: get_url("www/devices/ups/page"), //"ups.xml"
      data: {},
      data_type: 'xml',
      methode: "GET",
      refresh_tm: 0
    };
  }
})();