<?xml version="1.0"?>
<!--
   valuebar.xsl - Templates for creating value bars.
   Copyright (c) 2005, Generex GmbH. All rights reserved.
   klaus
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" >
  <xsl:output method="html" indent="yes" omit-xml-declaration="yes" encoding="iso-8859-1"/>


  <xsl:variable name="footeroffset" select="22"/>
  <xsl:variable name="scalelineheight" select="10"/>
  <xsl:variable name="scaledescwidth" select="35"/>
  <xsl:variable name="scalerulerwidth" select="7"/>
  <xsl:variable name="scalegapwidth" select="5"/>
  <xsl:variable name="scalewidth"   select="$scaledescwidth + $scalegapwidth + $scalerulerwidth"/>

  <xsl:template name="valuebar">

    <xsl:param name="value" select="'N/A'"/>
    <xsl:param name="footer-value" select="''"/>
    <xsl:param name="headline" select="'Value'"/>
    <xsl:param name="font-size" select="10"/>
    <xsl:param name="unit" select="''"/>
    <xsl:param name="footer-unit" select="''"/>
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="h" select="0"/>
    <xsl:param name="barx" select="0"/>
    <xsl:param name="bary" select="0"/>
    <xsl:param name="barw" select="17"/>
    <xsl:param name="suby" select="0"/>
    <xsl:param name="startval" select="0"/>
    <xsl:param name="endval" select="100"/>
    <xsl:param name="decimal-places" select="2"/>
    <xsl:param name="step" select="25"/>
    <xsl:param name="skip" select="0"/>
    <xsl:param name="shadowoffset" select="5"/>
    <xsl:param name="id" select="'1'"/>
    <xsl:param name="start-visibility" select="'hidden'"/>
    <xsl:param name="thresh-red-hi" select="''"/>
    <xsl:param name="thresh-red-lo" select="''"/>
    <xsl:param name="thresh-yellow-hi" select="''"/>
    <xsl:param name="thresh-yellow-lo" select="''"/>
    <xsl:param name="bright" select="0"/>
    <xsl:param name="with-scale-line" select="0"/>
    <xsl:param name="makescale" select="1"/>
    <xsl:param name="sel_page" select="0"/>
    <xsl:param name="default-color" select="'green'"/>
    <xsl:param name="scaler_id" select="'scaler_id'"/>

    <xsl:variable name="valid" select="string-length($value)>0"/>

    <xsl:variable name="real-val">
      <xsl:choose>
        <xsl:when test="$valid and $value &lt; $startval">
          <xsl:value-of  select="$startval"/>
        </xsl:when>
        <xsl:when test="$valid and $value &gt; $endval">
          <xsl:value-of  select="$endval"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of  select="$value"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="footer-val">
      <xsl:choose>
        <xsl:when test="$footer-value = ''">
          <xsl:call-template name="get-value">
            <xsl:with-param name="value" select="$value"/>
            <xsl:with-param name="unit" select="$unit"/>
            <xsl:with-param name="precision" select="$decimal-places"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="concat($footer-value, concat(' ', $footer-unit) )"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="relX" select="0"/>
    <xsl:variable name="relY" select="0"/>
    <xsl:variable name="x-string" select="string(floor($x))"/>
    <xsl:variable name="y-string" select="string(floor($y))"/>

    <xsl:variable name="valrange" select="$endval - $startval"/>
    <xsl:variable name="barh" select="$suby - $bary"/>
    <xsl:variable name="valsteps" select="$valrange div $step"/>

    <!--<xsl:message>Called valuebar</xsl:message>-->
    <xsl:variable name="id_txt">
      <xsl:choose>
        <xsl:when test="$sel_page=0">
          <xsl:value-of select="concat($id, concat($x-string, concat('-',$y-string)))"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$id"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="rel-id" select="concat('sub-',concat($headline, $id_txt))"/>

    <div id="{$id_txt}" style="position:absolute;left:{$x}px;top:{$y}px;visibility:{$start-visibility};">
      <!-- Display header -->
      <xsl:call-template name="header">
        <xsl:with-param name="x" select="$relX + $barx"/>
        <xsl:with-param name="y" select="$relY"/>
        <xsl:with-param name="w" select="$barw"/>
        <xsl:with-param name="h" select="$bary"/>
        <xsl:with-param name="header" select="$headline"/>
        <xsl:with-param name="id" select="$rel-id"/>
        <xsl:with-param name="font-size" select="$font-size"/>
      </xsl:call-template>

      <xsl:if test="$makescale = 1">
        <!-- Create left scale -->
        <xsl:call-template name="makescale">
          <xsl:with-param name="x" select="$relX"/>
          <xsl:with-param name="y" select="$relY + $suby"/>
          <xsl:with-param name="start" select="$startval"/>
          <xsl:with-param name="end" select="$endval"/>
          <xsl:with-param name="valstep" select="$step"/>
          <xsl:with-param name="pixstep" select="$barh div $valsteps"/>
          <xsl:with-param name="unit" select="$unit"/>
          <xsl:with-param name="id" select="$rel-id"/>
          <xsl:with-param name="scaler_id" select="$scaler_id"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$with-scale-line =  1">
        <div id="left-scale-line" style="position:absolute; left:{$relX + $scalewidth}px; top:{$relY + ($scalelineheight div 2) + ($suby - $valsteps) * ($barh div $valsteps)}px; height:{$barh + 6}px; width:1px;" >
          <img src="./lib/ups/image/ups/bluearea.gif" width="1" height="{$barh + 1}" alt="" border="0"/>
        </div>
      </xsl:if>
      <!-- Display bar areas -->
      <xsl:if test="$valid">
        <xsl:variable name="ledcolor">
          <xsl:call-template name="get-color">
            <xsl:with-param name="value" select="$value"/>
            <xsl:with-param name="thresh-red-hi" select="$thresh-red-hi"/>
            <xsl:with-param name="thresh-red-lo" select="$thresh-red-lo"/>
            <xsl:with-param name="thresh-yellow-hi" select="$thresh-yellow-hi"/>
            <xsl:with-param name="thresh-yellow-lo" select="$thresh-yellow-lo"/>
            <xsl:with-param name="default-color" select="$default-color"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:if test="($real-val - $startval) div $valrange &gt; 0">
          <xsl:call-template name="barchart">
            <xsl:with-param name="x" select="$relX + $barx + $shadowoffset "/>
            <xsl:with-param name="y" select="$relY + $bary + ($scalelineheight div 2) + $shadowoffset"/>
            <!-- +10-->
            <xsl:with-param name="w" select="$barw"/>
            <xsl:with-param name="h" select="$barh"/>
            <xsl:with-param name="share" select="($real-val - $startval) div $valrange"/>
            <!--<xsl:with-param name="id" select="$rel-id"/>-->
            <xsl:with-param name="id" select="concat($id,concat('_valuebar_',$x))"/>
            <xsl:with-param name="color" select="'gray'"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:call-template name="barchart">
          <xsl:with-param name="x" select="$relX + $barx"/>
          <xsl:with-param name="y" select="$relY + $bary + $scalelineheight div 2"/>
          <!-- +10-->
          <xsl:with-param name="w" select="$barw"/>
          <xsl:with-param name="h" select="$barh"/>
          <xsl:with-param name="share" select="($real-val - $startval) div $valrange"/>
          <!--<xsl:with-param name="id" select="$rel-id"/>-->
          <xsl:with-param name="id" select="concat($id,concat('_s_valuebar_',$x))"/>
          <xsl:with-param name="color" select="$ledcolor"/>
          <xsl:with-param name="bright" select="$bright"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:call-template name="footer">
        <xsl:with-param name="x" select="$relX + $barx"/>
        <xsl:with-param name="y" select="$relY + $suby + $footeroffset"/>
        <xsl:with-param name="w" select="$barw"/>
        <xsl:with-param name="h" select="$h - $suby +1"/>
        <xsl:with-param name="value" select="$footer-val"/>
        <xsl:with-param name="unit" select="''"/>
        <xsl:with-param name="id" select="$rel-id"/>
      </xsl:call-template>
    </div>

  </xsl:template>

  <xsl:template name="header">
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="w" select="50"/>
    <xsl:param name="h" select="100"/>
    <xsl:param name="header" select="''"/>
    <xsl:param name="id" select="'1'"/>
    <xsl:param name="font-size" select="10"/>
    <div id="{$id}" style="position:absolute; top:{$y}px; left:{$x}px; width:{$w}px; height:1px; text-align:center; font-size:{$font-size}px;" class="SmallBold">
      <script type="text/javascript">
        translate_text('<xsl:value-of select="$id"/>', '<xsl:value-of select="$header"/>');
      </script>
    </div>
  </xsl:template>

  <xsl:template name="footer">
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="w" select="50"/>
    <xsl:param name="h" select="100"/>
    <xsl:param name="value" select="0"/>
    <xsl:param name="unit" select="''"/>
    <xsl:param name="id" select="'1'"/>
    <xsl:param name="font-size" select="9"/>
    <div id="{concat($id, string(floor($y)))}" style="position:absolute; top:{$y}px; left:{$x}px; width:{$w}px; height:1px; text-align:center; font-size:{$font-size}px;" class="SmallBold">
      <xsl:value-of select="$value"/>
      <xsl:value-of select="$unit"/>
    </div>
  </xsl:template>

  <xsl:template name="barchart">
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="w" select="50"/>
    <xsl:param name="h" select="100"/>
    <xsl:param name="share" select="0.5"/>
    <xsl:param name="id" select="'1'"/>
    <xsl:param name="color" select="'blue'"/>
    <xsl:param name="bright" select="0"/>

    <xsl:variable name="fillh" select="round($h * $share)"/>
    <xsl:variable name="filly" select="($y + $h) - $fillh"/>
    <xsl:variable name="imgsrc">
      <xsl:choose>
        <xsl:when test="$bright = 0 or $color = 'gray'">
          <xsl:value-of select="concat('./lib/ups/image/ups/', concat($color, 'area.gif'))"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="concat('./lib/ups/image/ups/bright', concat($color, 'area.gif'))"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <!--    
    <xsl:message>Called barchart with x=<xsl:value-of select="$x"/>, y = <xsl:value-of select="$y"/>, w=<xsl:value-of select="$w"/>, h = <xsl:value-of select="$h"/>
    fillh=<xsl:value-of select="$fillh"/>, filly = <xsl:value-of select="$filly"/>, share=<xsl:value-of select="$share"/>
    </xsl:message>
    -->
    <!--<div id="{concat($id, string(floor($y)))}" style="position:absolute; top:{$filly}px; left:{$x}px; width:{$w}px; height:{$fillh}px; "><img src="{$imgsrc}" width="{$w}px" height="{$fillh}px" alt="" border="0"/></div>-->
    <div id="{$id}" style="position:absolute;top:{$filly}px;left:{$x}px;width:{$w}px;height:{$fillh}px;">
      <img src="{$imgsrc}" width="{$w}px" height="{$fillh}px" alt="" border="0"/>
    </div>
  </xsl:template>

  <xsl:template name="scaleruler">
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="w" select="0"/>
    <xsl:param name="id" select="'1'"/>
    <!-- 
    <xsl:message>Called scaleruler with x=<xsl:value-of select="$x"/>, y = <xsl:value-of select="$y"/></xsl:message>
    -->
    <div id="{concat($id, string(floor($y)))}" style="position:absolute; top:{$y}px; left:{$x}px; width:{$w}px; height:1px;background-color:#3F5987; overflow:hidden;">
      <!--<img src="./lib/ups/image/ups/bluearea.gif" width="{$w}" height="1" alt="" border="0"/>-->
    </div>
  </xsl:template>

  <xsl:template name="scaledescription">
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="w" select="20"/>
    <xsl:param name="value" select="0"/>
    <xsl:param name="unit" select="''"/>
    <xsl:param name="id" select="'1'"/>
    <!--<div id="{concat($id, string(floor($y)))}" style="position:absolute; top:{$y}px; left:{$x}px; width:{$w}px; height:{$scalelineheight}px; text-align:right;" class="SmallBold"><xsl:value-of select="$value"/>-->
    <div id="{$id}" style="position:absolute; top:{$y}px; left:{$x}px; width:{$w}px; height:{$scalelineheight}px; text-align:right;" class="SmallBold">
      <xsl:value-of select="$value"/>
    </div>
    <!--<xsl:value-of select="$unit"/>-->
  </xsl:template>

  <xsl:template name="scaler">
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="w" select="0"/>
    <xsl:param name="value" select="0"/>
    <xsl:param name="unit" select="''"/>
    <xsl:param name="id" select="'1'"/>
    <xsl:call-template name="scaledescription">
      <xsl:with-param name="x" select="$x"/>
      <xsl:with-param name="y" select="$y"/>
      <!--+10-->
      <xsl:with-param name="w" select="$scaledescwidth"/>
      <xsl:with-param name="value" select="$value"/>
      <xsl:with-param name="unit" select="$unit"/>
      <xsl:with-param name="id" select="$id"/>
    </xsl:call-template>
    <xsl:call-template name="scaleruler">
      <xsl:with-param name="x" select="$x + $scaledescwidth + $scalegapwidth"/>
      <xsl:with-param name="y" select="$y + $scalelineheight div 2"/>
      <xsl:with-param name="w" select="$scalerulerwidth"/>
      <xsl:with-param name="id" select="$id"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:variable name="inc_scale" select="'0'"/>
  <!--</xsl:variable>-->
  <xsl:template name="makescale">
    <xsl:param name="start" select="0"/>
    <xsl:param name="end"   select="100"/>
    <xsl:param name="valstep"   select="25"/>
    <xsl:param name="pixstep"   select="25"/>
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="100"/>
    <xsl:param name="unit" select="''"/>
    <xsl:param name="id" select="'1'"/>
    <xsl:param name="scaler_id" select="'scaler_id'"/>
    <xsl:param name="inc_scale" select="$inc_scale"/>
    <!--
    <xsl:message>Called makescale with start=<xsl:value-of select="$start"/>, end =<xsl:value-of select="$end"/>,  y = <xsl:value-of select="$y"/>
    </xsl:message>
    -->
    <xsl:choose>
      <xsl:when test="$start &lt; $end or $start = $end">
        <!--<xsl:message>Start recursion end =<xsl:value-of select="$end"/></xsl:message>-->
        <xsl:call-template name="scaler">
          <xsl:with-param name="x" select="$x"/>
          <xsl:with-param name="y" select="$y"/>
          <xsl:with-param name="w" select="$scalewidth"/>
          <xsl:with-param name="value" select="$start"/>
          <xsl:with-param name="unit" select="$unit"/>
          <!--<xsl:with-param name="id" select="$id"/>            -->
          <xsl:with-param name="id" select="concat($scaler_id, string($inc_scale))"/>
        </xsl:call-template>
        <xsl:call-template name="makescale">
          <xsl:with-param name="start" select="$start + $valstep"/>
          <xsl:with-param name="end" select="$end"/>
          <xsl:with-param name="x" select="$x"/>
          <xsl:with-param name="y" select="$y - $pixstep"/>
          <xsl:with-param name="valstep"   select="$valstep"/>
          <xsl:with-param name="pixstep"   select="$pixstep"/>
          <xsl:with-param name="unit" select="$unit"/>
          <xsl:with-param name="id" select="$id"/>
          <xsl:with-param name="inc_scale" select="$inc_scale + 1 "/>
          <xsl:with-param name="scaler_id" select="$scaler_id"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="get-inline-value-tag">
    <xsl:param name="value" select="0"/>
    <xsl:param name="unit" select="''"/>
    <xsl:param name="decimal-places" select="2"/>
    <xsl:param name="thresh-red-hi" select="''"/>
    <xsl:param name="thresh-red-lo" select="''"/>
    <xsl:param name="thresh-yellow-hi" select="''"/>
    <xsl:param name="thresh-yellow-lo" select="''"/>
    <xsl:param name="default-color" select="'blue'"/>
    <xsl:param name="default-style" select="'MediumBold'"/>

    <xsl:variable name="color">
      <xsl:call-template name="get-color">
        <xsl:with-param name="value" select="$value"/>
        <xsl:with-param name="thresh-red-hi" select="$thresh-red-hi"/>
        <xsl:with-param name="thresh-red-lo" select="$thresh-red-lo"/>
        <xsl:with-param name="thresh-yellow-hi" select="$thresh-yellow-hi"/>
        <xsl:with-param name="thresh-yellow-lo" select="$thresh-yellow-lo"/>
        <xsl:with-param name="default-color" select="$default-color"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="value-string">
      <xsl:call-template name="get-value">
        <xsl:with-param name="value" select="$value"/>
        <xsl:with-param name="unit" select="$unit"/>
        <xsl:with-param name="decimal-places" select="$decimal-places"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:message>
      val:<xsl:value-of select="$value"/>, vals:<xsl:value-of select="$value-string"/>,col:<xsl:value-of select="$color"/>
    </xsl:message>

    <xsl:element name="span">
      <xsl:attribute name="class">
        <xsl:value-of select="$default-style"/>
      </xsl:attribute>
      <xsl:attribute name="style">
        <xsl:value-of select="concat('text-color:', $color)"/>
      </xsl:attribute>
      <xsl:value-of select="$value-string"/>
    </xsl:element>
  </xsl:template>

  <xsl:template name="get-color">
    <xsl:param name="value" select="0"/>
    <xsl:param name="thresh-red-hi" select="''"/>
    <xsl:param name="thresh-red-lo" select="''"/>
    <xsl:param name="thresh-yellow-hi" select="''"/>
    <xsl:param name="thresh-yellow-lo" select="''"/>
    <xsl:param name="default-color" select="'blue'"/>

    <xsl:variable name="use-thresh-yellow-lo" select="string-length($thresh-yellow-lo) &gt; 0"/>
    <xsl:variable name="use-thresh-yellow-hi" select="string-length($thresh-yellow-hi) &gt; 0"/>
    <xsl:variable name="use-thresh-red-lo" select="string-length($thresh-red-lo) &gt; 0"/>
    <xsl:variable name="use-thresh-red-hi" select="string-length($thresh-red-hi) &gt; 0"/>

    <xsl:choose>
      <xsl:when test="not ($use-thresh-yellow-lo or $use-thresh-yellow-hi or $use-thresh-red-hi or $use-thresh-red-lo)">
        <xsl:value-of select="$default-color"/>
      </xsl:when>
      <xsl:when test="($use-thresh-red-hi and $value &gt; $thresh-red-hi) or ($use-thresh-red-lo and $value &lt; $thresh-red-lo)">
        <xsl:value-of select="'red'"/>
      </xsl:when>
      <xsl:when test="($use-thresh-yellow-lo and $value &lt; $thresh-yellow-lo) or ($use-thresh-yellow-hi and $value &gt; $thresh-yellow-hi)">
        <xsl:value-of select="'yellow'"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="'green'"/>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <!-- EOS -->
</xsl:stylesheet>