<?xml version="1.0"?>
<!--
   language.xsl - holds language ressources as variables.
   Language: English
   Copyright (c) 2005-2013, Generex GmbH. All rights reserved.
   Last update 2013: said template to-uppercase to-lowercase
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" omit-xml-declaration="yes" encoding="iso-8859-1"/>

  <xsl:variable name="hexDigits" select="'0123456789ABCDEF'" />
  <xsl:template name="toHex">
    <xsl:param name="decimalNumber" />
    <xsl:if test="$decimalNumber >= 16">
      <xsl:call-template name="toHex">
        <xsl:with-param name="decimalNumber" select="floor($decimalNumber div 16)" />
      </xsl:call-template>
    </xsl:if>
    <xsl:value-of select="substring($hexDigits, ($decimalNumber mod 16) + 1, 1)" />
  </xsl:template>

  <!-- safeNumber (returns 0 instead of 'NaN') -->
  <xsl:template name="safeNumber">
    <xsl:param name="val" select="0"/>
    <xsl:choose>
      <xsl:when test="string(number($val)) != 'NaN'">
        <xsl:value-of select="$val" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="0" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- unsigner: ensures unsignedness of n-bit values-->
  <xsl:template name="unsigner">
    <xsl:param name="val" select="0"/>
    <xsl:param name="bits" select="16"/>
    <xsl:variable name="offset">
      <xsl:choose>
        <xsl:when test="$val &lt; 0">
          <xsl:call-template name="power">
            <xsl:with-param name="base" select="2"/>
            <xsl:with-param name="exp" select="$bits"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>0</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:value-of select="$val + $offset"/>
  </xsl:template>

  <!-- ushor to short -->
  <xsl:template name="ushor_to_short">
    <xsl:param name="val" select="0"/>
    <xsl:param name="bits" select="16"/>
    <xsl:variable name="result">
      <xsl:choose>
        <xsl:when test="$val &gt; 32767">
          <xsl:call-template name="bit-or">
            <xsl:with-param name="val1" select="$val"/>
            <xsl:with-param name="val2" select="-65536"/>
            <xsl:with-param name="places" select="$bits"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$val"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:value-of select="$result"/>
  </xsl:template>

  <!-- bit-not template: calculate binary complement a numbers !-->
  <xsl:template name="bit-not">
    <xsl:param name="val" select="0"/>
    <xsl:param name="places" select="8"/>
    <xsl:variable name="rightmost-bit-not"  select="1 - ($val mod 2)"/>
    <xsl:variable name="ret-val">
      <xsl:choose>
        <xsl:when test="$places &lt; 1">
          <xsl:value-of select="$rightmost-bit-not"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:variable name="recursion">
            <xsl:call-template name="bit-not">
              <xsl:with-param name="val1" select="floor($val div 2)"/>
              <xsl:with-param name="places" select="$places  - 1"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:value-of select="$recursion * 2 + $rightmost-bit-not"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
  </xsl:template>

  <!-- bit-or template: calculate binary OR of two integer numbers !-->
  <xsl:template name="bit-or">
    <xsl:param name="val1" select="0"/>
    <xsl:param name="val2" select="0"/>
    <xsl:param name="places" select="8"/>
    <xsl:call-template name="generic-bit-operation">
      <xsl:with-param name="val1" select="$val1"/>
      <xsl:with-param name="val2" select="$val2"/>
      <xsl:with-param name="places" select="$places"/>
      <xsl:with-param name="op" select="'or'"/>
    </xsl:call-template>
  </xsl:template>

  <!-- bit-or template: calculate binary NOR of two integer numbers !-->
  <xsl:template name="bit-nor">
    <xsl:param name="val1" select="0"/>
    <xsl:param name="val2" select="0"/>
    <xsl:param name="places" select="8"/>
    <xsl:call-template name="generic-bit-operation">
      <xsl:with-param name="val1" select="$val1"/>
      <xsl:with-param name="val2" select="$val2"/>
      <xsl:with-param name="places" select="$places"/>
      <xsl:with-param name="op" select="'nor'"/>
    </xsl:call-template>
  </xsl:template>

  <!-- bit-or template: calculate binary AND of two integer numbers !-->
  <xsl:template name="bit-and">
    <xsl:param name="val1" select="0"/>
    <xsl:param name="val2" select="0"/>
    <xsl:param name="places" select="8"/>
    <xsl:call-template name="generic-bit-operation">
      <xsl:with-param name="val1" select="$val1"/>
      <xsl:with-param name="val2" select="$val2"/>
      <xsl:with-param name="places" select="$places"/>
      <xsl:with-param name="op" select="'and'"/>
    </xsl:call-template>
  </xsl:template>

  <!-- bit-or template: calculate binary NAND of two integer numbers !-->
  <xsl:template name="bit-nand">
    <xsl:param name="val1" select="0"/>
    <xsl:param name="val2" select="0"/>
    <xsl:param name="places" select="8"/>
    <xsl:call-template name="generic-bit-operation">
      <xsl:with-param name="val1" select="$val1"/>
      <xsl:with-param name="val2" select="$val2"/>
      <xsl:with-param name="places" select="$places"/>
      <xsl:with-param name="op" select="'nand'"/>
    </xsl:call-template>
  </xsl:template>

  <!-- bit-or template: calculate binary XOR of two integer numbers !-->
  <xsl:template name="bit-xor">
    <xsl:param name="val1" select="0"/>
    <xsl:param name="val2" select="0"/>
    <xsl:param name="places" select="8"/>
    <xsl:call-template name="generic-bit-operation">
      <xsl:with-param name="val1" select="$val1"/>
      <xsl:with-param name="val2" select="$val2"/>
      <xsl:with-param name="places" select="$places"/>
      <xsl:with-param name="op" select="'xor'"/>
    </xsl:call-template>
  </xsl:template>

  <!-- bit-or template: calculate generic binary operation (nand, nopr, and, or, xor, ) of two integer numbers !-->
  <xsl:template name="generic-bit-operation">
    <xsl:param name="val1" select="0"/>
    <xsl:param name="val2" select="0"/>
    <xsl:param name="places" select="8"/>
    <xsl:param name="op" select="'or'"/>
    <xsl:variable name="rmb1" select= "$val1 mod 2"/>
    <xsl:variable name="rmb2" select= "$val2 mod 2"/>
    <xsl:variable name="rightmost-bit-operation">
      <xsl:choose>
        <xsl:when test="$op = 'nor'">
          <xsl:value-of select="(1 - $rmb1)  * (1 - $rmb2)"/>
        </xsl:when>
        <xsl:when test="$op = 'and'">
          <xsl:value-of select="($rmb1  * $rmb2)"/>
        </xsl:when>
        <xsl:when test="$op = 'nand'">
          <xsl:value-of select="1 - ($rmb1  * $rmb2)"/>
        </xsl:when>
        <xsl:when test="$op = 'xor'">
          <xsl:value-of select="($rmb1 + $rmb2) mod 2"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="($rmb1 + $rmb2) mod 2 + ($rmb1  * $rmb2)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="ret-val">
      <xsl:choose>
        <xsl:when test="$places &lt; 1">
          <xsl:value-of select="$rightmost-bit-operation"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:variable name="recursion">
            <xsl:call-template name="generic-bit-operation">
              <xsl:with-param name="val1" select="floor($val1 div 2)"/>
              <xsl:with-param name="val2" select="floor($val2 div 2)"/>
              <xsl:with-param name="places" select="$places  - 1"/>
              <xsl:with-param name="op" select="$op"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:value-of select="$recursion * 2 + $rightmost-bit-operation"/>
        </xsl:otherwise>
      </xsl:choose>

    </xsl:variable>

    <xsl:choose>
      <xsl:when test="string-length($val1) = 0 or string-length($val2) = 0">

      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$ret-val"/>
      </xsl:otherwise>
    </xsl:choose>
    <!--
          <xsl:message>val1 = <xsl:value-of select="$val1"/>, val2 = <xsl:value-of select="$val2"/>, places = <xsl:value-of select="$places"/>
          op: <xsl:value-of select="$rmb1"/>.<xsl:value-of select="$op"/>.<xsl:value-of select="$rmb2"/>=<xsl:value-of select="$rightmost-bit-operation"/>
          Retval: <xsl:value-of select="$ret-val"/>
          </xsl:message>
          -->
  </xsl:template>

  <!-- power template: returns the $base to power of $exp-->
  <xsl:template name="power">
    <xsl:param name="base" select="1"/>
    <xsl:param name="exp" select="1"/>
    <xsl:choose>
      <xsl:when test="$exp &lt; 1">
        <xsl:value-of select="1"/>
      </xsl:when>
      <xsl:when test="$exp = 1">
        <xsl:value-of select="$base"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="tmp">
          <xsl:call-template name="power">
            <xsl:with-param name="base" select="$base"/>
            <xsl:with-param name="exp" select="($exp)-1"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:value-of select="$tmp *$base"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>



  <!-- getbit template: returns the $bit.th bit of $val (0-based!)-->
  <xsl:template name="getbit" >
    <xsl:param name="val" select="0"/>
    <xsl:param name="bit" select="0"/>

    <xsl:choose>
      <xsl:when test ="$bit &lt; 0">
        <xsl:value-of select="0"/>
      </xsl:when>
      <xsl:when test ="$bit = 0">
        <xsl:value-of select="$val mod 2"/>
      </xsl:when>

      <xsl:otherwise>
        <xsl:call-template name="getbit">
          <xsl:with-param name="val" select="floor($val div 2)"/>
          <xsl:with-param name="bit" select="($bit)-1"/>
        </xsl:call-template>
      </xsl:otherwise>

    </xsl:choose>
  </xsl:template>

  <!-- getbits template: returns the numeric value of $count-bit's starting from $start-bit of $val (0-based!) -->
  <xsl:template name="getbits" >
    <xsl:param name="val" select="0"/>
    <xsl:param name="start-bit" select="0"/>
    <xsl:param name="count-bits" select="0"/>

    <xsl:variable name="bit0">
      <xsl:call-template name="getbit">
        <xsl:with-param name="val" select="$val"/>
        <xsl:with-param name="bit" select="$start-bit"/>
      </xsl:call-template>
    </xsl:variable>


    <xsl:choose>
      <xsl:when test ="$count-bits &lt; 0">
        <xsl:value-of select="0"/>
      </xsl:when>
      <xsl:when test ="$count-bits = 1">
        <xsl:value-of select="$bit0"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="bit-n-1">
          <xsl:call-template name="getbits">
            <xsl:with-param name="val" select="$val"/>
            <xsl:with-param name="start-bit" select="$start-bit + 1"/>
            <xsl:with-param name="count-bits" select="$count-bits - 1"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:value-of select="2*$bit-n-1 + $bit0"/>
      </xsl:otherwise>

    </xsl:choose>
  </xsl:template>

  <!-- hexgetbit template: returns the $bit.th bit of $val (val as hex string)-->
  <xsl:template name="hexgetbit" >
    <xsl:param name="hexval" select="0"/>
    <xsl:param name="bit" select="0"/>
    <xsl:variable name="decval">
      <xsl:call-template name="hexoct2dec">
        <xsl:with-param name="val" select="$hexval"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:call-template name="getbit">
      <xsl:with-param name="val" select="$decval"/>
      <xsl:with-param name="bit" select="$bit"/>
    </xsl:call-template>
  </xsl:template>

  <!-- getbitstring template: returns $val as bitstring-->
  <xsl:template name="getbitstring" >
    <xsl:param 		name="val" select="'0'"/>
    <xsl:param 		name="dir" select="1"/>
    <xsl:variable name="first">
      <xsl:choose>
        <xsl:when test="number($val) > 1">
          <xsl:call-template name="getbitstring">
            <xsl:with-param name="val" select="floor(number($val) div 2)"/>
            <xsl:with-param name="dir" select="$dir"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="last" select="number($val) mod 2"/>
    <xsl:choose>
      <xsl:when test="$dir = 1">
        <xsl:value-of select="concat($first, $last)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat($last, $first)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- hexgetbitstring template: returns $val as bitstring ($val as hex string)-->
  <xsl:template name="hex2string" >
    <xsl:param 		name="hexval" select="'0'"/>
    <xsl:param 		name="dir" select="1"/>
    <xsl:variable name="decval">
      <xsl:call-template name="hexoct2dec">
        <xsl:with-param name="val" select="$hexval"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:call-template name="getbitstring">
      <xsl:with-param name="val" select="$decval"/>
      <xsl:with-param name="dir" select="$dir"/>
    </xsl:call-template>
  </xsl:template>


  <xsl:template name="multiplystring">
    <xsl:param 		name="count" select="1"/>
    <xsl:param 		name="string" select="'0'"/>
    <xsl:variable name="first">
      <xsl:if test="$count > 1">
        <xsl:call-template name="multiplystring">
          <xsl:with-param name="count" select="($count)-1"/>
          <xsl:with-param name="string" select="$string"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:variable>
    <xsl:variable name="last" select="$string"/>
    <xsl:value-of select="concat($first, $last)"/>
  </xsl:template>

  <!-- get bit string with fixed length -->
  <xsl:template name="getfixedbitstring">
    <xsl:param 		name="val" 		select="'0'" />
    <xsl:param 		name="places" select="16" />
    <xsl:param 		name="dir" 		select="1" />

    <!-- treat empty input as zero-->
    <xsl:variable name="num-val">
      <xsl:choose>
        <xsl:when test="string-length($val) = 0">
          <xsl:value-of select="0"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$val"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="real-val">
      <xsl:choose>
        <xsl:when test="$num-val &lt; 0">
          <xsl:variable name="binpower">
            <xsl:call-template name="power">
              <xsl:with-param name="base" select="2"/>
              <xsl:with-param name="exp" select="$places"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:value-of select="($binpower)+ $num-val"/>
        </xsl:when>

        <xsl:otherwise>
          <xsl:value-of select="$num-val"/>
        </xsl:otherwise>

      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="fixed">
      <xsl:call-template name="multiplystring">
        <xsl:with-param name="count" select="$places"/>
        <xsl:with-param name="string" select="'0'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="bitstring">
      <xsl:call-template name="getbitstring">
        <xsl:with-param name="val" select="$real-val"/>
        <xsl:with-param name="dir" select="$dir"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="bitlength" select="string-length($bitstring)"/>
    <xsl:choose>
      <xsl:when test="$dir=1">
        <xsl:value-of select="concat(substring($fixed, 1, ($places)-$bitlength), $bitstring)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat($bitstring, substring($fixed, 1, ($places)-$bitlength))"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--get a single bit from an ASCII bitstring -->
  <xsl:template name='getstringbit'>
    <xsl:param name="byte" select="0"/>
    <xsl:param name="bit" select="0"/>
    <xsl:choose>
      <xsl:when test="substring($byte,$bit +1,1) = '1'">
        <xsl:value-of select="1"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="0"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- get bit string with fixed length from hex-->
  <xsl:template name="hexgetfixedbitstring">
    <xsl:param 		name="val" 		select="'0'" />
    <xsl:param 		name="places" select="16" />
    <xsl:param 		name="dir" 		select="1" />
    <xsl:variable name="decval">
      <xsl:call-template name="hexoct2dec">
        <xsl:with-param name="val" select="$val"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="fixed">
      <xsl:call-template name="multiplystring">
        <xsl:with-param name="count" select="$places"/>
        <xsl:with-param name="string" select="'0'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="bitstring">
      <xsl:call-template name="getbitstring">
        <xsl:with-param name="val" select="$decval"/>
        <xsl:with-param name="dir" select="$dir"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="bitlength" select="string-length($bitstring)"/>
    <xsl:choose>
      <xsl:when test="$dir=1">
        <xsl:value-of select="concat(substring($fixed, 1, ($places)-$bitlength), $bitstring)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat($bitstring, substring($fixed, 1, ($places)-$bitlength))"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Summary of powers of two -->
  <xsl:variable name="bit34" select="17179869184"/>
  <xsl:variable name="bit33" select="8589934592"/>
  <xsl:variable name="bit32" select="4294967296"/>
  <xsl:variable name="bit31" select="2147483648"/>
  <xsl:variable name="bit30" select="1073741824"/>
  <xsl:variable name="bit29" select="536870912"/>
  <xsl:variable name="bit28" select="268435456"/>
  <xsl:variable name="bit27" select="134217728"/>
  <xsl:variable name="bit26" select="67108864"/>
  <xsl:variable name="bit25" select="33554432"/>
  <xsl:variable name="bit24" select="16777216"/>
  <xsl:variable name="bit23" select="8388608"/>
  <xsl:variable name="bit22" select="4194304"/>
  <xsl:variable name="bit21" select="2097152"/>
  <xsl:variable name="bit20" select="1048576"/>
  <xsl:variable name="bit19" select="524288"/>
  <xsl:variable name="bit18" select="262144"/>
  <xsl:variable name="bit17" select="131072"/>
  <xsl:variable name="bit16" select="65536"/>
  <xsl:variable name="bit15" select="32768"/>
  <xsl:variable name="bit14" select="16384"/>
  <xsl:variable name="bit13" select="8192"/>
  <xsl:variable name="bit12" select="4096"/>
  <xsl:variable name="bit11" select="2048"/>
  <xsl:variable name="bit10" select="1024"/>
  <xsl:variable name="bit9"  select="512"/>
  <xsl:variable name="bit8"  select="256"/>
  <xsl:variable name="bit7"  select="128"/>
  <xsl:variable name="bit6"  select="64"/>
  <xsl:variable name="bit5"  select="32"/>
  <xsl:variable name="bit4"  select="16"/>
  <xsl:variable name="bit3"  select="8"/>
  <xsl:variable name="bit2"  select="4"/>
  <xsl:variable name="bit1"  select="2"/>
  <xsl:variable name="bit0"  select="1"/>

  <!-- Bitmask template -->
  <xsl:template name="bit">
    <xsl:param name="val" select="0"/>
    <xsl:param name="bit" select="1"/>

    <!--<xsl:choose> old function-code!!
	    <xsl:when test="( $val mod ( $bit * 2 ) ) - ( $val mod ( $bit     ) )">1</xsl:when>
	    <xsl:otherwise>0</xsl:otherwise>
	  </xsl:choose>-->

    <xsl:variable name='and_result'>
      <xsl:call-template name='bit-and'>
        <xsl:with-param name='val1' select='$val'/>
        <xsl:with-param name='val2' select='$bit'/>
        <xsl:with-param name="places" select="64"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$bit = $and_result">1</xsl:when>
      <xsl:otherwise>0</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- hex octet to decimal -->
  <xsl:template name="hexoct2dec">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test='$value = ""'/>
      <xsl:when test='string-length($value) &lt; 5'>
        <xsl:call-template name='hexquad2dec'>
          <xsl:with-param name='value' select='substring($value,1,string-length($value))'/>
        </xsl:call-template>
      </xsl:when>

      <xsl:otherwise>
        <xsl:variable name='high'>
          <xsl:call-template name='hexquad2dec'>
            <xsl:with-param name='value' select='substring($value,1,4)'/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:variable name='low'>
          <xsl:call-template name='hexquad2dec'>
            <xsl:with-param name='value' select='substring($value,5,string-length($value)-4)'/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:value-of select='$high * 256 * 256 + $low'/>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <!-- hex quad to decimal -->
  <xsl:template name="hexquad2dec">
    <xsl:param name="value"/>

    <xsl:choose>
      <xsl:when test='$value = ""'/>

      <xsl:when test='string-length($value) &lt; 3'>

        <xsl:call-template name='hexpair2dec'>
          <xsl:with-param name='value' select='substring($value,1,2)'/>
        </xsl:call-template>
      </xsl:when>

      <xsl:when test='string-length($value) = 3'>

        <xsl:variable name='high'>
          <xsl:call-template name='cvt-hex-decimal-digit'>
            <xsl:with-param name='digit' select='substring($value, 1, 1)'/>
          </xsl:call-template>
        </xsl:variable>

        <xsl:variable name='low'>
          <xsl:call-template name='hexpair2dec'>
            <xsl:with-param name='value' select='substring($value,2,2)'/>
          </xsl:call-template>
        </xsl:variable>

        <xsl:value-of select='$high * 256 + $low'/>
      </xsl:when>

      <xsl:otherwise>

        <xsl:variable name='high'>
          <xsl:call-template name='hexpair2dec'>
            <xsl:with-param name='value' select='substring($value,1,2)'/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:variable name='low'>
          <xsl:call-template name='hexpair2dec'>
            <xsl:with-param name='value' select='substring($value,3,2)'/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:value-of select='$high * 256 + $low'/>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="hexpair2dec">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test='$value = ""'/>

      <xsl:when test='string-length($value) = 1'>
        <xsl:call-template name='cvt-hex-decimal-digit'>
          <xsl:with-param name='digit' select='$value'/>
        </xsl:call-template>
      </xsl:when>

      <xsl:otherwise>
        <xsl:variable name='high'>
          <xsl:call-template name='cvt-hex-decimal-digit'>
            <xsl:with-param name='digit' select='substring($value, 1, 1)'/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:variable name='low'>
          <xsl:call-template name='hexpair2dec'>
            <xsl:with-param name='value' select='substring($value, 2)'/>
          </xsl:call-template>
        </xsl:variable>

        <xsl:value-of select='$high* 16 + $low'/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name='cvt-hex-decimal-digit'>
    <xsl:param name='digit' select='0'/>
    <xsl:choose>
      <xsl:when test='$digit &lt;= 9'>
        <xsl:value-of select='$digit'/>
      </xsl:when>
      <xsl:when test='$digit = "a" or $digit = "A"'>10</xsl:when>
      <xsl:when test='$digit = "b" or $digit = "B"'>11</xsl:when>
      <xsl:when test='$digit = "c" or $digit = "C"'>12</xsl:when>
      <xsl:when test='$digit = "d" or $digit = "D"'>13</xsl:when>
      <xsl:when test='$digit = "e" or $digit = "E"'>14</xsl:when>
      <xsl:when test='$digit = "f" or $digit = "F"'>15</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="test-char-in-string">
    <xsl:param name="str"/>
    <xsl:param name="ch"/>
    <!--
      <xsl:message>
         Str: <xsl:value-of select="$str"/>
         Ch: <xsl:value-of select="$ch"/>
      </xsl:message>
      -->
    <xsl:variable name="left-op">
      <xsl:choose>
        <xsl:when test="substring($str, 1, 1) = $ch">
          <xsl:value-of select="1"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="0"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="right-op">
      <xsl:choose>
        <xsl:when test="string-length($str) &gt; 1">
          <xsl:call-template name="test-char-in-string">
            <xsl:with-param name="str" select="substring($str, 2, string-length($str)-1)"/>
            <xsl:with-param name="ch" select="$ch"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="0"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <!--
      <xsl:message>
         Right: <xsl:value-of select="$right-op"/>
         Left: <xsl:value-of select="$left-op"/>
      </xsl:message>
      -->
    <xsl:choose>
      <xsl:when test="$right-op + $left-op &gt; 0 ">
        <xsl:value-of select="1"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="0"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>



  <xsl:template name="get-format-string">
    <xsl:param name="decimal-places" select="0"/>
    <xsl:param name="leading-places" select="1"/>
    <xsl:variable name="decimal-format">
      <xsl:call-template name="multiplystring">
        <xsl:with-param 		name="count" select="$decimal-places"/>
        <xsl:with-param 		name="string" select="'0'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="leading-format">
      <xsl:call-template name="multiplystring">
        <xsl:with-param 		name="count" select="$leading-places"/>
        <xsl:with-param 		name="string" select="'0'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$decimal-places = 0">
        <xsl:value-of select="concat($leading-format, '')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat($leading-format, concat('.', $decimal-format))"/>

      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="roundDecimal">
    <xsl:param name="value" select="0.0" />
    <xsl:param name="precision" select="0" />
    <xsl:choose>

      <xsl:when test="string-length(substring-after($value,'.'))=0">
        <xsl:value-of select="$value" />
      </xsl:when>
      <xsl:when test="$precision=0">
        <xsl:value-of select="round($value)" />
      </xsl:when>
      <xsl:otherwise>
        <!-- Ops, A *not rounding* method follows... -->
        <xsl:value-of select="substring-before($value,'.')" />
        <xsl:text>.</xsl:text>
        <xsl:value-of select="substring(substring-after($value,'.'),1,$precision)" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="round-decimal">
    <xsl:param name="value"/>
    <xsl:param name="precision" select="0"/>
    <xsl:choose>
      <!-- check if valueis really a number -->
      <xsl:when test="number($value) = number($value) and $precision &gt; -1">
        <xsl:variable name="power10">
          <xsl:call-template name="power">
            <xsl:with-param name="base" select="10"/>
            <xsl:with-param name="exp" select="$precision"/>
          </xsl:call-template>
        </xsl:variable>
        <!--<xsl:message>Pow10:<xsl:value-of select="$power10"/>,dec:<xsl:value-of select="$decimal-places"/></xsl:message>-->

        <xsl:variable name="round-val">
          <xsl:choose>
            <xsl:when test="$precision &lt; 0">
              <xsl:value-of select="$value"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="round($value * $power10) div $power10"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>

        <xsl:variable name="format">
          <xsl:call-template name="get-format-string">
            <xsl:with-param name="decimal-places" select="$precision"/>
          </xsl:call-template>
        </xsl:variable>
        <!--		    <xsl:message>Roundval:<xsl:value-of select="$round-val"/>, Format:'<xsl:value-of select="$format"/>' Prec:<xsl:value-of select="$precision"/> Result:<xsl:value-of select="format-number($round-val, $format)"/>

		    </xsl:message>
		-->
        <xsl:value-of select="format-number($round-val, $format)"/>
      </xsl:when>
      <!-- check if value is "NaN" or "empty" -->
      <xsl:when test="string($value) = 'NaN' or string-length($value) = 0">
        <xsl:value-of select="'N/A'"/>
      </xsl:when>
      <!-- pipe value thru" -->
      <xsl:otherwise>
        <xsl:value-of select="$value"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="get-val">
    <xsl:param name="value"/>
    <xsl:param name="unit"/>
    <xsl:param name="precision" select="2"/>
    <!--<xsl:message>Val:<xsl:value-of select="$value"/></xsl:message>-->

    <xsl:variable name="round-val">
      <xsl:call-template name="round-decimal">
        <xsl:with-param name="value" select="$value"/>
        <xsl:with-param name="precision" select="$precision"/>
      </xsl:call-template>
    </xsl:variable>

    <!--<xsl:message>Roundval:<xsl:value-of select="$round-val"/></xsl:message>-->

    <xsl:choose>
      <xsl:when test="number($value) = number($value)">
        <xsl:value-of select="$round-val"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="'N/A'"/>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="get-value">
    <xsl:param name="value"/>
    <xsl:param name="unit"/>
    <xsl:param name="precision" select="2"/>
    <!--<xsl:message>Val:<xsl:value-of select="$value"/></xsl:message>-->

    <xsl:variable name="round-val">
      <xsl:call-template name="round-decimal">
        <xsl:with-param name="value" select="$value"/>
        <xsl:with-param name="precision" select="$precision"/>
      </xsl:call-template>
    </xsl:variable>

    <!--<xsl:message>Roundval:<xsl:value-of select="$round-val"/></xsl:message>-->

    <!--  oem View Name-->
    <xsl:variable name="oem_view_name" select="//values/value[@name='_oemViewName']/@val"/>
    <!-- N/A number -->
    <xsl:variable name="na_number">
      <xsl:choose>
        <xsl:when test="string($oem_view_name)='GEML' or string($oem_view_name)='geml'
	      	or string($oem_view_name)='GEMATCH' or string($oem_view_name)='gematch'
	      	or string($oem_view_name)='VH' or string($oem_view_name)='vh'
	      	or string($oem_view_name)='DELTA' or string($oem_view_name)='delta'
	      	or string($oem_view_name)='CP4' or string($oem_view_name)='cp4'">
          <xsl:value-of select="'-1'"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="'-9998'"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="number($value) &lt;number($na_number) or number($value)= number($na_number)">
        <xsl:value-of select="'N/A'"/>
      </xsl:when>
      <xsl:when test="number($value) = number($value)">
        <xsl:value-of select="concat($round-val, concat(' ', $unit))"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="'N/A'"/>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="replace-string">
    <xsl:param name="text" select="'12-34-56'"/>
    <xsl:param name="replace" select="'-'"/>
    <xsl:param name="with" select="':'"/>
    <xsl:choose>
      <xsl:when test="contains($text,$replace)">
        <xsl:value-of select="concat(substring-before($text,$replace),$with)"/>
        <xsl:call-template name="replace-string">

          <xsl:with-param name="text" select="substring-after($text,$replace)"/>
          <xsl:with-param name="replace" select="$replace"/>
          <xsl:with-param name="with" select="$with"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="replace-string_withbr">
    <xsl:param name="text"/>
    <xsl:param name="replace"/>
    <xsl:choose>
      <xsl:when test="contains($text,$replace)">
        <xsl:value-of select="substring-before($text,$replace)"/>
        <br/>
        <xsl:call-template name="replace-string_withbr">
          <xsl:with-param name="text" select="substring-after($text,$replace)"/>
          <xsl:with-param name="replace" select="$replace"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="tokenize">
    <xsl:param name="token-string" select="''"/>
    <xsl:param name="which" select="1"/>
    <xsl:param name="delim" select="','"/>
    <xsl:variable name="has-delim" select="contains($token-string, $delim)"/>
    <xsl:choose>
      <xsl:when test="$which &lt; 0">
        <xsl:value-of select="''"/>
      </xsl:when>
      <xsl:when test="not(contains($token-string, $delim))">
        <xsl:value-of select="$token-string"/>
      </xsl:when>
      <xsl:when test="$which = 1">
        <xsl:value-of select="substring-before($token-string, $delim)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="tokenize">
          <xsl:with-param name="token-string" select="substring-after($token-string, $delim)"/>
          <xsl:with-param name="which" select="$which - 1"/>
          <xsl:with-param name="delim" select="$delim"/>
        </xsl:call-template>

      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="cut-string">
    <xsl:param name="input-string" select="''"/>
    <xsl:param name="length" select="10"/>

    <xsl:choose>
      <xsl:when test="string-length($input-string) &gt; $length">
        <xsl:value-of select="concat(substring($input-string, 1, $length -3), '...')"/>
        <xsl:message>
          Text: <xsl:value-of select="concat(substring($input-string, 1, $length -3), '...')"/>
        </xsl:message>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$input-string"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="is-wiki-link">
    <xsl:param name="info-string" select="''"/>

    <xsl:variable name="first-token">
      <xsl:choose>
        <xsl:when test="contains($info-string, ' ')">
          <xsl:value-of select="substring-before($info-string, ' ')"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$info-string"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="second-token">
      <xsl:choose>
        <xsl:when test="contains($info-string, ' ')">
          <xsl:value-of select="substring-after($info-string, ' ')"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="''"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="not-empty">
      <xsl:choose>
        <xsl:when test="string-length($first-token) &gt; 2">
          <xsl:value-of select="'true'"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="'false'"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="is-wiki-link">
      <xsl:choose>
        <xsl:when test="$not-empty ='true' and substring($info-string,1,1)='[' and substring($info-string, string-length($info-string), 1)=']'">
          <xsl:value-of select="'true'"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="'false'"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="$is-wiki-link"/>
    <xsl:message>
      First: <xsl:value-of select="$first-token"/>
      Second: <xsl:value-of select="$second-token"/>
      Not empty: <xsl:value-of select="$not-empty"/>
      Wikilink: <xsl:value-of select="$is-wiki-link"/>
    </xsl:message>
  </xsl:template>

  <xsl:template name="get-wiki-link-url">
    <xsl:param name="info-string" select="''"/>
    <xsl:variable name="first-token">
      <xsl:choose>
        <xsl:when test="contains($info-string, ' ')">
          <xsl:value-of select="substring-before($info-string, ' ')"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$info-string"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="url">
      <xsl:choose>
        <xsl:when test="contains($info-string, ' ')">
          <xsl:value-of select="substring($first-token, 2, string-length($first-token)-1)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="substring($first-token, 2, string-length($first-token)-2)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="$url"/>
    <xsl:message>
      Token: <xsl:value-of select="$first-token"/>
      Link: <xsl:value-of select="$url"/>
    </xsl:message>
  </xsl:template>

  <xsl:template name="three-state-div">
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="w" select="60"/>
    <xsl:param name="h" select="45"/>
    <xsl:param name="text" select="''"/>
    <xsl:param name="class" select="''"/>
    <xsl:param name="pad-top" select="5"/>
    <xsl:param name="bit-string" select="''"/>
    <xsl:param name="bit" select="''"/>
    <xsl:param name="high-color" select="'#ff0000'"/>
    <xsl:param name="low-color" select="'#00ff00'"/>
    <xsl:param name="nor-color" select="'#f1f1f1'"/>
    <xsl:variable name="background-color">
      <xsl:choose>
        <xsl:when test="string-length($bit-string) = 0">
          <xsl:value-of select="$nor-color"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="substring($bit-string, $bit, 1) ='1'">
              <xsl:value-of select="$high-color"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$low-color"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <div style="position:absolute; left:{$x}px; top:{$y}px; width:{$w}px; height:{$h}px; background-color:{$background-color}; border:1px solid black">
      <div class="{$class}" style="padding-top:{$pad-top}px">
        <xsl:value-of select="$text"/>
      </div>
    </div>
  </xsl:template>


  <xsl:template name="four-state-div">
    <xsl:param name="x" select="0"/>
    <xsl:param name="y" select="0"/>
    <xsl:param name="w" select="60"/>
    <xsl:param name="h" select="45"/>
    <xsl:param name="text" select="''"/>
    <xsl:param name="class" select="''"/>
    <xsl:param name="pad-top" select="5"/>
    <xsl:param name="status-string" select="''"/>
    <xsl:param name="ack-string" select="''"/>
    <xsl:param name="bit" select="''"/>
    <xsl:param name="alarm-color" select="'#ff0000'"/>
    <xsl:param name="ok-color" select="'#00ff00'"/>
    <xsl:param name="ack-color" select="'#ff00ff'"/>
    <xsl:param name="nor-color" select="'#f1f1f1'"/>

    <xsl:variable name="background-color">
      <xsl:choose>
        <xsl:when test="string-length($status-string) = 0">
          <xsl:value-of select="$nor-color"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="substring($status-string, $bit, 1) ='1'">
              <xsl:choose>
                <xsl:when test="substring($ack-string, $bit, 1) ='1'">
                  <xsl:value-of select="$ack-color"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="$alarm-color"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$ok-color"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <div style="position:absolute; left:{$x}px; top:{$y}px; width:{$w}px; height:{$h}px; background-color:{$background-color}; border:1px solid black">
      <div class="{$class}" style="padding-top:{$pad-top}px">
        <xsl:value-of select="$text"/>
      </div>
    </div>
  </xsl:template>

  <xsl:template name="min">
    <xsl:param name="val1" select="0"/>
    <xsl:param name="val2" select="0"/>
    <!--<xsl:message>min called with <xsl:value-of select="$val1"/> and <xsl:value-of select="$val2"/></xsl:message>-->
    <xsl:choose>
      <xsl:when test="$val1 &gt; $val2">
        <xsl:value-of select="$val2"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$val1"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="max">
    <xsl:param name="val1" select="0"/>
    <xsl:param name="val2" select="0"/>
    <xsl:choose>
      <xsl:when test="$val1 &lt; $val2">
        <xsl:value-of select="$val2"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$val1"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="min-value">
    <xsl:param name="dataset" select="0"/>
    <xsl:param name="min" 		select="500"/>
    <xsl:param name="start" 	select="1"/>

    <xsl:variable	name="len" select="count($dataset/data)"/>

    <!--
	<xsl:message>min-value called with <xsl:value-of select="$len"/> elements and start = <xsl:value-of select="$start"/></xsl:message>
	<xsl:message>Firstminvalue: <xsl:value-of select="$first-min"/></xsl:message>
	<xsl:message>start value: <xsl:value-of select="$dataset/data[position() = $start]/@v"/></xsl:message>
	-->
    <xsl:variable	name="first-min">
      <xsl:choose>
        <xsl:when test="$len &lt; $start">
          <xsl:value-of select="$min"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="min">
            <xsl:with-param name="val1" select="$min"/>
            <xsl:with-param name="val2" select="$dataset/data[position() = $start]/@v"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$len &lt; $start">
        <xsl:value-of select="$min"/>
      </xsl:when>
      <xsl:when test="$len = $start">
        <xsl:value-of select="$first-min"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="min-value">
          <xsl:with-param name="dataset" select="$dataset"/>
          <xsl:with-param name="min" select="$first-min"/>
          <xsl:with-param name="start" select="$start + 1"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="max-value">
    <xsl:param name="dataset" select="0"/>
    <xsl:param name="max" 		select="500"/>
    <xsl:param name="start" 	select="1"/>

    <xsl:variable	name="len" select="count($dataset/data)"/>

    <!--<xsl:message>min-value called with <xsl:value-of select="$len"/> elements and start = <xsl:value-of select="$start"/></xsl:message>-->
    <!--<xsl:message>start value: <xsl:value-of select="$dataset/data[position() = $start]/@v"/></xsl:message>-->

    <xsl:variable	name="first-max">
      <xsl:choose>
        <xsl:when test="$len &lt; $start">
          <xsl:value-of select="$max"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="max">
            <xsl:with-param name="val1" select="$max"/>
            <xsl:with-param name="val2" select="$dataset/data[position() = $start]/@v"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$len &lt; $start">
        <xsl:value-of select="$max"/>
      </xsl:when>
      <xsl:when test="$len = $start">
        <xsl:value-of select="$first-max"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="max-value">
          <xsl:with-param name="dataset" 	select="$dataset"/>
          <xsl:with-param name="max" 			select="$first-max"/>
          <xsl:with-param name="start" 		select="$start + 1"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="max-value-from-report">
    <xsl:param name="report" select="0"/>
    <xsl:param name="max" 		select="500"/>
    <xsl:param name="start" 	select="1"/>

    <xsl:variable	name="len" select="count($report/dataset)"/>

    <!--<xsl:message>min-value called with <xsl:value-of select="$len"/> elements and start = <xsl:value-of select="$start"/></xsl:message>-->
    <!--<xsl:message>start value: <xsl:value-of select="$dataset/data[position() = $start]/@v"/></xsl:message>-->

    <xsl:variable	name="first-max">
      <xsl:choose>
        <xsl:when test="$len &lt; $start">
          <xsl:value-of select="$max"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:variable	name="tmp-first-max">
            <xsl:call-template name="max-value">
              <xsl:with-param name="dataset" select="$report/dataset[position() = $start]"/>
              <xsl:with-param name="max" select="$report/dataset[position() = $start]/data[1]/@v"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:call-template name="max">
            <xsl:with-param name="val1" select="$max"/>
            <xsl:with-param name="val2" select="$tmp-first-max"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$len &lt; $start">
        <xsl:value-of select="$max"/>
      </xsl:when>
      <xsl:when test="$len = $start">
        <xsl:value-of select="$first-max"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="max-value-from-report">
          <xsl:with-param name="report" 	select="$report"/>
          <xsl:with-param name="max" 			select="$first-max"/>
          <xsl:with-param name="start" 		select="$start + 1"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="min-value-from-report">
    <xsl:param name="report" select="0"/>
    <xsl:param name="min" 		select="500"/>
    <xsl:param name="start" 	select="1"/>

    <xsl:variable	name="len" select="count($report/dataset)"/>
    <!--
		<xsl:message>min-value called with <xsl:value-of select="$len"/> elements and start = <xsl:value-of select="$start"/></xsl:message>
		<xsl:message>start value: <xsl:value-of select="$min"/></xsl:message>
		-->
    <xsl:variable	name="first-min">
      <xsl:choose>
        <xsl:when test="$len &lt; $start">
          <xsl:value-of select="$min"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:variable	name="tmp-first-min">
            <xsl:call-template name="min-value">
              <xsl:with-param name="dataset" select="$report/dataset[position() = $start]"/>
              <xsl:with-param name="min" select="$report/dataset[position() = $start]/data[1]/@v"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:call-template name="min">
            <xsl:with-param name="val1" select="$min"/>
            <xsl:with-param name="val2" select="$tmp-first-min"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$len &lt; $start">
        <xsl:value-of select="$min"/>
      </xsl:when>
      <xsl:when test="$len = $start">
        <xsl:value-of select="$first-min"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="min-value-from-report">
          <xsl:with-param name="report" 	select="$report"/>
          <xsl:with-param name="min" 			select="$first-min"/>
          <xsl:with-param name="start" 		select="$start + 1"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="min-t-from-report">
    <xsl:param name="report" select="0"/>
    <xsl:param name="min" 		select="500"/>
    <xsl:param name="start" 	select="1"/>

    <xsl:variable	name="len" select="count($report/dataset)"/>
    <!--
		<xsl:message>min-value called with <xsl:value-of select="$len"/> elements and start = <xsl:value-of select="$start"/></xsl:message>
		<xsl:message>start value: <xsl:value-of select="$min"/></xsl:message>
	-->
    <xsl:variable	name="first-min">
      <xsl:choose>
        <xsl:when test="$len &lt; $start">
          <xsl:value-of select="$min"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="min">
            <xsl:with-param name="val1" select="$min"/>
            <xsl:with-param name="val2" select="$report/dataset[position() = $start]/data[1]/@t"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <!--<xsl:message>First min: <xsl:value-of select="$first-min"/></xsl:message>-->

    <xsl:choose>
      <xsl:when test="$len &lt; $start">
        <xsl:value-of select="$min"/>
      </xsl:when>
      <xsl:when test="$len = $start">
        <xsl:value-of select="$first-min"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="min-t-from-report">
          <xsl:with-param name="report" 	select="$report"/>
          <xsl:with-param name="min" 			select="$first-min"/>
          <xsl:with-param name="start" 		select="$start + 1"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="max-t-from-report">
    <xsl:param name="report" select="0"/>
    <xsl:param name="max" 		select="0"/>
    <xsl:param name="start" 	select="1"/>

    <xsl:variable	name="len" select="count($report/dataset)"/>

    <xsl:message>
      min-value called with <xsl:value-of select="$len"/> elements and start = <xsl:value-of select="$start"/>
    </xsl:message>
    <xsl:message>
      start value: <xsl:value-of select="$max"/>
    </xsl:message>

    <xsl:variable	name="first-max">
      <xsl:choose>
        <xsl:when test="$len &lt; $start">
          <xsl:value-of select="$max"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="max">
            <xsl:with-param name="val1" select="$max"/>
            <xsl:with-param name="val2" select="$report/dataset[position() = $start]/data[last()]/@t"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <!--<xsl:message>First min: <xsl:value-of select="$first-min"/></xsl:message>-->

    <xsl:choose>
      <xsl:when test="$len &lt; $start">
        <xsl:value-of select="$max"/>
      </xsl:when>
      <xsl:when test="$len = $start">
        <xsl:value-of select="$first-max"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="max-t-from-report">
          <xsl:with-param name="report" 	select="$report"/>
          <xsl:with-param name="max" 			select="$first-max"/>
          <xsl:with-param name="start" 		select="$start + 1"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>
  <xsl:variable name="c1" select="719499"/>
  <xsl:variable name="c2" select="1200"/>
  <xsl:variable name="c3" select="291 + 365*$c2"/>
  <xsl:variable name="c4" select="36700"/>
  <xsl:variable name="secs-per-day" 	select="86400"/>
  <xsl:variable name="secs-per-month" select="30*86400"/>
  <xsl:variable name="secs-per-year" 	select="12*30*86400"/>

  <xsl:template name="get-time-from-gx-date">
    <xsl:param name="date"/>

    <xsl:variable name="day">
      <xsl:call-template 	name="tokenize">
        <xsl:with-param name="token-string" select="$date"/>
        <xsl:with-param name="which" select="1"/>
        <xsl:with-param name="delim" select="'/'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="month">
      <xsl:call-template 	name="tokenize">
        <xsl:with-param name="token-string" select="$date"/>
        <xsl:with-param name="which" select="2"/>
        <xsl:with-param name="delim" select="'/'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="year">
      <xsl:call-template 	name="tokenize">
        <xsl:with-param name="token-string" select="$date"/>
        <xsl:with-param name="which" select="3"/>
        <xsl:with-param name="delim" select="'/'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:value-of select="round(($year div 4 - $year div 100 + $year div 400 + 367*($month - 1) div 12 + $day + $year*365 - 719499) * $secs-per-day)"/>

  </xsl:template>

  <xsl:template name="get-time-from-gx-time">
    <xsl:param name="time"/>

    <xsl:variable name="hours">
      <xsl:call-template 	name="tokenize">
        <xsl:with-param name="token-string" select="$time"/>
        <xsl:with-param name="which" select="1"/>
        <xsl:with-param name="delim" select="':'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="mins">
      <xsl:call-template 	name="tokenize">
        <xsl:with-param name="token-string" select="$time"/>
        <xsl:with-param name="which" select="2"/>
        <xsl:with-param name="delim" select="':'"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="secs">
      <xsl:call-template 	name="tokenize">
        <xsl:with-param name="token-string" select="$time"/>
        <xsl:with-param name="which" select="3"/>
        <xsl:with-param name="delim" select="':'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:value-of select="($hours*60 + $mins)*60 + $secs"/>

  </xsl:template>

  <xsl:template name="get-hh-tt-from-string">
    <xsl:param name="time" select="'0'"/>
    <xsl:param name="delim" select="':'"/>

    <xsl:variable name="hh">
      <xsl:choose>
        <xsl:when test="$time = '0'">
          <xsl:value-of select="'-'"/>
        </xsl:when>
        <xsl:when test="string-length(substring-after($time div 3600,'.'))=0">
          <xsl:value-of select="$time div 3600" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="substring-before($time div 3600,'.')" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="mm">
      <xsl:choose>
        <xsl:when test="$time = '0'">
          <xsl:value-of select="'--'"/>
        </xsl:when>
        <xsl:when test="string-length(substring-after(($time div 60) mod 60,'.'))=0">
          <xsl:value-of select="$time div 60" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="substring-before(($time div 60) mod 60,'.')" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test="$mm = '--' or $hh = '-'">
        <xsl:value-of select="concat($hh,concat(':',$mm))"/>
      </xsl:when>

      <xsl:when test="string-length($hh) &lt;2 and string-length($mm) &lt;2">
        <xsl:value-of select="concat(concat('0',$hh),concat(':',concat('0',$mm)))"/>
      </xsl:when>


      <xsl:when test="string-length($hh) &lt;2 and string-length($mm) = 2">
        <xsl:value-of select="concat(concat('0',$hh),concat(':',$mm))"/>
      </xsl:when>

      <xsl:when test="string-length($hh) = 2 and string-length($mm) &lt;2">
        <xsl:value-of select="concat($hh,concat(':',concat('0',$mm)))"/>
      </xsl:when>

      <xsl:otherwise>
        <xsl:value-of select="concat($hh,concat(':',$mm))"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="get-time-from-gx-date-time">
    <xsl:param name="date"/>
    <xsl:param name="time"/>
    <xsl:variable name="date-secs">
      <xsl:call-template name="get-time-from-gx-date">
        <xsl:with-param name="date" select="$date"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="time-secs">
      <xsl:call-template name="get-time-from-gx-time">
        <xsl:with-param name="time"  select="$time"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:value-of select="$date-secs + $time-secs"/>
  </xsl:template>


  <xsl:template name="get-year-from-time-t">
    <xsl:param name="time_t"/>
    <xsl:variable name="tmp-secs">
      <xsl:value-of select="floor($time_t div $secs-per-day)"/>
    </xsl:variable>

    <xsl:value-of select="floor(($tmp-secs + $c1)*$c2 div $c3)"/>
  </xsl:template>

  <xsl:template name="get-month-from-time-t">
    <xsl:param name="time_t"/>
    <xsl:variable name="rem-secs">
      <xsl:value-of select="floor($time_t div $secs-per-day)"/>
    </xsl:variable>
    <xsl:variable name="tmp-years">
      <xsl:call-template name="get-year-from-time-t">
        <xsl:with-param name="time_t" select="$time_t"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="tmp-months">
      <xsl:value-of select="($rem-secs + $c1)*$c2 - $tmp-years*$c3"/>
    </xsl:variable>
    <!--
		<xsl:message>
			time_t	=<xsl:value-of select="$rem-secs"/>
			tmp-years=<xsl:value-of select="$tmp-years"/>
			tmp-months=<xsl:value-of select="$tmp-months"/>
		</xsl:message>
		-->
    <xsl:value-of select="floor($tmp-months div $c4)"/>
  </xsl:template>

  <xsl:template name="get-day-from-time-t">
    <xsl:param name="time_t"/>
    <xsl:variable name="rem-secs">
      <xsl:value-of select="floor($time_t div $secs-per-day)"/>
    </xsl:variable>
    <xsl:variable name="tmp-years">
      <xsl:call-template name="get-year-from-time-t">
        <xsl:with-param name="time_t" select="$time_t"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="tmp-months">
      <xsl:call-template name="get-month-from-time-t">
        <xsl:with-param name="time_t" select="$time_t"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="tmp-days">
      <xsl:value-of select="($rem-secs + $c1)*$c2 - $tmp-years*$c3 - $tmp-months*$c4"/>
    </xsl:variable>
    <xsl:message>
      rem_secs	=<xsl:value-of select="$rem-secs"/>
      tmp-years=<xsl:value-of select="$tmp-years"/>
      tmp-months=<xsl:value-of select="$tmp-months"/>
      tmp-days=<xsl:value-of select="$tmp-days"/>
    </xsl:message>
    <xsl:value-of select="round($tmp-days div $c2)"/>
  </xsl:template>

  <xsl:template name="get-hours-from-time-t">
    <xsl:param name="time_t"/>
    <xsl:variable name="tmp-secs">
      <xsl:value-of select="floor($time_t mod $secs-per-day)"/>
    </xsl:variable>
    <xsl:message>
      time_t	=<xsl:value-of select="$time_t"/>
      tmp-secs=<xsl:value-of select="$tmp-secs"/>
      hours=<xsl:value-of select="floor($tmp-secs div 3600)"/>
    </xsl:message>

    <xsl:value-of select="floor($tmp-secs div 3600)"/>
  </xsl:template>

  <xsl:template name="get-minutes-from-time-t">
    <xsl:param name="time_t"/>
    <xsl:variable name="tmp-secs">
      <xsl:value-of select="floor($time_t mod 3600)"/>
    </xsl:variable>

    <xsl:value-of select="floor($tmp-secs div 60)"/>
  </xsl:template>

  <xsl:template name="get-secs-from-time-t">
    <xsl:param name="time_t"/>
    <xsl:value-of select="floor($time_t mod 60)"/>
  </xsl:template>


  <xsl:template name="get-color-by-id">
    <xsl:param name="id" select="''"/>
    <xsl:choose>
      <xsl:when test="$id='INVOLT'">orange</xsl:when>
      <xsl:when test="$id='involt1' or $id='INVOLT1'">orange</xsl:when>
      <xsl:when test="$id='involt2' or $id='INVOLT2'">red</xsl:when>
      <xsl:when test="$id='involt3' or $id='INVOLT3'">indianred</xsl:when>
      <xsl:when test="$id='OUTPUT_VOLT'">darkblue</xsl:when>
      <xsl:when test="$id='outvolt1' or $id='OUTPUT_VOLT1'">darkblue</xsl:when>
      <xsl:when test="$id='outvolt2' or $id='OUTPUT_VOLT2'">blue</xsl:when>
      <xsl:when test="$id='outvolt3' or $id='OUTPUT_VOLT3'">dodgerblue</xsl:when>
      <xsl:when test="$id='INFREQ' or $id='infreq'">khaki</xsl:when>
      <xsl:when test="$id='infreq1' or $id='INFREQ1'">khaki</xsl:when>
      <xsl:when test="$id='infreq2'  or $id='INFREQ2'">yellow</xsl:when>
      <xsl:when test="$id='infreq3'  or $id='INFREQ3'">gold</xsl:when>
      <xsl:when test="$id='OUTFREQ' or $id='outfreq' ">darkred</xsl:when>
      <xsl:when test="$id='outfreq1' or $id='OUTFREQ1'">darkred</xsl:when>
      <xsl:when test="$id='outfreq3' or $id='OUTFREQ2'">purple</xsl:when>
      <xsl:when test="$id='outfreq3' or $id='OUTFREQ3'">indigo</xsl:when>
      <xsl:when test="$id='OUTPOWER' ">teal</xsl:when>
      <xsl:when test="$id='load1' or $id='OUTPOWER1'">teal</xsl:when>
      <xsl:when test="$id='load2' or $id='OUTPOWER2'">green</xsl:when>
      <xsl:when test="$id='load3' or $id='OUTPOWER3'">olivedrab</xsl:when>
      <xsl:when test="$id='battvolt' or $id='BATTVOLT'">limegreen</xsl:when>
      <xsl:when test="$id='tempdeg' or $id='TEMPDEG'">honeydew</xsl:when>
      <xsl:when test="$id='battcap' or $id='BATTCAP'">navajowhite</xsl:when>
      <xsl:when test="$id='sm2_analog' or $id='SM2_ANALAOG'">peachpuff</xsl:when>
      <xsl:when test="$id='sm2_analog1' or $id='SM2_ANALAOG1'">peachpuff</xsl:when>
      <xsl:when test="$id='sm2_analog2' or $id='SM2_ANALAOG2'">papyawhip</xsl:when>
      <xsl:when test="$id='sm2_analog3' or $id='SM2_ANALAOG3'">lightyelloq</xsl:when>
      <xsl:when test="$id='sm2_analog4' or $id='SM2_ANALAOG4'">yellow</xsl:when>
      <xsl:when test="$id='sm2_analog5' or $id='SM2_ANALAOG5'">gold</xsl:when>
      <xsl:when test="$id='sm2_analog6' or $id='SM2_ANALAOG6'">orange</xsl:when>
      <xsl:when test="$id='sm2_analog7' or $id='SM2_ANALAOG7'">goldenrod</xsl:when>
      <xsl:when test="$id='sm2_analog8' or $id='SM2_ANALAOG8'">moccasin</xsl:when>
      <xsl:otherwise>N/A</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- From this line to the end: Said extention 05/2008-->
  <xsl:template name="power_val">
    <xsl:param name="value" select="0" />
    <xsl:choose>
      <xsl:when test="1000 >= $value ">
        <xsl:value-of select="$value"/>
      </xsl:when>
      <xsl:when test="1000 &lt; $value">
        <xsl:value-of select="$value div 1000"/>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="power_unit">
    <xsl:param name="value" select="0" />
    <xsl:choose>
      <!--<xsl:when test="$value &lt; 0"><xsl:value-of select="''"/></xsl:when>-->
      <xsl:when test="1000 >= $value and ($value &gt; 0 or $value =0 )" >
        <xsl:value-of select="'W'"/>
      </xsl:when>
      <xsl:when test="1000 &lt; $value">
        <xsl:value-of select="'KW'"/>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="var_value">
    <xsl:param name="value" select="0" />
    <xsl:param name="power_fail"  select="0"/>
    <xsl:choose>
      <xsl:when test="$value &lt; 0 and $power_fail =0">
        <xsl:value-of select="'n/a'"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$value"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="var_unit">
    <xsl:param name="value" select="0" />
    <xsl:param name="unit" select="0" />
    <xsl:param  name="spaces" select="''" />
    <xsl:choose>
      <xsl:when test="$value !='n/a'">
        <xsl:value-of select="$unit"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$spaces"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="temp_str">
    <xsl:param name="value" select="0" />
    <xsl:choose>
      <xsl:when test="$value=-1 or $value &lt; -99" >
        <xsl:value-of select="'N/A'"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$value"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--alarm condition text-->
  <!--BatteryBad-->
  <xsl:variable name="BatteryBad" select="'BatteryBad'"></xsl:variable>
  <!--OnBattery-->
  <xsl:variable name="OnBattery" select="'OnBattery'"></xsl:variable>
  <!--LowBattery-->
  <xsl:variable name="LowBattery" select="'LowBattery'"></xsl:variable>
  <!--DepletedBattery-->
  <xsl:variable name="DepletedBattery" select="'DepletedBattery'"></xsl:variable>
  <!--TempBad-->
  <xsl:variable name="TempBad" select="'TempBad'"></xsl:variable>
  <!--InputBad-->
  <xsl:variable name="InputBad" select="'InputBad'"></xsl:variable>
  <!--OutputBad-->
  <xsl:variable name="OutputBad" select="'OutputBad'"></xsl:variable>
  <!--OutputOverload-->
  <xsl:variable name="OutputOverload" select="'OutputOverload'"></xsl:variable>
  <!--OnBypass-->
  <xsl:variable name="OnBypass" select="'OnBypass'"></xsl:variable>
  <!--BypassBad-->
  <xsl:variable name="BypassBad" select="'BypassBad'"></xsl:variable>
  <!--OutputOffAsRequested -->
  <xsl:variable name="OutputOffAsRequested" select="'OutputOffAsRequested'"></xsl:variable>
  <!--UpsOffAsRequested -->
  <xsl:variable name="UpsOffAsRequested" select="'UpsOffAsRequested'"></xsl:variable>
  <!--ChargerFailed  -->
  <xsl:variable name="ChargerFailed" select="'ChargerFailed'"></xsl:variable>
  <!--UpsOutputOff -->
  <xsl:variable name="UpsOutputOff" select="'UpsOutputOff'"></xsl:variable>
  <!--UpsSystemOff-->
  <xsl:variable name="UpsSystemOff" select="'UpsSystemOff'"></xsl:variable>
  <!--FanFailure -->
  <xsl:variable name="FanFailure" select="'FanFailure'"></xsl:variable>
  <!--FuseFailure -->
  <xsl:variable name="FuseFailure" select="'FuseFailure'"></xsl:variable>
  <!--GeneralFault  -->
  <xsl:variable name="GeneralFault" select="'GeneralFault'"></xsl:variable>
  <!--DiagnosticTestFailed -->
  <xsl:variable name="DiagnosticTestFailed" select="'DiagnosticTestFailed'"></xsl:variable>
  <!--CommunicationsLost -->
  <xsl:variable name="CommunicationsLost" select="'CommunicationsLost'"></xsl:variable>
  <!--AwaitingPower-->
  <xsl:variable name="AwaitingPower" select="'AwaitingPower'"></xsl:variable>
  <!--ShutdownPending-->
  <xsl:variable name="ShutdownPending" select="'ShutdownPending'"></xsl:variable>
  <!--ShutdownImminent-->
  <xsl:variable name="ShutdownImminent" select="'ShutdownImminent'"></xsl:variable>
  <!--TestInProgress-->
  <xsl:variable name="TestInProgress" select="'TestInProgress'"></xsl:variable>
  <!--ReceptacleOff-->
  <xsl:variable name="ReceptacleOff" select="'ReceptacleOff'"></xsl:variable>
  <!--  EPROM Error-->
  <xsl:variable name="EPROMError" select="'EPROM Error'"></xsl:variable>

  <!--Voltage On Output-->
  <xsl:variable name="VoltageOnOutput" select="'VoltageOnOutput'"></xsl:variable>
  <!--Overvoltage on DC Link-->
  <xsl:variable name="OvervoltageOnDCLink" select="'OvervoltageOnDCLink'"></xsl:variable>
  <!--Input Circuit Failure-->
  <xsl:variable name="InputCircuitFailure" select="'InputCircuitFailure'"></xsl:variable>
  <!--Charge Converter Error-->
  <xsl:variable name="ChargeConverterError" select="'ChargeConverterError'"></xsl:variable>
  <!--Bypass Defect-->
  <xsl:variable name="BypassDefect" select="'BypassDefect'"></xsl:variable>
  <!--Phase Wrong-->
  <xsl:variable name="PhaseWrong" select="'PhaseWrong'"></xsl:variable>

  <!--HighspeedBusFailure -->
  <xsl:variable name="HighspeedBusFailure" select="'HighspeedBusFailure'" />
  <!--HighspeedBusCRCFailureA -->
  <xsl:variable name="HighspeedBusCRCFailureA" select="'HighspeedBusCRCFailureA'" />
  <!--ConnectivityBusFailure -->
  <xsl:variable name="ConnectivityBusFailure" select="'ConnectivityBusFailure'" />
  <!--HighspeedBusCRCFailureB -->
  <xsl:variable name="HighspeedBusCRCFailureB" select="'HighspeedBusCRCFailureB'" />
  <!--HighCurrentSharing -->
  <xsl:variable name="HighCurrentSharing" select="'HighCurrentSharing'" />
  <!--HighDCRipple -->
  <xsl:variable name="HighDCRipple" select="'HighDCRipple'" />

  <xsl:template name="get_alarm_condition">
    <xsl:choose>
      <xsl:when test="string-length(value[@name='CP4_ALRCOND']/@val) != 0">
        <xsl:value-of select="value[@name='CP4_ALRCOND']/@val"/>
      </xsl:when>
      <xsl:when test="string-length(value[@name='ALARMCONDITION']/@val) != 0">
        <xsl:value-of select="value[@name='ALARMCONDITION']/@val"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="0"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="prefix-string">
    <xsl:param 		name="with" select="'0'"/>
    <xsl:param 		name="string" select="'0'"/>
    <xsl:param 		name="len" select="'4'"/>
    <xsl:variable name="prefix">
      <xsl:choose>
        <xsl:when test=" $len &gt; string-length($string)">
          <xsl:call-template name="multiplystring">
            <xsl:with-param name="count" select="$len - string-length($string)"/>
            <xsl:with-param name="string" select="$with"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="''"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="concat($prefix, $string)"/>
  </xsl:template>

  <xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
  <xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>

  <xsl:template name="to-uppercase">
    <xsl:param name="toconvert" select="''"/>
    <xsl:value-of select="translate($toconvert,$lcletters,$ucletters)"/>
  </xsl:template>

  <xsl:template name="to-lowercase">
    <xsl:param name="toconvert" select="''"/>
    <xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
  </xsl:template>

  <!-- Temperature Value -->
  <xsl:template name="getTemperature">
    <!--unit = 0 Celsius , unit = 1 Fahrenheit-->
    <xsl:param name="value" select="0" />
    <xsl:param name="temp-unit" select="value[@name='_tempUnit']/@val" />
    <xsl:param name="precision" select="0" />

    <xsl:choose>
      <xsl:when test="$temp-unit=1">
        <xsl:call-template name="get-value">
          <xsl:with-param name="value" select="($value*1.8)+32.0" />
          <xsl:with-param name= "unit" select="'&#176;F'"/>
          <xsl:with-param name="precision" select="$precision"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="get-value">
          <xsl:with-param name="value" select="$value"/>
          <xsl:with-param name= "unit" select="'&#176;C'"/>
          <xsl:with-param name="precision" select="$precision"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


</xsl:stylesheet>